# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelpipelinerun/v1/modelpipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/modelpipelinerun/v1/modelpipelinerun.proto',
  package='github.com.metaprov.modelaapi.services.modelpipelinerun.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/modelpipelinerun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/modelpipelinerun/v1/modelpipelinerun.proto\x12:github.com.metaprov.modelaapi.services.modelpipelinerun.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xd6\x01\n\x1cListModelPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x03 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1dListModelPipelineRunsResponse\x12]\n\x05items\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRunList\"\x1a\n\x18ModelPipelineRunResponse\"y\n\x1d\x43reateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\" \n\x1e\x43reateModelPipelineRunResponse\"y\n\x1dUpdateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\" \n\x1eUpdateModelPipelineRunResponse\"=\n\x1aGetModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1bGetModelPipelineRunResponse\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelPipelineRunResponse\"a\n\x1e\x41pproveModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"!\n\x1f\x41pproveModelPipelineRunResponse\"^\n\x1b\x44\x65nyModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05stage\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\"\x1e\n\x1c\x44\x65nyModelPipelineRunResponse\"\x1f\n\x1dPauseModelPipelineRunResponse\"?\n\x1cPauseModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1eResumeModelPipelineRunResponse\"@\n\x1dResumeModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x41\x62ortModelPipelineRunResponse\"?\n\x1c\x41\x62ortModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xeb\x14\n\x17ModelPipelineRunService\x12\xf5\x01\n\x15ListModelPipelineRuns\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1alpha1/modelpipelineruns\x12\xfb\x01\n\x16\x43reateModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1alpha1/modelpipelineruns:\x01*\x12\xf6\x01\n\x13GetModelPipelineRun\x12V.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1alpha1/modelpipelineruns/{name}\x12\x9c\x02\n\x16UpdateModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunResponse\"K\x82\xd3\xe4\x93\x02\x45\x1a@/api/v1alpha1/modelpipelineruns/{modelpipelinerun.metadata.name}:\x01*\x12\x93\x02\n\x16\x44\x65leteModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunResponse\"B\x82\xd3\xe4\x93\x02<*:/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}\x12\x9e\x02\n\x17\x41pproveModelPipelineRun\x12Z.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest\x1a[.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunResponse\"J\x82\xd3\xe4\x93\x02\x44*B/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}:approve\x12\x95\x02\n\x14\x44\x65nyModelPipelineRun\x12W.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunResponse\"J\x82\xd3\xe4\x93\x02\x44*B/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}:approve\x12\xf8\x01\n\x15\x41\x62ortModelPipelineRun\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunResponse\"*\x82\xd3\xe4\x93\x02$\"\"/v1/modelpipelineruns/{name}:abort\x12\xf8\x01\n\x15PauseModelPipelineRun\x12X.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest\x1aY.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunResponse\"*\x82\xd3\xe4\x93\x02$\"\"/v1/modelpipelineruns/{name}:pause\x12\xfc\x01\n\x16ResumeModelPipelineRun\x12Y.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunResponse\"+\x82\xd3\xe4\x93\x02%\"#/v1/modelpipelineruns/{name}:resumeB<Z:github.com/metaprov/modelaapi/services/modelpipelinerun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTMODELPIPELINERUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=464,
)

_LISTMODELPIPELINERUNSREQUEST = _descriptor.Descriptor(
  name='ListModelPipelineRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELPIPELINERUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=464,
)


_LISTMODELPIPELINERUNSRESPONSE = _descriptor.Descriptor(
  name='ListModelPipelineRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=592,
)


_MODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=620,
)


_CREATEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=743,
)


_CREATEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='CreateModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=777,
)


_UPDATEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=900,
)


_UPDATEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=934,
)


_GETMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=997,
)


_GETMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='GetModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1133,
)


_DELETEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1199,
)


_DELETEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1201,
  serialized_end=1233,
)


_APPROVEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ApproveModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest.stage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1332,
)


_APPROVEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ApproveModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1367,
)


_DENYMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DenyModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stage', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest.stage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest.account', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1463,
)


_DENYMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DenyModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1465,
  serialized_end=1495,
)


_PAUSEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='PauseModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1497,
  serialized_end=1528,
)


_PAUSEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='PauseModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1593,
)


_RESUMEMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ResumeModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1595,
  serialized_end=1627,
)


_RESUMEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ResumeModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1629,
  serialized_end=1693,
)


_ABORTMODELPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='AbortModelPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1726,
)


_ABORTMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='AbortModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1728,
  serialized_end=1791,
)

_LISTMODELPIPELINERUNSREQUEST_LABELSENTRY.containing_type = _LISTMODELPIPELINERUNSREQUEST
_LISTMODELPIPELINERUNSREQUEST.fields_by_name['labels'].message_type = _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY
_LISTMODELPIPELINERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUNLIST
_CREATEMODELPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
_UPDATEMODELPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
_GETMODELPIPELINERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
DESCRIPTOR.message_types_by_name['ListModelPipelineRunsRequest'] = _LISTMODELPIPELINERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelineRunsResponse'] = _LISTMODELPIPELINERUNSRESPONSE
DESCRIPTOR.message_types_by_name['ModelPipelineRunResponse'] = _MODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateModelPipelineRunRequest'] = _CREATEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateModelPipelineRunResponse'] = _CREATEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunRequest'] = _UPDATEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunResponse'] = _UPDATEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetModelPipelineRunRequest'] = _GETMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['GetModelPipelineRunResponse'] = _GETMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunRequest'] = _DELETEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunResponse'] = _DELETEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['ApproveModelPipelineRunRequest'] = _APPROVEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ApproveModelPipelineRunResponse'] = _APPROVEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DenyModelPipelineRunRequest'] = _DENYMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DenyModelPipelineRunResponse'] = _DENYMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['PauseModelPipelineRunResponse'] = _PAUSEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['PauseModelPipelineRunRequest'] = _PAUSEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ResumeModelPipelineRunResponse'] = _RESUMEMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['ResumeModelPipelineRunRequest'] = _RESUMEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['AbortModelPipelineRunResponse'] = _ABORTMODELPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['AbortModelPipelineRunRequest'] = _ABORTMODELPIPELINERUNREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListModelPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsRequest)
_sym_db.RegisterMessage(ListModelPipelineRunsRequest.LabelsEntry)

ListModelPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ListModelPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsResponse)

ModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ModelPipelineRunResponse)

CreateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunRequest)

CreateModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.CreateModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunResponse)

UpdateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunRequest)

UpdateModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.UpdateModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunResponse)

GetModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRunRequest)

GetModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.GetModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetModelPipelineRunResponse)

DeleteModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunRequest)

DeleteModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DeleteModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunResponse)

ApproveModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ApproveModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(ApproveModelPipelineRunRequest)

ApproveModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ApproveModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ApproveModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ApproveModelPipelineRunResponse)

DenyModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DenyModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DenyModelPipelineRunRequest)

DenyModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DenyModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DENYMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.DenyModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(DenyModelPipelineRunResponse)

PauseModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(PauseModelPipelineRunResponse)

PauseModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('PauseModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.PauseModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(PauseModelPipelineRunRequest)

ResumeModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRunResponse)

ResumeModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ResumeModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ResumeModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(ResumeModelPipelineRunRequest)

AbortModelPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortModelPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortModelPipelineRunResponse)

AbortModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelpipelinerun.v1.modelpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelpipelinerun.v1.AbortModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortModelPipelineRunRequest)


DESCRIPTOR._options = None
_LISTMODELPIPELINERUNSREQUEST_LABELSENTRY._options = None

_MODELPIPELINERUNSERVICE = _descriptor.ServiceDescriptor(
  name='ModelPipelineRunService',
  full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1794,
  serialized_end=4461,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModelPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.ListModelPipelineRuns',
    index=0,
    containing_service=None,
    input_type=_LISTMODELPIPELINERUNSREQUEST,
    output_type=_LISTMODELPIPELINERUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/api/v1alpha1/modelpipelineruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.CreateModelPipelineRun',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELPIPELINERUNREQUEST,
    output_type=_CREATEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\037/api/v1alpha1/modelpipelineruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.GetModelPipelineRun',
    index=2,
    containing_service=None,
    input_type=_GETMODELPIPELINERUNREQUEST,
    output_type=_GETMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/api/v1alpha1/modelpipelineruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.UpdateModelPipelineRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELPIPELINERUNREQUEST,
    output_type=_UPDATEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002E\032@/api/v1alpha1/modelpipelineruns/{modelpipelinerun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.DeleteModelPipelineRun',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELPIPELINERUNREQUEST,
    output_type=_DELETEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002<*:/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ApproveModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.ApproveModelPipelineRun',
    index=5,
    containing_service=None,
    input_type=_APPROVEMODELPIPELINERUNREQUEST,
    output_type=_APPROVEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002D*B/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}:approve',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DenyModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.DenyModelPipelineRun',
    index=6,
    containing_service=None,
    input_type=_DENYMODELPIPELINERUNREQUEST,
    output_type=_DENYMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002D*B/api/v1/modelpipelineruns/{modelpipelinerun.metadata.name}:approve',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.AbortModelPipelineRun',
    index=7,
    containing_service=None,
    input_type=_ABORTMODELPIPELINERUNREQUEST,
    output_type=_ABORTMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\"/v1/modelpipelineruns/{name}:abort',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PauseModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.PauseModelPipelineRun',
    index=8,
    containing_service=None,
    input_type=_PAUSEMODELPIPELINERUNREQUEST,
    output_type=_PAUSEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\"/v1/modelpipelineruns/{name}:pause',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResumeModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.modelpipelinerun.v1.ModelPipelineRunService.ResumeModelPipelineRun',
    index=9,
    containing_service=None,
    input_type=_RESUMEMODELPIPELINERUNREQUEST,
    output_type=_RESUMEMODELPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002%\"#/v1/modelpipelineruns/{name}:resume',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELPIPELINERUNSERVICE)

DESCRIPTOR.services_by_name['ModelPipelineRunService'] = _MODELPIPELINERUNSERVICE

# @@protoc_insertion_point(module_scope)
