# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto',
  package='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1',
  syntax='proto2',
  serialized_options=b'Z\010v1alpha1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nDgithub.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x12\x34github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1\x1a\"k8s.io/api/core/v1/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\"\xbb\x01\n\x07\x43omment\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\tauthorRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0f\n\x07replyTo\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12<\n\x08postedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0c\n\x04sent\x18\x06 \x01(\x08\"\xfc\x01\n\nPostMortem\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12R\n\x04spec\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec\x12V\n\x06status\x18\x03 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus\"\x9c\x01\n\x13PostMortemCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\xa3\x01\n\x0ePostMortemList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12O\n\x05items\x18\x02 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x96\x03\n\x0ePostMortemSpec\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x38\n\x0blocationRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\thandledBy\x18\x03 \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12P\n\x05\x61lert\x18\x04 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert\x12U\n\x08timeline\x18\x05 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent\x12\x11\n\trootCause\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t\x12\r\n\x05owner\x18\x08 \x01(\t\"\x8d\x01\n\x10PostMortemStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12]\n\nconditions\x18\x02 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition\"S\n\x0bRaisedAlert\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xf0\x01\n\x06Review\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12N\n\x04spec\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec\x12R\n\x06status\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus\"\x98\x01\n\x0fReviewCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x9b\x01\n\nReviewList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12K\n\x05items\x18\x02 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\xba\x01\n\nReviewSpec\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12O\n\x08messages\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment\x12\r\n\x05owner\x18\x03 \x01(\t\x12\x14\n\x0cnotifierName\x18\x04 \x01(\t\"\xc6\x01\n\x0cReviewStatus\x12?\n\x0blastUpdated\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12Y\n\nconditions\x18\x03 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition\"\xf3\x01\n\x07RunBook\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12O\n\x04spec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec\x12S\n\x06status\x18\x03 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus\"\xdd\x01\n\x10RunBookCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x42\n\x0elastUpdateTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x9d\x01\n\x0bRunBookList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12L\n\x05items\x18\x02 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x8c\x01\n\x0bRunBookSpec\x12\x36\n\tentityRef\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x36\n\tauthorRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\r\n\x05owner\x18\x03 \x01(\t\"\x87\x01\n\rRunBookStatus\x12\x1a\n\x12observedGeneration\x18\x01 \x01(\x03\x12Z\n\nconditions\x18\x02 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition\"X\n\rTimeLineEvent\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x36\n\x02\x61t\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xea\x01\n\x04Todo\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12L\n\x04spec\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec\x12P\n\x06status\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus\"\x96\x01\n\rTodoCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x97\x01\n\x08TodoList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12I\n\x05items\x18\x02 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x86\x02\n\x08TodoSpec\x12\x0c\n\x04task\x18\x01 \x01(\t\x12\x36\n\tentityRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x14\n\x0cnotifierName\x18\x03 \x01(\t\x12\x12\n\nassignedTo\x18\x04 \x01(\t\x12\x0f\n\x07\x66lagged\x18\x05 \x01(\x08\x12<\n\x08reminder\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12;\n\x07\x64ueDate\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\x90\x01\n\nTodoStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x1a\n\x12observedGeneration\x18\x02 \x01(\x03\x12W\n\nconditions\x18\x03 \x03(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoConditionB\nZ\x08v1alpha1'
  ,
  dependencies=[k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2.DESCRIPTOR,])




_COMMENT = _descriptor.Descriptor(
  name='Comment',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.authorRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replyTo', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.replyTo', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.content', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postedAt', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.postedAt', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sent', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment.sent', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=322,
  serialized_end=509,
)


_POSTMORTEM = _descriptor.Descriptor(
  name='PostMortem',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=764,
)


_POSTMORTEMCONDITION = _descriptor.Descriptor(
  name='PostMortemCondition',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition.lastTransitionTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=767,
  serialized_end=923,
)


_POSTMORTEMLIST = _descriptor.Descriptor(
  name='PostMortemList',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=1089,
)


_POSTMORTEMSPEC = _descriptor.Descriptor(
  name='PostMortemSpec',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entityRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.entityRef', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='locationRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.locationRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='handledBy', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.handledBy', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.alert', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeline', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.timeline', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rootCause', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.rootCause', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.summary', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec.owner', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1498,
)


_POSTMORTEMSTATUS = _descriptor.Descriptor(
  name='PostMortemStatus',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus.observedGeneration', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1501,
  serialized_end=1642,
)


_RAISEDALERT = _descriptor.Descriptor(
  name='RaisedAlert',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='at', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert.at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1644,
  serialized_end=1727,
)


_REVIEW = _descriptor.Descriptor(
  name='Review',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1970,
)


_REVIEWCONDITION = _descriptor.Descriptor(
  name='ReviewCondition',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition.lastTransitionTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2125,
)


_REVIEWLIST = _descriptor.Descriptor(
  name='ReviewList',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2128,
  serialized_end=2283,
)


_REVIEWSPEC = _descriptor.Descriptor(
  name='ReviewSpec',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entityRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec.entityRef', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messages', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec.messages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifierName', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec.notifierName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2472,
)


_REVIEWSTATUS = _descriptor.Descriptor(
  name='ReviewStatus',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastUpdated', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus.lastUpdated', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus.observedGeneration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus.conditions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2475,
  serialized_end=2673,
)


_RUNBOOK = _descriptor.Descriptor(
  name='RunBook',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2676,
  serialized_end=2919,
)


_RUNBOOKCONDITION = _descriptor.Descriptor(
  name='RunBookCondition',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastUpdateTime', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.lastUpdateTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.lastTransitionTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2922,
  serialized_end=3143,
)


_RUNBOOKLIST = _descriptor.Descriptor(
  name='RunBookList',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3146,
  serialized_end=3303,
)


_RUNBOOKSPEC = _descriptor.Descriptor(
  name='RunBookSpec',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entityRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec.entityRef', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec.authorRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec.owner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3306,
  serialized_end=3446,
)


_RUNBOOKSTATUS = _descriptor.Descriptor(
  name='RunBookStatus',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus.observedGeneration', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3449,
  serialized_end=3584,
)


_TIMELINEEVENT = _descriptor.Descriptor(
  name='TimeLineEvent',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent.content', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='at', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent.at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3586,
  serialized_end=3674,
)


_TODO = _descriptor.Descriptor(
  name='Todo',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3677,
  serialized_end=3911,
)


_TODOCONDITION = _descriptor.Descriptor(
  name='TodoCondition',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition.lastTransitionTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3914,
  serialized_end=4064,
)


_TODOLIST = _descriptor.Descriptor(
  name='TodoList',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4067,
  serialized_end=4218,
)


_TODOSPEC = _descriptor.Descriptor(
  name='TodoSpec',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='task', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.task', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entityRef', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.entityRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notifierName', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.notifierName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='assignedTo', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.assignedTo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flagged', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.flagged', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reminder', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.reminder', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dueDate', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec.dueDate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4221,
  serialized_end=4483,
)


_TODOSTATUS = _descriptor.Descriptor(
  name='TodoStatus',
  full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus.observedGeneration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus.conditions', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4486,
  serialized_end=4630,
)

_COMMENT.fields_by_name['authorRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_COMMENT.fields_by_name['postedAt'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_POSTMORTEM.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_POSTMORTEM.fields_by_name['spec'].message_type = _POSTMORTEMSPEC
_POSTMORTEM.fields_by_name['status'].message_type = _POSTMORTEMSTATUS
_POSTMORTEMCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_POSTMORTEMLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_POSTMORTEMLIST.fields_by_name['items'].message_type = _POSTMORTEM
_POSTMORTEMSPEC.fields_by_name['entityRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_POSTMORTEMSPEC.fields_by_name['locationRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_POSTMORTEMSPEC.fields_by_name['handledBy'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_POSTMORTEMSPEC.fields_by_name['alert'].message_type = _RAISEDALERT
_POSTMORTEMSPEC.fields_by_name['timeline'].message_type = _TIMELINEEVENT
_POSTMORTEMSTATUS.fields_by_name['conditions'].message_type = _POSTMORTEMCONDITION
_RAISEDALERT.fields_by_name['at'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_REVIEW.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_REVIEW.fields_by_name['spec'].message_type = _REVIEWSPEC
_REVIEW.fields_by_name['status'].message_type = _REVIEWSTATUS
_REVIEWCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_REVIEWLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_REVIEWLIST.fields_by_name['items'].message_type = _REVIEW
_REVIEWSPEC.fields_by_name['entityRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_REVIEWSPEC.fields_by_name['messages'].message_type = _COMMENT
_REVIEWSTATUS.fields_by_name['lastUpdated'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_REVIEWSTATUS.fields_by_name['conditions'].message_type = _REVIEWCONDITION
_RUNBOOK.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_RUNBOOK.fields_by_name['spec'].message_type = _RUNBOOKSPEC
_RUNBOOK.fields_by_name['status'].message_type = _RUNBOOKSTATUS
_RUNBOOKCONDITION.fields_by_name['lastUpdateTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_RUNBOOKCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_RUNBOOKLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_RUNBOOKLIST.fields_by_name['items'].message_type = _RUNBOOK
_RUNBOOKSPEC.fields_by_name['entityRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_RUNBOOKSPEC.fields_by_name['authorRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_RUNBOOKSTATUS.fields_by_name['conditions'].message_type = _RUNBOOKCONDITION
_TIMELINEEVENT.fields_by_name['at'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_TODO.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_TODO.fields_by_name['spec'].message_type = _TODOSPEC
_TODO.fields_by_name['status'].message_type = _TODOSTATUS
_TODOCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_TODOLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_TODOLIST.fields_by_name['items'].message_type = _TODO
_TODOSPEC.fields_by_name['entityRef'].message_type = k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2._OBJECTREFERENCE
_TODOSPEC.fields_by_name['reminder'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_TODOSPEC.fields_by_name['dueDate'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_TODOSTATUS.fields_by_name['conditions'].message_type = _TODOCONDITION
DESCRIPTOR.message_types_by_name['Comment'] = _COMMENT
DESCRIPTOR.message_types_by_name['PostMortem'] = _POSTMORTEM
DESCRIPTOR.message_types_by_name['PostMortemCondition'] = _POSTMORTEMCONDITION
DESCRIPTOR.message_types_by_name['PostMortemList'] = _POSTMORTEMLIST
DESCRIPTOR.message_types_by_name['PostMortemSpec'] = _POSTMORTEMSPEC
DESCRIPTOR.message_types_by_name['PostMortemStatus'] = _POSTMORTEMSTATUS
DESCRIPTOR.message_types_by_name['RaisedAlert'] = _RAISEDALERT
DESCRIPTOR.message_types_by_name['Review'] = _REVIEW
DESCRIPTOR.message_types_by_name['ReviewCondition'] = _REVIEWCONDITION
DESCRIPTOR.message_types_by_name['ReviewList'] = _REVIEWLIST
DESCRIPTOR.message_types_by_name['ReviewSpec'] = _REVIEWSPEC
DESCRIPTOR.message_types_by_name['ReviewStatus'] = _REVIEWSTATUS
DESCRIPTOR.message_types_by_name['RunBook'] = _RUNBOOK
DESCRIPTOR.message_types_by_name['RunBookCondition'] = _RUNBOOKCONDITION
DESCRIPTOR.message_types_by_name['RunBookList'] = _RUNBOOKLIST
DESCRIPTOR.message_types_by_name['RunBookSpec'] = _RUNBOOKSPEC
DESCRIPTOR.message_types_by_name['RunBookStatus'] = _RUNBOOKSTATUS
DESCRIPTOR.message_types_by_name['TimeLineEvent'] = _TIMELINEEVENT
DESCRIPTOR.message_types_by_name['Todo'] = _TODO
DESCRIPTOR.message_types_by_name['TodoCondition'] = _TODOCONDITION
DESCRIPTOR.message_types_by_name['TodoList'] = _TODOLIST
DESCRIPTOR.message_types_by_name['TodoSpec'] = _TODOSPEC
DESCRIPTOR.message_types_by_name['TodoStatus'] = _TODOSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Comment = _reflection.GeneratedProtocolMessageType('Comment', (_message.Message,), {
  'DESCRIPTOR' : _COMMENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Comment)
  })
_sym_db.RegisterMessage(Comment)

PostMortem = _reflection.GeneratedProtocolMessageType('PostMortem', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEM,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem)
  })
_sym_db.RegisterMessage(PostMortem)

PostMortemCondition = _reflection.GeneratedProtocolMessageType('PostMortemCondition', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemCondition)
  })
_sym_db.RegisterMessage(PostMortemCondition)

PostMortemList = _reflection.GeneratedProtocolMessageType('PostMortemList', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList)
  })
_sym_db.RegisterMessage(PostMortemList)

PostMortemSpec = _reflection.GeneratedProtocolMessageType('PostMortemSpec', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemSpec)
  })
_sym_db.RegisterMessage(PostMortemSpec)

PostMortemStatus = _reflection.GeneratedProtocolMessageType('PostMortemStatus', (_message.Message,), {
  'DESCRIPTOR' : _POSTMORTEMSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemStatus)
  })
_sym_db.RegisterMessage(PostMortemStatus)

RaisedAlert = _reflection.GeneratedProtocolMessageType('RaisedAlert', (_message.Message,), {
  'DESCRIPTOR' : _RAISEDALERT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RaisedAlert)
  })
_sym_db.RegisterMessage(RaisedAlert)

Review = _reflection.GeneratedProtocolMessageType('Review', (_message.Message,), {
  'DESCRIPTOR' : _REVIEW,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review)
  })
_sym_db.RegisterMessage(Review)

ReviewCondition = _reflection.GeneratedProtocolMessageType('ReviewCondition', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewCondition)
  })
_sym_db.RegisterMessage(ReviewCondition)

ReviewList = _reflection.GeneratedProtocolMessageType('ReviewList', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewList)
  })
_sym_db.RegisterMessage(ReviewList)

ReviewSpec = _reflection.GeneratedProtocolMessageType('ReviewSpec', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewSpec)
  })
_sym_db.RegisterMessage(ReviewSpec)

ReviewStatus = _reflection.GeneratedProtocolMessageType('ReviewStatus', (_message.Message,), {
  'DESCRIPTOR' : _REVIEWSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.ReviewStatus)
  })
_sym_db.RegisterMessage(ReviewStatus)

RunBook = _reflection.GeneratedProtocolMessageType('RunBook', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOK,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook)
  })
_sym_db.RegisterMessage(RunBook)

RunBookCondition = _reflection.GeneratedProtocolMessageType('RunBookCondition', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookCondition)
  })
_sym_db.RegisterMessage(RunBookCondition)

RunBookList = _reflection.GeneratedProtocolMessageType('RunBookList', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookList)
  })
_sym_db.RegisterMessage(RunBookList)

RunBookSpec = _reflection.GeneratedProtocolMessageType('RunBookSpec', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookSpec)
  })
_sym_db.RegisterMessage(RunBookSpec)

RunBookStatus = _reflection.GeneratedProtocolMessageType('RunBookStatus', (_message.Message,), {
  'DESCRIPTOR' : _RUNBOOKSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBookStatus)
  })
_sym_db.RegisterMessage(RunBookStatus)

TimeLineEvent = _reflection.GeneratedProtocolMessageType('TimeLineEvent', (_message.Message,), {
  'DESCRIPTOR' : _TIMELINEEVENT,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TimeLineEvent)
  })
_sym_db.RegisterMessage(TimeLineEvent)

Todo = _reflection.GeneratedProtocolMessageType('Todo', (_message.Message,), {
  'DESCRIPTOR' : _TODO,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo)
  })
_sym_db.RegisterMessage(Todo)

TodoCondition = _reflection.GeneratedProtocolMessageType('TodoCondition', (_message.Message,), {
  'DESCRIPTOR' : _TODOCONDITION,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoCondition)
  })
_sym_db.RegisterMessage(TodoCondition)

TodoList = _reflection.GeneratedProtocolMessageType('TodoList', (_message.Message,), {
  'DESCRIPTOR' : _TODOLIST,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoList)
  })
_sym_db.RegisterMessage(TodoList)

TodoSpec = _reflection.GeneratedProtocolMessageType('TodoSpec', (_message.Message,), {
  'DESCRIPTOR' : _TODOSPEC,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoSpec)
  })
_sym_db.RegisterMessage(TodoSpec)

TodoStatus = _reflection.GeneratedProtocolMessageType('TodoStatus', (_message.Message,), {
  'DESCRIPTOR' : _TODOSTATUS,
  '__module__' : 'github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.generated_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.TodoStatus)
  })
_sym_db.RegisterMessage(TodoStatus)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
