# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto',
  package='github.com.metaprov.modelaapi.services.datapipelinerun.v1',
  syntax='proto3',
  serialized_options=b'Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nOgithub.com/metaprov/modelaapi/services/datapipelinerun/v1/datapipelinerun.proto\x12\x39github.com.metaprov.modelaapi.services.datapipelinerun.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd1\x01\n\x1aListDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12q\n\x06labels\x18\x02 \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x1bListDataPipelineRunResponse\x12X\n\x05items\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRunList\"s\n\x1c\x43reateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1d\x43reateDataPipelineRunResponse\"s\n\x1cUpdateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x1f\n\x1dUpdateDataPipelineRunResponse\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x1aGetDataPipelineRunResponse\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1f\n\x1d\x44\x65leteDataPipelineRunResponse\"\x1e\n\x1c\x41\x62ortDataPipelineRunResponse\">\n\x1b\x41\x62ortDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xda\x0b\n\x16\x44\x61taPipelineRunService\x12\xe3\x01\n\x14ListDataPipelineRuns\x12U.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest\x1aV.github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/datapipelineruns\x12\xeb\x01\n\x15\x43reateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/datapipelineruns:\x01*\x12\xe6\x01\n\x12GetDataPipelineRun\x12T.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest\x1aU.github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/datapipelineruns/{name}\x12\x8b\x02\n\x15UpdateDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse\"?\x82\xd3\xe4\x93\x02\x39\x1a\x34/v1/datapipelineruns/{datapipelinerun.metadata.name}:\x01*\x12\xff\x01\n\x15\x44\x65leteDataPipelineRun\x12W.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest\x1aX.github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/api/v1/datapipelineruns/{namespace}/{name}\x12\xf2\x01\n\x14\x41\x62ortDataPipelineRun\x12V.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest\x1aW.github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse\")\x82\xd3\xe4\x93\x02#\"!/v1/datapipelineruns/{name}:abortB;Z9github.com/metaprov/modelaapi/services/datapipelinerun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTDATAPIPELINERUNREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=452,
)

_LISTDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='ListDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTDATAPIPELINERUNREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=243,
  serialized_end=452,
)


_LISTDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='ListDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=454,
  serialized_end=573,
)


_CREATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=575,
  serialized_end=690,
)


_CREATEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='CreateDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=723,
)


_UPDATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=840,
)


_UPDATEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='UpdateDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=873,
)


_GETDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=935,
)


_GETDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='GetDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=1064,
)


_DELETEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1066,
  serialized_end=1129,
)


_DELETEDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='DeleteDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1162,
)


_ABORTDATAPIPELINERUNRESPONSE = _descriptor.Descriptor(
  name='AbortDataPipelineRunResponse',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1164,
  serialized_end=1194,
)


_ABORTDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='AbortDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1196,
  serialized_end=1258,
)

_LISTDATAPIPELINERUNREQUEST_LABELSENTRY.containing_type = _LISTDATAPIPELINERUNREQUEST
_LISTDATAPIPELINERUNREQUEST.fields_by_name['labels'].message_type = _LISTDATAPIPELINERUNREQUEST_LABELSENTRY
_LISTDATAPIPELINERUNRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUNLIST
_CREATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_UPDATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_GETDATAPIPELINERUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
DESCRIPTOR.message_types_by_name['ListDataPipelineRunRequest'] = _LISTDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelineRunResponse'] = _LISTDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest'] = _CREATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateDataPipelineRunResponse'] = _CREATEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest'] = _UPDATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunResponse'] = _UPDATEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest'] = _GETDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['GetDataPipelineRunResponse'] = _GETDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest'] = _DELETEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunResponse'] = _DELETEDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['AbortDataPipelineRunResponse'] = _ABORTDATAPIPELINERUNRESPONSE
DESCRIPTOR.message_types_by_name['AbortDataPipelineRunRequest'] = _ABORTDATAPIPELINERUNREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunRequest)
_sym_db.RegisterMessage(ListDataPipelineRunRequest.LabelsEntry)

ListDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.ListDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunResponse)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

CreateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.CreateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunResponse)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

UpdateDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.UpdateDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

GetDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.GetDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetDataPipelineRunResponse)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

DeleteDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.DeleteDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunResponse)

AbortDataPipelineRunResponse = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunResponse)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunResponse)

AbortDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('AbortDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datapipelinerun.v1.datapipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datapipelinerun.v1.AbortDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(AbortDataPipelineRunRequest)


DESCRIPTOR._options = None
_LISTDATAPIPELINERUNREQUEST_LABELSENTRY._options = None

_DATAPIPELINERUNSERVICE = _descriptor.ServiceDescriptor(
  name='DataPipelineRunService',
  full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1261,
  serialized_end=2759,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListDataPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.ListDataPipelineRuns',
    index=0,
    containing_service=None,
    input_type=_LISTDATAPIPELINERUNREQUEST,
    output_type=_LISTDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/v1/datapipelineruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.CreateDataPipelineRun',
    index=1,
    containing_service=None,
    input_type=_CREATEDATAPIPELINERUNREQUEST,
    output_type=_CREATEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\024/v1/datapipelineruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.GetDataPipelineRun',
    index=2,
    containing_service=None,
    input_type=_GETDATAPIPELINERUNREQUEST,
    output_type=_GETDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002\035\022\033/v1/datapipelineruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.UpdateDataPipelineRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEDATAPIPELINERUNREQUEST,
    output_type=_UPDATEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0324/v1/datapipelineruns/{datapipelinerun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.DeleteDataPipelineRun',
    index=4,
    containing_service=None,
    input_type=_DELETEDATAPIPELINERUNREQUEST,
    output_type=_DELETEDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002-*+/api/v1/datapipelineruns/{namespace}/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AbortDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.datapipelinerun.v1.DataPipelineRunService.AbortDataPipelineRun',
    index=5,
    containing_service=None,
    input_type=_ABORTDATAPIPELINERUNREQUEST,
    output_type=_ABORTDATAPIPELINERUNRESPONSE,
    serialized_options=b'\202\323\344\223\002#\"!/v1/datapipelineruns/{name}:abort',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATAPIPELINERUNSERVICE)

DESCRIPTOR.services_by_name['DataPipelineRunService'] = _DATAPIPELINERUNSERVICE

# @@protoc_insertion_point(module_scope)
