# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto',
  package='github.com.metaprov.modelaapi.services.apitoken.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/apitoken/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto\x12\x32github.com.metaprov.modelaapi.services.apitoken.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbe\x01\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x15ListApiTokensResponse\x12R\n\x05items\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiTokenList\"\x12\n\x10\x41piTokenResponse\"x\n\x15\x43reateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43reateApiTokenResponse\"f\n\x15UpdateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x18\n\x16UpdateApiTokenResponse\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x13GetApiTokenResponse\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1cGetApiTokenNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1dGetApiTokenNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteApiTokenResponse\"\x18\n\x16\x41piTokenCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"I\n\x14\x41piTokenLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"&\n\x15\x41piTokenLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\";\n\x18\x41piTokenGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n\x15\x41piTokenLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"h\n\x15\x43hangePasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03old\x18\x03 \x01(\t\x12\x0b\n\x03new\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x05 \x01(\t\"\x18\n\x16\x43hangePasswordResponse\"Z\n\x14ResetPasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03new\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x04 \x01(\t\"\x16\n\x14ResetPasswordReponse2\xc0\x08\n\x0f\x41piTokenService\x12\xbb\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/apitokens\x12\xc8\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\r/v1/apitokens:\x08\x61pitoken\x12\xc8\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest\x1aG.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/{namespace}/apitokens/{name}\x12\x80\x02\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse\"W\x82\xd3\xe4\x93\x02Q\x1a\x45/v1/{apitoken.metadata.namespace}/apitokens//{apitoken.metadata.name}:\x08\x61pitoken\x12\xd5\x01\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse\",\x82\xd3\xe4\x93\x02&*$/api/{namespace}/v1/apitokens/{name}B4Z2github.com/metaprov/modelaapi/services/apitoken/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTAPITOKENSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=476,
)

_LISTAPITOKENSREQUEST = _descriptor.Descriptor(
  name='ListApiTokensRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTAPITOKENSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=476,
)


_LISTAPITOKENSRESPONSE = _descriptor.Descriptor(
  name='ListApiTokensResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=585,
)


_APITOKENRESPONSE = _descriptor.Descriptor(
  name='ApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=587,
  serialized_end=605,
)


_CREATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='CreateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=607,
  serialized_end=727,
)


_CREATEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='CreateApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=753,
)


_UPDATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='UpdateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=857,
)


_UPDATEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='UpdateApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=859,
  serialized_end=883,
)


_GETAPITOKENREQUEST = _descriptor.Descriptor(
  name='GetApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=938,
)


_GETAPITOKENRESPONSE = _descriptor.Descriptor(
  name='GetApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=940,
  serialized_end=1054,
)


_GETAPITOKENNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetApiTokenNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1056,
  serialized_end=1119,
)


_GETAPITOKENNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetApiTokenNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1121,
  serialized_end=1237,
)


_DELETEAPITOKENREQUEST = _descriptor.Descriptor(
  name='DeleteApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1295,
)


_DELETEAPITOKENRESPONSE = _descriptor.Descriptor(
  name='DeleteApiTokenResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1297,
  serialized_end=1321,
)


_APITOKENCREATERESPONSE = _descriptor.Descriptor(
  name='ApiTokenCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1347,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1365,
)


_RESETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ResetPasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1367,
  serialized_end=1390,
)


_APITOKENLOGINREQUEST = _descriptor.Descriptor(
  name='ApiTokenLoginRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1392,
  serialized_end=1465,
)


_APITOKENLOGINRESPONSE = _descriptor.Descriptor(
  name='ApiTokenLoginResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1505,
)


_APITOKENGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='ApiTokenGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1566,
)


_APITOKENLOGOUTREQUEST = _descriptor.Descriptor(
  name='ApiTokenLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1568,
  serialized_end=1606,
)


_CHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='ChangePasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.old', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.new', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest.confirmedNew', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1608,
  serialized_end=1712,
)


_CHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ChangePasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1714,
  serialized_end=1738,
)


_RESETPASSWORDREQUEST = _descriptor.Descriptor(
  name='ResetPasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.new', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest.confirmedNew', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1740,
  serialized_end=1830,
)


_RESETPASSWORDREPONSE = _descriptor.Descriptor(
  name='ResetPasswordReponse',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1832,
  serialized_end=1854,
)

_LISTAPITOKENSREQUEST_LABELSENTRY.containing_type = _LISTAPITOKENSREQUEST
_LISTAPITOKENSREQUEST.fields_by_name['labels'].message_type = _LISTAPITOKENSREQUEST_LABELSENTRY
_LISTAPITOKENSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKENLIST
_CREATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_UPDATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_GETAPITOKENRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_GETAPITOKENNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListApiTokensRequest'] = _LISTAPITOKENSREQUEST
DESCRIPTOR.message_types_by_name['ListApiTokensResponse'] = _LISTAPITOKENSRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenResponse'] = _APITOKENRESPONSE
DESCRIPTOR.message_types_by_name['CreateApiTokenRequest'] = _CREATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['CreateApiTokenResponse'] = _CREATEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest'] = _UPDATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['UpdateApiTokenResponse'] = _UPDATEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetApiTokenRequest'] = _GETAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['GetApiTokenResponse'] = _GETAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesRequest'] = _GETAPITOKENNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesResponse'] = _GETAPITOKENNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest'] = _DELETEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['DeleteApiTokenResponse'] = _DELETEAPITOKENRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenCreateResponse'] = _APITOKENCREATERESPONSE
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordResponse'] = _RESETPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenLoginRequest'] = _APITOKENLOGINREQUEST
DESCRIPTOR.message_types_by_name['ApiTokenLoginResponse'] = _APITOKENLOGINRESPONSE
DESCRIPTOR.message_types_by_name['ApiTokenGetByNameRequest'] = _APITOKENGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['ApiTokenLogoutRequest'] = _APITOKENLOGOUTREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordRequest'] = _CHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordResponse'] = _CHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordRequest'] = _RESETPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ResetPasswordReponse'] = _RESETPASSWORDREPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPITOKENSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)
_sym_db.RegisterMessage(ListApiTokensRequest.LabelsEntry)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

ApiTokenResponse = _reflection.GeneratedProtocolMessageType('ApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse)
  })
_sym_db.RegisterMessage(ApiTokenResponse)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

CreateApiTokenResponse = _reflection.GeneratedProtocolMessageType('CreateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse)
  })
_sym_db.RegisterMessage(CreateApiTokenResponse)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

UpdateApiTokenResponse = _reflection.GeneratedProtocolMessageType('UpdateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse)
  })
_sym_db.RegisterMessage(UpdateApiTokenResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

GetApiTokenResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse)
  })
_sym_db.RegisterMessage(GetApiTokenResponse)

GetApiTokenNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesRequest)

GetApiTokenNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesResponse)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

DeleteApiTokenResponse = _reflection.GeneratedProtocolMessageType('DeleteApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse)
  })
_sym_db.RegisterMessage(DeleteApiTokenResponse)

ApiTokenCreateResponse = _reflection.GeneratedProtocolMessageType('ApiTokenCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse)
  })
_sym_db.RegisterMessage(ApiTokenCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

ApiTokenLoginRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest)
  })
_sym_db.RegisterMessage(ApiTokenLoginRequest)

ApiTokenLoginResponse = _reflection.GeneratedProtocolMessageType('ApiTokenLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse)
  })
_sym_db.RegisterMessage(ApiTokenLoginResponse)

ApiTokenGetByNameRequest = _reflection.GeneratedProtocolMessageType('ApiTokenGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenGetByNameRequest)
  })
_sym_db.RegisterMessage(ApiTokenGetByNameRequest)

ApiTokenLogoutRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLogoutRequest)
  })
_sym_db.RegisterMessage(ApiTokenLogoutRequest)

ChangePasswordRequest = _reflection.GeneratedProtocolMessageType('ChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordRequest)
  })
_sym_db.RegisterMessage(ChangePasswordRequest)

ChangePasswordResponse = _reflection.GeneratedProtocolMessageType('ChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ChangePasswordResponse)
  })
_sym_db.RegisterMessage(ChangePasswordResponse)

ResetPasswordRequest = _reflection.GeneratedProtocolMessageType('ResetPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordRequest)
  })
_sym_db.RegisterMessage(ResetPasswordRequest)

ResetPasswordReponse = _reflection.GeneratedProtocolMessageType('ResetPasswordReponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ResetPasswordReponse)
  })
_sym_db.RegisterMessage(ResetPasswordReponse)


DESCRIPTOR._options = None
_LISTAPITOKENSREQUEST_LABELSENTRY._options = None

_APITOKENSERVICE = _descriptor.ServiceDescriptor(
  name='ApiTokenService',
  full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1857,
  serialized_end=2945,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListApiTokens',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.ListApiTokens',
    index=0,
    containing_service=None,
    input_type=_LISTAPITOKENSREQUEST,
    output_type=_LISTAPITOKENSRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\r/v1/apitokens',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.CreateApiToken',
    index=1,
    containing_service=None,
    input_type=_CREATEAPITOKENREQUEST,
    output_type=_CREATEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\r/v1/apitokens:\010apitoken',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.GetApiToken',
    index=2,
    containing_service=None,
    input_type=_GETAPITOKENREQUEST,
    output_type=_GETAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /v1/{namespace}/apitokens/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.UpdateApiToken',
    index=3,
    containing_service=None,
    input_type=_UPDATEAPITOKENREQUEST,
    output_type=_UPDATEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002Q\032E/v1/{apitoken.metadata.namespace}/apitokens//{apitoken.metadata.name}:\010apitoken',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteApiToken',
    full_name='github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService.DeleteApiToken',
    index=4,
    containing_service=None,
    input_type=_DELETEAPITOKENREQUEST,
    output_type=_DELETEAPITOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002&*$/api/{namespace}/v1/apitokens/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_APITOKENSERVICE)

DESCRIPTOR.services_by_name['ApiTokenService'] = _APITOKENSERVICE

# @@protoc_insertion_point(module_scope)
