# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto',
  package='github.com.metaprov.modelaapi.services.modelcompilerrun.v1',
  syntax='proto3',
  serialized_options=b'Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nQgithub.com/metaprov/modelaapi/services/modelcompilerrun/v1/modelcompilerrun.proto\x12:github.com.metaprov.modelaapi.services.modelcompilerrun.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xd6\x01\n\x1cListModelCompilerRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12t\n\x06labels\x18\x03 \x03(\x0b\x32\x64.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x1dListModelCompilerRunsResponse\x12]\n\x05items\x18\x01 \x01(\x0b\x32N.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRunList\"\x1a\n\x18ModelCompilerRunResponse\"y\n\x1d\x43reateModelCompilerRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1e\x43reateModelCompilerRunResponse\"y\n\x1dUpdateModelCompilerRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\" \n\x1eUpdateModelCompilerRunResponse\"=\n\x1aGetModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x01\n\x1bGetModelCompilerRunResponse\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelCompilerRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"@\n\x1d\x44\x65leteModelCompilerRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\" \n\x1e\x44\x65leteModelCompilerRunResponse2\xbd\n\n\x17ModelCompilerRunService\x12\xf5\x01\n\x15ListModelCompilerRuns\x12X.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest\x1aY.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1alpha1/modelcompilerruns\x12\xfb\x01\n\x16\x43reateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse\"*\x82\xd3\xe4\x93\x02$\"\x1f/api/v1alpha1/modelcompilerruns:\x01*\x12\xf6\x01\n\x13GetModelCompilerRun\x12V.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest\x1aW.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1alpha1/modelcompilerruns/{name}\x12\x9c\x02\n\x16UpdateModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse\"K\x82\xd3\xe4\x93\x02\x45\x1a@/api/v1alpha1/modelcompilerruns/{modelcompilerrun.metadata.name}:\x01*\x12\x93\x02\n\x16\x44\x65leteModelCompilerRun\x12Y.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest\x1aZ.github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse\"B\x82\xd3\xe4\x93\x02<*:/api/v1/modelcompilerruns/{modelcompilerrun.metadata.name}B<Z:github.com/metaprov/modelaapi/services/modelcompilerrun/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=464,
)

_LISTMODELCOMPILERRUNSREQUEST = _descriptor.Descriptor(
  name='ListModelCompilerRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=464,
)


_LISTMODELCOMPILERRUNSRESPONSE = _descriptor.Descriptor(
  name='ListModelCompilerRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=592,
)


_MODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='ModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=594,
  serialized_end=620,
)


_CREATEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='CreateModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=743,
)


_CREATEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='CreateModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=777,
)


_UPDATEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='UpdateModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=900,
)


_UPDATEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='UpdateModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=902,
  serialized_end=934,
)


_GETMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='GetModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=997,
)


_GETMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='GetModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1000,
  serialized_end=1133,
)


_DELETEMODELCOMPILERRUNREQUEST = _descriptor.Descriptor(
  name='DeleteModelCompilerRunRequest',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1135,
  serialized_end=1199,
)


_DELETEMODELCOMPILERRUNRESPONSE = _descriptor.Descriptor(
  name='DeleteModelCompilerRunResponse',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1201,
  serialized_end=1233,
)

_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY.containing_type = _LISTMODELCOMPILERRUNSREQUEST
_LISTMODELCOMPILERRUNSREQUEST.fields_by_name['labels'].message_type = _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY
_LISTMODELCOMPILERRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUNLIST
_CREATEMODELCOMPILERRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
_UPDATEMODELCOMPILERRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
_GETMODELCOMPILERRUNRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELCOMPILERRUN
DESCRIPTOR.message_types_by_name['ListModelCompilerRunsRequest'] = _LISTMODELCOMPILERRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListModelCompilerRunsResponse'] = _LISTMODELCOMPILERRUNSRESPONSE
DESCRIPTOR.message_types_by_name['ModelCompilerRunResponse'] = _MODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['CreateModelCompilerRunRequest'] = _CREATEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['CreateModelCompilerRunResponse'] = _CREATEMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunRequest'] = _UPDATEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelCompilerRunResponse'] = _UPDATEMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['GetModelCompilerRunRequest'] = _GETMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['GetModelCompilerRunResponse'] = _GETMODELCOMPILERRUNRESPONSE
DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunRequest'] = _DELETEMODELCOMPILERRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelCompilerRunResponse'] = _DELETEMODELCOMPILERRUNRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListModelCompilerRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsRequest)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsRequest)
_sym_db.RegisterMessage(ListModelCompilerRunsRequest.LabelsEntry)

ListModelCompilerRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelCompilerRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELCOMPILERRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ListModelCompilerRunsResponse)
  })
_sym_db.RegisterMessage(ListModelCompilerRunsResponse)

ModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('ModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _MODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(ModelCompilerRunResponse)

CreateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunRequest)

CreateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('CreateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.CreateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(CreateModelCompilerRunResponse)

UpdateModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunRequest)

UpdateModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('UpdateModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.UpdateModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(UpdateModelCompilerRunResponse)

GetModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(GetModelCompilerRunRequest)

GetModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('GetModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.GetModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(GetModelCompilerRunResponse)

DeleteModelCompilerRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunRequest)

DeleteModelCompilerRunResponse = _reflection.GeneratedProtocolMessageType('DeleteModelCompilerRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELCOMPILERRUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.modelcompilerrun.v1.modelcompilerrun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.modelcompilerrun.v1.DeleteModelCompilerRunResponse)
  })
_sym_db.RegisterMessage(DeleteModelCompilerRunResponse)


DESCRIPTOR._options = None
_LISTMODELCOMPILERRUNSREQUEST_LABELSENTRY._options = None

_MODELCOMPILERRUNSERVICE = _descriptor.ServiceDescriptor(
  name='ModelCompilerRunService',
  full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1236,
  serialized_end=2577,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListModelCompilerRuns',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.ListModelCompilerRuns',
    index=0,
    containing_service=None,
    input_type=_LISTMODELCOMPILERRUNSREQUEST,
    output_type=_LISTMODELCOMPILERRUNSRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/api/v1alpha1/modelcompilerruns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.CreateModelCompilerRun',
    index=1,
    containing_service=None,
    input_type=_CREATEMODELCOMPILERRUNREQUEST,
    output_type=_CREATEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002$\"\037/api/v1alpha1/modelcompilerruns:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.GetModelCompilerRun',
    index=2,
    containing_service=None,
    input_type=_GETMODELCOMPILERRUNREQUEST,
    output_type=_GETMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/api/v1alpha1/modelcompilerruns/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.UpdateModelCompilerRun',
    index=3,
    containing_service=None,
    input_type=_UPDATEMODELCOMPILERRUNREQUEST,
    output_type=_UPDATEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002E\032@/api/v1alpha1/modelcompilerruns/{modelcompilerrun.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelCompilerRun',
    full_name='github.com.metaprov.modelaapi.services.modelcompilerrun.v1.ModelCompilerRunService.DeleteModelCompilerRun',
    index=4,
    containing_service=None,
    input_type=_DELETEMODELCOMPILERRUNREQUEST,
    output_type=_DELETEMODELCOMPILERRUNRESPONSE,
    serialized_options=b'\202\323\344\223\002<*:/api/v1/modelcompilerruns/{modelcompilerrun.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MODELCOMPILERRUNSERVICE)

DESCRIPTOR.services_by_name['ModelCompilerRunService'] = _MODELCOMPILERRUNSERVICE

# @@protoc_insertion_point(module_scope)
