# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto',
  package='github.com.metaprov.modelaapi.services.postmortem.v1',
  syntax='proto3',
  serialized_options=b'Z4github.com/metaprov/modelaapi/services/postmortem/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nEgithub.com/metaprov/modelaapi/services/postmortem/v1/postmortem.proto\x12\x34github.com.metaprov.modelaapi.services.postmortem.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\"\xc4\x01\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x17ListPostMortemsResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortemList\"i\n\x17\x43reatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x1a\n\x18\x43reatePostMortemResponse\"i\n\x17UpdatePostMortemRequest\x12N\n\x04item\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x1a\n\x18UpdatePostMortemResponse\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x15GetPostMortemResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65letePostMortemResponse2\xd5\x08\n\x11PostMortemService\x12\xc7\x01\n\x0fListPostMortems\x12L.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest\x1aM.github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1/postmortems\x12\xcd\x01\n\x10\x43reatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/postmortems:\x01*\x12\xc8\x01\n\rGetPostMortem\x12J.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest\x1aK.github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/postmortems/{name}\x12\xe8\x01\n\x10UpdatePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse\"5\x82\xd3\xe4\x93\x02/\x1a*/v1/postmortems/{postmortem.metadata.name}:\x01*\x12\xef\x01\n\x10\x44\x65letePostMortem\x12M.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest\x1aN.github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse\"<\x82\xd3\xe4\x93\x02\x36*4/api/v1alpha1/postmortems/{postmortem.metadata.name}B6Z4github.com/metaprov/modelaapi/services/postmortem/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTPOSTMORTEMSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=424,
)

_LISTPOSTMORTEMSREQUEST = _descriptor.Descriptor(
  name='ListPostMortemsRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPOSTMORTEMSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=228,
  serialized_end=424,
)


_LISTPOSTMORTEMSRESPONSE = _descriptor.Descriptor(
  name='ListPostMortemsResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=536,
)


_CREATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='CreatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=643,
)


_CREATEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='CreatePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=671,
)


_UPDATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='UpdatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=778,
)


_UPDATEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='UpdatePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=806,
)


_GETPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='GetPostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=808,
  serialized_end=863,
)


_GETPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='GetPostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=982,
)


_DELETEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='DeletePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=984,
  serialized_end=1042,
)


_DELETEPOSTMORTEMRESPONSE = _descriptor.Descriptor(
  name='DeletePostMortemResponse',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1070,
)

_LISTPOSTMORTEMSREQUEST_LABELSENTRY.containing_type = _LISTPOSTMORTEMSREQUEST
_LISTPOSTMORTEMSREQUEST.fields_by_name['labels'].message_type = _LISTPOSTMORTEMSREQUEST_LABELSENTRY
_LISTPOSTMORTEMSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEMLIST
_CREATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_UPDATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_GETPOSTMORTEMRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
DESCRIPTOR.message_types_by_name['ListPostMortemsRequest'] = _LISTPOSTMORTEMSREQUEST
DESCRIPTOR.message_types_by_name['ListPostMortemsResponse'] = _LISTPOSTMORTEMSRESPONSE
DESCRIPTOR.message_types_by_name['CreatePostMortemRequest'] = _CREATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['CreatePostMortemResponse'] = _CREATEPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest'] = _UPDATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['UpdatePostMortemResponse'] = _UPDATEPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['GetPostMortemRequest'] = _GETPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['GetPostMortemResponse'] = _GETPOSTMORTEMRESPONSE
DESCRIPTOR.message_types_by_name['DeletePostMortemRequest'] = _DELETEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['DeletePostMortemResponse'] = _DELETEPOSTMORTEMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)
_sym_db.RegisterMessage(ListPostMortemsRequest.LabelsEntry)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

CreatePostMortemResponse = _reflection.GeneratedProtocolMessageType('CreatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.CreatePostMortemResponse)
  })
_sym_db.RegisterMessage(CreatePostMortemResponse)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

UpdatePostMortemResponse = _reflection.GeneratedProtocolMessageType('UpdatePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.UpdatePostMortemResponse)
  })
_sym_db.RegisterMessage(UpdatePostMortemResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

GetPostMortemResponse = _reflection.GeneratedProtocolMessageType('GetPostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.GetPostMortemResponse)
  })
_sym_db.RegisterMessage(GetPostMortemResponse)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

DeletePostMortemResponse = _reflection.GeneratedProtocolMessageType('DeletePostMortemResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.postmortem.v1.postmortem_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.postmortem.v1.DeletePostMortemResponse)
  })
_sym_db.RegisterMessage(DeletePostMortemResponse)


DESCRIPTOR._options = None
_LISTPOSTMORTEMSREQUEST_LABELSENTRY._options = None

_POSTMORTEMSERVICE = _descriptor.ServiceDescriptor(
  name='PostMortemService',
  full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1073,
  serialized_end=2182,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListPostMortems',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.ListPostMortems',
    index=0,
    containing_service=None,
    input_type=_LISTPOSTMORTEMSREQUEST,
    output_type=_LISTPOSTMORTEMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1/postmortems',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.CreatePostMortem',
    index=1,
    containing_service=None,
    input_type=_CREATEPOSTMORTEMREQUEST,
    output_type=_CREATEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\"\017/v1/postmortems:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.GetPostMortem',
    index=2,
    containing_service=None,
    input_type=_GETPOSTMORTEMREQUEST,
    output_type=_GETPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/postmortems/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.UpdatePostMortem',
    index=3,
    containing_service=None,
    input_type=_UPDATEPOSTMORTEMREQUEST,
    output_type=_UPDATEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\002/\032*/v1/postmortems/{postmortem.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePostMortem',
    full_name='github.com.metaprov.modelaapi.services.postmortem.v1.PostMortemService.DeletePostMortem',
    index=4,
    containing_service=None,
    input_type=_DELETEPOSTMORTEMREQUEST,
    output_type=_DELETEPOSTMORTEMRESPONSE,
    serialized_options=b'\202\323\344\223\0026*4/api/v1alpha1/postmortems/{postmortem.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_POSTMORTEMSERVICE)

DESCRIPTOR.services_by_name['PostMortemService'] = _POSTMORTEMSERVICE

# @@protoc_insertion_point(module_scope)
