# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto',
  package='github.com.metaprov.modelaapi.services.objectstored.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/metaprov/modelaapi/services/objectstored/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nIgithub.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto\x12\x36github.com.metaprov.modelaapi.services.objectstored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"!\n\x0eIngestResponse\x12\x0f\n\x07liveKey\x18\x01 \x01(\t\"%\n\x0eObjectResponse\x12\x13\n\x0b\x61rchivePath\x18\x01 \x01(\t\"\xdb\x02\n\rObjectRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x06 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry\x12\x0b\n\x03key\x18\x07 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"-\n\x1c\x45xistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x32\xa2\x05\n\x12ObjectstoreService\x12\x99\x01\n\x06Ingest\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07\x41rchive\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07Recover\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\xb5\x01\n\x14\x45xistInVirtualBucket\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1aT.github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse\"\x00\x42\x38Z6github.com/metaprov/modelaapi/services/objectstored/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_INGESTRESPONSE = _descriptor.Descriptor(
  name='IngestResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='liveKey', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse.liveKey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=237,
)


_OBJECTRESPONSE = _descriptor.Descriptor(
  name='ObjectResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='archivePath', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse.archivePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=239,
  serialized_end=276,
)


_OBJECTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=581,
  serialized_end=626,
)

_OBJECTREQUEST = _descriptor.Descriptor(
  name='ObjectRequest',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.secret', index=2,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.key', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_OBJECTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=626,
)


_EXISTINVIRTUALBUCKETRESPONSE = _descriptor.Descriptor(
  name='ExistInVirtualBucketResponse',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exist', full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse.exist', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=628,
  serialized_end=673,
)

_OBJECTREQUEST_SECRETENTRY.containing_type = _OBJECTREQUEST
_OBJECTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_OBJECTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_OBJECTREQUEST.fields_by_name['secret'].message_type = _OBJECTREQUEST_SECRETENTRY
DESCRIPTOR.message_types_by_name['IngestResponse'] = _INGESTRESPONSE
DESCRIPTOR.message_types_by_name['ObjectResponse'] = _OBJECTRESPONSE
DESCRIPTOR.message_types_by_name['ObjectRequest'] = _OBJECTREQUEST
DESCRIPTOR.message_types_by_name['ExistInVirtualBucketResponse'] = _EXISTINVIRTUALBUCKETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)

ObjectResponse = _reflection.GeneratedProtocolMessageType('ObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse)
  })
_sym_db.RegisterMessage(ObjectResponse)

ObjectRequest = _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest)
  })
_sym_db.RegisterMessage(ObjectRequest)
_sym_db.RegisterMessage(ObjectRequest.SecretEntry)

ExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('ExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(ExistInVirtualBucketResponse)


DESCRIPTOR._options = None
_OBJECTREQUEST_SECRETENTRY._options = None

_OBJECTSTORESERVICE = _descriptor.ServiceDescriptor(
  name='ObjectstoreService',
  full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=676,
  serialized_end=1350,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ingest',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Ingest',
    index=0,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Archive',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Archive',
    index=1,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Recover',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.Recover',
    index=2,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_OBJECTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExistInVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.objectstored.v1.ObjectstoreService.ExistInVirtualBucket',
    index=3,
    containing_service=None,
    input_type=_OBJECTREQUEST,
    output_type=_EXISTINVIRTUALBUCKETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBJECTSTORESERVICE)

DESCRIPTOR.services_by_name['ObjectstoreService'] = _OBJECTSTORESERVICE

# @@protoc_insertion_point(module_scope)
