# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/account/v1/account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/account/v1/account.proto',
  package='github.com.metaprov.modelaapi.services.account.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/account/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/account/v1/account.proto\x12\x31github.com.metaprov.modelaapi.services.account.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xbb\x01\n\x13ListAccountsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n\x14ListAccountsResponse\x12Q\n\x05items\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.AccountList\"\x11\n\x0f\x41\x63\x63ountResponse\"v\n\x14\x43reateAccountRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\x12\x10\n\x08password\x18\x02 \x01(\t\"\x17\n\x15\x43reateAccountResponse\"d\n\x14UpdateAccountRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x17\n\x15UpdateAccountResponse\"4\n\x11GetAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x12GetAccountResponse\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\x12\x0c\n\x04yaml\x18\x02 \x01(\t\">\n\x1bGetAccountNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1cGetAccountNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"7\n\x14\x44\x65leteAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteAccountResponse\"\x17\n\x15\x41\x63\x63ountCreateResponse\"\x10\n\x0eLogoutResponse\"\x17\n\x15ResetPasswordResponse\"H\n\x13\x41\x63\x63ountLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"%\n\x14\x41\x63\x63ountLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t\":\n\x17\x41\x63\x63ountGetByNameRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"%\n\x14\x41\x63\x63ountLogoutRequest\x12\r\n\x05token\x18\x01 \x01(\t\"h\n\x15\x43hangePasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03old\x18\x03 \x01(\t\x12\x0b\n\x03new\x18\x04 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x05 \x01(\t\"\x18\n\x16\x43hangePasswordResponse\"Z\n\x14ResetPasswordRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03new\x18\x03 \x01(\t\x12\x14\n\x0c\x63onfirmedNew\x18\x04 \x01(\t\"\x16\n\x14ResetPasswordReponse\"Z\n\x13UploadAvatarRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nbucketName\x18\x03 \x01(\t\x12\x0e\n\x06\x61vatar\x18\x04 \x01(\x0c\"\x15\n\x13UploadAvatarReponse\"8\n\x15\x44ownloadAvatarRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\'\n\x15\x44ownloadAvatarReponse\x12\x0e\n\x06\x61vatar\x18\x01 \x01(\x0c\x32\xe2\x11\n\x0e\x41\x63\x63ountService\x12\xb5\x01\n\x0cListAccounts\x12\x46.github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest\x1aG.github.com.metaprov.modelaapi.services.account.v1.ListAccountsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/accounts\x12\xc1\x01\n\rCreateAccount\x12G.github.com.metaprov.modelaapi.services.account.v1.CreateAccountRequest\x1aH.github.com.metaprov.modelaapi.services.account.v1.CreateAccountResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x0c/v1/accounts:\x07\x61\x63\x63ount\x12\xc2\x01\n\nGetAccount\x12\x44.github.com.metaprov.modelaapi.services.account.v1.GetAccountRequest\x1a\x45.github.com.metaprov.modelaapi.services.account.v1.GetAccountResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/{namespace}/accounts/{name}\x12\xf7\x01\n\rUpdateAccount\x12G.github.com.metaprov.modelaapi.services.account.v1.UpdateAccountRequest\x1aH.github.com.metaprov.modelaapi.services.account.v1.UpdateAccountResponse\"S\x82\xd3\xe4\x93\x02M\x1a\x42/v1/{account.metadata.namespace}/accounts//{account.metadata.name}:\x07\x61\x63\x63ount\x12\xcf\x01\n\rDeleteAccount\x12G.github.com.metaprov.modelaapi.services.account.v1.DeleteAccountRequest\x1aH.github.com.metaprov.modelaapi.services.account.v1.DeleteAccountResponse\"+\x82\xd3\xe4\x93\x02%*#/api/{namespace}/v1/accounts/{name}\x12\xef\x01\n\x14GetAccountNamespaces\x12N.github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesRequest\x1aO.github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/{namespace}/v1/accounts/{name}:namespaces\x12\x9a\x01\n\x05Login\x12\x46.github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest\x1aG.github.com.metaprov.modelaapi.services.account.v1.AccountLoginResponse\"\x00\x12\x96\x01\n\x06Logout\x12G.github.com.metaprov.modelaapi.services.account.v1.AccountLogoutRequest\x1a\x41.github.com.metaprov.modelaapi.services.account.v1.LogoutResponse\"\x00\x12\xa7\x01\n\x0e\x43hangePassword\x12H.github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest\x1aI.github.com.metaprov.modelaapi.services.account.v1.ChangePasswordResponse\"\x00\x12\xa4\x01\n\rResetPassword\x12G.github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest\x1aH.github.com.metaprov.modelaapi.services.account.v1.ResetPasswordResponse\"\x00\x12\xa0\x01\n\x0cUploadAvatar\x12\x46.github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest\x1a\x46.github.com.metaprov.modelaapi.services.account.v1.UploadAvatarReponse\"\x00\x12\xa6\x01\n\x0e\x44ownloadAvatar\x12H.github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarRequest\x1aH.github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarReponse\"\x00\x42\x33Z1github.com/metaprov/modelaapi/services/account/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,])




_LISTACCOUNTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=425,
  serialized_end=470,
)

_LISTACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListAccountsRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTACCOUNTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=470,
)


_LISTACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListAccountsResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.account.v1.ListAccountsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=577,
)


_ACCOUNTRESPONSE = _descriptor.Descriptor(
  name='AccountResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=579,
  serialized_end=596,
)


_CREATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.CreateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.account.v1.CreateAccountRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.account.v1.CreateAccountRequest.password', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=716,
)


_CREATEACCOUNTRESPONSE = _descriptor.Descriptor(
  name='CreateAccountResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.CreateAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=718,
  serialized_end=741,
)


_UPDATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='UpdateAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.UpdateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.account.v1.UpdateAccountRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=743,
  serialized_end=843,
)


_UPDATEACCOUNTRESPONSE = _descriptor.Descriptor(
  name='UpdateAccountResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.UpdateAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=868,
)


_GETACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=870,
  serialized_end=922,
)


_GETACCOUNTRESPONSE = _descriptor.Descriptor(
  name='GetAccountResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1036,
)


_GETACCOUNTNAMESPACESREQUEST = _descriptor.Descriptor(
  name='GetAccountNamespacesRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1100,
)


_GETACCOUNTNAMESPACESRESPONSE = _descriptor.Descriptor(
  name='GetAccountNamespacesResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesResponse.namespaces', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1102,
  serialized_end=1217,
)


_DELETEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeleteAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.DeleteAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.DeleteAccountRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.DeleteAccountRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1219,
  serialized_end=1274,
)


_DELETEACCOUNTRESPONSE = _descriptor.Descriptor(
  name='DeleteAccountResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.DeleteAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1276,
  serialized_end=1299,
)


_ACCOUNTCREATERESPONSE = _descriptor.Descriptor(
  name='AccountCreateResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1301,
  serialized_end=1324,
)


_LOGOUTRESPONSE = _descriptor.Descriptor(
  name='LogoutResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.LogoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1326,
  serialized_end=1342,
)


_RESETPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ResetPasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1344,
  serialized_end=1367,
)


_ACCOUNTLOGINREQUEST = _descriptor.Descriptor(
  name='AccountLoginRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1441,
)


_ACCOUNTLOGINRESPONSE = _descriptor.Descriptor(
  name='AccountLoginResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLoginResponse.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1480,
)


_ACCOUNTGETBYNAMEREQUEST = _descriptor.Descriptor(
  name='AccountGetByNameRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountGetByNameRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountGetByNameRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountGetByNameRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1482,
  serialized_end=1540,
)


_ACCOUNTLOGOUTREQUEST = _descriptor.Descriptor(
  name='AccountLogoutRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLogoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='github.com.metaprov.modelaapi.services.account.v1.AccountLogoutRequest.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1542,
  serialized_end=1579,
)


_CHANGEPASSWORDREQUEST = _descriptor.Descriptor(
  name='ChangePasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old', full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest.old', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest.new', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest.confirmedNew', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1581,
  serialized_end=1685,
)


_CHANGEPASSWORDRESPONSE = _descriptor.Descriptor(
  name='ChangePasswordResponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ChangePasswordResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1687,
  serialized_end=1711,
)


_RESETPASSWORDREQUEST = _descriptor.Descriptor(
  name='ResetPasswordRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new', full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest.new', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confirmedNew', full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest.confirmedNew', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1713,
  serialized_end=1803,
)


_RESETPASSWORDREPONSE = _descriptor.Descriptor(
  name='ResetPasswordReponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.ResetPasswordReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1827,
)


_UPLOADAVATARREQUEST = _descriptor.Descriptor(
  name='UploadAvatarRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucketName', full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest.bucketName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='avatar', full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest.avatar', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1829,
  serialized_end=1919,
)


_UPLOADAVATARREPONSE = _descriptor.Descriptor(
  name='UploadAvatarReponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.UploadAvatarReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1921,
  serialized_end=1942,
)


_DOWNLOADAVATARREQUEST = _descriptor.Descriptor(
  name='DownloadAvatarRequest',
  full_name='github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1944,
  serialized_end=2000,
)


_DOWNLOADAVATARREPONSE = _descriptor.Descriptor(
  name='DownloadAvatarReponse',
  full_name='github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarReponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='avatar', full_name='github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarReponse.avatar', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2002,
  serialized_end=2041,
)

_LISTACCOUNTSREQUEST_LABELSENTRY.containing_type = _LISTACCOUNTSREQUEST
_LISTACCOUNTSREQUEST.fields_by_name['labels'].message_type = _LISTACCOUNTSREQUEST_LABELSENTRY
_LISTACCOUNTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNTLIST
_CREATEACCOUNTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_UPDATEACCOUNTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_GETACCOUNTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_GETACCOUNTNAMESPACESRESPONSE.fields_by_name['namespaces'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._NAMESPACEINFO
DESCRIPTOR.message_types_by_name['ListAccountsRequest'] = _LISTACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListAccountsResponse'] = _LISTACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['AccountResponse'] = _ACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CreateAccountRequest'] = _CREATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CreateAccountResponse'] = _CREATEACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAccountRequest'] = _UPDATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['UpdateAccountResponse'] = _UPDATEACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountRequest'] = _GETACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['GetAccountResponse'] = _GETACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountNamespacesRequest'] = _GETACCOUNTNAMESPACESREQUEST
DESCRIPTOR.message_types_by_name['GetAccountNamespacesResponse'] = _GETACCOUNTNAMESPACESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAccountRequest'] = _DELETEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccountResponse'] = _DELETEACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['AccountCreateResponse'] = _ACCOUNTCREATERESPONSE
DESCRIPTOR.message_types_by_name['LogoutResponse'] = _LOGOUTRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordResponse'] = _RESETPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['AccountLoginRequest'] = _ACCOUNTLOGINREQUEST
DESCRIPTOR.message_types_by_name['AccountLoginResponse'] = _ACCOUNTLOGINRESPONSE
DESCRIPTOR.message_types_by_name['AccountGetByNameRequest'] = _ACCOUNTGETBYNAMEREQUEST
DESCRIPTOR.message_types_by_name['AccountLogoutRequest'] = _ACCOUNTLOGOUTREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordRequest'] = _CHANGEPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ChangePasswordResponse'] = _CHANGEPASSWORDRESPONSE
DESCRIPTOR.message_types_by_name['ResetPasswordRequest'] = _RESETPASSWORDREQUEST
DESCRIPTOR.message_types_by_name['ResetPasswordReponse'] = _RESETPASSWORDREPONSE
DESCRIPTOR.message_types_by_name['UploadAvatarRequest'] = _UPLOADAVATARREQUEST
DESCRIPTOR.message_types_by_name['UploadAvatarReponse'] = _UPLOADAVATARREPONSE
DESCRIPTOR.message_types_by_name['DownloadAvatarRequest'] = _DOWNLOADAVATARREQUEST
DESCRIPTOR.message_types_by_name['DownloadAvatarReponse'] = _DOWNLOADAVATARREPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTACCOUNTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)
_sym_db.RegisterMessage(ListAccountsRequest.LabelsEntry)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

AccountResponse = _reflection.GeneratedProtocolMessageType('AccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountResponse)
  })
_sym_db.RegisterMessage(AccountResponse)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

CreateAccountResponse = _reflection.GeneratedProtocolMessageType('CreateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.CreateAccountResponse)
  })
_sym_db.RegisterMessage(CreateAccountResponse)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

UpdateAccountResponse = _reflection.GeneratedProtocolMessageType('UpdateAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.UpdateAccountResponse)
  })
_sym_db.RegisterMessage(UpdateAccountResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

GetAccountResponse = _reflection.GeneratedProtocolMessageType('GetAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.GetAccountResponse)
  })
_sym_db.RegisterMessage(GetAccountResponse)

GetAccountNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetAccountNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesRequest)
  })
_sym_db.RegisterMessage(GetAccountNamespacesRequest)

GetAccountNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetAccountNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.GetAccountNamespacesResponse)
  })
_sym_db.RegisterMessage(GetAccountNamespacesResponse)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)

DeleteAccountResponse = _reflection.GeneratedProtocolMessageType('DeleteAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.DeleteAccountResponse)
  })
_sym_db.RegisterMessage(DeleteAccountResponse)

AccountCreateResponse = _reflection.GeneratedProtocolMessageType('AccountCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountCreateResponse)
  })
_sym_db.RegisterMessage(AccountCreateResponse)

LogoutResponse = _reflection.GeneratedProtocolMessageType('LogoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOGOUTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.LogoutResponse)
  })
_sym_db.RegisterMessage(LogoutResponse)

ResetPasswordResponse = _reflection.GeneratedProtocolMessageType('ResetPasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ResetPasswordResponse)
  })
_sym_db.RegisterMessage(ResetPasswordResponse)

AccountLoginRequest = _reflection.GeneratedProtocolMessageType('AccountLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountLoginRequest)
  })
_sym_db.RegisterMessage(AccountLoginRequest)

AccountLoginResponse = _reflection.GeneratedProtocolMessageType('AccountLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountLoginResponse)
  })
_sym_db.RegisterMessage(AccountLoginResponse)

AccountGetByNameRequest = _reflection.GeneratedProtocolMessageType('AccountGetByNameRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTGETBYNAMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountGetByNameRequest)
  })
_sym_db.RegisterMessage(AccountGetByNameRequest)

AccountLogoutRequest = _reflection.GeneratedProtocolMessageType('AccountLogoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTLOGOUTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.AccountLogoutRequest)
  })
_sym_db.RegisterMessage(AccountLogoutRequest)

ChangePasswordRequest = _reflection.GeneratedProtocolMessageType('ChangePasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ChangePasswordRequest)
  })
_sym_db.RegisterMessage(ChangePasswordRequest)

ChangePasswordResponse = _reflection.GeneratedProtocolMessageType('ChangePasswordResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEPASSWORDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ChangePasswordResponse)
  })
_sym_db.RegisterMessage(ChangePasswordResponse)

ResetPasswordRequest = _reflection.GeneratedProtocolMessageType('ResetPasswordRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ResetPasswordRequest)
  })
_sym_db.RegisterMessage(ResetPasswordRequest)

ResetPasswordReponse = _reflection.GeneratedProtocolMessageType('ResetPasswordReponse', (_message.Message,), {
  'DESCRIPTOR' : _RESETPASSWORDREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.ResetPasswordReponse)
  })
_sym_db.RegisterMessage(ResetPasswordReponse)

UploadAvatarRequest = _reflection.GeneratedProtocolMessageType('UploadAvatarRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADAVATARREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.UploadAvatarRequest)
  })
_sym_db.RegisterMessage(UploadAvatarRequest)

UploadAvatarReponse = _reflection.GeneratedProtocolMessageType('UploadAvatarReponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADAVATARREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.UploadAvatarReponse)
  })
_sym_db.RegisterMessage(UploadAvatarReponse)

DownloadAvatarRequest = _reflection.GeneratedProtocolMessageType('DownloadAvatarRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADAVATARREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarRequest)
  })
_sym_db.RegisterMessage(DownloadAvatarRequest)

DownloadAvatarReponse = _reflection.GeneratedProtocolMessageType('DownloadAvatarReponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADAVATARREPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.account.v1.account_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.account.v1.DownloadAvatarReponse)
  })
_sym_db.RegisterMessage(DownloadAvatarReponse)


DESCRIPTOR._options = None
_LISTACCOUNTSREQUEST_LABELSENTRY._options = None

_ACCOUNTSERVICE = _descriptor.ServiceDescriptor(
  name='AccountService',
  full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2044,
  serialized_end=4318,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAccounts',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.ListAccounts',
    index=0,
    containing_service=None,
    input_type=_LISTACCOUNTSREQUEST,
    output_type=_LISTACCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/accounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccount',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.CreateAccount',
    index=1,
    containing_service=None,
    input_type=_CREATEACCOUNTREQUEST,
    output_type=_CREATEACCOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\014/v1/accounts:\007account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccount',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.GetAccount',
    index=2,
    containing_service=None,
    input_type=_GETACCOUNTREQUEST,
    output_type=_GETACCOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v1/{namespace}/accounts/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccount',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.UpdateAccount',
    index=3,
    containing_service=None,
    input_type=_UPDATEACCOUNTREQUEST,
    output_type=_UPDATEACCOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\002M\032B/v1/{account.metadata.namespace}/accounts//{account.metadata.name}:\007account',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAccount',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.DeleteAccount',
    index=4,
    containing_service=None,
    input_type=_DELETEACCOUNTREQUEST,
    output_type=_DELETEACCOUNTRESPONSE,
    serialized_options=b'\202\323\344\223\002%*#/api/{namespace}/v1/accounts/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountNamespaces',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.GetAccountNamespaces',
    index=5,
    containing_service=None,
    input_type=_GETACCOUNTNAMESPACESREQUEST,
    output_type=_GETACCOUNTNAMESPACESRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./api/{namespace}/v1/accounts/{name}:namespaces',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Login',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.Login',
    index=6,
    containing_service=None,
    input_type=_ACCOUNTLOGINREQUEST,
    output_type=_ACCOUNTLOGINRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Logout',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.Logout',
    index=7,
    containing_service=None,
    input_type=_ACCOUNTLOGOUTREQUEST,
    output_type=_LOGOUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ChangePassword',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.ChangePassword',
    index=8,
    containing_service=None,
    input_type=_CHANGEPASSWORDREQUEST,
    output_type=_CHANGEPASSWORDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ResetPassword',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.ResetPassword',
    index=9,
    containing_service=None,
    input_type=_RESETPASSWORDREQUEST,
    output_type=_RESETPASSWORDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UploadAvatar',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.UploadAvatar',
    index=10,
    containing_service=None,
    input_type=_UPLOADAVATARREQUEST,
    output_type=_UPLOADAVATARREPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadAvatar',
    full_name='github.com.metaprov.modelaapi.services.account.v1.AccountService.DownloadAvatar',
    index=11,
    containing_service=None,
    input_type=_DOWNLOADAVATARREQUEST,
    output_type=_DOWNLOADAVATARREPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTSERVICE)

DESCRIPTOR.services_by_name['AccountService'] = _ACCOUNTSERVICE

# @@protoc_insertion_point(module_scope)
