# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/apimachinery/pkg/api/resource/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='k8s.io/apimachinery/pkg/api/resource/generated.proto',
  package='k8s.io.apimachinery.pkg.api.resource',
  syntax='proto2',
  serialized_options=b'Z\010resource',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4k8s.io/apimachinery/pkg/api/resource/generated.proto\x12$k8s.io.apimachinery.pkg.api.resource\"\x1a\n\x08Quantity\x12\x0e\n\x06string\x18\x01 \x01(\tB\nZ\x08resource'
)




_QUANTITY = _descriptor.Descriptor(
  name='Quantity',
  full_name='k8s.io.apimachinery.pkg.api.resource.Quantity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='string', full_name='k8s.io.apimachinery.pkg.api.resource.Quantity.string', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=120,
)

DESCRIPTOR.message_types_by_name['Quantity'] = _QUANTITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Quantity = _reflection.GeneratedProtocolMessageType('Quantity', (_message.Message,), {
  'DESCRIPTOR' : _QUANTITY,
  '__module__' : 'k8s.io.apimachinery.pkg.api.resource.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.apimachinery.pkg.api.resource.Quantity)
  })
_sym_db.RegisterMessage(Quantity)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
