# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/data/v1/data.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from k8s.io.api.core.v1 import generated_pb2 as k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/data/v1/data.proto',
  package='github.com.metaprov.modelaapi.services.data.v1',
  syntax='proto3',
  serialized_options=b'Z.github.com/metaprov/modelaapi/services/data/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9github.com/metaprov/modelaapi/services/data/v1/data.proto\x12.github.com.metaprov.modelaapi.services.data.v1\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a\"k8s.io/api/core/v1/generated.proto\"\xfd\x03\n\x11\x44sReadFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12]\n\x06secret\x18\x06 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x83\x04\n\x14\x44sReadFeatureRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x06 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xcf\x04\n\x12\x44sWriteFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x07\x63ontent\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x07 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd0\x02\n\x12\x44sReadAudioRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x03 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x89\x04\n\x17\x44sReadTextCorpusRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x05 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xd8\x04\n\x17\x44sReadFromStoreResponse\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12M\n\x06result\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x04 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x06 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"p\n\x18\x44sRunDataPipelineRequest\x12T\n\x08pipeline\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"j\n\x19\x44sRunDataPipelineResponse\x12M\n\x06result\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\xc7\x06\n\x12\x44sRunRecipeRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12^\n\x06secret\x18\x07 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry\x12L\n\x06recipe\x18\x08 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12R\n\treciperun\x18\t \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"c\n\x13\x44sRunRecipeResponse\x12L\n\x06result\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x87\x06\n\x1c\x44sCreateRecipeProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry\x12L\n\x06recipe\x18\x08 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"l\n\x1d\x44sCreateRecipeProfileResponse\x12K\n\x06result\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\x14\n\x12\x44\x61taSourceResponse\"\x11\n\x0f\x44\x61tasetResponse\"\xbb\x05\n\x1d\x44sCreateDatasetProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12i\n\x06secret\x18\x07 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x80\x01\n\x1e\x44sCreateDatasetProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12Q\n\x07profile\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\xd7\x06\n\x1b\x44sCreateModelProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12g\n\x06secret\x18\n \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateModelProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xc5\x07\n%DsCreateForecastPartitionFilesRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12q\n\x06secret\x18\n \x03(\x0b\x32\x61.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry\x12X\n\tforecasts\x18\x0b \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ForecastObj\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"}\n&DsCreateForecastPartitionFilesResponse\x12S\n\npartitions\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.data.v1.PartitionValues\"/\n\x0fPartitionValues\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"\xd5\x06\n\x1a\x44sMergeForecastFileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\n \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"*\n\x1b\x44sMergeForecastFileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xd8\x06\n\x1b\x44sCreateStudyProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05study\x18\x04 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12O\n\x06models\x18\x08 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12g\n\x06secret\x18\t \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x1c\x44sCreateStudyProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\"\xb1\x05\n\x18\x44sValidateDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x64\n\x06secret\x18\x07 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"w\n\x19\x44sValidateDatasetResponse\x12Z\n\x06result\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataValidationResult\"\xef\x04\n\x18\x44sGenerateDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x64\n\x06secret\x18\x06 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry\x12\x0c\n\x04rows\x18\x07 \x01(\x05\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"(\n\x19\x44sGenerateDatasetResponse\x12\x0b\n\x03key\x18\x01 \x01(\t\"\xfb\x05\n\x15\x44sSplitDatasetRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x08 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xc8\x05\n\x1c\x44sSplitDatasetToRungsRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\x06\x62ucket\x18\x03 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry\x12\r\n\x05rungs\x18\x08 \x01(\x05\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x1f\n\x1d\x44sSplitDatasetToRungsResponse\"O\n\x16\x44sSplitDatasetResponse\x12\x10\n\x08training\x18\x01 \x01(\x05\x12\x0f\n\x07testing\x18\x02 \x01(\x05\x12\x12\n\nvalidation\x18\x03 \x01(\x05\"\xe1\x05\n\x1c\x44sCreateColumnProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12h\n\x06secret\x18\x07 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry\x12\x12\n\ncolumnType\x18\x08 \x01(\t\x12\x12\n\ncolumnName\x18\t \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"s\n\x1d\x44sCreateColumnProfileResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x04plot\x18\x02 \x01(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"\xbe\x05\n\x17\x44sDatasetProfileRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\x06\x62ucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x63\n\x06secret\x18\x07 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry\x12\r\n\x05quick\x18\x08 \x01(\x08\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"m\n\x18\x44sDatasetProfileResponse\x12Q\n\x07profile\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x80\x04\n\x14\x44sInferSchemaRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\x08\x66latfile\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12`\n\x06secret\x18\x05 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"j\n\x15\x44sInferSchemaResponse\x12Q\n\x07profile\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x82\x04\n\x15\x44sGetTableViewRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12T\n\x08\x66latfile\x18\x02 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FlatFileSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\x12U\n\nconnection\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x05 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"h\n\x16\x44sGetTableViewResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xf3\x02\n\x1d\x44sGetMisclassTableViewRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12i\n\x06secret\x18\x03 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry\x12\x0b\n\x03key\x18\x04 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"p\n\x1e\x44sGetMisclassTableViewResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xa3\x07\n\x18\x43reateModelReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xac\x07\n\x1b\x43reateForecastReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12Q\n\x08\x66orecast\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12g\n\x06secret\x18\x08 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xe1\x04\n\x1a\x43reateSummaryReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12U\n\nconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x66\n\x06secret\x18\x08 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"#\n\x14\x43reateReportResponse\x12\x0b\n\x03pdf\x18\x01 \x01(\x0c\"\x87\x06\n\x1a\x43reateDatasetReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12U\n\nconnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x06 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x66\n\x06secret\x18\x07 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry\x12P\n\x06report\x18\x08 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xa8\x07\n\x18\x43reateStudyReportRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12T\n\ndatasource\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12S\n\x06models\x18\x06 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelList\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x64\n\x06secret\x18\t \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry\x12P\n\x06report\x18\n \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\xc6\x03\n\x0f\x41skModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0e\n\x06\x62udget\x18\x06 \x01(\x05\"b\n\x10\x41skModelResponse\x12N\n\x05model\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x87\x04\n\x10TellModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12N\n\x05study\x18\x03 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12T\n\ndatasource\x18\x04 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x05 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x13\n\x11TellModelResponse\"\x13\n\x11\x44sShutdownRequest\"\x14\n\x12\x44sShutdownResponse\"\xa2\x07\n\x14ValidateModelRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12N\n\x05model\x18\x06 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12W\n\tpredictor\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12U\n\nconnection\x18\x08 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12`\n\x06secret\x18\n \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"x\n\x15ValidateModelResponse\x12_\n\x06result\x18\x01 \x03(\x0b\x32O.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelValidationResult\"\xda\x02\n\x17\x44sTestConnectionRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x63\n\x06secret\x18\x03 \x03(\x0b\x32S.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"7\n\x18\x44sTestConnectionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\xf7\x05\n\x13\x44sStudyEndedRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12_\n\x06secret\x18\x08 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x44sStudyEndedResponse\"\xfd\x05\n\x16SaveOptimizerDBRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12N\n\x05study\x18\x05 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12U\n\nconnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12T\n\x06\x62ucket\x18\x07 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x62\n\x06secret\x18\x08 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x19\n\x17SaveOptimizerDBResponse\"\x80\x02\n\x15\x44sGetDatabasesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x02 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"+\n\x16\x44sGetDatabasesResponse\x12\x11\n\tdatabases\x18\x01 \x03(\t\"\x90\x02\n\x12\x44sGetTablesRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12^\n\x06secret\x18\x02 \x03(\x0b\x32N.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"%\n\x13\x44sGetTablesResponse\x12\x0e\n\x06tables\x18\x01 \x03(\t\"\x9f\x02\n\x13\x44sExecuteSqlRequest\x12U\n\nconnection\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12_\n\x06secret\x18\x02 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"f\n\x14\x44sExecuteSqlResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\xb9\x07\n\x11\x44sSnapshotRequest\x12R\n\x07product\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12Y\n\x07version\x18\x02 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12W\n\x0c\x64\x62\x63onnection\x18\x05 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x08\x64\x62secret\x18\x06 \x03(\x0b\x32O.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry\x12\\\n\x11storageconnection\x18\x07 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12k\n\rstoragesecret\x18\x08 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry\x12T\n\x06\x62ucket\x18\t \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x0b\n\x03key\x18\n \x01(\t\x1a/\n\rDbsecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x34\n\x12StoragesecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x14\n\x12\x44sSnapshotResponse2\x8b/\n\x0b\x44\x61taService\x12\x98\x01\n\x08ReadFile\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9e\x01\n\x0bReadFeature\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\x9a\x01\n\tReadAudio\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fRunDataPipeline\x12H.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse\"\x00\x12\x96\x01\n\tRunRecipe\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse\"\x00\x12\x9a\x01\n\tWriteFile\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse\"\x00\x12\xa8\x01\n\x0fValidateDataset\x12H.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse\"\x00\x12\xa8\x01\n\x0fGenerateDataset\x12H.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest\x1aI.github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse\"\x00\x12\x9f\x01\n\x0cSplitDataset\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse\"\x00\x12\xb4\x01\n\x13\x43reateColumnProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse\"\x00\x12\x9c\x01\n\x0bInferSchema\x12\x44.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest\x1a\x45.github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse\"\x00\x12\x9f\x01\n\x0cGetTableView\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse\"\x00\x12\xb7\x01\n\x14GetMisclassTableView\x12M.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest\x1aN.github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse\"\x00\x12\xb4\x01\n\x13SplitDatasetToRungs\x12L.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse\"\x00\x12\xb7\x01\n\x14\x43reateDatasetProfile\x12M.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest\x1aN.github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateModelProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse\"\x00\x12\xb1\x01\n\x12\x43reateStudyProfile\x12K.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest\x1aL.github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse\"\x00\x12\xb4\x01\n\x13\x43reateRecipeProfile\x12L.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest\x1aM.github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse\"\x00\x12\xa5\x01\n\x11\x43reateModelReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa5\x01\n\x11\x43reateStudyReport\x12H.github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateDatasetReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xab\x01\n\x14\x43reateForecastReport\x12K.github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\xa9\x01\n\x13\x43reateSummaryReport\x12J.github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse\"\x00\x12\x8f\x01\n\x08\x41skModel\x12?.github.com.metaprov.modelaapi.services.data.v1.AskModelRequest\x1a@.github.com.metaprov.modelaapi.services.data.v1.AskModelResponse\"\x00\x12\x92\x01\n\tTellModel\x12@.github.com.metaprov.modelaapi.services.data.v1.TellModelRequest\x1a\x41.github.com.metaprov.modelaapi.services.data.v1.TellModelResponse\"\x00\x12\xc8\x01\n\x15PartitionForecastFile\x12U.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest\x1aV.github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse\"\x00\x12\xae\x01\n\x11MergeForecastFile\x12J.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest\x1aK.github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse\"\x00\x12\x9e\x01\n\rValidateModel\x12\x44.github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest\x1a\x45.github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse\"\x00\x12\xa7\x01\n\x10\x44sTestConnection\x12G.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest\x1aH.github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse\"\x00\x12\x93\x01\n\x08ShutDown\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse\"\x00\x12\x99\x01\n\nStudyEnded\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse\"\x00\x12\xa4\x01\n\x0fSaveOptimizerDB\x12\x46.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest\x1aG.github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse\"\x00\x12\x9f\x01\n\x0cGetDatabases\x12\x45.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest\x1a\x46.github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse\"\x00\x12\x96\x01\n\tGetTables\x12\x42.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest\x1a\x43.github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse\"\x00\x12\x99\x01\n\nExecuteSql\x12\x43.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest\x1a\x44.github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse\"\x00\x12\x93\x01\n\x08Snapshot\x12\x41.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest\x1a\x42.github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse\"\x00\x42\x30Z.github.com/metaprov/modelaapi/services/data/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,k8s_dot_io_dot_api_dot_core_dot_v1_dot_generated__pb2.DESCRIPTOR,])




_DSREADFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSREADFILEREQUEST = _descriptor.Descriptor(
  name='DsReadFileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.connection', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.bucket', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.secret', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSREADFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=499,
  serialized_end=1008,
)


_DSREADFEATUREREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSREADFEATUREREQUEST = _descriptor.Descriptor(
  name='DsReadFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.bucket', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.connection', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.secret', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSREADFEATUREREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1011,
  serialized_end=1526,
)


_DSWRITEFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSWRITEFILEREQUEST = _descriptor.Descriptor(
  name='DsWriteFileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.bucket', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.connection', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.secret', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSWRITEFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1529,
  serialized_end=2120,
)


_DSREADAUDIOREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSREADAUDIOREQUEST = _descriptor.Descriptor(
  name='DsReadAudioRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.secret', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSREADAUDIOREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2459,
)


_DSREADTEXTCORPUSREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSREADTEXTCORPUSREQUEST = _descriptor.Descriptor(
  name='DsReadTextCorpusRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSREADTEXTCORPUSREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2462,
  serialized_end=2983,
)


_DSREADFROMSTORERESPONSE_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSREADFROMSTORERESPONSE = _descriptor.Descriptor(
  name='DsReadFromStoreResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.result', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.bucket', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.secret', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSREADFROMSTORERESPONSE_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2986,
  serialized_end=3586,
)


_DSRUNDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='DsRunDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pipeline', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest.pipeline', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3588,
  serialized_end=3700,
)


_DSRUNDATAPIPELINERESPONSE = _descriptor.Descriptor(
  name='DsRunDataPipelineResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3702,
  serialized_end=3808,
)


_DSRUNRECIPEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSRUNRECIPEREQUEST = _descriptor.Descriptor(
  name='DsRunRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.bucket', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipe', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.recipe', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reciperun', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.reciperun', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSRUNRECIPEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3811,
  serialized_end=4650,
)


_DSRUNRECIPERESPONSE = _descriptor.Descriptor(
  name='DsRunRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4652,
  serialized_end=4751,
)


_DSCREATERECIPEPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATERECIPEPROFILEREQUEST = _descriptor.Descriptor(
  name='DsCreateRecipeProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.bucket', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recipe', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.recipe', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATERECIPEPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4754,
  serialized_end=5529,
)


_DSCREATERECIPEPROFILERESPONSE = _descriptor.Descriptor(
  name='DsCreateRecipeProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5531,
  serialized_end=5639,
)


_DATASOURCERESPONSE = _descriptor.Descriptor(
  name='DataSourceResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DataSourceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5641,
  serialized_end=5661,
)


_DATASETRESPONSE = _descriptor.Descriptor(
  name='DatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5663,
  serialized_end=5680,
)


_DSCREATEDATASETPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATEDATASETPROFILEREQUEST = _descriptor.Descriptor(
  name='DsCreateDatasetProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.bucket', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATEDATASETPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5683,
  serialized_end=6382,
)


_DSCREATEDATASETPROFILERESPONSE = _descriptor.Descriptor(
  name='DsCreateDatasetProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse.profile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6385,
  serialized_end=6513,
)


_DSCREATEMODELPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATEMODELPROFILEREQUEST = _descriptor.Descriptor(
  name='DsCreateModelProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.connection', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.bucket', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.secret', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATEMODELPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6516,
  serialized_end=7371,
)


_DSCREATEMODELPROFILERESPONSE = _descriptor.Descriptor(
  name='DsCreateModelProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7373,
  serialized_end=7416,
)


_DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATEFORECASTPARTITIONFILESREQUEST = _descriptor.Descriptor(
  name='DsCreateForecastPartitionFilesRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.connection', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.bucket', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.secret', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecasts', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.forecasts', index=9,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7419,
  serialized_end=8384,
)


_DSCREATEFORECASTPARTITIONFILESRESPONSE = _descriptor.Descriptor(
  name='DsCreateForecastPartitionFilesResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='partitions', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse.partitions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8386,
  serialized_end=8511,
)


_PARTITIONVALUES = _descriptor.Descriptor(
  name='PartitionValues',
  full_name='github.com.metaprov.modelaapi.services.data.v1.PartitionValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.data.v1.PartitionValues.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='github.com.metaprov.modelaapi.services.data.v1.PartitionValues.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8513,
  serialized_end=8560,
)


_DSMERGEFORECASTFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSMERGEFORECASTFILEREQUEST = _descriptor.Descriptor(
  name='DsMergeForecastFileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.connection', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.bucket', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.secret', index=8,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSMERGEFORECASTFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8563,
  serialized_end=9416,
)


_DSMERGEFORECASTFILERESPONSE = _descriptor.Descriptor(
  name='DsMergeForecastFileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9418,
  serialized_end=9460,
)


_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATESTUDYPROFILEREQUEST = _descriptor.Descriptor(
  name='DsCreateStudyProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.study', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.bucket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.models', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.secret', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9463,
  serialized_end=10319,
)


_DSCREATESTUDYPROFILERESPONSE = _descriptor.Descriptor(
  name='DsCreateStudyProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10321,
  serialized_end=10364,
)


_DSVALIDATEDATASETREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSVALIDATEDATASETREQUEST = _descriptor.Descriptor(
  name='DsValidateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.bucket', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSVALIDATEDATASETREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10367,
  serialized_end=11056,
)


_DSVALIDATEDATASETRESPONSE = _descriptor.Descriptor(
  name='DsValidateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11058,
  serialized_end=11177,
)


_DSGENERATEDATASETREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSGENERATEDATASETREQUEST = _descriptor.Descriptor(
  name='DsGenerateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.bucket', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.secret', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.rows', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSGENERATEDATASETREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11180,
  serialized_end=11803,
)


_DSGENERATEDATASETRESPONSE = _descriptor.Descriptor(
  name='DsGenerateDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11805,
  serialized_end=11845,
)


_DSSPLITDATASETREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSSPLITDATASETREQUEST = _descriptor.Descriptor(
  name='DsSplitDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.datasource', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.study', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.connection', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.secret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSSPLITDATASETREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11848,
  serialized_end=12611,
)


_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSSPLITDATASETTORUNGSREQUEST = _descriptor.Descriptor(
  name='DsSplitDatasetToRungsRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.bucket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.datasource', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rungs', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.rungs', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12614,
  serialized_end=13326,
)


_DSSPLITDATASETTORUNGSRESPONSE = _descriptor.Descriptor(
  name='DsSplitDatasetToRungsResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13328,
  serialized_end=13359,
)


_DSSPLITDATASETRESPONSE = _descriptor.Descriptor(
  name='DsSplitDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='training', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse.training', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='testing', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse.testing', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validation', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse.validation', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13361,
  serialized_end=13440,
)


_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSCREATECOLUMNPROFILEREQUEST = _descriptor.Descriptor(
  name='DsCreateColumnProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.bucket', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnType', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.columnType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='columnName', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.columnName', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13443,
  serialized_end=14180,
)


_DSCREATECOLUMNPROFILERESPONSE = _descriptor.Descriptor(
  name='DsCreateColumnProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plot', full_name='github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse.plot', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14182,
  serialized_end=14297,
)


_DSDATASETPROFILEREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSDATASETPROFILEREQUEST = _descriptor.Descriptor(
  name='DsDatasetProfileRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.bucket', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quick', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.quick', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSDATASETPROFILEREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14300,
  serialized_end=15002,
)


_DSDATASETPROFILERESPONSE = _descriptor.Descriptor(
  name='DsDatasetProfileResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileResponse.profile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15004,
  serialized_end=15113,
)


_DSINFERSCHEMAREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSINFERSCHEMAREQUEST = _descriptor.Descriptor(
  name='DsInferSchemaRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatfile', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.flatfile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSINFERSCHEMAREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15116,
  serialized_end=15628,
)


_DSINFERSCHEMARESPONSE = _descriptor.Descriptor(
  name='DsInferSchemaResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse.profile', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15630,
  serialized_end=15736,
)


_DSGETTABLEVIEWREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSGETTABLEVIEWREQUEST = _descriptor.Descriptor(
  name='DsGetTableViewRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flatfile', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.flatfile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.connection', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSGETTABLEVIEWREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15739,
  serialized_end=16253,
)


_DSGETTABLEVIEWRESPONSE = _descriptor.Descriptor(
  name='DsGetTableViewResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableview', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse.tableview', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16255,
  serialized_end=16359,
)


_DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSGETMISCLASSTABLEVIEWREQUEST = _descriptor.Descriptor(
  name='DsGetMisclassTableViewRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.bucket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.secret', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.key', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16362,
  serialized_end=16733,
)


_DSGETMISCLASSTABLEVIEWRESPONSE = _descriptor.Descriptor(
  name='DsGetMisclassTableViewResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableview', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse.tableview', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16735,
  serialized_end=16847,
)


_CREATEMODELREPORTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_CREATEMODELREPORTREQUEST = _descriptor.Descriptor(
  name='CreateModelReportRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.study', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.datasource', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.connection', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.secret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.bucket', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.report', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEMODELREPORTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16850,
  serialized_end=17781,
)


_CREATEFORECASTREPORTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_CREATEFORECASTREPORTREQUEST = _descriptor.Descriptor(
  name='CreateForecastReportRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.study', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.datasource', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forecast', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.forecast', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.connection', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.secret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.bucket', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.report', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEFORECASTREPORTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17784,
  serialized_end=18724,
)


_CREATESUMMARYREPORTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_CREATESUMMARYREPORTREQUEST = _descriptor.Descriptor(
  name='CreateSummaryReportRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.connection', index=2,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.secret', index=3,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.bucket', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.report', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESUMMARYREPORTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18727,
  serialized_end=19336,
)


_CREATEREPORTRESPONSE = _descriptor.Descriptor(
  name='CreateReportResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pdf', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse.pdf', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19338,
  serialized_end=19373,
)


_CREATEDATASETREPORTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_CREATEDATASETREPORTREQUEST = _descriptor.Descriptor(
  name='CreateDatasetReportRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.connection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.bucket', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.secret', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.report', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEDATASETREPORTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19376,
  serialized_end=20151,
)


_CREATESTUDYREPORTREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_CREATESTUDYREPORTREQUEST = _descriptor.Descriptor(
  name='CreateStudyReportRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.study', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.datasource', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='models', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.models', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.bucket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.connection', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.secret', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.report', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATESTUDYREPORTREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20154,
  serialized_end=21090,
)


_ASKMODELREQUEST = _descriptor.Descriptor(
  name='AskModelRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.study', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.datasource', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='budget', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelRequest.budget', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21093,
  serialized_end=21547,
)


_ASKMODELRESPONSE = _descriptor.Descriptor(
  name='AskModelResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.AskModelResponse.model', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21549,
  serialized_end=21647,
)


_TELLMODELREQUEST = _descriptor.Descriptor(
  name='TellModelRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.study', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.datasource', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.dataset', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21650,
  serialized_end=22169,
)


_TELLMODELRESPONSE = _descriptor.Descriptor(
  name='TellModelResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.TellModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22171,
  serialized_end=22190,
)


_DSSHUTDOWNREQUEST = _descriptor.Descriptor(
  name='DsShutdownRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22192,
  serialized_end=22211,
)


_DSSHUTDOWNRESPONSE = _descriptor.Descriptor(
  name='DsShutdownResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22213,
  serialized_end=22233,
)


_VALIDATEMODELREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_VALIDATEMODELREQUEST = _descriptor.Descriptor(
  name='ValidateModelRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.model', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='predictor', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.predictor', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.connection', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.bucket', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.secret', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_VALIDATEMODELREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22236,
  serialized_end=23166,
)


_VALIDATEMODELRESPONSE = _descriptor.Descriptor(
  name='ValidateModelResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse.result', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23168,
  serialized_end=23288,
)


_DSTESTCONNECTIONREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSTESTCONNECTIONREQUEST = _descriptor.Descriptor(
  name='DsTestConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.bucket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.secret', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSTESTCONNECTIONREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23291,
  serialized_end=23637,
)


_DSTESTCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='DsTestConnectionResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse.status', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23639,
  serialized_end=23694,
)


_DSSTUDYENDEDREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSSTUDYENDEDREQUEST = _descriptor.Descriptor(
  name='DsStudyEndedRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.bucket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.secret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSSTUDYENDEDREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23697,
  serialized_end=24456,
)


_DSSTUDYENDEDRESPONSE = _descriptor.Descriptor(
  name='DsStudyEndedResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24458,
  serialized_end=24480,
)


_SAVEOPTIMIZERDBREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_SAVEOPTIMIZERDBREQUEST = _descriptor.Descriptor(
  name='SaveOptimizerDBRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='study', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.study', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.connection', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.bucket', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.secret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SAVEOPTIMIZERDBREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24483,
  serialized_end=25248,
)


_SAVEOPTIMIZERDBRESPONSE = _descriptor.Descriptor(
  name='SaveOptimizerDBResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25250,
  serialized_end=25275,
)


_DSGETDATABASESREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSGETDATABASESREQUEST = _descriptor.Descriptor(
  name='DsGetDatabasesRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.secret', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSGETDATABASESREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25278,
  serialized_end=25534,
)


_DSGETDATABASESRESPONSE = _descriptor.Descriptor(
  name='DsGetDatabasesResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='databases', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse.databases', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25536,
  serialized_end=25579,
)


_DSGETTABLESREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSGETTABLESREQUEST = _descriptor.Descriptor(
  name='DsGetTablesRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.secret', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databaseName', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.databaseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSGETTABLESREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25582,
  serialized_end=25854,
)


_DSGETTABLESRESPONSE = _descriptor.Descriptor(
  name='DsGetTablesResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse.tables', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25856,
  serialized_end=25893,
)


_DSEXECUTESQLREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1008,
)

_DSEXECUTESQLREQUEST = _descriptor.Descriptor(
  name='DsExecuteSqlRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.connection', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.secret', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='databaseName', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.databaseName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sql', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.sql', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSEXECUTESQLREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25896,
  serialized_end=26183,
)


_DSEXECUTESQLRESPONSE = _descriptor.Descriptor(
  name='DsExecuteSqlResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tableview', full_name='github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse.tableview', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26185,
  serialized_end=26287,
)


_DSSNAPSHOTREQUEST_DBSECRETENTRY = _descriptor.Descriptor(
  name='DbsecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27142,
  serialized_end=27189,
)

_DSSNAPSHOTREQUEST_STORAGESECRETENTRY = _descriptor.Descriptor(
  name='StoragesecretEntry',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27191,
  serialized_end=27243,
)

_DSSNAPSHOTREQUEST = _descriptor.Descriptor(
  name='DsSnapshotRequest',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.product', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasource', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.datasource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataset', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.dataset', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dbconnection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.dbconnection', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dbsecret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.dbsecret', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageconnection', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.storageconnection', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storagesecret', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.storagesecret', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.bucket', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.key', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DSSNAPSHOTREQUEST_DBSECRETENTRY, _DSSNAPSHOTREQUEST_STORAGESECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26290,
  serialized_end=27243,
)


_DSSNAPSHOTRESPONSE = _descriptor.Descriptor(
  name='DsSnapshotResponse',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27245,
  serialized_end=27265,
)

_DSREADFILEREQUEST_SECRETENTRY.containing_type = _DSREADFILEREQUEST
_DSREADFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSREADFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSREADFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSREADFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSREADFILEREQUEST.fields_by_name['secret'].message_type = _DSREADFILEREQUEST_SECRETENTRY
_DSREADFEATUREREQUEST_SECRETENTRY.containing_type = _DSREADFEATUREREQUEST
_DSREADFEATUREREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSREADFEATUREREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSREADFEATUREREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSREADFEATUREREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSREADFEATUREREQUEST.fields_by_name['secret'].message_type = _DSREADFEATUREREQUEST_SECRETENTRY
_DSWRITEFILEREQUEST_SECRETENTRY.containing_type = _DSWRITEFILEREQUEST
_DSWRITEFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSWRITEFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSWRITEFILEREQUEST.fields_by_name['content'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSWRITEFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSWRITEFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSWRITEFILEREQUEST.fields_by_name['secret'].message_type = _DSWRITEFILEREQUEST_SECRETENTRY
_DSREADAUDIOREQUEST_SECRETENTRY.containing_type = _DSREADAUDIOREQUEST
_DSREADAUDIOREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSREADAUDIOREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSREADAUDIOREQUEST.fields_by_name['secret'].message_type = _DSREADAUDIOREQUEST_SECRETENTRY
_DSREADTEXTCORPUSREQUEST_SECRETENTRY.containing_type = _DSREADTEXTCORPUSREQUEST
_DSREADTEXTCORPUSREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSREADTEXTCORPUSREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSREADTEXTCORPUSREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSREADTEXTCORPUSREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSREADTEXTCORPUSREQUEST.fields_by_name['secret'].message_type = _DSREADTEXTCORPUSREQUEST_SECRETENTRY
_DSREADFROMSTORERESPONSE_SECRETENTRY.containing_type = _DSREADFROMSTORERESPONSE
_DSREADFROMSTORERESPONSE.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSREADFROMSTORERESPONSE.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSREADFROMSTORERESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSREADFROMSTORERESPONSE.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSREADFROMSTORERESPONSE.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSREADFROMSTORERESPONSE.fields_by_name['secret'].message_type = _DSREADFROMSTORERESPONSE_SECRETENTRY
_DSRUNDATAPIPELINEREQUEST.fields_by_name['pipeline'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_DSRUNDATAPIPELINERESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSRUNRECIPEREQUEST_SECRETENTRY.containing_type = _DSRUNRECIPEREQUEST
_DSRUNRECIPEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSRUNRECIPEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSRUNRECIPEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSRUNRECIPEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSRUNRECIPEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSRUNRECIPEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSRUNRECIPEREQUEST.fields_by_name['secret'].message_type = _DSRUNRECIPEREQUEST_SECRETENTRY
_DSRUNRECIPEREQUEST.fields_by_name['recipe'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_DSRUNRECIPEREQUEST.fields_by_name['reciperun'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_DSRUNRECIPERESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_DSCREATERECIPEPROFILEREQUEST_SECRETENTRY.containing_type = _DSCREATERECIPEPROFILEREQUEST
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['secret'].message_type = _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY
_DSCREATERECIPEPROFILEREQUEST.fields_by_name['recipe'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_DSCREATERECIPEPROFILERESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
_DSCREATEDATASETPROFILEREQUEST_SECRETENTRY.containing_type = _DSCREATEDATASETPROFILEREQUEST
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATEDATASETPROFILEREQUEST.fields_by_name['secret'].message_type = _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY
_DSCREATEDATASETPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_DSCREATEMODELPROFILEREQUEST_SECRETENTRY.containing_type = _DSCREATEMODELPROFILEREQUEST
_DSCREATEMODELPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATEMODELPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATEMODELPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATEMODELPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATEMODELPROFILEREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSCREATEMODELPROFILEREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_DSCREATEMODELPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATEMODELPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATEMODELPROFILEREQUEST.fields_by_name['secret'].message_type = _DSCREATEMODELPROFILEREQUEST_SECRETENTRY
_DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY.containing_type = _DSCREATEFORECASTPARTITIONFILESREQUEST
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['secret'].message_type = _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY
_DSCREATEFORECASTPARTITIONFILESREQUEST.fields_by_name['forecasts'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._FORECASTOBJ
_DSCREATEFORECASTPARTITIONFILESRESPONSE.fields_by_name['partitions'].message_type = _PARTITIONVALUES
_DSMERGEFORECASTFILEREQUEST_SECRETENTRY.containing_type = _DSMERGEFORECASTFILEREQUEST
_DSMERGEFORECASTFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSMERGEFORECASTFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSMERGEFORECASTFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSMERGEFORECASTFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSMERGEFORECASTFILEREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSMERGEFORECASTFILEREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_DSMERGEFORECASTFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSMERGEFORECASTFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSMERGEFORECASTFILEREQUEST.fields_by_name['secret'].message_type = _DSMERGEFORECASTFILEREQUEST_SECRETENTRY
_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY.containing_type = _DSCREATESTUDYPROFILEREQUEST
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['models'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_DSCREATESTUDYPROFILEREQUEST.fields_by_name['secret'].message_type = _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY
_DSVALIDATEDATASETREQUEST_SECRETENTRY.containing_type = _DSVALIDATEDATASETREQUEST
_DSVALIDATEDATASETREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSVALIDATEDATASETREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSVALIDATEDATASETREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSVALIDATEDATASETREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSVALIDATEDATASETREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSVALIDATEDATASETREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSVALIDATEDATASETREQUEST.fields_by_name['secret'].message_type = _DSVALIDATEDATASETREQUEST_SECRETENTRY
_DSVALIDATEDATASETRESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAVALIDATIONRESULT
_DSGENERATEDATASETREQUEST_SECRETENTRY.containing_type = _DSGENERATEDATASETREQUEST
_DSGENERATEDATASETREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSGENERATEDATASETREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSGENERATEDATASETREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSGENERATEDATASETREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSGENERATEDATASETREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSGENERATEDATASETREQUEST.fields_by_name['secret'].message_type = _DSGENERATEDATASETREQUEST_SECRETENTRY
_DSSPLITDATASETREQUEST_SECRETENTRY.containing_type = _DSSPLITDATASETREQUEST
_DSSPLITDATASETREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSSPLITDATASETREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSSPLITDATASETREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSSPLITDATASETREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSSPLITDATASETREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSSPLITDATASETREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSSPLITDATASETREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSSPLITDATASETREQUEST.fields_by_name['secret'].message_type = _DSSPLITDATASETREQUEST_SECRETENTRY
_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY.containing_type = _DSSPLITDATASETTORUNGSREQUEST
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSSPLITDATASETTORUNGSREQUEST.fields_by_name['secret'].message_type = _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY
_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY.containing_type = _DSCREATECOLUMNPROFILEREQUEST
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSCREATECOLUMNPROFILEREQUEST.fields_by_name['secret'].message_type = _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY
_DSCREATECOLUMNPROFILERESPONSE.fields_by_name['plot'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._PLOT
_DSDATASETPROFILEREQUEST_SECRETENTRY.containing_type = _DSDATASETPROFILEREQUEST
_DSDATASETPROFILEREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSDATASETPROFILEREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSDATASETPROFILEREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSDATASETPROFILEREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSDATASETPROFILEREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSDATASETPROFILEREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSDATASETPROFILEREQUEST.fields_by_name['secret'].message_type = _DSDATASETPROFILEREQUEST_SECRETENTRY
_DSDATASETPROFILERESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_DSINFERSCHEMAREQUEST_SECRETENTRY.containing_type = _DSINFERSCHEMAREQUEST
_DSINFERSCHEMAREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSINFERSCHEMAREQUEST.fields_by_name['flatfile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FLATFILESPEC
_DSINFERSCHEMAREQUEST.fields_by_name['location'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATALOCATION
_DSINFERSCHEMAREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSINFERSCHEMAREQUEST.fields_by_name['secret'].message_type = _DSINFERSCHEMAREQUEST_SECRETENTRY
_DSINFERSCHEMARESPONSE.fields_by_name['profile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._DATASETPROFILE
_DSGETTABLEVIEWREQUEST_SECRETENTRY.containing_type = _DSGETTABLEVIEWREQUEST
_DSGETTABLEVIEWREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSGETTABLEVIEWREQUEST.fields_by_name['flatfile'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FLATFILESPEC
_DSGETTABLEVIEWREQUEST.fields_by_name['location'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATALOCATION
_DSGETTABLEVIEWREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSGETTABLEVIEWREQUEST.fields_by_name['secret'].message_type = _DSGETTABLEVIEWREQUEST_SECRETENTRY
_DSGETTABLEVIEWRESPONSE.fields_by_name['tableview'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
_DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY.containing_type = _DSGETMISCLASSTABLEVIEWREQUEST
_DSGETMISCLASSTABLEVIEWREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSGETMISCLASSTABLEVIEWREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSGETMISCLASSTABLEVIEWREQUEST.fields_by_name['secret'].message_type = _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY
_DSGETMISCLASSTABLEVIEWRESPONSE.fields_by_name['tableview'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
_CREATEMODELREPORTREQUEST_SECRETENTRY.containing_type = _CREATEMODELREPORTREQUEST
_CREATEMODELREPORTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATEMODELREPORTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATEMODELREPORTREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_CREATEMODELREPORTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEMODELREPORTREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_CREATEMODELREPORTREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_CREATEMODELREPORTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATEMODELREPORTREQUEST.fields_by_name['secret'].message_type = _CREATEMODELREPORTREQUEST_SECRETENTRY
_CREATEMODELREPORTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATEMODELREPORTREQUEST.fields_by_name['report'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_CREATEFORECASTREPORTREQUEST_SECRETENTRY.containing_type = _CREATEFORECASTREPORTREQUEST
_CREATEFORECASTREPORTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATEFORECASTREPORTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATEFORECASTREPORTREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_CREATEFORECASTREPORTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEFORECASTREPORTREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_CREATEFORECASTREPORTREQUEST.fields_by_name['forecast'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_CREATEFORECASTREPORTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATEFORECASTREPORTREQUEST.fields_by_name['secret'].message_type = _CREATEFORECASTREPORTREQUEST_SECRETENTRY
_CREATEFORECASTREPORTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATEFORECASTREPORTREQUEST.fields_by_name['report'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_CREATESUMMARYREPORTREQUEST_SECRETENTRY.containing_type = _CREATESUMMARYREPORTREQUEST
_CREATESUMMARYREPORTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATESUMMARYREPORTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATESUMMARYREPORTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATESUMMARYREPORTREQUEST.fields_by_name['secret'].message_type = _CREATESUMMARYREPORTREQUEST_SECRETENTRY
_CREATESUMMARYREPORTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATESUMMARYREPORTREQUEST.fields_by_name['report'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_CREATEDATASETREPORTREQUEST_SECRETENTRY.containing_type = _CREATEDATASETREPORTREQUEST
_CREATEDATASETREPORTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATEDATASETREPORTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATEDATASETREPORTREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_CREATEDATASETREPORTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEDATASETREPORTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATEDATASETREPORTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATEDATASETREPORTREQUEST.fields_by_name['secret'].message_type = _CREATEDATASETREPORTREQUEST_SECRETENTRY
_CREATEDATASETREPORTREQUEST.fields_by_name['report'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_CREATESTUDYREPORTREQUEST_SECRETENTRY.containing_type = _CREATESTUDYREPORTREQUEST
_CREATESTUDYREPORTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATESTUDYREPORTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATESTUDYREPORTREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_CREATESTUDYREPORTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATESTUDYREPORTREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_CREATESTUDYREPORTREQUEST.fields_by_name['models'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELLIST
_CREATESTUDYREPORTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATESTUDYREPORTREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATESTUDYREPORTREQUEST.fields_by_name['secret'].message_type = _CREATESTUDYREPORTREQUEST_SECRETENTRY
_CREATESTUDYREPORTREQUEST.fields_by_name['report'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_ASKMODELREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_ASKMODELREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_ASKMODELREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_ASKMODELREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_ASKMODELREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_ASKMODELRESPONSE.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_TELLMODELREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_TELLMODELREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_TELLMODELREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_TELLMODELREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_TELLMODELREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_TELLMODELREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_VALIDATEMODELREQUEST_SECRETENTRY.containing_type = _VALIDATEMODELREQUEST
_VALIDATEMODELREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_VALIDATEMODELREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_VALIDATEMODELREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_VALIDATEMODELREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_VALIDATEMODELREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_VALIDATEMODELREQUEST.fields_by_name['model'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_VALIDATEMODELREQUEST.fields_by_name['predictor'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_VALIDATEMODELREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_VALIDATEMODELREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_VALIDATEMODELREQUEST.fields_by_name['secret'].message_type = _VALIDATEMODELREQUEST_SECRETENTRY
_VALIDATEMODELRESPONSE.fields_by_name['result'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELVALIDATIONRESULT
_DSTESTCONNECTIONREQUEST_SECRETENTRY.containing_type = _DSTESTCONNECTIONREQUEST
_DSTESTCONNECTIONREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSTESTCONNECTIONREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSTESTCONNECTIONREQUEST.fields_by_name['secret'].message_type = _DSTESTCONNECTIONREQUEST_SECRETENTRY
_DSSTUDYENDEDREQUEST_SECRETENTRY.containing_type = _DSSTUDYENDEDREQUEST
_DSSTUDYENDEDREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSSTUDYENDEDREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSSTUDYENDEDREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSSTUDYENDEDREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSSTUDYENDEDREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_DSSTUDYENDEDREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSSTUDYENDEDREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_DSSTUDYENDEDREQUEST.fields_by_name['secret'].message_type = _DSSTUDYENDEDREQUEST_SECRETENTRY
_SAVEOPTIMIZERDBREQUEST_SECRETENTRY.containing_type = _SAVEOPTIMIZERDBREQUEST
_SAVEOPTIMIZERDBREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_SAVEOPTIMIZERDBREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_SAVEOPTIMIZERDBREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_SAVEOPTIMIZERDBREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_SAVEOPTIMIZERDBREQUEST.fields_by_name['study'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_SAVEOPTIMIZERDBREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_SAVEOPTIMIZERDBREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_SAVEOPTIMIZERDBREQUEST.fields_by_name['secret'].message_type = _SAVEOPTIMIZERDBREQUEST_SECRETENTRY
_DSGETDATABASESREQUEST_SECRETENTRY.containing_type = _DSGETDATABASESREQUEST
_DSGETDATABASESREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSGETDATABASESREQUEST.fields_by_name['secret'].message_type = _DSGETDATABASESREQUEST_SECRETENTRY
_DSGETTABLESREQUEST_SECRETENTRY.containing_type = _DSGETTABLESREQUEST
_DSGETTABLESREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSGETTABLESREQUEST.fields_by_name['secret'].message_type = _DSGETTABLESREQUEST_SECRETENTRY
_DSEXECUTESQLREQUEST_SECRETENTRY.containing_type = _DSEXECUTESQLREQUEST
_DSEXECUTESQLREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSEXECUTESQLREQUEST.fields_by_name['secret'].message_type = _DSEXECUTESQLREQUEST_SECRETENTRY
_DSEXECUTESQLRESPONSE.fields_by_name['tableview'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
_DSSNAPSHOTREQUEST_DBSECRETENTRY.containing_type = _DSSNAPSHOTREQUEST
_DSSNAPSHOTREQUEST_STORAGESECRETENTRY.containing_type = _DSSNAPSHOTREQUEST
_DSSNAPSHOTREQUEST.fields_by_name['product'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_DSSNAPSHOTREQUEST.fields_by_name['version'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_DSSNAPSHOTREQUEST.fields_by_name['datasource'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_DSSNAPSHOTREQUEST.fields_by_name['dataset'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_DSSNAPSHOTREQUEST.fields_by_name['dbconnection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSSNAPSHOTREQUEST.fields_by_name['dbsecret'].message_type = _DSSNAPSHOTREQUEST_DBSECRETENTRY
_DSSNAPSHOTREQUEST.fields_by_name['storageconnection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_DSSNAPSHOTREQUEST.fields_by_name['storagesecret'].message_type = _DSSNAPSHOTREQUEST_STORAGESECRETENTRY
_DSSNAPSHOTREQUEST.fields_by_name['bucket'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
DESCRIPTOR.message_types_by_name['DsReadFileRequest'] = _DSREADFILEREQUEST
DESCRIPTOR.message_types_by_name['DsReadFeatureRequest'] = _DSREADFEATUREREQUEST
DESCRIPTOR.message_types_by_name['DsWriteFileRequest'] = _DSWRITEFILEREQUEST
DESCRIPTOR.message_types_by_name['DsReadAudioRequest'] = _DSREADAUDIOREQUEST
DESCRIPTOR.message_types_by_name['DsReadTextCorpusRequest'] = _DSREADTEXTCORPUSREQUEST
DESCRIPTOR.message_types_by_name['DsReadFromStoreResponse'] = _DSREADFROMSTORERESPONSE
DESCRIPTOR.message_types_by_name['DsRunDataPipelineRequest'] = _DSRUNDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DsRunDataPipelineResponse'] = _DSRUNDATAPIPELINERESPONSE
DESCRIPTOR.message_types_by_name['DsRunRecipeRequest'] = _DSRUNRECIPEREQUEST
DESCRIPTOR.message_types_by_name['DsRunRecipeResponse'] = _DSRUNRECIPERESPONSE
DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileRequest'] = _DSCREATERECIPEPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsCreateRecipeProfileResponse'] = _DSCREATERECIPEPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DataSourceResponse'] = _DATASOURCERESPONSE
DESCRIPTOR.message_types_by_name['DatasetResponse'] = _DATASETRESPONSE
DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileRequest'] = _DSCREATEDATASETPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsCreateDatasetProfileResponse'] = _DSCREATEDATASETPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DsCreateModelProfileRequest'] = _DSCREATEMODELPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsCreateModelProfileResponse'] = _DSCREATEMODELPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DsCreateForecastPartitionFilesRequest'] = _DSCREATEFORECASTPARTITIONFILESREQUEST
DESCRIPTOR.message_types_by_name['DsCreateForecastPartitionFilesResponse'] = _DSCREATEFORECASTPARTITIONFILESRESPONSE
DESCRIPTOR.message_types_by_name['PartitionValues'] = _PARTITIONVALUES
DESCRIPTOR.message_types_by_name['DsMergeForecastFileRequest'] = _DSMERGEFORECASTFILEREQUEST
DESCRIPTOR.message_types_by_name['DsMergeForecastFileResponse'] = _DSMERGEFORECASTFILERESPONSE
DESCRIPTOR.message_types_by_name['DsCreateStudyProfileRequest'] = _DSCREATESTUDYPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsCreateStudyProfileResponse'] = _DSCREATESTUDYPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DsValidateDatasetRequest'] = _DSVALIDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['DsValidateDatasetResponse'] = _DSVALIDATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DsGenerateDatasetRequest'] = _DSGENERATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['DsGenerateDatasetResponse'] = _DSGENERATEDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DsSplitDatasetRequest'] = _DSSPLITDATASETREQUEST
DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsRequest'] = _DSSPLITDATASETTORUNGSREQUEST
DESCRIPTOR.message_types_by_name['DsSplitDatasetToRungsResponse'] = _DSSPLITDATASETTORUNGSRESPONSE
DESCRIPTOR.message_types_by_name['DsSplitDatasetResponse'] = _DSSPLITDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DsCreateColumnProfileRequest'] = _DSCREATECOLUMNPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsCreateColumnProfileResponse'] = _DSCREATECOLUMNPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DsDatasetProfileRequest'] = _DSDATASETPROFILEREQUEST
DESCRIPTOR.message_types_by_name['DsDatasetProfileResponse'] = _DSDATASETPROFILERESPONSE
DESCRIPTOR.message_types_by_name['DsInferSchemaRequest'] = _DSINFERSCHEMAREQUEST
DESCRIPTOR.message_types_by_name['DsInferSchemaResponse'] = _DSINFERSCHEMARESPONSE
DESCRIPTOR.message_types_by_name['DsGetTableViewRequest'] = _DSGETTABLEVIEWREQUEST
DESCRIPTOR.message_types_by_name['DsGetTableViewResponse'] = _DSGETTABLEVIEWRESPONSE
DESCRIPTOR.message_types_by_name['DsGetMisclassTableViewRequest'] = _DSGETMISCLASSTABLEVIEWREQUEST
DESCRIPTOR.message_types_by_name['DsGetMisclassTableViewResponse'] = _DSGETMISCLASSTABLEVIEWRESPONSE
DESCRIPTOR.message_types_by_name['CreateModelReportRequest'] = _CREATEMODELREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateForecastReportRequest'] = _CREATEFORECASTREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateSummaryReportRequest'] = _CREATESUMMARYREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateReportResponse'] = _CREATEREPORTRESPONSE
DESCRIPTOR.message_types_by_name['CreateDatasetReportRequest'] = _CREATEDATASETREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateStudyReportRequest'] = _CREATESTUDYREPORTREQUEST
DESCRIPTOR.message_types_by_name['AskModelRequest'] = _ASKMODELREQUEST
DESCRIPTOR.message_types_by_name['AskModelResponse'] = _ASKMODELRESPONSE
DESCRIPTOR.message_types_by_name['TellModelRequest'] = _TELLMODELREQUEST
DESCRIPTOR.message_types_by_name['TellModelResponse'] = _TELLMODELRESPONSE
DESCRIPTOR.message_types_by_name['DsShutdownRequest'] = _DSSHUTDOWNREQUEST
DESCRIPTOR.message_types_by_name['DsShutdownResponse'] = _DSSHUTDOWNRESPONSE
DESCRIPTOR.message_types_by_name['ValidateModelRequest'] = _VALIDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['ValidateModelResponse'] = _VALIDATEMODELRESPONSE
DESCRIPTOR.message_types_by_name['DsTestConnectionRequest'] = _DSTESTCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DsTestConnectionResponse'] = _DSTESTCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DsStudyEndedRequest'] = _DSSTUDYENDEDREQUEST
DESCRIPTOR.message_types_by_name['DsStudyEndedResponse'] = _DSSTUDYENDEDRESPONSE
DESCRIPTOR.message_types_by_name['SaveOptimizerDBRequest'] = _SAVEOPTIMIZERDBREQUEST
DESCRIPTOR.message_types_by_name['SaveOptimizerDBResponse'] = _SAVEOPTIMIZERDBRESPONSE
DESCRIPTOR.message_types_by_name['DsGetDatabasesRequest'] = _DSGETDATABASESREQUEST
DESCRIPTOR.message_types_by_name['DsGetDatabasesResponse'] = _DSGETDATABASESRESPONSE
DESCRIPTOR.message_types_by_name['DsGetTablesRequest'] = _DSGETTABLESREQUEST
DESCRIPTOR.message_types_by_name['DsGetTablesResponse'] = _DSGETTABLESRESPONSE
DESCRIPTOR.message_types_by_name['DsExecuteSqlRequest'] = _DSEXECUTESQLREQUEST
DESCRIPTOR.message_types_by_name['DsExecuteSqlResponse'] = _DSEXECUTESQLRESPONSE
DESCRIPTOR.message_types_by_name['DsSnapshotRequest'] = _DSSNAPSHOTREQUEST
DESCRIPTOR.message_types_by_name['DsSnapshotResponse'] = _DSSNAPSHOTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DsReadFileRequest = _reflection.GeneratedProtocolMessageType('DsReadFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFileRequest)
  })
_sym_db.RegisterMessage(DsReadFileRequest)
_sym_db.RegisterMessage(DsReadFileRequest.SecretEntry)

DsReadFeatureRequest = _reflection.GeneratedProtocolMessageType('DsReadFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFeatureRequest)
  })
_sym_db.RegisterMessage(DsReadFeatureRequest)
_sym_db.RegisterMessage(DsReadFeatureRequest.SecretEntry)

DsWriteFileRequest = _reflection.GeneratedProtocolMessageType('DsWriteFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSWRITEFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSWRITEFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsWriteFileRequest)
  })
_sym_db.RegisterMessage(DsWriteFileRequest)
_sym_db.RegisterMessage(DsWriteFileRequest.SecretEntry)

DsReadAudioRequest = _reflection.GeneratedProtocolMessageType('DsReadAudioRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADAUDIOREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADAUDIOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadAudioRequest)
  })
_sym_db.RegisterMessage(DsReadAudioRequest)
_sym_db.RegisterMessage(DsReadAudioRequest.SecretEntry)

DsReadTextCorpusRequest = _reflection.GeneratedProtocolMessageType('DsReadTextCorpusRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADTEXTCORPUSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadTextCorpusRequest)
  })
_sym_db.RegisterMessage(DsReadTextCorpusRequest)
_sym_db.RegisterMessage(DsReadTextCorpusRequest.SecretEntry)

DsReadFromStoreResponse = _reflection.GeneratedProtocolMessageType('DsReadFromStoreResponse', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSREADFROMSTORERESPONSE_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSREADFROMSTORERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsReadFromStoreResponse)
  })
_sym_db.RegisterMessage(DsReadFromStoreResponse)
_sym_db.RegisterMessage(DsReadFromStoreResponse.SecretEntry)

DsRunDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineRequest)
  })
_sym_db.RegisterMessage(DsRunDataPipelineRequest)

DsRunDataPipelineResponse = _reflection.GeneratedProtocolMessageType('DsRunDataPipelineResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNDATAPIPELINERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunDataPipelineResponse)
  })
_sym_db.RegisterMessage(DsRunDataPipelineResponse)

DsRunRecipeRequest = _reflection.GeneratedProtocolMessageType('DsRunRecipeRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSRUNRECIPEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSRUNRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeRequest)
  })
_sym_db.RegisterMessage(DsRunRecipeRequest)
_sym_db.RegisterMessage(DsRunRecipeRequest.SecretEntry)

DsRunRecipeResponse = _reflection.GeneratedProtocolMessageType('DsRunRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSRUNRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsRunRecipeResponse)
  })
_sym_db.RegisterMessage(DsRunRecipeResponse)

DsCreateRecipeProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATERECIPEPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest)
_sym_db.RegisterMessage(DsCreateRecipeProfileRequest.SecretEntry)

DsCreateRecipeProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateRecipeProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATERECIPEPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateRecipeProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateRecipeProfileResponse)

DataSourceResponse = _reflection.GeneratedProtocolMessageType('DataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DataSourceResponse)
  })
_sym_db.RegisterMessage(DataSourceResponse)

DatasetResponse = _reflection.GeneratedProtocolMessageType('DatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DatasetResponse)
  })
_sym_db.RegisterMessage(DatasetResponse)

DsCreateDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest)
_sym_db.RegisterMessage(DsCreateDatasetProfileRequest.SecretEntry)

DsCreateDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateDatasetProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateDatasetProfileResponse)

DsCreateModelProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEMODELPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateModelProfileRequest)
_sym_db.RegisterMessage(DsCreateModelProfileRequest.SecretEntry)

DsCreateModelProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateModelProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEMODELPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateModelProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateModelProfileResponse)

DsCreateForecastPartitionFilesRequest = _reflection.GeneratedProtocolMessageType('DsCreateForecastPartitionFilesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesRequest)
  })
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesRequest)
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesRequest.SecretEntry)

DsCreateForecastPartitionFilesResponse = _reflection.GeneratedProtocolMessageType('DsCreateForecastPartitionFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATEFORECASTPARTITIONFILESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateForecastPartitionFilesResponse)
  })
_sym_db.RegisterMessage(DsCreateForecastPartitionFilesResponse)

PartitionValues = _reflection.GeneratedProtocolMessageType('PartitionValues', (_message.Message,), {
  'DESCRIPTOR' : _PARTITIONVALUES,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.PartitionValues)
  })
_sym_db.RegisterMessage(PartitionValues)

DsMergeForecastFileRequest = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSMERGEFORECASTFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileRequest)
  })
_sym_db.RegisterMessage(DsMergeForecastFileRequest)
_sym_db.RegisterMessage(DsMergeForecastFileRequest.SecretEntry)

DsMergeForecastFileResponse = _reflection.GeneratedProtocolMessageType('DsMergeForecastFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSMERGEFORECASTFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsMergeForecastFileResponse)
  })
_sym_db.RegisterMessage(DsMergeForecastFileResponse)

DsCreateStudyProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATESTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileRequest)
_sym_db.RegisterMessage(DsCreateStudyProfileRequest.SecretEntry)

DsCreateStudyProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATESTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateStudyProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateStudyProfileResponse)

DsValidateDatasetRequest = _reflection.GeneratedProtocolMessageType('DsValidateDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSVALIDATEDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSVALIDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetRequest)
  })
_sym_db.RegisterMessage(DsValidateDatasetRequest)
_sym_db.RegisterMessage(DsValidateDatasetRequest.SecretEntry)

DsValidateDatasetResponse = _reflection.GeneratedProtocolMessageType('DsValidateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSVALIDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsValidateDatasetResponse)
  })
_sym_db.RegisterMessage(DsValidateDatasetResponse)

DsGenerateDatasetRequest = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGENERATEDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGENERATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetRequest)
  })
_sym_db.RegisterMessage(DsGenerateDatasetRequest)
_sym_db.RegisterMessage(DsGenerateDatasetRequest.SecretEntry)

DsGenerateDatasetResponse = _reflection.GeneratedProtocolMessageType('DsGenerateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGENERATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGenerateDatasetResponse)
  })
_sym_db.RegisterMessage(DsGenerateDatasetResponse)

DsSplitDatasetRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetRequest)
_sym_db.RegisterMessage(DsSplitDatasetRequest.SecretEntry)

DsSplitDatasetToRungsRequest = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsRequest)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest)
_sym_db.RegisterMessage(DsSplitDatasetToRungsRequest.SecretEntry)

DsSplitDatasetToRungsResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetToRungsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETTORUNGSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetToRungsResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetToRungsResponse)

DsSplitDatasetResponse = _reflection.GeneratedProtocolMessageType('DsSplitDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSPLITDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSplitDatasetResponse)
  })
_sym_db.RegisterMessage(DsSplitDatasetResponse)

DsCreateColumnProfileRequest = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileRequest)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileRequest)
_sym_db.RegisterMessage(DsCreateColumnProfileRequest.SecretEntry)

DsCreateColumnProfileResponse = _reflection.GeneratedProtocolMessageType('DsCreateColumnProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSCREATECOLUMNPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsCreateColumnProfileResponse)
  })
_sym_db.RegisterMessage(DsCreateColumnProfileResponse)

DsDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('DsDatasetProfileRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSDATASETPROFILEREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileRequest)
  })
_sym_db.RegisterMessage(DsDatasetProfileRequest)
_sym_db.RegisterMessage(DsDatasetProfileRequest.SecretEntry)

DsDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('DsDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsDatasetProfileResponse)
  })
_sym_db.RegisterMessage(DsDatasetProfileResponse)

DsInferSchemaRequest = _reflection.GeneratedProtocolMessageType('DsInferSchemaRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSINFERSCHEMAREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSINFERSCHEMAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaRequest)
  })
_sym_db.RegisterMessage(DsInferSchemaRequest)
_sym_db.RegisterMessage(DsInferSchemaRequest.SecretEntry)

DsInferSchemaResponse = _reflection.GeneratedProtocolMessageType('DsInferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSINFERSCHEMARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsInferSchemaResponse)
  })
_sym_db.RegisterMessage(DsInferSchemaResponse)

DsGetTableViewRequest = _reflection.GeneratedProtocolMessageType('DsGetTableViewRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewRequest)
  })
_sym_db.RegisterMessage(DsGetTableViewRequest)
_sym_db.RegisterMessage(DsGetTableViewRequest.SecretEntry)

DsGetTableViewResponse = _reflection.GeneratedProtocolMessageType('DsGetTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTableViewResponse)
  })
_sym_db.RegisterMessage(DsGetTableViewResponse)

DsGetMisclassTableViewRequest = _reflection.GeneratedProtocolMessageType('DsGetMisclassTableViewRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewRequest)
  })
_sym_db.RegisterMessage(DsGetMisclassTableViewRequest)
_sym_db.RegisterMessage(DsGetMisclassTableViewRequest.SecretEntry)

DsGetMisclassTableViewResponse = _reflection.GeneratedProtocolMessageType('DsGetMisclassTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETMISCLASSTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetMisclassTableViewResponse)
  })
_sym_db.RegisterMessage(DsGetMisclassTableViewResponse)

CreateModelReportRequest = _reflection.GeneratedProtocolMessageType('CreateModelReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEMODELREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEMODELREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateModelReportRequest)
  })
_sym_db.RegisterMessage(CreateModelReportRequest)
_sym_db.RegisterMessage(CreateModelReportRequest.SecretEntry)

CreateForecastReportRequest = _reflection.GeneratedProtocolMessageType('CreateForecastReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFORECASTREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateForecastReportRequest)
  })
_sym_db.RegisterMessage(CreateForecastReportRequest)
_sym_db.RegisterMessage(CreateForecastReportRequest.SecretEntry)

CreateSummaryReportRequest = _reflection.GeneratedProtocolMessageType('CreateSummaryReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESUMMARYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateSummaryReportRequest)
  })
_sym_db.RegisterMessage(CreateSummaryReportRequest)
_sym_db.RegisterMessage(CreateSummaryReportRequest.SecretEntry)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

CreateDatasetReportRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEDATASETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateDatasetReportRequest)
  })
_sym_db.RegisterMessage(CreateDatasetReportRequest)
_sym_db.RegisterMessage(CreateDatasetReportRequest.SecretEntry)

CreateStudyReportRequest = _reflection.GeneratedProtocolMessageType('CreateStudyReportRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATESTUDYREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.CreateStudyReportRequest)
  })
_sym_db.RegisterMessage(CreateStudyReportRequest)
_sym_db.RegisterMessage(CreateStudyReportRequest.SecretEntry)

AskModelRequest = _reflection.GeneratedProtocolMessageType('AskModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelRequest)
  })
_sym_db.RegisterMessage(AskModelRequest)

AskModelResponse = _reflection.GeneratedProtocolMessageType('AskModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _ASKMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.AskModelResponse)
  })
_sym_db.RegisterMessage(AskModelResponse)

TellModelRequest = _reflection.GeneratedProtocolMessageType('TellModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelRequest)
  })
_sym_db.RegisterMessage(TellModelRequest)

TellModelResponse = _reflection.GeneratedProtocolMessageType('TellModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _TELLMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.TellModelResponse)
  })
_sym_db.RegisterMessage(TellModelResponse)

DsShutdownRequest = _reflection.GeneratedProtocolMessageType('DsShutdownRequest', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownRequest)
  })
_sym_db.RegisterMessage(DsShutdownRequest)

DsShutdownResponse = _reflection.GeneratedProtocolMessageType('DsShutdownResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSHUTDOWNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsShutdownResponse)
  })
_sym_db.RegisterMessage(DsShutdownResponse)

ValidateModelRequest = _reflection.GeneratedProtocolMessageType('ValidateModelRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _VALIDATEMODELREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _VALIDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelRequest)
  })
_sym_db.RegisterMessage(ValidateModelRequest)
_sym_db.RegisterMessage(ValidateModelRequest.SecretEntry)

ValidateModelResponse = _reflection.GeneratedProtocolMessageType('ValidateModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.ValidateModelResponse)
  })
_sym_db.RegisterMessage(ValidateModelResponse)

DsTestConnectionRequest = _reflection.GeneratedProtocolMessageType('DsTestConnectionRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSTESTCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionRequest)
  })
_sym_db.RegisterMessage(DsTestConnectionRequest)
_sym_db.RegisterMessage(DsTestConnectionRequest.SecretEntry)

DsTestConnectionResponse = _reflection.GeneratedProtocolMessageType('DsTestConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSTESTCONNECTIONRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsTestConnectionResponse)
  })
_sym_db.RegisterMessage(DsTestConnectionResponse)

DsStudyEndedRequest = _reflection.GeneratedProtocolMessageType('DsStudyEndedRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSTUDYENDEDREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSTUDYENDEDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedRequest)
  })
_sym_db.RegisterMessage(DsStudyEndedRequest)
_sym_db.RegisterMessage(DsStudyEndedRequest.SecretEntry)

DsStudyEndedResponse = _reflection.GeneratedProtocolMessageType('DsStudyEndedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSTUDYENDEDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsStudyEndedResponse)
  })
_sym_db.RegisterMessage(DsStudyEndedResponse)

SaveOptimizerDBRequest = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _SAVEOPTIMIZERDBREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBRequest)
  })
_sym_db.RegisterMessage(SaveOptimizerDBRequest)
_sym_db.RegisterMessage(SaveOptimizerDBRequest.SecretEntry)

SaveOptimizerDBResponse = _reflection.GeneratedProtocolMessageType('SaveOptimizerDBResponse', (_message.Message,), {
  'DESCRIPTOR' : _SAVEOPTIMIZERDBRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.SaveOptimizerDBResponse)
  })
_sym_db.RegisterMessage(SaveOptimizerDBResponse)

DsGetDatabasesRequest = _reflection.GeneratedProtocolMessageType('DsGetDatabasesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETDATABASESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETDATABASESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesRequest)
  })
_sym_db.RegisterMessage(DsGetDatabasesRequest)
_sym_db.RegisterMessage(DsGetDatabasesRequest.SecretEntry)

DsGetDatabasesResponse = _reflection.GeneratedProtocolMessageType('DsGetDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETDATABASESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetDatabasesResponse)
  })
_sym_db.RegisterMessage(DsGetDatabasesResponse)

DsGetTablesRequest = _reflection.GeneratedProtocolMessageType('DsGetTablesRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSGETTABLESREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSGETTABLESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesRequest)
  })
_sym_db.RegisterMessage(DsGetTablesRequest)
_sym_db.RegisterMessage(DsGetTablesRequest.SecretEntry)

DsGetTablesResponse = _reflection.GeneratedProtocolMessageType('DsGetTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSGETTABLESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsGetTablesResponse)
  })
_sym_db.RegisterMessage(DsGetTablesResponse)

DsExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('DsExecuteSqlRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSEXECUTESQLREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSEXECUTESQLREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlRequest)
  })
_sym_db.RegisterMessage(DsExecuteSqlRequest)
_sym_db.RegisterMessage(DsExecuteSqlRequest.SecretEntry)

DsExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('DsExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSEXECUTESQLRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsExecuteSqlResponse)
  })
_sym_db.RegisterMessage(DsExecuteSqlResponse)

DsSnapshotRequest = _reflection.GeneratedProtocolMessageType('DsSnapshotRequest', (_message.Message,), {

  'DbsecretEntry' : _reflection.GeneratedProtocolMessageType('DbsecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_DBSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.DbsecretEntry)
    })
  ,

  'StoragesecretEntry' : _reflection.GeneratedProtocolMessageType('StoragesecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _DSSNAPSHOTREQUEST_STORAGESECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest.StoragesecretEntry)
    })
  ,
  'DESCRIPTOR' : _DSSNAPSHOTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotRequest)
  })
_sym_db.RegisterMessage(DsSnapshotRequest)
_sym_db.RegisterMessage(DsSnapshotRequest.DbsecretEntry)
_sym_db.RegisterMessage(DsSnapshotRequest.StoragesecretEntry)

DsSnapshotResponse = _reflection.GeneratedProtocolMessageType('DsSnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _DSSNAPSHOTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.data.v1.data_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.data.v1.DsSnapshotResponse)
  })
_sym_db.RegisterMessage(DsSnapshotResponse)


DESCRIPTOR._options = None
_DSREADFILEREQUEST_SECRETENTRY._options = None
_DSREADFEATUREREQUEST_SECRETENTRY._options = None
_DSWRITEFILEREQUEST_SECRETENTRY._options = None
_DSREADAUDIOREQUEST_SECRETENTRY._options = None
_DSREADTEXTCORPUSREQUEST_SECRETENTRY._options = None
_DSREADFROMSTORERESPONSE_SECRETENTRY._options = None
_DSRUNRECIPEREQUEST_SECRETENTRY._options = None
_DSCREATERECIPEPROFILEREQUEST_SECRETENTRY._options = None
_DSCREATEDATASETPROFILEREQUEST_SECRETENTRY._options = None
_DSCREATEMODELPROFILEREQUEST_SECRETENTRY._options = None
_DSCREATEFORECASTPARTITIONFILESREQUEST_SECRETENTRY._options = None
_DSMERGEFORECASTFILEREQUEST_SECRETENTRY._options = None
_DSCREATESTUDYPROFILEREQUEST_SECRETENTRY._options = None
_DSVALIDATEDATASETREQUEST_SECRETENTRY._options = None
_DSGENERATEDATASETREQUEST_SECRETENTRY._options = None
_DSSPLITDATASETREQUEST_SECRETENTRY._options = None
_DSSPLITDATASETTORUNGSREQUEST_SECRETENTRY._options = None
_DSCREATECOLUMNPROFILEREQUEST_SECRETENTRY._options = None
_DSDATASETPROFILEREQUEST_SECRETENTRY._options = None
_DSINFERSCHEMAREQUEST_SECRETENTRY._options = None
_DSGETTABLEVIEWREQUEST_SECRETENTRY._options = None
_DSGETMISCLASSTABLEVIEWREQUEST_SECRETENTRY._options = None
_CREATEMODELREPORTREQUEST_SECRETENTRY._options = None
_CREATEFORECASTREPORTREQUEST_SECRETENTRY._options = None
_CREATESUMMARYREPORTREQUEST_SECRETENTRY._options = None
_CREATEDATASETREPORTREQUEST_SECRETENTRY._options = None
_CREATESTUDYREPORTREQUEST_SECRETENTRY._options = None
_VALIDATEMODELREQUEST_SECRETENTRY._options = None
_DSTESTCONNECTIONREQUEST_SECRETENTRY._options = None
_DSSTUDYENDEDREQUEST_SECRETENTRY._options = None
_SAVEOPTIMIZERDBREQUEST_SECRETENTRY._options = None
_DSGETDATABASESREQUEST_SECRETENTRY._options = None
_DSGETTABLESREQUEST_SECRETENTRY._options = None
_DSEXECUTESQLREQUEST_SECRETENTRY._options = None
_DSSNAPSHOTREQUEST_DBSECRETENTRY._options = None
_DSSNAPSHOTREQUEST_STORAGESECRETENTRY._options = None

_DATASERVICE = _descriptor.ServiceDescriptor(
  name='DataService',
  full_name='github.com.metaprov.modelaapi.services.data.v1.DataService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=27268,
  serialized_end=33295,
  methods=[
  _descriptor.MethodDescriptor(
    name='ReadFile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ReadFile',
    index=0,
    containing_service=None,
    input_type=_DSREADFILEREQUEST,
    output_type=_DSREADFROMSTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadFeature',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ReadFeature',
    index=1,
    containing_service=None,
    input_type=_DSREADFEATUREREQUEST,
    output_type=_DSREADFROMSTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReadAudio',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ReadAudio',
    index=2,
    containing_service=None,
    input_type=_DSREADAUDIOREQUEST,
    output_type=_DSREADFROMSTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.RunDataPipeline',
    index=3,
    containing_service=None,
    input_type=_DSRUNDATAPIPELINEREQUEST,
    output_type=_DSRUNDATAPIPELINERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunRecipe',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.RunRecipe',
    index=4,
    containing_service=None,
    input_type=_DSRUNRECIPEREQUEST,
    output_type=_DSRUNRECIPERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WriteFile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.WriteFile',
    index=5,
    containing_service=None,
    input_type=_DSWRITEFILEREQUEST,
    output_type=_DSREADFROMSTORERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateDataset',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ValidateDataset',
    index=6,
    containing_service=None,
    input_type=_DSVALIDATEDATASETREQUEST,
    output_type=_DSVALIDATEDATASETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GenerateDataset',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.GenerateDataset',
    index=7,
    containing_service=None,
    input_type=_DSGENERATEDATASETREQUEST,
    output_type=_DSGENERATEDATASETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SplitDataset',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.SplitDataset',
    index=8,
    containing_service=None,
    input_type=_DSSPLITDATASETREQUEST,
    output_type=_DSSPLITDATASETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateColumnProfile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateColumnProfile',
    index=9,
    containing_service=None,
    input_type=_DSCREATECOLUMNPROFILEREQUEST,
    output_type=_DSCREATECOLUMNPROFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='InferSchema',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.InferSchema',
    index=10,
    containing_service=None,
    input_type=_DSINFERSCHEMAREQUEST,
    output_type=_DSINFERSCHEMARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTableView',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.GetTableView',
    index=11,
    containing_service=None,
    input_type=_DSGETTABLEVIEWREQUEST,
    output_type=_DSGETTABLEVIEWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMisclassTableView',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.GetMisclassTableView',
    index=12,
    containing_service=None,
    input_type=_DSGETMISCLASSTABLEVIEWREQUEST,
    output_type=_DSGETMISCLASSTABLEVIEWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SplitDatasetToRungs',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.SplitDatasetToRungs',
    index=13,
    containing_service=None,
    input_type=_DSSPLITDATASETTORUNGSREQUEST,
    output_type=_DSSPLITDATASETTORUNGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDatasetProfile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateDatasetProfile',
    index=14,
    containing_service=None,
    input_type=_DSCREATEDATASETPROFILEREQUEST,
    output_type=_DSCREATEDATASETPROFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelProfile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateModelProfile',
    index=15,
    containing_service=None,
    input_type=_DSCREATEMODELPROFILEREQUEST,
    output_type=_DSCREATEMODELPROFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStudyProfile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateStudyProfile',
    index=16,
    containing_service=None,
    input_type=_DSCREATESTUDYPROFILEREQUEST,
    output_type=_DSCREATESTUDYPROFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecipeProfile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateRecipeProfile',
    index=17,
    containing_service=None,
    input_type=_DSCREATERECIPEPROFILEREQUEST,
    output_type=_DSCREATERECIPEPROFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelReport',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateModelReport',
    index=18,
    containing_service=None,
    input_type=_CREATEMODELREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStudyReport',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateStudyReport',
    index=19,
    containing_service=None,
    input_type=_CREATESTUDYREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDatasetReport',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateDatasetReport',
    index=20,
    containing_service=None,
    input_type=_CREATEDATASETREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateForecastReport',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateForecastReport',
    index=21,
    containing_service=None,
    input_type=_CREATEFORECASTREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateSummaryReport',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.CreateSummaryReport',
    index=22,
    containing_service=None,
    input_type=_CREATESUMMARYREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AskModel',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.AskModel',
    index=23,
    containing_service=None,
    input_type=_ASKMODELREQUEST,
    output_type=_ASKMODELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TellModel',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.TellModel',
    index=24,
    containing_service=None,
    input_type=_TELLMODELREQUEST,
    output_type=_TELLMODELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PartitionForecastFile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.PartitionForecastFile',
    index=25,
    containing_service=None,
    input_type=_DSCREATEFORECASTPARTITIONFILESREQUEST,
    output_type=_DSCREATEFORECASTPARTITIONFILESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MergeForecastFile',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.MergeForecastFile',
    index=26,
    containing_service=None,
    input_type=_DSMERGEFORECASTFILEREQUEST,
    output_type=_DSMERGEFORECASTFILERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValidateModel',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ValidateModel',
    index=27,
    containing_service=None,
    input_type=_VALIDATEMODELREQUEST,
    output_type=_VALIDATEMODELRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DsTestConnection',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.DsTestConnection',
    index=28,
    containing_service=None,
    input_type=_DSTESTCONNECTIONREQUEST,
    output_type=_DSTESTCONNECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ShutDown',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ShutDown',
    index=29,
    containing_service=None,
    input_type=_DSSHUTDOWNREQUEST,
    output_type=_DSSHUTDOWNRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StudyEnded',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.StudyEnded',
    index=30,
    containing_service=None,
    input_type=_DSSTUDYENDEDREQUEST,
    output_type=_DSSTUDYENDEDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SaveOptimizerDB',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.SaveOptimizerDB',
    index=31,
    containing_service=None,
    input_type=_SAVEOPTIMIZERDBREQUEST,
    output_type=_SAVEOPTIMIZERDBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDatabases',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.GetDatabases',
    index=32,
    containing_service=None,
    input_type=_DSGETDATABASESREQUEST,
    output_type=_DSGETDATABASESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTables',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.GetTables',
    index=33,
    containing_service=None,
    input_type=_DSGETTABLESREQUEST,
    output_type=_DSGETTABLESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteSql',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.ExecuteSql',
    index=34,
    containing_service=None,
    input_type=_DSEXECUTESQLREQUEST,
    output_type=_DSEXECUTESQLRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Snapshot',
    full_name='github.com.metaprov.modelaapi.services.data.v1.DataService.Snapshot',
    index=35,
    containing_service=None,
    input_type=_DSSNAPSHOTREQUEST,
    output_type=_DSSNAPSHOTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATASERVICE)

DESCRIPTOR.services_by_name['DataService'] = _DATASERVICE

# @@protoc_insertion_point(module_scope)
