# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: k8s.io/api/core/v1/generated.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from k8s.io.apimachinery.pkg.api.resource import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2
from k8s.io.apimachinery.pkg.apis.meta.v1 import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2
from k8s.io.apimachinery.pkg.runtime.schema import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2
from k8s.io.apimachinery.pkg.util.intstr import generated_pb2 as k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='k8s.io/api/core/v1/generated.proto',
  package='k8s.io.api.core.v1',
  syntax='proto2',
  serialized_options=b'Z\002v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"k8s.io/api/core/v1/generated.proto\x12\x12k8s.io.api.core.v1\x1a\x34k8s.io/apimachinery/pkg/api/resource/generated.proto\x1a\x34k8s.io/apimachinery/pkg/apis/meta/v1/generated.proto\x1a/k8s.io/apimachinery/pkg/runtime/generated.proto\x1a\x36k8s.io/apimachinery/pkg/runtime/schema/generated.proto\x1a\x33k8s.io/apimachinery/pkg/util/intstr/generated.proto\"i\n AWSElasticBlockStoreVolumeSource\x12\x10\n\x08volumeID\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x05\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\"\xb6\x01\n\x08\x41\x66\x66inity\x12\x36\n\x0cnodeAffinity\x18\x01 \x01(\x0b\x32 .k8s.io.api.core.v1.NodeAffinity\x12\x34\n\x0bpodAffinity\x18\x02 \x01(\x0b\x32\x1f.k8s.io.api.core.v1.PodAffinity\x12<\n\x0fpodAntiAffinity\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodAntiAffinity\"2\n\x0e\x41ttachedVolume\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndevicePath\x18\x02 \x01(\t\"N\n\tAvoidPods\x12\x41\n\x0fpreferAvoidPods\x18\x01 \x03(\x0b\x32(.k8s.io.api.core.v1.PreferAvoidPodsEntry\"\x7f\n\x15\x41zureDiskVolumeSource\x12\x10\n\x08\x64iskName\x18\x01 \x01(\t\x12\x0f\n\x07\x64iskURI\x18\x02 \x01(\t\x12\x13\n\x0b\x63\x61\x63hingMode\x18\x03 \x01(\t\x12\x0e\n\x06\x66sType\x18\x04 \x01(\t\x12\x10\n\x08readOnly\x18\x05 \x01(\x08\x12\x0c\n\x04kind\x18\x06 \x01(\t\"s\n\x1f\x41zureFilePersistentVolumeSource\x12\x12\n\nsecretName\x18\x01 \x01(\t\x12\x11\n\tshareName\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12\x17\n\x0fsecretNamespace\x18\x04 \x01(\t\"P\n\x15\x41zureFileVolumeSource\x12\x12\n\nsecretName\x18\x01 \x01(\t\x12\x11\n\tshareName\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\"\x82\x01\n\x07\x42inding\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x06target\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\x90\x04\n\x19\x43SIPersistentVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x14\n\x0cvolumeHandle\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12\x0e\n\x06\x66sType\x18\x04 \x01(\t\x12]\n\x10volumeAttributes\x18\x05 \x03(\x0b\x32\x43.k8s.io.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry\x12G\n\x1a\x63ontrollerPublishSecretRef\x18\x06 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12?\n\x12nodeStageSecretRef\x18\x07 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x41\n\x14nodePublishSecretRef\x18\x08 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x46\n\x19\x63ontrollerExpandSecretRef\x18\t \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x1a\x37\n\x15VolumeAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x99\x02\n\x0f\x43SIVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x10\n\x08readOnly\x18\x02 \x01(\x08\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12S\n\x10volumeAttributes\x18\x04 \x03(\x0b\x32\x39.k8s.io.api.core.v1.CSIVolumeSource.VolumeAttributesEntry\x12\x46\n\x14nodePublishSecretRef\x18\x05 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x1a\x37\n\x15VolumeAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\")\n\x0c\x43\x61pabilities\x12\x0b\n\x03\x61\x64\x64\x18\x01 \x03(\t\x12\x0c\n\x04\x64rop\x18\x02 \x03(\t\"\xaa\x01\n\x1c\x43\x65phFSPersistentVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x12\n\nsecretFile\x18\x04 \x01(\t\x12\x36\n\tsecretRef\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x10\n\x08readOnly\x18\x06 \x01(\x08\"\xa5\x01\n\x12\x43\x65phFSVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x12\n\nsecretFile\x18\x04 \x01(\t\x12;\n\tsecretRef\x18\x05 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08readOnly\x18\x06 \x01(\x08\"\x8a\x01\n\x1c\x43inderPersistentVolumeSource\x12\x10\n\x08volumeID\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12\x36\n\tsecretRef\x18\x04 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\"\x85\x01\n\x12\x43inderVolumeSource\x12\x10\n\x08volumeID\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12;\n\tsecretRef\x18\x04 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\"(\n\x0e\x43lientIPConfig\x12\x16\n\x0etimeoutSeconds\x18\x01 \x01(\x05\"R\n\x12\x43omponentCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"\x91\x01\n\x0f\x43omponentStatus\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12:\n\nconditions\x18\x02 \x03(\x0b\x32&.k8s.io.api.core.v1.ComponentCondition\"\x8b\x01\n\x13\x43omponentStatusList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x32\n\x05items\x18\x02 \x03(\x0b\x32#.k8s.io.api.core.v1.ComponentStatus\"\xbc\x02\n\tConfigMap\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x11\n\timmutable\x18\x04 \x01(\x08\x12\x35\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\'.k8s.io.api.core.v1.ConfigMap.DataEntry\x12\x41\n\nbinaryData\x18\x03 \x03(\x0b\x32-.k8s.io.api.core.v1.ConfigMap.BinaryDataEntry\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x42inaryDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"n\n\x12\x43onfigMapEnvSource\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08optional\x18\x02 \x01(\x08\"}\n\x14\x43onfigMapKeySelector\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\"\x7f\n\rConfigMapList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.ConfigMap\"|\n\x19\x43onfigMapNodeConfigSource\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uid\x18\x03 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x04 \x01(\t\x12\x18\n\x10kubeletConfigKey\x18\x05 \x01(\t\"\x9d\x01\n\x13\x43onfigMapProjection\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.KeyToPath\x12\x10\n\x08optional\x18\x04 \x01(\x08\"\xb4\x01\n\x15\x43onfigMapVolumeSource\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.KeyToPath\x12\x13\n\x0b\x64\x65\x66\x61ultMode\x18\x03 \x01(\x05\x12\x10\n\x08optional\x18\x04 \x01(\x08\"\xa7\x06\n\tContainer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x03(\t\x12\x12\n\nworkingDir\x18\x05 \x01(\t\x12\x30\n\x05ports\x18\x06 \x03(\x0b\x32!.k8s.io.api.core.v1.ContainerPort\x12\x32\n\x07\x65nvFrom\x18\x13 \x03(\x0b\x32!.k8s.io.api.core.v1.EnvFromSource\x12\'\n\x03\x65nv\x18\x07 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.EnvVar\x12;\n\tresources\x18\x08 \x01(\x0b\x32(.k8s.io.api.core.v1.ResourceRequirements\x12\x35\n\x0cvolumeMounts\x18\t \x03(\x0b\x32\x1f.k8s.io.api.core.v1.VolumeMount\x12\x37\n\rvolumeDevices\x18\x15 \x03(\x0b\x32 .k8s.io.api.core.v1.VolumeDevice\x12\x30\n\rlivenessProbe\x18\n \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12\x31\n\x0ereadinessProbe\x18\x0b \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12/\n\x0cstartupProbe\x18\x16 \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12\x30\n\tlifecycle\x18\x0c \x01(\x0b\x32\x1d.k8s.io.api.core.v1.Lifecycle\x12\x1e\n\x16terminationMessagePath\x18\r \x01(\t\x12 \n\x18terminationMessagePolicy\x18\x14 \x01(\t\x12\x17\n\x0fimagePullPolicy\x18\x0e \x01(\t\x12<\n\x0fsecurityContext\x18\x0f \x01(\x0b\x32#.k8s.io.api.core.v1.SecurityContext\x12\r\n\x05stdin\x18\x10 \x01(\x08\x12\x11\n\tstdinOnce\x18\x11 \x01(\x08\x12\x0b\n\x03tty\x18\x12 \x01(\x08\"2\n\x0e\x43ontainerImage\x12\r\n\x05names\x18\x01 \x03(\t\x12\x11\n\tsizeBytes\x18\x02 \x01(\x03\"h\n\rContainerPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08hostPort\x18\x02 \x01(\x05\x12\x15\n\rcontainerPort\x18\x03 \x01(\x05\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x0e\n\x06hostIP\x18\x05 \x01(\t\"\xca\x01\n\x0e\x43ontainerState\x12:\n\x07waiting\x18\x01 \x01(\x0b\x32).k8s.io.api.core.v1.ContainerStateWaiting\x12:\n\x07running\x18\x02 \x01(\x0b\x32).k8s.io.api.core.v1.ContainerStateRunning\x12@\n\nterminated\x18\x03 \x01(\x0b\x32,.k8s.io.api.core.v1.ContainerStateTerminated\"V\n\x15\x43ontainerStateRunning\x12=\n\tstartedAt\x18\x01 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"\xf1\x01\n\x18\x43ontainerStateTerminated\x12\x10\n\x08\x65xitCode\x18\x01 \x01(\x05\x12\x0e\n\x06signal\x18\x02 \x01(\x05\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12=\n\tstartedAt\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12>\n\nfinishedAt\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x13\n\x0b\x63ontainerID\x18\x07 \x01(\t\"8\n\x15\x43ontainerStateWaiting\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xf4\x01\n\x0f\x43ontainerStatus\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\x05state\x18\x02 \x01(\x0b\x32\".k8s.io.api.core.v1.ContainerState\x12\x35\n\tlastState\x18\x03 \x01(\x0b\x32\".k8s.io.api.core.v1.ContainerState\x12\r\n\x05ready\x18\x04 \x01(\x08\x12\x14\n\x0crestartCount\x18\x05 \x01(\x05\x12\r\n\x05image\x18\x06 \x01(\t\x12\x0f\n\x07imageID\x18\x07 \x01(\t\x12\x13\n\x0b\x63ontainerID\x18\x08 \x01(\t\x12\x0f\n\x07started\x18\t \x01(\x08\"\x1e\n\x0e\x44\x61\x65monEndpoint\x12\x0c\n\x04Port\x18\x01 \x01(\x05\"Q\n\x15\x44ownwardAPIProjection\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32).k8s.io.api.core.v1.DownwardAPIVolumeFile\"\xb3\x01\n\x15\x44ownwardAPIVolumeFile\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x08\x66ieldRef\x18\x02 \x01(\x0b\x32\'.k8s.io.api.core.v1.ObjectFieldSelector\x12\x43\n\x10resourceFieldRef\x18\x03 \x01(\x0b\x32).k8s.io.api.core.v1.ResourceFieldSelector\x12\x0c\n\x04mode\x18\x04 \x01(\x05\"h\n\x17\x44ownwardAPIVolumeSource\x12\x38\n\x05items\x18\x01 \x03(\x0b\x32).k8s.io.api.core.v1.DownwardAPIVolumeFile\x12\x13\n\x0b\x64\x65\x66\x61ultMode\x18\x02 \x01(\x05\"i\n\x14\x45mptyDirVolumeSource\x12\x0e\n\x06medium\x18\x01 \x01(\t\x12\x41\n\tsizeLimit\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\"y\n\x0f\x45ndpointAddress\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x03 \x01(\t\x12\x10\n\x08nodeName\x18\x04 \x01(\t\x12\x36\n\ttargetRef\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"Q\n\x0c\x45ndpointPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x13\n\x0b\x61ppProtocol\x18\x04 \x01(\t\"\xb9\x01\n\x0e\x45ndpointSubset\x12\x36\n\taddresses\x18\x01 \x03(\x0b\x32#.k8s.io.api.core.v1.EndpointAddress\x12>\n\x11notReadyAddresses\x18\x02 \x03(\x0b\x32#.k8s.io.api.core.v1.EndpointAddress\x12/\n\x05ports\x18\x03 \x03(\x0b\x32 .k8s.io.api.core.v1.EndpointPort\"\x84\x01\n\tEndpoints\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x07subsets\x18\x02 \x03(\x0b\x32\".k8s.io.api.core.v1.EndpointSubset\"\x7f\n\rEndpointsList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.Endpoints\"\x95\x01\n\rEnvFromSource\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12<\n\x0c\x63onfigMapRef\x18\x02 \x01(\x0b\x32&.k8s.io.api.core.v1.ConfigMapEnvSource\x12\x36\n\tsecretRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretEnvSource\"Z\n\x06\x45nvVar\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x33\n\tvalueFrom\x18\x03 \x01(\x0b\x32 .k8s.io.api.core.v1.EnvVarSource\"\x8e\x02\n\x0c\x45nvVarSource\x12\x39\n\x08\x66ieldRef\x18\x01 \x01(\x0b\x32\'.k8s.io.api.core.v1.ObjectFieldSelector\x12\x43\n\x10resourceFieldRef\x18\x02 \x01(\x0b\x32).k8s.io.api.core.v1.ResourceFieldSelector\x12\x41\n\x0f\x63onfigMapKeyRef\x18\x03 \x01(\x0b\x32(.k8s.io.api.core.v1.ConfigMapKeySelector\x12;\n\x0csecretKeyRef\x18\x04 \x01(\x0b\x32%.k8s.io.api.core.v1.SecretKeySelector\"\x81\x01\n\x12\x45phemeralContainer\x12N\n\x18\x65phemeralContainerCommon\x18\x01 \x01(\x0b\x32,.k8s.io.api.core.v1.EphemeralContainerCommon\x12\x1b\n\x13targetContainerName\x18\x02 \x01(\t\"\xb6\x06\n\x18\x45phemeralContainerCommon\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x03 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x03(\t\x12\x12\n\nworkingDir\x18\x05 \x01(\t\x12\x30\n\x05ports\x18\x06 \x03(\x0b\x32!.k8s.io.api.core.v1.ContainerPort\x12\x32\n\x07\x65nvFrom\x18\x13 \x03(\x0b\x32!.k8s.io.api.core.v1.EnvFromSource\x12\'\n\x03\x65nv\x18\x07 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.EnvVar\x12;\n\tresources\x18\x08 \x01(\x0b\x32(.k8s.io.api.core.v1.ResourceRequirements\x12\x35\n\x0cvolumeMounts\x18\t \x03(\x0b\x32\x1f.k8s.io.api.core.v1.VolumeMount\x12\x37\n\rvolumeDevices\x18\x15 \x03(\x0b\x32 .k8s.io.api.core.v1.VolumeDevice\x12\x30\n\rlivenessProbe\x18\n \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12\x31\n\x0ereadinessProbe\x18\x0b \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12/\n\x0cstartupProbe\x18\x16 \x01(\x0b\x32\x19.k8s.io.api.core.v1.Probe\x12\x30\n\tlifecycle\x18\x0c \x01(\x0b\x32\x1d.k8s.io.api.core.v1.Lifecycle\x12\x1e\n\x16terminationMessagePath\x18\r \x01(\t\x12 \n\x18terminationMessagePolicy\x18\x14 \x01(\t\x12\x17\n\x0fimagePullPolicy\x18\x0e \x01(\t\x12<\n\x0fsecurityContext\x18\x0f \x01(\x0b\x32#.k8s.io.api.core.v1.SecurityContext\x12\r\n\x05stdin\x18\x10 \x01(\x08\x12\x11\n\tstdinOnce\x18\x11 \x01(\x08\x12\x0b\n\x03tty\x18\x12 \x01(\x08\"\x9e\x01\n\x13\x45phemeralContainers\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x43\n\x13\x65phemeralContainers\x18\x02 \x03(\x0b\x32&.k8s.io.api.core.v1.EphemeralContainer\"g\n\x15\x45phemeralVolumeSource\x12N\n\x13volumeClaimTemplate\x18\x01 \x01(\x0b\x32\x31.k8s.io.api.core.v1.PersistentVolumeClaimTemplate\"\xf0\x04\n\x05\x45vent\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x0einvolvedObject\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12/\n\x06source\x18\x05 \x01(\x0b\x32\x1f.k8s.io.api.core.v1.EventSource\x12\x42\n\x0e\x66irstTimestamp\x18\x06 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x41\n\rlastTimestamp\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\r\n\x05\x63ount\x18\x08 \x01(\x05\x12\x0c\n\x04type\x18\t \x01(\t\x12\x42\n\teventTime\x18\n \x01(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime\x12/\n\x06series\x18\x0b \x01(\x0b\x32\x1f.k8s.io.api.core.v1.EventSeries\x12\x0e\n\x06\x61\x63tion\x18\x0c \x01(\t\x12\x34\n\x07related\x18\r \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x1a\n\x12reportingComponent\x18\x0e \x01(\t\x12\x19\n\x11reportingInstance\x18\x0f \x01(\t\"w\n\tEventList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.k8s.io.api.core.v1.Event\"g\n\x0b\x45ventSeries\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12I\n\x10lastObservedTime\x18\x02 \x01(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.MicroTime\".\n\x0b\x45ventSource\x12\x11\n\tcomponent\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\"\x1d\n\nExecAction\x12\x0f\n\x07\x63ommand\x18\x01 \x03(\t\"b\n\x0e\x46\x43VolumeSource\x12\x12\n\ntargetWWNs\x18\x01 \x03(\t\x12\x0b\n\x03lun\x18\x02 \x01(\x05\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\x12\r\n\x05wwids\x18\x05 \x03(\t\"\x84\x02\n\x1a\x46lexPersistentVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x36\n\tsecretRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\x12L\n\x07options\x18\x05 \x03(\x0b\x32;.k8s.io.api.core.v1.FlexPersistentVolumeSource.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf5\x01\n\x10\x46lexVolumeSource\x12\x0e\n\x06\x64river\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12;\n\tsecretRef\x18\x03 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\x12\x42\n\x07options\x18\x05 \x03(\x0b\x32\x31.k8s.io.api.core.v1.FlexVolumeSource.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"?\n\x13\x46lockerVolumeSource\x12\x13\n\x0b\x64\x61tasetName\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tasetUUID\x18\x02 \x01(\t\"d\n\x1dGCEPersistentDiskVolumeSource\x12\x0e\n\x06pdName\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x05\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\"N\n\x13GitRepoVolumeSource\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x02 \x01(\t\x12\x11\n\tdirectory\x18\x03 \x01(\t\"p\n\x1fGlusterfsPersistentVolumeSource\x12\x11\n\tendpoints\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12\x1a\n\x12\x65ndpointsNamespace\x18\x04 \x01(\t\"J\n\x15GlusterfsVolumeSource\x12\x11\n\tendpoints\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\"\xb0\x01\n\rHTTPGetAction\x12\x0c\n\x04path\x18\x01 \x01(\t\x12>\n\x04port\x18\x02 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0e\n\x06scheme\x18\x04 \x01(\t\x12\x33\n\x0bhttpHeaders\x18\x05 \x03(\x0b\x32\x1e.k8s.io.api.core.v1.HTTPHeader\")\n\nHTTPHeader\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xa3\x01\n\x07Handler\x12,\n\x04\x65xec\x18\x01 \x01(\x0b\x32\x1e.k8s.io.api.core.v1.ExecAction\x12\x32\n\x07httpGet\x18\x02 \x01(\x0b\x32!.k8s.io.api.core.v1.HTTPGetAction\x12\x36\n\ttcpSocket\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.TCPSocketAction\"*\n\tHostAlias\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x11\n\thostnames\x18\x02 \x03(\t\"2\n\x14HostPathVolumeSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x9b\x02\n\x1bISCSIPersistentVolumeSource\x12\x14\n\x0ctargetPortal\x18\x01 \x01(\t\x12\x0b\n\x03iqn\x18\x02 \x01(\t\x12\x0b\n\x03lun\x18\x03 \x01(\x05\x12\x16\n\x0eiscsiInterface\x18\x04 \x01(\t\x12\x0e\n\x06\x66sType\x18\x05 \x01(\t\x12\x10\n\x08readOnly\x18\x06 \x01(\x08\x12\x0f\n\x07portals\x18\x07 \x03(\t\x12\x19\n\x11\x63hapAuthDiscovery\x18\x08 \x01(\x08\x12\x17\n\x0f\x63hapAuthSession\x18\x0b \x01(\x08\x12\x36\n\tsecretRef\x18\n \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x15\n\rinitiatorName\x18\x0c \x01(\t\"\x96\x02\n\x11ISCSIVolumeSource\x12\x14\n\x0ctargetPortal\x18\x01 \x01(\t\x12\x0b\n\x03iqn\x18\x02 \x01(\t\x12\x0b\n\x03lun\x18\x03 \x01(\x05\x12\x16\n\x0eiscsiInterface\x18\x04 \x01(\t\x12\x0e\n\x06\x66sType\x18\x05 \x01(\t\x12\x10\n\x08readOnly\x18\x06 \x01(\x08\x12\x0f\n\x07portals\x18\x07 \x03(\t\x12\x19\n\x11\x63hapAuthDiscovery\x18\x08 \x01(\x08\x12\x17\n\x0f\x63hapAuthSession\x18\x0b \x01(\x08\x12;\n\tsecretRef\x18\n \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x15\n\rinitiatorName\x18\x0c \x01(\t\"4\n\tKeyToPath\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\x05\"i\n\tLifecycle\x12.\n\tpostStart\x18\x01 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.Handler\x12,\n\x07preStop\x18\x02 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.Handler\"\x82\x01\n\nLimitRange\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x30\n\x04spec\x18\x02 \x01(\x0b\x32\".k8s.io.api.core.v1.LimitRangeSpec\"\xec\x06\n\x0eLimitRangeItem\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x38\n\x03max\x18\x02 \x03(\x0b\x32+.k8s.io.api.core.v1.LimitRangeItem.MaxEntry\x12\x38\n\x03min\x18\x03 \x03(\x0b\x32+.k8s.io.api.core.v1.LimitRangeItem.MinEntry\x12@\n\x07\x64\x65\x66\x61ult\x18\x04 \x03(\x0b\x32/.k8s.io.api.core.v1.LimitRangeItem.DefaultEntry\x12N\n\x0e\x64\x65\x66\x61ultRequest\x18\x05 \x03(\x0b\x32\x36.k8s.io.api.core.v1.LimitRangeItem.DefaultRequestEntry\x12Z\n\x14maxLimitRequestRatio\x18\x06 \x03(\x0b\x32<.k8s.io.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry\x1aZ\n\x08MaxEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1aZ\n\x08MinEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1a^\n\x0c\x44\x65\x66\x61ultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1a\x65\n\x13\x44\x65\x66\x61ultRequestEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1ak\n\x19MaxLimitRequestRatioEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\x81\x01\n\x0eLimitRangeList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.k8s.io.api.core.v1.LimitRange\"D\n\x0eLimitRangeSpec\x12\x32\n\x06limits\x18\x01 \x03(\x0b\x32\".k8s.io.api.core.v1.LimitRangeItem\"\x86\x01\n\x04List\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12<\n\x05items\x18\x02 \x03(\x0b\x32-.k8s.io.apimachinery.pkg.runtime.RawExtension\"b\n\x13LoadBalancerIngress\x12\n\n\x02ip\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12-\n\x05ports\x18\x04 \x03(\x0b\x32\x1e.k8s.io.api.core.v1.PortStatus\"N\n\x12LoadBalancerStatus\x12\x38\n\x07ingress\x18\x01 \x03(\x0b\x32\'.k8s.io.api.core.v1.LoadBalancerIngress\"$\n\x14LocalObjectReference\x12\x0c\n\x04name\x18\x01 \x01(\t\"1\n\x11LocalVolumeSource\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\"A\n\x0fNFSVolumeSource\x12\x0e\n\x06server\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\"\xb5\x01\n\tNamespace\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12/\n\x04spec\x18\x02 \x01(\x0b\x32!.k8s.io.api.core.v1.NamespaceSpec\x12\x33\n\x06status\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.NamespaceStatus\"\x9b\x01\n\x12NamespaceCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x7f\n\rNamespaceList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.Namespace\"#\n\rNamespaceSpec\x12\x12\n\nfinalizers\x18\x01 \x03(\t\"\\\n\x0fNamespaceStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12:\n\nconditions\x18\x02 \x03(\x0b\x32&.k8s.io.api.core.v1.NamespaceCondition\"\xa6\x01\n\x04Node\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12*\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.k8s.io.api.core.v1.NodeSpec\x12.\n\x06status\x18\x03 \x01(\x0b\x32\x1e.k8s.io.api.core.v1.NodeStatus\",\n\x0bNodeAddress\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"\xce\x01\n\x0cNodeAffinity\x12X\n.requiredDuringSchedulingIgnoredDuringExecution\x18\x01 \x01(\x0b\x32 .k8s.io.api.core.v1.NodeSelector\x12\x64\n/preferredDuringSchedulingIgnoredDuringExecution\x18\x02 \x03(\x0b\x32+.k8s.io.api.core.v1.PreferredSchedulingTerm\"\xdd\x01\n\rNodeCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x45\n\x11lastHeartbeatTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"T\n\x10NodeConfigSource\x12@\n\tconfigMap\x18\x02 \x01(\x0b\x32-.k8s.io.api.core.v1.ConfigMapNodeConfigSource\"\xcc\x01\n\x10NodeConfigStatus\x12\x36\n\x08\x61ssigned\x18\x01 \x01(\x0b\x32$.k8s.io.api.core.v1.NodeConfigSource\x12\x34\n\x06\x61\x63tive\x18\x02 \x01(\x0b\x32$.k8s.io.api.core.v1.NodeConfigSource\x12;\n\rlastKnownGood\x18\x03 \x01(\x0b\x32$.k8s.io.api.core.v1.NodeConfigSource\x12\r\n\x05\x65rror\x18\x04 \x01(\t\"R\n\x13NodeDaemonEndpoints\x12;\n\x0fkubeletEndpoint\x18\x01 \x01(\x0b\x32\".k8s.io.api.core.v1.DaemonEndpoint\"u\n\x08NodeList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.k8s.io.api.core.v1.Node\" \n\x10NodeProxyOptions\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xb3\x01\n\rNodeResources\x12\x41\n\x08\x63\x61pacity\x18\x01 \x03(\x0b\x32/.k8s.io.api.core.v1.NodeResources.CapacityEntry\x1a_\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"O\n\x0cNodeSelector\x12?\n\x11nodeSelectorTerms\x18\x01 \x03(\x0b\x32$.k8s.io.api.core.v1.NodeSelectorTerm\"H\n\x17NodeSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x9b\x01\n\x10NodeSelectorTerm\x12\x45\n\x10matchExpressions\x18\x01 \x03(\x0b\x32+.k8s.io.api.core.v1.NodeSelectorRequirement\x12@\n\x0bmatchFields\x18\x02 \x03(\x0b\x32+.k8s.io.api.core.v1.NodeSelectorRequirement\"\xd3\x01\n\x08NodeSpec\x12\x0f\n\x07podCIDR\x18\x01 \x01(\t\x12\x10\n\x08podCIDRs\x18\x07 \x03(\t\x12\x12\n\nproviderID\x18\x03 \x01(\t\x12\x15\n\runschedulable\x18\x04 \x01(\x08\x12)\n\x06taints\x18\x05 \x03(\x0b\x32\x19.k8s.io.api.core.v1.Taint\x12:\n\x0c\x63onfigSource\x18\x06 \x01(\x0b\x32$.k8s.io.api.core.v1.NodeConfigSource\x12\x12\n\nexternalID\x18\x02 \x01(\t\"\x86\x06\n\nNodeStatus\x12>\n\x08\x63\x61pacity\x18\x01 \x03(\x0b\x32,.k8s.io.api.core.v1.NodeStatus.CapacityEntry\x12\x44\n\x0b\x61llocatable\x18\x02 \x03(\x0b\x32/.k8s.io.api.core.v1.NodeStatus.AllocatableEntry\x12\r\n\x05phase\x18\x03 \x01(\t\x12\x35\n\nconditions\x18\x04 \x03(\x0b\x32!.k8s.io.api.core.v1.NodeCondition\x12\x32\n\taddresses\x18\x05 \x03(\x0b\x32\x1f.k8s.io.api.core.v1.NodeAddress\x12@\n\x0f\x64\x61\x65monEndpoints\x18\x06 \x01(\x0b\x32\'.k8s.io.api.core.v1.NodeDaemonEndpoints\x12\x34\n\x08nodeInfo\x18\x07 \x01(\x0b\x32\".k8s.io.api.core.v1.NodeSystemInfo\x12\x32\n\x06images\x18\x08 \x03(\x0b\x32\".k8s.io.api.core.v1.ContainerImage\x12\x14\n\x0cvolumesInUse\x18\t \x03(\t\x12;\n\x0fvolumesAttached\x18\n \x03(\x0b\x32\".k8s.io.api.core.v1.AttachedVolume\x12\x34\n\x06\x63onfig\x18\x0b \x01(\x0b\x32$.k8s.io.api.core.v1.NodeConfigStatus\x1a_\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1a\x62\n\x10\x41llocatableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\xf1\x01\n\x0eNodeSystemInfo\x12\x11\n\tmachineID\x18\x01 \x01(\t\x12\x12\n\nsystemUUID\x18\x02 \x01(\t\x12\x0e\n\x06\x62ootID\x18\x03 \x01(\t\x12\x15\n\rkernelVersion\x18\x04 \x01(\t\x12\x0f\n\x07osImage\x18\x05 \x01(\t\x12\x1f\n\x17\x63ontainerRuntimeVersion\x18\x06 \x01(\t\x12\x16\n\x0ekubeletVersion\x18\x07 \x01(\t\x12\x18\n\x10kubeProxyVersion\x18\x08 \x01(\t\x12\x17\n\x0foperatingSystem\x18\t \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\n \x01(\t\"<\n\x13ObjectFieldSelector\x12\x12\n\napiVersion\x18\x01 \x01(\t\x12\x11\n\tfieldPath\x18\x02 \x01(\t\"\x8d\x01\n\x0fObjectReference\x12\x0c\n\x04kind\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0b\n\x03uid\x18\x04 \x01(\t\x12\x12\n\napiVersion\x18\x05 \x01(\t\x12\x17\n\x0fresourceVersion\x18\x06 \x01(\t\x12\x11\n\tfieldPath\x18\x07 \x01(\t\"\xca\x01\n\x10PersistentVolume\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x36\n\x04spec\x18\x02 \x01(\x0b\x32(.k8s.io.api.core.v1.PersistentVolumeSpec\x12:\n\x06status\x18\x03 \x01(\x0b\x32*.k8s.io.api.core.v1.PersistentVolumeStatus\"\xd9\x01\n\x15PersistentVolumeClaim\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x02 \x01(\x0b\x32-.k8s.io.api.core.v1.PersistentVolumeClaimSpec\x12?\n\x06status\x18\x03 \x01(\x0b\x32/.k8s.io.api.core.v1.PersistentVolumeClaimStatus\"\xea\x01\n\x1ePersistentVolumeClaimCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x41\n\rlastProbeTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"\x97\x01\n\x19PersistentVolumeClaimList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).k8s.io.api.core.v1.PersistentVolumeClaim\"\xb9\x02\n\x19PersistentVolumeClaimSpec\x12\x13\n\x0b\x61\x63\x63\x65ssModes\x18\x01 \x03(\t\x12\x45\n\x08selector\x18\x04 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12;\n\tresources\x18\x02 \x01(\x0b\x32(.k8s.io.api.core.v1.ResourceRequirements\x12\x12\n\nvolumeName\x18\x03 \x01(\t\x12\x18\n\x10storageClassName\x18\x05 \x01(\t\x12\x12\n\nvolumeMode\x18\x06 \x01(\t\x12\x41\n\ndataSource\x18\x07 \x01(\x0b\x32-.k8s.io.api.core.v1.TypedLocalObjectReference\"\xbb\x02\n\x1bPersistentVolumeClaimStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63\x65ssModes\x18\x02 \x03(\t\x12O\n\x08\x63\x61pacity\x18\x03 \x03(\x0b\x32=.k8s.io.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry\x12\x46\n\nconditions\x18\x04 \x03(\x0b\x32\x32.k8s.io.api.core.v1.PersistentVolumeClaimCondition\x1a_\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\xa0\x01\n\x1dPersistentVolumeClaimTemplate\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x02 \x01(\x0b\x32-.k8s.io.api.core.v1.PersistentVolumeClaimSpec\"H\n!PersistentVolumeClaimVolumeSource\x12\x11\n\tclaimName\x18\x01 \x01(\t\x12\x10\n\x08readOnly\x18\x02 \x01(\x08\"\x8d\x01\n\x14PersistentVolumeList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x33\n\x05items\x18\x02 \x03(\x0b\x32$.k8s.io.api.core.v1.PersistentVolume\"\xbd\x0b\n\x16PersistentVolumeSource\x12L\n\x11gcePersistentDisk\x18\x01 \x01(\x0b\x32\x31.k8s.io.api.core.v1.GCEPersistentDiskVolumeSource\x12R\n\x14\x61wsElasticBlockStore\x18\x02 \x01(\x0b\x32\x34.k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource\x12:\n\x08hostPath\x18\x03 \x01(\x0b\x32(.k8s.io.api.core.v1.HostPathVolumeSource\x12\x46\n\tglusterfs\x18\x04 \x01(\x0b\x32\x33.k8s.io.api.core.v1.GlusterfsPersistentVolumeSource\x12\x30\n\x03nfs\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.NFSVolumeSource\x12:\n\x03rbd\x18\x06 \x01(\x0b\x32-.k8s.io.api.core.v1.RBDPersistentVolumeSource\x12>\n\x05iscsi\x18\x07 \x01(\x0b\x32/.k8s.io.api.core.v1.ISCSIPersistentVolumeSource\x12@\n\x06\x63inder\x18\x08 \x01(\x0b\x32\x30.k8s.io.api.core.v1.CinderPersistentVolumeSource\x12@\n\x06\x63\x65phfs\x18\t \x01(\x0b\x32\x30.k8s.io.api.core.v1.CephFSPersistentVolumeSource\x12.\n\x02\x66\x63\x18\n \x01(\x0b\x32\".k8s.io.api.core.v1.FCVolumeSource\x12\x38\n\x07\x66locker\x18\x0b \x01(\x0b\x32\'.k8s.io.api.core.v1.FlockerVolumeSource\x12\x42\n\nflexVolume\x18\x0c \x01(\x0b\x32..k8s.io.api.core.v1.FlexPersistentVolumeSource\x12\x46\n\tazureFile\x18\r \x01(\x0b\x32\x33.k8s.io.api.core.v1.AzureFilePersistentVolumeSource\x12I\n\rvsphereVolume\x18\x0e \x01(\x0b\x32\x32.k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource\x12\x38\n\x07quobyte\x18\x0f \x01(\x0b\x32\'.k8s.io.api.core.v1.QuobyteVolumeSource\x12<\n\tazureDisk\x18\x10 \x01(\x0b\x32).k8s.io.api.core.v1.AzureDiskVolumeSource\x12R\n\x14photonPersistentDisk\x18\x11 \x01(\x0b\x32\x34.k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource\x12@\n\x0eportworxVolume\x18\x12 \x01(\x0b\x32(.k8s.io.api.core.v1.PortworxVolumeSource\x12\x42\n\x07scaleIO\x18\x13 \x01(\x0b\x32\x31.k8s.io.api.core.v1.ScaleIOPersistentVolumeSource\x12\x34\n\x05local\x18\x14 \x01(\x0b\x32%.k8s.io.api.core.v1.LocalVolumeSource\x12\x46\n\tstorageos\x18\x15 \x01(\x0b\x32\x33.k8s.io.api.core.v1.StorageOSPersistentVolumeSource\x12:\n\x03\x63si\x18\x16 \x01(\x0b\x32-.k8s.io.api.core.v1.CSIPersistentVolumeSource\"\x82\x04\n\x14PersistentVolumeSpec\x12H\n\x08\x63\x61pacity\x18\x01 \x03(\x0b\x32\x36.k8s.io.api.core.v1.PersistentVolumeSpec.CapacityEntry\x12J\n\x16persistentVolumeSource\x18\x02 \x01(\x0b\x32*.k8s.io.api.core.v1.PersistentVolumeSource\x12\x13\n\x0b\x61\x63\x63\x65ssModes\x18\x03 \x03(\t\x12\x35\n\x08\x63laimRef\x18\x04 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12%\n\x1dpersistentVolumeReclaimPolicy\x18\x05 \x01(\t\x12\x18\n\x10storageClassName\x18\x06 \x01(\t\x12\x14\n\x0cmountOptions\x18\x07 \x03(\t\x12\x12\n\nvolumeMode\x18\x08 \x01(\t\x12<\n\x0cnodeAffinity\x18\t \x01(\x0b\x32&.k8s.io.api.core.v1.VolumeNodeAffinity\x1a_\n\rCapacityEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"H\n\x16PersistentVolumeStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\"@\n PhotonPersistentDiskVolumeSource\x12\x0c\n\x04pdID\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\"\xa3\x01\n\x03Pod\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12)\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.PodSpec\x12-\n\x06status\x18\x03 \x01(\x0b\x32\x1d.k8s.io.api.core.v1.PodStatus\"\xd0\x01\n\x0bPodAffinity\x12[\n.requiredDuringSchedulingIgnoredDuringExecution\x18\x01 \x03(\x0b\x32#.k8s.io.api.core.v1.PodAffinityTerm\x12\x64\n/preferredDuringSchedulingIgnoredDuringExecution\x18\x02 \x03(\x0b\x32+.k8s.io.api.core.v1.WeightedPodAffinityTerm\"\xd6\x01\n\x0fPodAffinityTerm\x12J\n\rlabelSelector\x18\x01 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x12\n\nnamespaces\x18\x02 \x03(\t\x12\x13\n\x0btopologyKey\x18\x03 \x01(\t\x12N\n\x11namespaceSelector\x18\x04 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\"\xd4\x01\n\x0fPodAntiAffinity\x12[\n.requiredDuringSchedulingIgnoredDuringExecution\x18\x01 \x03(\x0b\x32#.k8s.io.api.core.v1.PodAffinityTerm\x12\x64\n/preferredDuringSchedulingIgnoredDuringExecution\x18\x02 \x03(\x0b\x32+.k8s.io.api.core.v1.WeightedPodAffinityTerm\"a\n\x10PodAttachOptions\x12\r\n\x05stdin\x18\x01 \x01(\x08\x12\x0e\n\x06stdout\x18\x02 \x01(\x08\x12\x0e\n\x06stderr\x18\x03 \x01(\x08\x12\x0b\n\x03tty\x18\x04 \x01(\x08\x12\x11\n\tcontainer\x18\x05 \x01(\t\"\xd8\x01\n\x0cPodCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x41\n\rlastProbeTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x46\n\x12lastTransitionTime\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x0f\n\x07message\x18\x06 \x01(\t\"n\n\x0cPodDNSConfig\x12\x13\n\x0bnameservers\x18\x01 \x03(\t\x12\x10\n\x08searches\x18\x02 \x03(\t\x12\x37\n\x07options\x18\x03 \x03(\x0b\x32&.k8s.io.api.core.v1.PodDNSConfigOption\"1\n\x12PodDNSConfigOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"p\n\x0ePodExecOptions\x12\r\n\x05stdin\x18\x01 \x01(\x08\x12\x0e\n\x06stdout\x18\x02 \x01(\x08\x12\x0e\n\x06stderr\x18\x03 \x01(\x08\x12\x0b\n\x03tty\x18\x04 \x01(\x08\x12\x11\n\tcontainer\x18\x05 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x06 \x03(\t\"\x13\n\x05PodIP\x12\n\n\x02ip\x18\x01 \x01(\t\"s\n\x07PodList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.k8s.io.api.core.v1.Pod\"\xfa\x01\n\rPodLogOptions\x12\x11\n\tcontainer\x18\x01 \x01(\t\x12\x0e\n\x06\x66ollow\x18\x02 \x01(\x08\x12\x10\n\x08previous\x18\x03 \x01(\x08\x12\x14\n\x0csinceSeconds\x18\x04 \x01(\x03\x12=\n\tsinceTime\x18\x05 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\ntimestamps\x18\x06 \x01(\x08\x12\x11\n\ttailLines\x18\x07 \x01(\x03\x12\x12\n\nlimitBytes\x18\x08 \x01(\x03\x12$\n\x1cinsecureSkipTLSVerifyBackend\x18\t \x01(\x08\"&\n\x15PodPortForwardOptions\x12\r\n\x05ports\x18\x01 \x03(\x05\"\x1f\n\x0fPodProxyOptions\x12\x0c\n\x04path\x18\x01 \x01(\t\")\n\x10PodReadinessGate\x12\x15\n\rconditionType\x18\x01 \x01(\t\"\x8b\x03\n\x12PodSecurityContext\x12:\n\x0eseLinuxOptions\x18\x01 \x01(\x0b\x32\".k8s.io.api.core.v1.SELinuxOptions\x12I\n\x0ewindowsOptions\x18\x08 \x01(\x0b\x32\x31.k8s.io.api.core.v1.WindowsSecurityContextOptions\x12\x11\n\trunAsUser\x18\x02 \x01(\x03\x12\x12\n\nrunAsGroup\x18\x06 \x01(\x03\x12\x14\n\x0crunAsNonRoot\x18\x03 \x01(\x08\x12\x1a\n\x12supplementalGroups\x18\x04 \x03(\x03\x12\x0f\n\x07\x66sGroup\x18\x05 \x01(\x03\x12+\n\x07sysctls\x18\x07 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.Sysctl\x12\x1b\n\x13\x66sGroupChangePolicy\x18\t \x01(\t\x12:\n\x0eseccompProfile\x18\n \x01(\x0b\x32\".k8s.io.api.core.v1.SeccompProfile\"[\n\x0cPodSignature\x12K\n\rpodController\x18\x01 \x01(\x0b\x32\x34.k8s.io.apimachinery.pkg.apis.meta.v1.OwnerReference\"\xe5\x0b\n\x07PodSpec\x12+\n\x07volumes\x18\x01 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.Volume\x12\x35\n\x0einitContainers\x18\x14 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.Container\x12\x31\n\ncontainers\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.Container\x12\x43\n\x13\x65phemeralContainers\x18\" \x03(\x0b\x32&.k8s.io.api.core.v1.EphemeralContainer\x12\x15\n\rrestartPolicy\x18\x03 \x01(\t\x12%\n\x1dterminationGracePeriodSeconds\x18\x04 \x01(\x03\x12\x1d\n\x15\x61\x63tiveDeadlineSeconds\x18\x05 \x01(\x03\x12\x11\n\tdnsPolicy\x18\x06 \x01(\t\x12\x43\n\x0cnodeSelector\x18\x07 \x03(\x0b\x32-.k8s.io.api.core.v1.PodSpec.NodeSelectorEntry\x12\x1a\n\x12serviceAccountName\x18\x08 \x01(\t\x12\x16\n\x0eserviceAccount\x18\t \x01(\t\x12$\n\x1c\x61utomountServiceAccountToken\x18\x15 \x01(\x08\x12\x10\n\x08nodeName\x18\n \x01(\t\x12\x13\n\x0bhostNetwork\x18\x0b \x01(\x08\x12\x0f\n\x07hostPID\x18\x0c \x01(\x08\x12\x0f\n\x07hostIPC\x18\r \x01(\x08\x12\x1d\n\x15shareProcessNamespace\x18\x1b \x01(\x08\x12?\n\x0fsecurityContext\x18\x0e \x01(\x0b\x32&.k8s.io.api.core.v1.PodSecurityContext\x12\x42\n\x10imagePullSecrets\x18\x0f \x03(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08hostname\x18\x10 \x01(\t\x12\x11\n\tsubdomain\x18\x11 \x01(\t\x12.\n\x08\x61\x66\x66inity\x18\x12 \x01(\x0b\x32\x1c.k8s.io.api.core.v1.Affinity\x12\x15\n\rschedulerName\x18\x13 \x01(\t\x12\x33\n\x0btolerations\x18\x16 \x03(\x0b\x32\x1e.k8s.io.api.core.v1.Toleration\x12\x32\n\x0bhostAliases\x18\x17 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.HostAlias\x12\x19\n\x11priorityClassName\x18\x18 \x01(\t\x12\x10\n\x08priority\x18\x19 \x01(\x05\x12\x33\n\tdnsConfig\x18\x1a \x01(\x0b\x32 .k8s.io.api.core.v1.PodDNSConfig\x12<\n\x0ereadinessGates\x18\x1c \x03(\x0b\x32$.k8s.io.api.core.v1.PodReadinessGate\x12\x18\n\x10runtimeClassName\x18\x1d \x01(\t\x12\x1a\n\x12\x65nableServiceLinks\x18\x1e \x01(\x08\x12\x18\n\x10preemptionPolicy\x18\x1f \x01(\t\x12;\n\x08overhead\x18  \x03(\x0b\x32).k8s.io.api.core.v1.PodSpec.OverheadEntry\x12O\n\x19topologySpreadConstraints\x18! \x03(\x0b\x32,.k8s.io.api.core.v1.TopologySpreadConstraint\x12\x19\n\x11setHostnameAsFQDN\x18# \x01(\x08\x1a\x33\n\x11NodeSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a_\n\rOverheadEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\xf4\x03\n\tPodStatus\x12\r\n\x05phase\x18\x01 \x01(\t\x12\x34\n\nconditions\x18\x02 \x03(\x0b\x32 .k8s.io.api.core.v1.PodCondition\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x19\n\x11nominatedNodeName\x18\x0b \x01(\t\x12\x0e\n\x06hostIP\x18\x05 \x01(\t\x12\r\n\x05podIP\x18\x06 \x01(\t\x12)\n\x06podIPs\x18\x0c \x03(\x0b\x32\x19.k8s.io.api.core.v1.PodIP\x12=\n\tstartTime\x18\x07 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x42\n\x15initContainerStatuses\x18\n \x03(\x0b\x32#.k8s.io.api.core.v1.ContainerStatus\x12>\n\x11\x63ontainerStatuses\x18\x08 \x03(\x0b\x32#.k8s.io.api.core.v1.ContainerStatus\x12\x10\n\x08qosClass\x18\t \x01(\t\x12G\n\x1a\x65phemeralContainerStatuses\x18\r \x03(\x0b\x32#.k8s.io.api.core.v1.ContainerStatus\"\x84\x01\n\x0fPodStatusResult\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x06status\x18\x02 \x01(\x0b\x32\x1d.k8s.io.api.core.v1.PodStatus\"\x88\x01\n\x0bPodTemplate\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x35\n\x08template\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\"\x83\x01\n\x0fPodTemplateList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12.\n\x05items\x18\x02 \x03(\x0b\x32\x1f.k8s.io.api.core.v1.PodTemplate\"\x80\x01\n\x0fPodTemplateSpec\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12)\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.PodSpec\";\n\nPortStatus\x12\x0c\n\x04port\x18\x01 \x01(\x05\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"J\n\x14PortworxVolumeSource\x12\x10\n\x08volumeID\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\"\x1c\n\rPreconditions\x12\x0b\n\x03uid\x18\x01 \x01(\t\"\xb1\x01\n\x14PreferAvoidPodsEntry\x12\x36\n\x0cpodSignature\x18\x01 \x01(\x0b\x32 .k8s.io.api.core.v1.PodSignature\x12@\n\x0c\x65victionTime\x18\x02 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"c\n\x17PreferredSchedulingTerm\x12\x0e\n\x06weight\x18\x01 \x01(\x05\x12\x38\n\npreference\x18\x02 \x01(\x0b\x32$.k8s.io.api.core.v1.NodeSelectorTerm\"\xdc\x01\n\x05Probe\x12,\n\x07handler\x18\x01 \x01(\x0b\x32\x1b.k8s.io.api.core.v1.Handler\x12\x1b\n\x13initialDelaySeconds\x18\x02 \x01(\x05\x12\x16\n\x0etimeoutSeconds\x18\x03 \x01(\x05\x12\x15\n\rperiodSeconds\x18\x04 \x01(\x05\x12\x18\n\x10successThreshold\x18\x05 \x01(\x05\x12\x18\n\x10\x66\x61ilureThreshold\x18\x06 \x01(\x05\x12%\n\x1dterminationGracePeriodSeconds\x18\x07 \x01(\x03\"c\n\x15ProjectedVolumeSource\x12\x35\n\x07sources\x18\x01 \x03(\x0b\x32$.k8s.io.api.core.v1.VolumeProjection\x12\x13\n\x0b\x64\x65\x66\x61ultMode\x18\x02 \x01(\x05\"v\n\x13QuobyteVolumeSource\x12\x10\n\x08registry\x18\x01 \x01(\t\x12\x0e\n\x06volume\x18\x02 \x01(\t\x12\x10\n\x08readOnly\x18\x03 \x01(\x08\x12\x0c\n\x04user\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x0e\n\x06tenant\x18\x06 \x01(\t\"\xc3\x01\n\x19RBDPersistentVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12\x0c\n\x04pool\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x0f\n\x07keyring\x18\x06 \x01(\t\x12\x36\n\tsecretRef\x18\x07 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x10\n\x08readOnly\x18\x08 \x01(\x08\"\xbe\x01\n\x0fRBDVolumeSource\x12\x10\n\x08monitors\x18\x01 \x03(\t\x12\r\n\x05image\x18\x02 \x01(\t\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12\x0c\n\x04pool\x18\x04 \x01(\t\x12\x0c\n\x04user\x18\x05 \x01(\t\x12\x0f\n\x07keyring\x18\x06 \x01(\t\x12;\n\tsecretRef\x18\x07 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08readOnly\x18\x08 \x01(\x08\"r\n\x0fRangeAllocation\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\r\n\x05range\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\"\xd9\x01\n\x15ReplicationController\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x02 \x01(\x0b\x32-.k8s.io.api.core.v1.ReplicationControllerSpec\x12?\n\x06status\x18\x03 \x01(\x0b\x32/.k8s.io.api.core.v1.ReplicationControllerStatus\"\xa7\x01\n\x1eReplicationControllerCondition\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x46\n\x12lastTransitionTime\x18\x03 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\"\x97\x01\n\x19ReplicationControllerList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x38\n\x05items\x18\x02 \x03(\x0b\x32).k8s.io.api.core.v1.ReplicationController\"\xfd\x01\n\x19ReplicationControllerSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x17\n\x0fminReadySeconds\x18\x04 \x01(\x05\x12M\n\x08selector\x18\x02 \x03(\x0b\x32;.k8s.io.api.core.v1.ReplicationControllerSpec.SelectorEntry\x12\x35\n\x08template\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.PodTemplateSpec\x1a/\n\rSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe3\x01\n\x1bReplicationControllerStatus\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x1c\n\x14\x66ullyLabeledReplicas\x18\x02 \x01(\x05\x12\x15\n\rreadyReplicas\x18\x04 \x01(\x05\x12\x19\n\x11\x61vailableReplicas\x18\x05 \x01(\x05\x12\x1a\n\x12observedGeneration\x18\x03 \x01(\x03\x12\x46\n\nconditions\x18\x06 \x03(\x0b\x32\x32.k8s.io.api.core.v1.ReplicationControllerCondition\"\x81\x01\n\x15ResourceFieldSelector\x12\x15\n\rcontainerName\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12?\n\x07\x64ivisor\x18\x03 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity\"\xc1\x01\n\rResourceQuota\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x33\n\x04spec\x18\x02 \x01(\x0b\x32%.k8s.io.api.core.v1.ResourceQuotaSpec\x12\x37\n\x06status\x18\x03 \x01(\x0b\x32\'.k8s.io.api.core.v1.ResourceQuotaStatus\"\x87\x01\n\x11ResourceQuotaList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x30\n\x05items\x18\x02 \x03(\x0b\x32!.k8s.io.api.core.v1.ResourceQuota\"\xf9\x01\n\x11ResourceQuotaSpec\x12=\n\x04hard\x18\x01 \x03(\x0b\x32/.k8s.io.api.core.v1.ResourceQuotaSpec.HardEntry\x12\x0e\n\x06scopes\x18\x02 \x03(\t\x12\x38\n\rscopeSelector\x18\x03 \x01(\x0b\x32!.k8s.io.api.core.v1.ScopeSelector\x1a[\n\tHardEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\xd1\x02\n\x13ResourceQuotaStatus\x12?\n\x04hard\x18\x01 \x03(\x0b\x32\x31.k8s.io.api.core.v1.ResourceQuotaStatus.HardEntry\x12?\n\x04used\x18\x02 \x03(\x0b\x32\x31.k8s.io.api.core.v1.ResourceQuotaStatus.UsedEntry\x1a[\n\tHardEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1a[\n\tUsedEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"\xe6\x02\n\x14ResourceRequirements\x12\x44\n\x06limits\x18\x01 \x03(\x0b\x32\x34.k8s.io.api.core.v1.ResourceRequirements.LimitsEntry\x12H\n\x08requests\x18\x02 \x03(\x0b\x32\x36.k8s.io.api.core.v1.ResourceRequirements.RequestsEntry\x1a]\n\x0bLimitsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\x1a_\n\rRequestsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12=\n\x05value\x18\x02 \x01(\x0b\x32..k8s.io.apimachinery.pkg.api.resource.Quantity:\x02\x38\x01\"I\n\x0eSELinuxOptions\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\"\x86\x02\n\x1dScaleIOPersistentVolumeSource\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0e\n\x06system\x18\x02 \x01(\t\x12\x36\n\tsecretRef\x18\x03 \x01(\x0b\x32#.k8s.io.api.core.v1.SecretReference\x12\x12\n\nsslEnabled\x18\x04 \x01(\x08\x12\x18\n\x10protectionDomain\x18\x05 \x01(\t\x12\x13\n\x0bstoragePool\x18\x06 \x01(\t\x12\x13\n\x0bstorageMode\x18\x07 \x01(\t\x12\x12\n\nvolumeName\x18\x08 \x01(\t\x12\x0e\n\x06\x66sType\x18\t \x01(\t\x12\x10\n\x08readOnly\x18\n \x01(\x08\"\x81\x02\n\x13ScaleIOVolumeSource\x12\x0f\n\x07gateway\x18\x01 \x01(\t\x12\x0e\n\x06system\x18\x02 \x01(\t\x12;\n\tsecretRef\x18\x03 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x12\n\nsslEnabled\x18\x04 \x01(\x08\x12\x18\n\x10protectionDomain\x18\x05 \x01(\t\x12\x13\n\x0bstoragePool\x18\x06 \x01(\t\x12\x13\n\x0bstorageMode\x18\x07 \x01(\t\x12\x12\n\nvolumeName\x18\x08 \x01(\t\x12\x0e\n\x06\x66sType\x18\t \x01(\t\x12\x10\n\x08readOnly\x18\n \x01(\x08\"`\n\rScopeSelector\x12O\n\x10matchExpressions\x18\x01 \x03(\x0b\x32\x35.k8s.io.api.core.v1.ScopedResourceSelectorRequirement\"X\n!ScopedResourceSelectorRequirement\x12\x11\n\tscopeName\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"8\n\x0eSeccompProfile\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x18\n\x10localhostProfile\x18\x02 \x01(\t\"\xc1\x02\n\x06Secret\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x11\n\timmutable\x18\x05 \x01(\x08\x12\x32\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32$.k8s.io.api.core.v1.Secret.DataEntry\x12>\n\nstringData\x18\x04 \x03(\x0b\x32*.k8s.io.api.core.v1.Secret.StringDataEntry\x12\x0c\n\x04type\x18\x03 \x01(\t\x1a+\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a\x31\n\x0fStringDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x0fSecretEnvSource\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x10\n\x08optional\x18\x02 \x01(\x08\"z\n\x11SecretKeySelector\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x10\n\x08optional\x18\x03 \x01(\x08\"y\n\nSecretList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.k8s.io.api.core.v1.Secret\"\x9a\x01\n\x10SecretProjection\x12\x46\n\x14localObjectReference\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.KeyToPath\x12\x10\n\x08optional\x18\x04 \x01(\x08\"2\n\x0fSecretReference\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"}\n\x12SecretVolumeSource\x12\x12\n\nsecretName\x18\x01 \x01(\t\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.k8s.io.api.core.v1.KeyToPath\x12\x13\n\x0b\x64\x65\x66\x61ultMode\x18\x03 \x01(\x05\x12\x10\n\x08optional\x18\x04 \x01(\x08\"\xb2\x03\n\x0fSecurityContext\x12\x36\n\x0c\x63\x61pabilities\x18\x01 \x01(\x0b\x32 .k8s.io.api.core.v1.Capabilities\x12\x12\n\nprivileged\x18\x02 \x01(\x08\x12:\n\x0eseLinuxOptions\x18\x03 \x01(\x0b\x32\".k8s.io.api.core.v1.SELinuxOptions\x12I\n\x0ewindowsOptions\x18\n \x01(\x0b\x32\x31.k8s.io.api.core.v1.WindowsSecurityContextOptions\x12\x11\n\trunAsUser\x18\x04 \x01(\x03\x12\x12\n\nrunAsGroup\x18\x08 \x01(\x03\x12\x14\n\x0crunAsNonRoot\x18\x05 \x01(\x08\x12\x1e\n\x16readOnlyRootFilesystem\x18\x06 \x01(\x08\x12 \n\x18\x61llowPrivilegeEscalation\x18\x07 \x01(\x08\x12\x11\n\tprocMount\x18\t \x01(\t\x12:\n\x0eseccompProfile\x18\x0b \x01(\x0b\x32\".k8s.io.api.core.v1.SeccompProfile\"M\n\x13SerializedReference\x12\x36\n\treference\x18\x01 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xaf\x01\n\x07Service\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12-\n\x04spec\x18\x02 \x01(\x0b\x32\x1f.k8s.io.api.core.v1.ServiceSpec\x12\x31\n\x06status\x18\x03 \x01(\x0b\x32!.k8s.io.api.core.v1.ServiceStatus\"\xf4\x01\n\x0eServiceAccount\x12\x42\n\x08metadata\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x34\n\x07secrets\x18\x02 \x03(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\x12\x42\n\x10imagePullSecrets\x18\x03 \x03(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\x12$\n\x1c\x61utomountServiceAccountToken\x18\x04 \x01(\x08\"\x89\x01\n\x12ServiceAccountList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".k8s.io.api.core.v1.ServiceAccount\"Z\n\x1dServiceAccountTokenProjection\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x19\n\x11\x65xpirationSeconds\x18\x02 \x01(\x03\x12\x0c\n\x04path\x18\x03 \x01(\t\"{\n\x0bServiceList\x12@\n\x08metadata\x18\x01 \x01(\x0b\x32..k8s.io.apimachinery.pkg.apis.meta.v1.ListMeta\x12*\n\x05items\x18\x02 \x03(\x0b\x32\x1b.k8s.io.api.core.v1.Service\"\xa8\x01\n\x0bServicePort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x13\n\x0b\x61ppProtocol\x18\x06 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x44\n\ntargetPort\x18\x04 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x10\n\x08nodePort\x18\x05 \x01(\x05\"#\n\x13ServiceProxyOptions\x12\x0c\n\x04path\x18\x01 \x01(\t\"\xad\x05\n\x0bServiceSpec\x12.\n\x05ports\x18\x01 \x03(\x0b\x32\x1f.k8s.io.api.core.v1.ServicePort\x12?\n\x08selector\x18\x02 \x03(\x0b\x32-.k8s.io.api.core.v1.ServiceSpec.SelectorEntry\x12\x11\n\tclusterIP\x18\x03 \x01(\t\x12\x12\n\nclusterIPs\x18\x12 \x03(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x13\n\x0b\x65xternalIPs\x18\x05 \x03(\t\x12\x17\n\x0fsessionAffinity\x18\x07 \x01(\t\x12\x16\n\x0eloadBalancerIP\x18\x08 \x01(\t\x12 \n\x18loadBalancerSourceRanges\x18\t \x03(\t\x12\x14\n\x0c\x65xternalName\x18\n \x01(\t\x12\x1d\n\x15\x65xternalTrafficPolicy\x18\x0b \x01(\t\x12\x1b\n\x13healthCheckNodePort\x18\x0c \x01(\x05\x12 \n\x18publishNotReadyAddresses\x18\r \x01(\x08\x12H\n\x15sessionAffinityConfig\x18\x0e \x01(\x0b\x32).k8s.io.api.core.v1.SessionAffinityConfig\x12\x14\n\x0ctopologyKeys\x18\x10 \x03(\t\x12\x12\n\nipFamilies\x18\x13 \x03(\t\x12\x16\n\x0eipFamilyPolicy\x18\x11 \x01(\t\x12%\n\x1d\x61llocateLoadBalancerNodePorts\x18\x14 \x01(\x08\x12\x19\n\x11loadBalancerClass\x18\x15 \x01(\t\x12\x1d\n\x15internalTrafficPolicy\x18\x16 \x01(\t\x1a/\n\rSelectorEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x92\x01\n\rServiceStatus\x12<\n\x0cloadBalancer\x18\x01 \x01(\x0b\x32&.k8s.io.api.core.v1.LoadBalancerStatus\x12\x43\n\nconditions\x18\x02 \x03(\x0b\x32/.k8s.io.apimachinery.pkg.apis.meta.v1.Condition\"M\n\x15SessionAffinityConfig\x12\x34\n\x08\x63lientIP\x18\x01 \x01(\x0b\x32\".k8s.io.api.core.v1.ClientIPConfig\"\xa8\x01\n\x1fStorageOSPersistentVolumeSource\x12\x12\n\nvolumeName\x18\x01 \x01(\t\x12\x17\n\x0fvolumeNamespace\x18\x02 \x01(\t\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\x12\x36\n\tsecretRef\x18\x05 \x01(\x0b\x32#.k8s.io.api.core.v1.ObjectReference\"\xa3\x01\n\x15StorageOSVolumeSource\x12\x12\n\nvolumeName\x18\x01 \x01(\t\x12\x17\n\x0fvolumeNamespace\x18\x02 \x01(\t\x12\x0e\n\x06\x66sType\x18\x03 \x01(\t\x12\x10\n\x08readOnly\x18\x04 \x01(\x08\x12;\n\tsecretRef\x18\x05 \x01(\x0b\x32(.k8s.io.api.core.v1.LocalObjectReference\"%\n\x06Sysctl\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"_\n\x0fTCPSocketAction\x12>\n\x04port\x18\x01 \x01(\x0b\x32\x30.k8s.io.apimachinery.pkg.util.intstr.IntOrString\x12\x0c\n\x04host\x18\x02 \x01(\t\"r\n\x05Taint\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\t\x12=\n\ttimeAdded\x18\x04 \x01(\x0b\x32*.k8s.io.apimachinery.pkg.apis.meta.v1.Time\"e\n\nToleration\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x04 \x01(\t\x12\x19\n\x11tolerationSeconds\x18\x05 \x01(\x03\"?\n TopologySelectorLabelRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\t\"k\n\x14TopologySelectorTerm\x12S\n\x15matchLabelExpressions\x18\x01 \x03(\x0b\x32\x34.k8s.io.api.core.v1.TopologySelectorLabelRequirement\"\xa7\x01\n\x18TopologySpreadConstraint\x12\x0f\n\x07maxSkew\x18\x01 \x01(\x05\x12\x13\n\x0btopologyKey\x18\x02 \x01(\t\x12\x19\n\x11whenUnsatisfiable\x18\x03 \x01(\t\x12J\n\rlabelSelector\x18\x04 \x01(\x0b\x32\x33.k8s.io.apimachinery.pkg.apis.meta.v1.LabelSelector\"I\n\x19TypedLocalObjectReference\x12\x10\n\x08\x61piGroup\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"N\n\x06Volume\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x36\n\x0cvolumeSource\x18\x02 \x01(\x0b\x32 .k8s.io.api.core.v1.VolumeSource\"0\n\x0cVolumeDevice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ndevicePath\x18\x02 \x01(\t\"\x80\x01\n\x0bVolumeMount\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08readOnly\x18\x02 \x01(\x08\x12\x11\n\tmountPath\x18\x03 \x01(\t\x12\x0f\n\x07subPath\x18\x04 \x01(\t\x12\x18\n\x10mountPropagation\x18\x05 \x01(\t\x12\x13\n\x0bsubPathExpr\x18\x06 \x01(\t\"H\n\x12VolumeNodeAffinity\x12\x32\n\x08required\x18\x01 \x01(\x0b\x32 .k8s.io.api.core.v1.NodeSelector\"\x94\x02\n\x10VolumeProjection\x12\x34\n\x06secret\x18\x01 \x01(\x0b\x32$.k8s.io.api.core.v1.SecretProjection\x12>\n\x0b\x64ownwardAPI\x18\x02 \x01(\x0b\x32).k8s.io.api.core.v1.DownwardAPIProjection\x12:\n\tconfigMap\x18\x03 \x01(\x0b\x32\'.k8s.io.api.core.v1.ConfigMapProjection\x12N\n\x13serviceAccountToken\x18\x04 \x01(\x0b\x32\x31.k8s.io.api.core.v1.ServiceAccountTokenProjection\"\x99\x0e\n\x0cVolumeSource\x12:\n\x08hostPath\x18\x01 \x01(\x0b\x32(.k8s.io.api.core.v1.HostPathVolumeSource\x12:\n\x08\x65mptyDir\x18\x02 \x01(\x0b\x32(.k8s.io.api.core.v1.EmptyDirVolumeSource\x12L\n\x11gcePersistentDisk\x18\x03 \x01(\x0b\x32\x31.k8s.io.api.core.v1.GCEPersistentDiskVolumeSource\x12R\n\x14\x61wsElasticBlockStore\x18\x04 \x01(\x0b\x32\x34.k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource\x12\x38\n\x07gitRepo\x18\x05 \x01(\x0b\x32\'.k8s.io.api.core.v1.GitRepoVolumeSource\x12\x36\n\x06secret\x18\x06 \x01(\x0b\x32&.k8s.io.api.core.v1.SecretVolumeSource\x12\x30\n\x03nfs\x18\x07 \x01(\x0b\x32#.k8s.io.api.core.v1.NFSVolumeSource\x12\x34\n\x05iscsi\x18\x08 \x01(\x0b\x32%.k8s.io.api.core.v1.ISCSIVolumeSource\x12<\n\tglusterfs\x18\t \x01(\x0b\x32).k8s.io.api.core.v1.GlusterfsVolumeSource\x12T\n\x15persistentVolumeClaim\x18\n \x01(\x0b\x32\x35.k8s.io.api.core.v1.PersistentVolumeClaimVolumeSource\x12\x30\n\x03rbd\x18\x0b \x01(\x0b\x32#.k8s.io.api.core.v1.RBDVolumeSource\x12\x38\n\nflexVolume\x18\x0c \x01(\x0b\x32$.k8s.io.api.core.v1.FlexVolumeSource\x12\x36\n\x06\x63inder\x18\r \x01(\x0b\x32&.k8s.io.api.core.v1.CinderVolumeSource\x12\x36\n\x06\x63\x65phfs\x18\x0e \x01(\x0b\x32&.k8s.io.api.core.v1.CephFSVolumeSource\x12\x38\n\x07\x66locker\x18\x0f \x01(\x0b\x32\'.k8s.io.api.core.v1.FlockerVolumeSource\x12@\n\x0b\x64ownwardAPI\x18\x10 \x01(\x0b\x32+.k8s.io.api.core.v1.DownwardAPIVolumeSource\x12.\n\x02\x66\x63\x18\x11 \x01(\x0b\x32\".k8s.io.api.core.v1.FCVolumeSource\x12<\n\tazureFile\x18\x12 \x01(\x0b\x32).k8s.io.api.core.v1.AzureFileVolumeSource\x12<\n\tconfigMap\x18\x13 \x01(\x0b\x32).k8s.io.api.core.v1.ConfigMapVolumeSource\x12I\n\rvsphereVolume\x18\x14 \x01(\x0b\x32\x32.k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource\x12\x38\n\x07quobyte\x18\x15 \x01(\x0b\x32\'.k8s.io.api.core.v1.QuobyteVolumeSource\x12<\n\tazureDisk\x18\x16 \x01(\x0b\x32).k8s.io.api.core.v1.AzureDiskVolumeSource\x12R\n\x14photonPersistentDisk\x18\x17 \x01(\x0b\x32\x34.k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource\x12<\n\tprojected\x18\x1a \x01(\x0b\x32).k8s.io.api.core.v1.ProjectedVolumeSource\x12@\n\x0eportworxVolume\x18\x18 \x01(\x0b\x32(.k8s.io.api.core.v1.PortworxVolumeSource\x12\x38\n\x07scaleIO\x18\x19 \x01(\x0b\x32\'.k8s.io.api.core.v1.ScaleIOVolumeSource\x12<\n\tstorageos\x18\x1b \x01(\x0b\x32).k8s.io.api.core.v1.StorageOSVolumeSource\x12\x30\n\x03\x63si\x18\x1c \x01(\x0b\x32#.k8s.io.api.core.v1.CSIVolumeSource\x12<\n\tephemeral\x18\x1d \x01(\x0b\x32).k8s.io.api.core.v1.EphemeralVolumeSource\"x\n\x1eVsphereVirtualDiskVolumeSource\x12\x12\n\nvolumePath\x18\x01 \x01(\t\x12\x0e\n\x06\x66sType\x18\x02 \x01(\t\x12\x19\n\x11storagePolicyName\x18\x03 \x01(\t\x12\x17\n\x0fstoragePolicyID\x18\x04 \x01(\t\"g\n\x17WeightedPodAffinityTerm\x12\x0e\n\x06weight\x18\x01 \x01(\x05\x12<\n\x0fpodAffinityTerm\x18\x02 \x01(\x0b\x32#.k8s.io.api.core.v1.PodAffinityTerm\"r\n\x1dWindowsSecurityContextOptions\x12\x1e\n\x16gmsaCredentialSpecName\x18\x01 \x01(\t\x12\x1a\n\x12gmsaCredentialSpec\x18\x02 \x01(\t\x12\x15\n\rrunAsUserName\x18\x03 \x01(\tB\x04Z\x02v1'
  ,
  dependencies=[k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_schema_dot_generated__pb2.DESCRIPTOR,k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2.DESCRIPTOR,])




_AWSELASTICBLOCKSTOREVOLUMESOURCE = _descriptor.Descriptor(
  name='AWSElasticBlockStoreVolumeSource',
  full_name='k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeID', full_name='k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource.volumeID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition', full_name='k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource.partition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=324,
  serialized_end=429,
)


_AFFINITY = _descriptor.Descriptor(
  name='Affinity',
  full_name='k8s.io.api.core.v1.Affinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeAffinity', full_name='k8s.io.api.core.v1.Affinity.nodeAffinity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podAffinity', full_name='k8s.io.api.core.v1.Affinity.podAffinity', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podAntiAffinity', full_name='k8s.io.api.core.v1.Affinity.podAntiAffinity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=614,
)


_ATTACHEDVOLUME = _descriptor.Descriptor(
  name='AttachedVolume',
  full_name='k8s.io.api.core.v1.AttachedVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.AttachedVolume.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devicePath', full_name='k8s.io.api.core.v1.AttachedVolume.devicePath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=666,
)


_AVOIDPODS = _descriptor.Descriptor(
  name='AvoidPods',
  full_name='k8s.io.api.core.v1.AvoidPods',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preferAvoidPods', full_name='k8s.io.api.core.v1.AvoidPods.preferAvoidPods', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=746,
)


_AZUREDISKVOLUMESOURCE = _descriptor.Descriptor(
  name='AzureDiskVolumeSource',
  full_name='k8s.io.api.core.v1.AzureDiskVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='diskName', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.diskName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='diskURI', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.diskURI', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cachingMode', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.cachingMode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.fsType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.readOnly', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.api.core.v1.AzureDiskVolumeSource.kind', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=875,
)


_AZUREFILEPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='AzureFilePersistentVolumeSource',
  full_name='k8s.io.api.core.v1.AzureFilePersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secretName', full_name='k8s.io.api.core.v1.AzureFilePersistentVolumeSource.secretName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shareName', full_name='k8s.io.api.core.v1.AzureFilePersistentVolumeSource.shareName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.AzureFilePersistentVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretNamespace', full_name='k8s.io.api.core.v1.AzureFilePersistentVolumeSource.secretNamespace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=877,
  serialized_end=992,
)


_AZUREFILEVOLUMESOURCE = _descriptor.Descriptor(
  name='AzureFileVolumeSource',
  full_name='k8s.io.api.core.v1.AzureFileVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secretName', full_name='k8s.io.api.core.v1.AzureFileVolumeSource.secretName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shareName', full_name='k8s.io.api.core.v1.AzureFileVolumeSource.shareName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.AzureFileVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=994,
  serialized_end=1074,
)


_BINDING = _descriptor.Descriptor(
  name='Binding',
  full_name='k8s.io.api.core.v1.Binding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Binding.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target', full_name='k8s.io.api.core.v1.Binding.target', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1077,
  serialized_end=1207,
)


_CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY = _descriptor.Descriptor(
  name='VolumeAttributesEntry',
  full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1738,
)

_CSIPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='CSIPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.driver', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeHandle', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.volumeHandle', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.fsType', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeAttributes', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.volumeAttributes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerPublishSecretRef', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.controllerPublishSecretRef', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeStageSecretRef', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.nodeStageSecretRef', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodePublishSecretRef', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.nodePublishSecretRef', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='controllerExpandSecretRef', full_name='k8s.io.api.core.v1.CSIPersistentVolumeSource.controllerExpandSecretRef', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1738,
)


_CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY = _descriptor.Descriptor(
  name='VolumeAttributesEntry',
  full_name='k8s.io.api.core.v1.CSIVolumeSource.VolumeAttributesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.CSIVolumeSource.VolumeAttributesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.CSIVolumeSource.VolumeAttributesEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1683,
  serialized_end=1738,
)

_CSIVOLUMESOURCE = _descriptor.Descriptor(
  name='CSIVolumeSource',
  full_name='k8s.io.api.core.v1.CSIVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver', full_name='k8s.io.api.core.v1.CSIVolumeSource.driver', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CSIVolumeSource.readOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.CSIVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeAttributes', full_name='k8s.io.api.core.v1.CSIVolumeSource.volumeAttributes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodePublishSecretRef', full_name='k8s.io.api.core.v1.CSIVolumeSource.nodePublishSecretRef', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1741,
  serialized_end=2022,
)


_CAPABILITIES = _descriptor.Descriptor(
  name='Capabilities',
  full_name='k8s.io.api.core.v1.Capabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='add', full_name='k8s.io.api.core.v1.Capabilities.add', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop', full_name='k8s.io.api.core.v1.Capabilities.drop', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2065,
)


_CEPHFSPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='CephFSPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitors', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.monitors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretFile', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.secretFile', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.secretRef', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CephFSPersistentVolumeSource.readOnly', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2068,
  serialized_end=2238,
)


_CEPHFSVOLUMESOURCE = _descriptor.Descriptor(
  name='CephFSVolumeSource',
  full_name='k8s.io.api.core.v1.CephFSVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitors', full_name='k8s.io.api.core.v1.CephFSVolumeSource.monitors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.CephFSVolumeSource.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.CephFSVolumeSource.user', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretFile', full_name='k8s.io.api.core.v1.CephFSVolumeSource.secretFile', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.CephFSVolumeSource.secretRef', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CephFSVolumeSource.readOnly', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2241,
  serialized_end=2406,
)


_CINDERPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='CinderPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.CinderPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeID', full_name='k8s.io.api.core.v1.CinderPersistentVolumeSource.volumeID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.CinderPersistentVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CinderPersistentVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.CinderPersistentVolumeSource.secretRef', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2409,
  serialized_end=2547,
)


_CINDERVOLUMESOURCE = _descriptor.Descriptor(
  name='CinderVolumeSource',
  full_name='k8s.io.api.core.v1.CinderVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeID', full_name='k8s.io.api.core.v1.CinderVolumeSource.volumeID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.CinderVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.CinderVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.CinderVolumeSource.secretRef', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2550,
  serialized_end=2683,
)


_CLIENTIPCONFIG = _descriptor.Descriptor(
  name='ClientIPConfig',
  full_name='k8s.io.api.core.v1.ClientIPConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeoutSeconds', full_name='k8s.io.api.core.v1.ClientIPConfig.timeoutSeconds', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2685,
  serialized_end=2725,
)


_COMPONENTCONDITION = _descriptor.Descriptor(
  name='ComponentCondition',
  full_name='k8s.io.api.core.v1.ComponentCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.ComponentCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.ComponentCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.ComponentCondition.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='k8s.io.api.core.v1.ComponentCondition.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2809,
)


_COMPONENTSTATUS = _descriptor.Descriptor(
  name='ComponentStatus',
  full_name='k8s.io.api.core.v1.ComponentStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ComponentStatus.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.ComponentStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2812,
  serialized_end=2957,
)


_COMPONENTSTATUSLIST = _descriptor.Descriptor(
  name='ComponentStatusList',
  full_name='k8s.io.api.core.v1.ComponentStatusList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ComponentStatusList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ComponentStatusList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2960,
  serialized_end=3099,
)


_CONFIGMAP_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='k8s.io.api.core.v1.ConfigMap.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ConfigMap.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ConfigMap.DataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3324,
  serialized_end=3367,
)

_CONFIGMAP_BINARYDATAENTRY = _descriptor.Descriptor(
  name='BinaryDataEntry',
  full_name='k8s.io.api.core.v1.ConfigMap.BinaryDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ConfigMap.BinaryDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ConfigMap.BinaryDataEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3369,
  serialized_end=3418,
)

_CONFIGMAP = _descriptor.Descriptor(
  name='ConfigMap',
  full_name='k8s.io.api.core.v1.ConfigMap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ConfigMap.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='immutable', full_name='k8s.io.api.core.v1.ConfigMap.immutable', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='k8s.io.api.core.v1.ConfigMap.data', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binaryData', full_name='k8s.io.api.core.v1.ConfigMap.binaryData', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CONFIGMAP_DATAENTRY, _CONFIGMAP_BINARYDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3102,
  serialized_end=3418,
)


_CONFIGMAPENVSOURCE = _descriptor.Descriptor(
  name='ConfigMapEnvSource',
  full_name='k8s.io.api.core.v1.ConfigMapEnvSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.ConfigMapEnvSource.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.ConfigMapEnvSource.optional', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3420,
  serialized_end=3530,
)


_CONFIGMAPKEYSELECTOR = _descriptor.Descriptor(
  name='ConfigMapKeySelector',
  full_name='k8s.io.api.core.v1.ConfigMapKeySelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.ConfigMapKeySelector.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ConfigMapKeySelector.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.ConfigMapKeySelector.optional', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3532,
  serialized_end=3657,
)


_CONFIGMAPLIST = _descriptor.Descriptor(
  name='ConfigMapList',
  full_name='k8s.io.api.core.v1.ConfigMapList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ConfigMapList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ConfigMapList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3659,
  serialized_end=3786,
)


_CONFIGMAPNODECONFIGSOURCE = _descriptor.Descriptor(
  name='ConfigMapNodeConfigSource',
  full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource.uid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource.resourceVersion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubeletConfigKey', full_name='k8s.io.api.core.v1.ConfigMapNodeConfigSource.kubeletConfigKey', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3788,
  serialized_end=3912,
)


_CONFIGMAPPROJECTION = _descriptor.Descriptor(
  name='ConfigMapProjection',
  full_name='k8s.io.api.core.v1.ConfigMapProjection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.ConfigMapProjection.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ConfigMapProjection.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.ConfigMapProjection.optional', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3915,
  serialized_end=4072,
)


_CONFIGMAPVOLUMESOURCE = _descriptor.Descriptor(
  name='ConfigMapVolumeSource',
  full_name='k8s.io.api.core.v1.ConfigMapVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.ConfigMapVolumeSource.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ConfigMapVolumeSource.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultMode', full_name='k8s.io.api.core.v1.ConfigMapVolumeSource.defaultMode', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.ConfigMapVolumeSource.optional', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4075,
  serialized_end=4255,
)


_CONTAINER = _descriptor.Descriptor(
  name='Container',
  full_name='k8s.io.api.core.v1.Container',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.Container.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='k8s.io.api.core.v1.Container.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='k8s.io.api.core.v1.Container.command', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='k8s.io.api.core.v1.Container.args', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workingDir', full_name='k8s.io.api.core.v1.Container.workingDir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.Container.ports', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='envFrom', full_name='k8s.io.api.core.v1.Container.envFrom', index=6,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env', full_name='k8s.io.api.core.v1.Container.env', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='k8s.io.api.core.v1.Container.resources', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeMounts', full_name='k8s.io.api.core.v1.Container.volumeMounts', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeDevices', full_name='k8s.io.api.core.v1.Container.volumeDevices', index=10,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessProbe', full_name='k8s.io.api.core.v1.Container.livenessProbe', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readinessProbe', full_name='k8s.io.api.core.v1.Container.readinessProbe', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startupProbe', full_name='k8s.io.api.core.v1.Container.startupProbe', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle', full_name='k8s.io.api.core.v1.Container.lifecycle', index=14,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationMessagePath', full_name='k8s.io.api.core.v1.Container.terminationMessagePath', index=15,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationMessagePolicy', full_name='k8s.io.api.core.v1.Container.terminationMessagePolicy', index=16,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagePullPolicy', full_name='k8s.io.api.core.v1.Container.imagePullPolicy', index=17,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='securityContext', full_name='k8s.io.api.core.v1.Container.securityContext', index=18,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='k8s.io.api.core.v1.Container.stdin', index=19,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdinOnce', full_name='k8s.io.api.core.v1.Container.stdinOnce', index=20,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tty', full_name='k8s.io.api.core.v1.Container.tty', index=21,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4258,
  serialized_end=5065,
)


_CONTAINERIMAGE = _descriptor.Descriptor(
  name='ContainerImage',
  full_name='k8s.io.api.core.v1.ContainerImage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='names', full_name='k8s.io.api.core.v1.ContainerImage.names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='k8s.io.api.core.v1.ContainerImage.sizeBytes', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5067,
  serialized_end=5117,
)


_CONTAINERPORT = _descriptor.Descriptor(
  name='ContainerPort',
  full_name='k8s.io.api.core.v1.ContainerPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.ContainerPort.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostPort', full_name='k8s.io.api.core.v1.ContainerPort.hostPort', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containerPort', full_name='k8s.io.api.core.v1.ContainerPort.containerPort', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='k8s.io.api.core.v1.ContainerPort.protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostIP', full_name='k8s.io.api.core.v1.ContainerPort.hostIP', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5119,
  serialized_end=5223,
)


_CONTAINERSTATE = _descriptor.Descriptor(
  name='ContainerState',
  full_name='k8s.io.api.core.v1.ContainerState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='waiting', full_name='k8s.io.api.core.v1.ContainerState.waiting', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='running', full_name='k8s.io.api.core.v1.ContainerState.running', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminated', full_name='k8s.io.api.core.v1.ContainerState.terminated', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5226,
  serialized_end=5428,
)


_CONTAINERSTATERUNNING = _descriptor.Descriptor(
  name='ContainerStateRunning',
  full_name='k8s.io.api.core.v1.ContainerStateRunning',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='startedAt', full_name='k8s.io.api.core.v1.ContainerStateRunning.startedAt', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5430,
  serialized_end=5516,
)


_CONTAINERSTATETERMINATED = _descriptor.Descriptor(
  name='ContainerStateTerminated',
  full_name='k8s.io.api.core.v1.ContainerStateTerminated',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exitCode', full_name='k8s.io.api.core.v1.ContainerStateTerminated.exitCode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal', full_name='k8s.io.api.core.v1.ContainerStateTerminated.signal', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.ContainerStateTerminated.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.ContainerStateTerminated.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startedAt', full_name='k8s.io.api.core.v1.ContainerStateTerminated.startedAt', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finishedAt', full_name='k8s.io.api.core.v1.ContainerStateTerminated.finishedAt', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containerID', full_name='k8s.io.api.core.v1.ContainerStateTerminated.containerID', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5519,
  serialized_end=5760,
)


_CONTAINERSTATEWAITING = _descriptor.Descriptor(
  name='ContainerStateWaiting',
  full_name='k8s.io.api.core.v1.ContainerStateWaiting',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.ContainerStateWaiting.reason', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.ContainerStateWaiting.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5762,
  serialized_end=5818,
)


_CONTAINERSTATUS = _descriptor.Descriptor(
  name='ContainerStatus',
  full_name='k8s.io.api.core.v1.ContainerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.ContainerStatus.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='k8s.io.api.core.v1.ContainerStatus.state', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastState', full_name='k8s.io.api.core.v1.ContainerStatus.lastState', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ready', full_name='k8s.io.api.core.v1.ContainerStatus.ready', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='restartCount', full_name='k8s.io.api.core.v1.ContainerStatus.restartCount', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='k8s.io.api.core.v1.ContainerStatus.image', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imageID', full_name='k8s.io.api.core.v1.ContainerStatus.imageID', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containerID', full_name='k8s.io.api.core.v1.ContainerStatus.containerID', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='k8s.io.api.core.v1.ContainerStatus.started', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5821,
  serialized_end=6065,
)


_DAEMONENDPOINT = _descriptor.Descriptor(
  name='DaemonEndpoint',
  full_name='k8s.io.api.core.v1.DaemonEndpoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Port', full_name='k8s.io.api.core.v1.DaemonEndpoint.Port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6067,
  serialized_end=6097,
)


_DOWNWARDAPIPROJECTION = _descriptor.Descriptor(
  name='DownwardAPIProjection',
  full_name='k8s.io.api.core.v1.DownwardAPIProjection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.DownwardAPIProjection.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6099,
  serialized_end=6180,
)


_DOWNWARDAPIVOLUMEFILE = _descriptor.Descriptor(
  name='DownwardAPIVolumeFile',
  full_name='k8s.io.api.core.v1.DownwardAPIVolumeFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.DownwardAPIVolumeFile.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldRef', full_name='k8s.io.api.core.v1.DownwardAPIVolumeFile.fieldRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceFieldRef', full_name='k8s.io.api.core.v1.DownwardAPIVolumeFile.resourceFieldRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='k8s.io.api.core.v1.DownwardAPIVolumeFile.mode', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6183,
  serialized_end=6362,
)


_DOWNWARDAPIVOLUMESOURCE = _descriptor.Descriptor(
  name='DownwardAPIVolumeSource',
  full_name='k8s.io.api.core.v1.DownwardAPIVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.DownwardAPIVolumeSource.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultMode', full_name='k8s.io.api.core.v1.DownwardAPIVolumeSource.defaultMode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6364,
  serialized_end=6468,
)


_EMPTYDIRVOLUMESOURCE = _descriptor.Descriptor(
  name='EmptyDirVolumeSource',
  full_name='k8s.io.api.core.v1.EmptyDirVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='medium', full_name='k8s.io.api.core.v1.EmptyDirVolumeSource.medium', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sizeLimit', full_name='k8s.io.api.core.v1.EmptyDirVolumeSource.sizeLimit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6470,
  serialized_end=6575,
)


_ENDPOINTADDRESS = _descriptor.Descriptor(
  name='EndpointAddress',
  full_name='k8s.io.api.core.v1.EndpointAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='k8s.io.api.core.v1.EndpointAddress.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='k8s.io.api.core.v1.EndpointAddress.hostname', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeName', full_name='k8s.io.api.core.v1.EndpointAddress.nodeName', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetRef', full_name='k8s.io.api.core.v1.EndpointAddress.targetRef', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6577,
  serialized_end=6698,
)


_ENDPOINTPORT = _descriptor.Descriptor(
  name='EndpointPort',
  full_name='k8s.io.api.core.v1.EndpointPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.EndpointPort.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='k8s.io.api.core.v1.EndpointPort.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='k8s.io.api.core.v1.EndpointPort.protocol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appProtocol', full_name='k8s.io.api.core.v1.EndpointPort.appProtocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6700,
  serialized_end=6781,
)


_ENDPOINTSUBSET = _descriptor.Descriptor(
  name='EndpointSubset',
  full_name='k8s.io.api.core.v1.EndpointSubset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='k8s.io.api.core.v1.EndpointSubset.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notReadyAddresses', full_name='k8s.io.api.core.v1.EndpointSubset.notReadyAddresses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.EndpointSubset.ports', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6784,
  serialized_end=6969,
)


_ENDPOINTS = _descriptor.Descriptor(
  name='Endpoints',
  full_name='k8s.io.api.core.v1.Endpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Endpoints.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsets', full_name='k8s.io.api.core.v1.Endpoints.subsets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6972,
  serialized_end=7104,
)


_ENDPOINTSLIST = _descriptor.Descriptor(
  name='EndpointsList',
  full_name='k8s.io.api.core.v1.EndpointsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.EndpointsList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.EndpointsList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7106,
  serialized_end=7233,
)


_ENVFROMSOURCE = _descriptor.Descriptor(
  name='EnvFromSource',
  full_name='k8s.io.api.core.v1.EnvFromSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='k8s.io.api.core.v1.EnvFromSource.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configMapRef', full_name='k8s.io.api.core.v1.EnvFromSource.configMapRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.EnvFromSource.secretRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7236,
  serialized_end=7385,
)


_ENVVAR = _descriptor.Descriptor(
  name='EnvVar',
  full_name='k8s.io.api.core.v1.EnvVar',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.EnvVar.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.EnvVar.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valueFrom', full_name='k8s.io.api.core.v1.EnvVar.valueFrom', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7387,
  serialized_end=7477,
)


_ENVVARSOURCE = _descriptor.Descriptor(
  name='EnvVarSource',
  full_name='k8s.io.api.core.v1.EnvVarSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fieldRef', full_name='k8s.io.api.core.v1.EnvVarSource.fieldRef', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceFieldRef', full_name='k8s.io.api.core.v1.EnvVarSource.resourceFieldRef', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configMapKeyRef', full_name='k8s.io.api.core.v1.EnvVarSource.configMapKeyRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretKeyRef', full_name='k8s.io.api.core.v1.EnvVarSource.secretKeyRef', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7480,
  serialized_end=7750,
)


_EPHEMERALCONTAINER = _descriptor.Descriptor(
  name='EphemeralContainer',
  full_name='k8s.io.api.core.v1.EphemeralContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ephemeralContainerCommon', full_name='k8s.io.api.core.v1.EphemeralContainer.ephemeralContainerCommon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetContainerName', full_name='k8s.io.api.core.v1.EphemeralContainer.targetContainerName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7753,
  serialized_end=7882,
)


_EPHEMERALCONTAINERCOMMON = _descriptor.Descriptor(
  name='EphemeralContainerCommon',
  full_name='k8s.io.api.core.v1.EphemeralContainerCommon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.command', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.args', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='workingDir', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.workingDir', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.ports', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='envFrom', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.envFrom', index=6,
      number=19, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.env', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.resources', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeMounts', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.volumeMounts', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeDevices', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.volumeDevices', index=10,
      number=21, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='livenessProbe', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.livenessProbe', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readinessProbe', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.readinessProbe', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startupProbe', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.startupProbe', index=13,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.lifecycle', index=14,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationMessagePath', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.terminationMessagePath', index=15,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationMessagePolicy', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.terminationMessagePolicy', index=16,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagePullPolicy', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.imagePullPolicy', index=17,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='securityContext', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.securityContext', index=18,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdin', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.stdin', index=19,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdinOnce', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.stdinOnce', index=20,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tty', full_name='k8s.io.api.core.v1.EphemeralContainerCommon.tty', index=21,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7885,
  serialized_end=8707,
)


_EPHEMERALCONTAINERS = _descriptor.Descriptor(
  name='EphemeralContainers',
  full_name='k8s.io.api.core.v1.EphemeralContainers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.EphemeralContainers.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeralContainers', full_name='k8s.io.api.core.v1.EphemeralContainers.ephemeralContainers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8710,
  serialized_end=8868,
)


_EPHEMERALVOLUMESOURCE = _descriptor.Descriptor(
  name='EphemeralVolumeSource',
  full_name='k8s.io.api.core.v1.EphemeralVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeClaimTemplate', full_name='k8s.io.api.core.v1.EphemeralVolumeSource.volumeClaimTemplate', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8870,
  serialized_end=8973,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='k8s.io.api.core.v1.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Event.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='involvedObject', full_name='k8s.io.api.core.v1.Event.involvedObject', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.Event.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.Event.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source', full_name='k8s.io.api.core.v1.Event.source', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firstTimestamp', full_name='k8s.io.api.core.v1.Event.firstTimestamp', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTimestamp', full_name='k8s.io.api.core.v1.Event.lastTimestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='k8s.io.api.core.v1.Event.count', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.Event.type', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eventTime', full_name='k8s.io.api.core.v1.Event.eventTime', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='series', full_name='k8s.io.api.core.v1.Event.series', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='k8s.io.api.core.v1.Event.action', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='related', full_name='k8s.io.api.core.v1.Event.related', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reportingComponent', full_name='k8s.io.api.core.v1.Event.reportingComponent', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reportingInstance', full_name='k8s.io.api.core.v1.Event.reportingInstance', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8976,
  serialized_end=9600,
)


_EVENTLIST = _descriptor.Descriptor(
  name='EventList',
  full_name='k8s.io.api.core.v1.EventList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.EventList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.EventList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9602,
  serialized_end=9721,
)


_EVENTSERIES = _descriptor.Descriptor(
  name='EventSeries',
  full_name='k8s.io.api.core.v1.EventSeries',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='k8s.io.api.core.v1.EventSeries.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastObservedTime', full_name='k8s.io.api.core.v1.EventSeries.lastObservedTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9723,
  serialized_end=9826,
)


_EVENTSOURCE = _descriptor.Descriptor(
  name='EventSource',
  full_name='k8s.io.api.core.v1.EventSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='k8s.io.api.core.v1.EventSource.component', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='k8s.io.api.core.v1.EventSource.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9828,
  serialized_end=9874,
)


_EXECACTION = _descriptor.Descriptor(
  name='ExecAction',
  full_name='k8s.io.api.core.v1.ExecAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='k8s.io.api.core.v1.ExecAction.command', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9876,
  serialized_end=9905,
)


_FCVOLUMESOURCE = _descriptor.Descriptor(
  name='FCVolumeSource',
  full_name='k8s.io.api.core.v1.FCVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetWWNs', full_name='k8s.io.api.core.v1.FCVolumeSource.targetWWNs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lun', full_name='k8s.io.api.core.v1.FCVolumeSource.lun', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.FCVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.FCVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wwids', full_name='k8s.io.api.core.v1.FCVolumeSource.wwids', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9907,
  serialized_end=10005,
)


_FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10222,
  serialized_end=10268,
)

_FLEXPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='FlexPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.driver', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.secretRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='k8s.io.api.core.v1.FlexPersistentVolumeSource.options', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10008,
  serialized_end=10268,
)


_FLEXVOLUMESOURCE_OPTIONSENTRY = _descriptor.Descriptor(
  name='OptionsEntry',
  full_name='k8s.io.api.core.v1.FlexVolumeSource.OptionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.FlexVolumeSource.OptionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.FlexVolumeSource.OptionsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10222,
  serialized_end=10268,
)

_FLEXVOLUMESOURCE = _descriptor.Descriptor(
  name='FlexVolumeSource',
  full_name='k8s.io.api.core.v1.FlexVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='driver', full_name='k8s.io.api.core.v1.FlexVolumeSource.driver', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.FlexVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.FlexVolumeSource.secretRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.FlexVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='k8s.io.api.core.v1.FlexVolumeSource.options', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FLEXVOLUMESOURCE_OPTIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10271,
  serialized_end=10516,
)


_FLOCKERVOLUMESOURCE = _descriptor.Descriptor(
  name='FlockerVolumeSource',
  full_name='k8s.io.api.core.v1.FlockerVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datasetName', full_name='k8s.io.api.core.v1.FlockerVolumeSource.datasetName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='datasetUUID', full_name='k8s.io.api.core.v1.FlockerVolumeSource.datasetUUID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10518,
  serialized_end=10581,
)


_GCEPERSISTENTDISKVOLUMESOURCE = _descriptor.Descriptor(
  name='GCEPersistentDiskVolumeSource',
  full_name='k8s.io.api.core.v1.GCEPersistentDiskVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pdName', full_name='k8s.io.api.core.v1.GCEPersistentDiskVolumeSource.pdName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.GCEPersistentDiskVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partition', full_name='k8s.io.api.core.v1.GCEPersistentDiskVolumeSource.partition', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.GCEPersistentDiskVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10583,
  serialized_end=10683,
)


_GITREPOVOLUMESOURCE = _descriptor.Descriptor(
  name='GitRepoVolumeSource',
  full_name='k8s.io.api.core.v1.GitRepoVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='repository', full_name='k8s.io.api.core.v1.GitRepoVolumeSource.repository', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='k8s.io.api.core.v1.GitRepoVolumeSource.revision', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directory', full_name='k8s.io.api.core.v1.GitRepoVolumeSource.directory', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10685,
  serialized_end=10763,
)


_GLUSTERFSPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='GlusterfsPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.GlusterfsPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='k8s.io.api.core.v1.GlusterfsPersistentVolumeSource.endpoints', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.GlusterfsPersistentVolumeSource.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.GlusterfsPersistentVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpointsNamespace', full_name='k8s.io.api.core.v1.GlusterfsPersistentVolumeSource.endpointsNamespace', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10765,
  serialized_end=10877,
)


_GLUSTERFSVOLUMESOURCE = _descriptor.Descriptor(
  name='GlusterfsVolumeSource',
  full_name='k8s.io.api.core.v1.GlusterfsVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='k8s.io.api.core.v1.GlusterfsVolumeSource.endpoints', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.GlusterfsVolumeSource.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.GlusterfsVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10879,
  serialized_end=10953,
)


_HTTPGETACTION = _descriptor.Descriptor(
  name='HTTPGetAction',
  full_name='k8s.io.api.core.v1.HTTPGetAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.HTTPGetAction.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='k8s.io.api.core.v1.HTTPGetAction.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='k8s.io.api.core.v1.HTTPGetAction.host', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheme', full_name='k8s.io.api.core.v1.HTTPGetAction.scheme', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='httpHeaders', full_name='k8s.io.api.core.v1.HTTPGetAction.httpHeaders', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10956,
  serialized_end=11132,
)


_HTTPHEADER = _descriptor.Descriptor(
  name='HTTPHeader',
  full_name='k8s.io.api.core.v1.HTTPHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.HTTPHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.HTTPHeader.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11134,
  serialized_end=11175,
)


_HANDLER = _descriptor.Descriptor(
  name='Handler',
  full_name='k8s.io.api.core.v1.Handler',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='exec', full_name='k8s.io.api.core.v1.Handler.exec', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='httpGet', full_name='k8s.io.api.core.v1.Handler.httpGet', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpSocket', full_name='k8s.io.api.core.v1.Handler.tcpSocket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11178,
  serialized_end=11341,
)


_HOSTALIAS = _descriptor.Descriptor(
  name='HostAlias',
  full_name='k8s.io.api.core.v1.HostAlias',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='k8s.io.api.core.v1.HostAlias.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostnames', full_name='k8s.io.api.core.v1.HostAlias.hostnames', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11343,
  serialized_end=11385,
)


_HOSTPATHVOLUMESOURCE = _descriptor.Descriptor(
  name='HostPathVolumeSource',
  full_name='k8s.io.api.core.v1.HostPathVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.HostPathVolumeSource.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.HostPathVolumeSource.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11387,
  serialized_end=11437,
)


_ISCSIPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='ISCSIPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetPortal', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.targetPortal', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iqn', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.iqn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lun', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.lun', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iscsiInterface', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.iscsiInterface', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.fsType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.readOnly', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portals', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.portals', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chapAuthDiscovery', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.chapAuthDiscovery', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chapAuthSession', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.chapAuthSession', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.secretRef', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initiatorName', full_name='k8s.io.api.core.v1.ISCSIPersistentVolumeSource.initiatorName', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11440,
  serialized_end=11723,
)


_ISCSIVOLUMESOURCE = _descriptor.Descriptor(
  name='ISCSIVolumeSource',
  full_name='k8s.io.api.core.v1.ISCSIVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='targetPortal', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.targetPortal', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iqn', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.iqn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lun', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.lun', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iscsiInterface', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.iscsiInterface', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.fsType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.readOnly', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portals', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.portals', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chapAuthDiscovery', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.chapAuthDiscovery', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chapAuthSession', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.chapAuthSession', index=8,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.secretRef', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initiatorName', full_name='k8s.io.api.core.v1.ISCSIVolumeSource.initiatorName', index=10,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11726,
  serialized_end=12004,
)


_KEYTOPATH = _descriptor.Descriptor(
  name='KeyToPath',
  full_name='k8s.io.api.core.v1.KeyToPath',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.KeyToPath.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.KeyToPath.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='k8s.io.api.core.v1.KeyToPath.mode', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12006,
  serialized_end=12058,
)


_LIFECYCLE = _descriptor.Descriptor(
  name='Lifecycle',
  full_name='k8s.io.api.core.v1.Lifecycle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='postStart', full_name='k8s.io.api.core.v1.Lifecycle.postStart', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preStop', full_name='k8s.io.api.core.v1.Lifecycle.preStop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12060,
  serialized_end=12165,
)


_LIMITRANGE = _descriptor.Descriptor(
  name='LimitRange',
  full_name='k8s.io.api.core.v1.LimitRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.LimitRange.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.LimitRange.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12168,
  serialized_end=12298,
)


_LIMITRANGEITEM_MAXENTRY = _descriptor.Descriptor(
  name='MaxEntry',
  full_name='k8s.io.api.core.v1.LimitRangeItem.MaxEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.LimitRangeItem.MaxEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.LimitRangeItem.MaxEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12687,
  serialized_end=12777,
)

_LIMITRANGEITEM_MINENTRY = _descriptor.Descriptor(
  name='MinEntry',
  full_name='k8s.io.api.core.v1.LimitRangeItem.MinEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.LimitRangeItem.MinEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.LimitRangeItem.MinEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12779,
  serialized_end=12869,
)

_LIMITRANGEITEM_DEFAULTENTRY = _descriptor.Descriptor(
  name='DefaultEntry',
  full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12871,
  serialized_end=12965,
)

_LIMITRANGEITEM_DEFAULTREQUESTENTRY = _descriptor.Descriptor(
  name='DefaultRequestEntry',
  full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultRequestEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultRequestEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.LimitRangeItem.DefaultRequestEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12967,
  serialized_end=13068,
)

_LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY = _descriptor.Descriptor(
  name='MaxLimitRequestRatioEntry',
  full_name='k8s.io.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13070,
  serialized_end=13177,
)

_LIMITRANGEITEM = _descriptor.Descriptor(
  name='LimitRangeItem',
  full_name='k8s.io.api.core.v1.LimitRangeItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.LimitRangeItem.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max', full_name='k8s.io.api.core.v1.LimitRangeItem.max', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min', full_name='k8s.io.api.core.v1.LimitRangeItem.min', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default', full_name='k8s.io.api.core.v1.LimitRangeItem.default', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultRequest', full_name='k8s.io.api.core.v1.LimitRangeItem.defaultRequest', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='maxLimitRequestRatio', full_name='k8s.io.api.core.v1.LimitRangeItem.maxLimitRequestRatio', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LIMITRANGEITEM_MAXENTRY, _LIMITRANGEITEM_MINENTRY, _LIMITRANGEITEM_DEFAULTENTRY, _LIMITRANGEITEM_DEFAULTREQUESTENTRY, _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12301,
  serialized_end=13177,
)


_LIMITRANGELIST = _descriptor.Descriptor(
  name='LimitRangeList',
  full_name='k8s.io.api.core.v1.LimitRangeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.LimitRangeList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.LimitRangeList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13180,
  serialized_end=13309,
)


_LIMITRANGESPEC = _descriptor.Descriptor(
  name='LimitRangeSpec',
  full_name='k8s.io.api.core.v1.LimitRangeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limits', full_name='k8s.io.api.core.v1.LimitRangeSpec.limits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13311,
  serialized_end=13379,
)


_LIST = _descriptor.Descriptor(
  name='List',
  full_name='k8s.io.api.core.v1.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.List.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.List.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13382,
  serialized_end=13516,
)


_LOADBALANCERINGRESS = _descriptor.Descriptor(
  name='LoadBalancerIngress',
  full_name='k8s.io.api.core.v1.LoadBalancerIngress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='k8s.io.api.core.v1.LoadBalancerIngress.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='k8s.io.api.core.v1.LoadBalancerIngress.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.LoadBalancerIngress.ports', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13518,
  serialized_end=13616,
)


_LOADBALANCERSTATUS = _descriptor.Descriptor(
  name='LoadBalancerStatus',
  full_name='k8s.io.api.core.v1.LoadBalancerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ingress', full_name='k8s.io.api.core.v1.LoadBalancerStatus.ingress', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13618,
  serialized_end=13696,
)


_LOCALOBJECTREFERENCE = _descriptor.Descriptor(
  name='LocalObjectReference',
  full_name='k8s.io.api.core.v1.LocalObjectReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.LocalObjectReference.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13698,
  serialized_end=13734,
)


_LOCALVOLUMESOURCE = _descriptor.Descriptor(
  name='LocalVolumeSource',
  full_name='k8s.io.api.core.v1.LocalVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.LocalVolumeSource.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.LocalVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13736,
  serialized_end=13785,
)


_NFSVOLUMESOURCE = _descriptor.Descriptor(
  name='NFSVolumeSource',
  full_name='k8s.io.api.core.v1.NFSVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='k8s.io.api.core.v1.NFSVolumeSource.server', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.NFSVolumeSource.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.NFSVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13787,
  serialized_end=13852,
)


_NAMESPACE = _descriptor.Descriptor(
  name='Namespace',
  full_name='k8s.io.api.core.v1.Namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Namespace.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.Namespace.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.Namespace.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13855,
  serialized_end=14036,
)


_NAMESPACECONDITION = _descriptor.Descriptor(
  name='NamespaceCondition',
  full_name='k8s.io.api.core.v1.NamespaceCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.NamespaceCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.NamespaceCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.api.core.v1.NamespaceCondition.lastTransitionTime', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.NamespaceCondition.reason', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.NamespaceCondition.message', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14039,
  serialized_end=14194,
)


_NAMESPACELIST = _descriptor.Descriptor(
  name='NamespaceList',
  full_name='k8s.io.api.core.v1.NamespaceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.NamespaceList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.NamespaceList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14196,
  serialized_end=14323,
)


_NAMESPACESPEC = _descriptor.Descriptor(
  name='NamespaceSpec',
  full_name='k8s.io.api.core.v1.NamespaceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='finalizers', full_name='k8s.io.api.core.v1.NamespaceSpec.finalizers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14325,
  serialized_end=14360,
)


_NAMESPACESTATUS = _descriptor.Descriptor(
  name='NamespaceStatus',
  full_name='k8s.io.api.core.v1.NamespaceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='k8s.io.api.core.v1.NamespaceStatus.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.NamespaceStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14362,
  serialized_end=14454,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='k8s.io.api.core.v1.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Node.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.Node.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.Node.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14457,
  serialized_end=14623,
)


_NODEADDRESS = _descriptor.Descriptor(
  name='NodeAddress',
  full_name='k8s.io.api.core.v1.NodeAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.NodeAddress.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='k8s.io.api.core.v1.NodeAddress.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14625,
  serialized_end=14669,
)


_NODEAFFINITY = _descriptor.Descriptor(
  name='NodeAffinity',
  full_name='k8s.io.api.core.v1.NodeAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requiredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.NodeAffinity.requiredDuringSchedulingIgnoredDuringExecution', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.NodeAffinity.preferredDuringSchedulingIgnoredDuringExecution', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14672,
  serialized_end=14878,
)


_NODECONDITION = _descriptor.Descriptor(
  name='NodeCondition',
  full_name='k8s.io.api.core.v1.NodeCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.NodeCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.NodeCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastHeartbeatTime', full_name='k8s.io.api.core.v1.NodeCondition.lastHeartbeatTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.api.core.v1.NodeCondition.lastTransitionTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.NodeCondition.reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.NodeCondition.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14881,
  serialized_end=15102,
)


_NODECONFIGSOURCE = _descriptor.Descriptor(
  name='NodeConfigSource',
  full_name='k8s.io.api.core.v1.NodeConfigSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configMap', full_name='k8s.io.api.core.v1.NodeConfigSource.configMap', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15104,
  serialized_end=15188,
)


_NODECONFIGSTATUS = _descriptor.Descriptor(
  name='NodeConfigStatus',
  full_name='k8s.io.api.core.v1.NodeConfigStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='assigned', full_name='k8s.io.api.core.v1.NodeConfigStatus.assigned', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active', full_name='k8s.io.api.core.v1.NodeConfigStatus.active', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastKnownGood', full_name='k8s.io.api.core.v1.NodeConfigStatus.lastKnownGood', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='k8s.io.api.core.v1.NodeConfigStatus.error', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15191,
  serialized_end=15395,
)


_NODEDAEMONENDPOINTS = _descriptor.Descriptor(
  name='NodeDaemonEndpoints',
  full_name='k8s.io.api.core.v1.NodeDaemonEndpoints',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kubeletEndpoint', full_name='k8s.io.api.core.v1.NodeDaemonEndpoints.kubeletEndpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15397,
  serialized_end=15479,
)


_NODELIST = _descriptor.Descriptor(
  name='NodeList',
  full_name='k8s.io.api.core.v1.NodeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.NodeList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.NodeList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15481,
  serialized_end=15598,
)


_NODEPROXYOPTIONS = _descriptor.Descriptor(
  name='NodeProxyOptions',
  full_name='k8s.io.api.core.v1.NodeProxyOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.NodeProxyOptions.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15600,
  serialized_end=15632,
)


_NODERESOURCES_CAPACITYENTRY = _descriptor.Descriptor(
  name='CapacityEntry',
  full_name='k8s.io.api.core.v1.NodeResources.CapacityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.NodeResources.CapacityEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.NodeResources.CapacityEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15719,
  serialized_end=15814,
)

_NODERESOURCES = _descriptor.Descriptor(
  name='NodeResources',
  full_name='k8s.io.api.core.v1.NodeResources',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='k8s.io.api.core.v1.NodeResources.capacity', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODERESOURCES_CAPACITYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15635,
  serialized_end=15814,
)


_NODESELECTOR = _descriptor.Descriptor(
  name='NodeSelector',
  full_name='k8s.io.api.core.v1.NodeSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodeSelectorTerms', full_name='k8s.io.api.core.v1.NodeSelector.nodeSelectorTerms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15816,
  serialized_end=15895,
)


_NODESELECTORREQUIREMENT = _descriptor.Descriptor(
  name='NodeSelectorRequirement',
  full_name='k8s.io.api.core.v1.NodeSelectorRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.NodeSelectorRequirement.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='k8s.io.api.core.v1.NodeSelectorRequirement.operator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='k8s.io.api.core.v1.NodeSelectorRequirement.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15897,
  serialized_end=15969,
)


_NODESELECTORTERM = _descriptor.Descriptor(
  name='NodeSelectorTerm',
  full_name='k8s.io.api.core.v1.NodeSelectorTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchExpressions', full_name='k8s.io.api.core.v1.NodeSelectorTerm.matchExpressions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='matchFields', full_name='k8s.io.api.core.v1.NodeSelectorTerm.matchFields', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15972,
  serialized_end=16127,
)


_NODESPEC = _descriptor.Descriptor(
  name='NodeSpec',
  full_name='k8s.io.api.core.v1.NodeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='podCIDR', full_name='k8s.io.api.core.v1.NodeSpec.podCIDR', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podCIDRs', full_name='k8s.io.api.core.v1.NodeSpec.podCIDRs', index=1,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='providerID', full_name='k8s.io.api.core.v1.NodeSpec.providerID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unschedulable', full_name='k8s.io.api.core.v1.NodeSpec.unschedulable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='taints', full_name='k8s.io.api.core.v1.NodeSpec.taints', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configSource', full_name='k8s.io.api.core.v1.NodeSpec.configSource', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='externalID', full_name='k8s.io.api.core.v1.NodeSpec.externalID', index=6,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16130,
  serialized_end=16341,
)


_NODESTATUS_CAPACITYENTRY = _descriptor.Descriptor(
  name='CapacityEntry',
  full_name='k8s.io.api.core.v1.NodeStatus.CapacityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.NodeStatus.CapacityEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.NodeStatus.CapacityEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15719,
  serialized_end=15814,
)

_NODESTATUS_ALLOCATABLEENTRY = _descriptor.Descriptor(
  name='AllocatableEntry',
  full_name='k8s.io.api.core.v1.NodeStatus.AllocatableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.NodeStatus.AllocatableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.NodeStatus.AllocatableEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17020,
  serialized_end=17118,
)

_NODESTATUS = _descriptor.Descriptor(
  name='NodeStatus',
  full_name='k8s.io.api.core.v1.NodeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='k8s.io.api.core.v1.NodeStatus.capacity', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocatable', full_name='k8s.io.api.core.v1.NodeStatus.allocatable', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phase', full_name='k8s.io.api.core.v1.NodeStatus.phase', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.NodeStatus.conditions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='addresses', full_name='k8s.io.api.core.v1.NodeStatus.addresses', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='daemonEndpoints', full_name='k8s.io.api.core.v1.NodeStatus.daemonEndpoints', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeInfo', full_name='k8s.io.api.core.v1.NodeStatus.nodeInfo', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='images', full_name='k8s.io.api.core.v1.NodeStatus.images', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumesInUse', full_name='k8s.io.api.core.v1.NodeStatus.volumesInUse', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumesAttached', full_name='k8s.io.api.core.v1.NodeStatus.volumesAttached', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='k8s.io.api.core.v1.NodeStatus.config', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NODESTATUS_CAPACITYENTRY, _NODESTATUS_ALLOCATABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16344,
  serialized_end=17118,
)


_NODESYSTEMINFO = _descriptor.Descriptor(
  name='NodeSystemInfo',
  full_name='k8s.io.api.core.v1.NodeSystemInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='machineID', full_name='k8s.io.api.core.v1.NodeSystemInfo.machineID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='systemUUID', full_name='k8s.io.api.core.v1.NodeSystemInfo.systemUUID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bootID', full_name='k8s.io.api.core.v1.NodeSystemInfo.bootID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kernelVersion', full_name='k8s.io.api.core.v1.NodeSystemInfo.kernelVersion', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='osImage', full_name='k8s.io.api.core.v1.NodeSystemInfo.osImage', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containerRuntimeVersion', full_name='k8s.io.api.core.v1.NodeSystemInfo.containerRuntimeVersion', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubeletVersion', full_name='k8s.io.api.core.v1.NodeSystemInfo.kubeletVersion', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kubeProxyVersion', full_name='k8s.io.api.core.v1.NodeSystemInfo.kubeProxyVersion', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operatingSystem', full_name='k8s.io.api.core.v1.NodeSystemInfo.operatingSystem', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='architecture', full_name='k8s.io.api.core.v1.NodeSystemInfo.architecture', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17121,
  serialized_end=17362,
)


_OBJECTFIELDSELECTOR = _descriptor.Descriptor(
  name='ObjectFieldSelector',
  full_name='k8s.io.api.core.v1.ObjectFieldSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiVersion', full_name='k8s.io.api.core.v1.ObjectFieldSelector.apiVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldPath', full_name='k8s.io.api.core.v1.ObjectFieldSelector.fieldPath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17364,
  serialized_end=17424,
)


_OBJECTREFERENCE = _descriptor.Descriptor(
  name='ObjectReference',
  full_name='k8s.io.api.core.v1.ObjectReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.api.core.v1.ObjectReference.kind', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='k8s.io.api.core.v1.ObjectReference.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.ObjectReference.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.api.core.v1.ObjectReference.uid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apiVersion', full_name='k8s.io.api.core.v1.ObjectReference.apiVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resourceVersion', full_name='k8s.io.api.core.v1.ObjectReference.resourceVersion', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fieldPath', full_name='k8s.io.api.core.v1.ObjectReference.fieldPath', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17427,
  serialized_end=17568,
)


_PERSISTENTVOLUME = _descriptor.Descriptor(
  name='PersistentVolume',
  full_name='k8s.io.api.core.v1.PersistentVolume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PersistentVolume.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.PersistentVolume.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.PersistentVolume.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17571,
  serialized_end=17773,
)


_PERSISTENTVOLUMECLAIM = _descriptor.Descriptor(
  name='PersistentVolumeClaim',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaim',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PersistentVolumeClaim.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.PersistentVolumeClaim.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.PersistentVolumeClaim.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17776,
  serialized_end=17993,
)


_PERSISTENTVOLUMECLAIMCONDITION = _descriptor.Descriptor(
  name='PersistentVolumeClaimCondition',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastProbeTime', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.lastProbeTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.lastTransitionTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.PersistentVolumeClaimCondition.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17996,
  serialized_end=18230,
)


_PERSISTENTVOLUMECLAIMLIST = _descriptor.Descriptor(
  name='PersistentVolumeClaimList',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PersistentVolumeClaimList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.PersistentVolumeClaimList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18233,
  serialized_end=18384,
)


_PERSISTENTVOLUMECLAIMSPEC = _descriptor.Descriptor(
  name='PersistentVolumeClaimSpec',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accessModes', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.accessModes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.selector', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.resources', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeName', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.volumeName', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageClassName', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.storageClassName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeMode', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.volumeMode', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dataSource', full_name='k8s.io.api.core.v1.PersistentVolumeClaimSpec.dataSource', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18387,
  serialized_end=18700,
)


_PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY = _descriptor.Descriptor(
  name='CapacityEntry',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15719,
  serialized_end=15814,
)

_PERSISTENTVOLUMECLAIMSTATUS = _descriptor.Descriptor(
  name='PersistentVolumeClaimStatus',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessModes', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.accessModes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.capacity', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.PersistentVolumeClaimStatus.conditions', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18703,
  serialized_end=19018,
)


_PERSISTENTVOLUMECLAIMTEMPLATE = _descriptor.Descriptor(
  name='PersistentVolumeClaimTemplate',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PersistentVolumeClaimTemplate.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.PersistentVolumeClaimTemplate.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19021,
  serialized_end=19181,
)


_PERSISTENTVOLUMECLAIMVOLUMESOURCE = _descriptor.Descriptor(
  name='PersistentVolumeClaimVolumeSource',
  full_name='k8s.io.api.core.v1.PersistentVolumeClaimVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='claimName', full_name='k8s.io.api.core.v1.PersistentVolumeClaimVolumeSource.claimName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.PersistentVolumeClaimVolumeSource.readOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19183,
  serialized_end=19255,
)


_PERSISTENTVOLUMELIST = _descriptor.Descriptor(
  name='PersistentVolumeList',
  full_name='k8s.io.api.core.v1.PersistentVolumeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PersistentVolumeList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.PersistentVolumeList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19258,
  serialized_end=19399,
)


_PERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='PersistentVolumeSource',
  full_name='k8s.io.api.core.v1.PersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gcePersistentDisk', full_name='k8s.io.api.core.v1.PersistentVolumeSource.gcePersistentDisk', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsElasticBlockStore', full_name='k8s.io.api.core.v1.PersistentVolumeSource.awsElasticBlockStore', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostPath', full_name='k8s.io.api.core.v1.PersistentVolumeSource.hostPath', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glusterfs', full_name='k8s.io.api.core.v1.PersistentVolumeSource.glusterfs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nfs', full_name='k8s.io.api.core.v1.PersistentVolumeSource.nfs', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rbd', full_name='k8s.io.api.core.v1.PersistentVolumeSource.rbd', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iscsi', full_name='k8s.io.api.core.v1.PersistentVolumeSource.iscsi', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cinder', full_name='k8s.io.api.core.v1.PersistentVolumeSource.cinder', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cephfs', full_name='k8s.io.api.core.v1.PersistentVolumeSource.cephfs', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fc', full_name='k8s.io.api.core.v1.PersistentVolumeSource.fc', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flocker', full_name='k8s.io.api.core.v1.PersistentVolumeSource.flocker', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flexVolume', full_name='k8s.io.api.core.v1.PersistentVolumeSource.flexVolume', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azureFile', full_name='k8s.io.api.core.v1.PersistentVolumeSource.azureFile', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vsphereVolume', full_name='k8s.io.api.core.v1.PersistentVolumeSource.vsphereVolume', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quobyte', full_name='k8s.io.api.core.v1.PersistentVolumeSource.quobyte', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azureDisk', full_name='k8s.io.api.core.v1.PersistentVolumeSource.azureDisk', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photonPersistentDisk', full_name='k8s.io.api.core.v1.PersistentVolumeSource.photonPersistentDisk', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portworxVolume', full_name='k8s.io.api.core.v1.PersistentVolumeSource.portworxVolume', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaleIO', full_name='k8s.io.api.core.v1.PersistentVolumeSource.scaleIO', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local', full_name='k8s.io.api.core.v1.PersistentVolumeSource.local', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageos', full_name='k8s.io.api.core.v1.PersistentVolumeSource.storageos', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csi', full_name='k8s.io.api.core.v1.PersistentVolumeSource.csi', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19402,
  serialized_end=20871,
)


_PERSISTENTVOLUMESPEC_CAPACITYENTRY = _descriptor.Descriptor(
  name='CapacityEntry',
  full_name='k8s.io.api.core.v1.PersistentVolumeSpec.CapacityEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.CapacityEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.CapacityEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15719,
  serialized_end=15814,
)

_PERSISTENTVOLUMESPEC = _descriptor.Descriptor(
  name='PersistentVolumeSpec',
  full_name='k8s.io.api.core.v1.PersistentVolumeSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capacity', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.capacity', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persistentVolumeSource', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.persistentVolumeSource', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accessModes', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.accessModes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimRef', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.claimRef', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persistentVolumeReclaimPolicy', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.persistentVolumeReclaimPolicy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageClassName', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.storageClassName', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mountOptions', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.mountOptions', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeMode', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.volumeMode', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeAffinity', full_name='k8s.io.api.core.v1.PersistentVolumeSpec.nodeAffinity', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PERSISTENTVOLUMESPEC_CAPACITYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20874,
  serialized_end=21388,
)


_PERSISTENTVOLUMESTATUS = _descriptor.Descriptor(
  name='PersistentVolumeStatus',
  full_name='k8s.io.api.core.v1.PersistentVolumeStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='k8s.io.api.core.v1.PersistentVolumeStatus.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.PersistentVolumeStatus.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.PersistentVolumeStatus.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21390,
  serialized_end=21462,
)


_PHOTONPERSISTENTDISKVOLUMESOURCE = _descriptor.Descriptor(
  name='PhotonPersistentDiskVolumeSource',
  full_name='k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pdID', full_name='k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource.pdID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21464,
  serialized_end=21528,
)


_POD = _descriptor.Descriptor(
  name='Pod',
  full_name='k8s.io.api.core.v1.Pod',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Pod.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.Pod.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.Pod.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21531,
  serialized_end=21694,
)


_PODAFFINITY = _descriptor.Descriptor(
  name='PodAffinity',
  full_name='k8s.io.api.core.v1.PodAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requiredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.PodAffinity.requiredDuringSchedulingIgnoredDuringExecution', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.PodAffinity.preferredDuringSchedulingIgnoredDuringExecution', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21697,
  serialized_end=21905,
)


_PODAFFINITYTERM = _descriptor.Descriptor(
  name='PodAffinityTerm',
  full_name='k8s.io.api.core.v1.PodAffinityTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='labelSelector', full_name='k8s.io.api.core.v1.PodAffinityTerm.labelSelector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespaces', full_name='k8s.io.api.core.v1.PodAffinityTerm.namespaces', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topologyKey', full_name='k8s.io.api.core.v1.PodAffinityTerm.topologyKey', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespaceSelector', full_name='k8s.io.api.core.v1.PodAffinityTerm.namespaceSelector', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21908,
  serialized_end=22122,
)


_PODANTIAFFINITY = _descriptor.Descriptor(
  name='PodAntiAffinity',
  full_name='k8s.io.api.core.v1.PodAntiAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requiredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.PodAntiAffinity.requiredDuringSchedulingIgnoredDuringExecution', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preferredDuringSchedulingIgnoredDuringExecution', full_name='k8s.io.api.core.v1.PodAntiAffinity.preferredDuringSchedulingIgnoredDuringExecution', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22125,
  serialized_end=22337,
)


_PODATTACHOPTIONS = _descriptor.Descriptor(
  name='PodAttachOptions',
  full_name='k8s.io.api.core.v1.PodAttachOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stdin', full_name='k8s.io.api.core.v1.PodAttachOptions.stdin', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdout', full_name='k8s.io.api.core.v1.PodAttachOptions.stdout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='k8s.io.api.core.v1.PodAttachOptions.stderr', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tty', full_name='k8s.io.api.core.v1.PodAttachOptions.tty', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container', full_name='k8s.io.api.core.v1.PodAttachOptions.container', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22339,
  serialized_end=22436,
)


_PODCONDITION = _descriptor.Descriptor(
  name='PodCondition',
  full_name='k8s.io.api.core.v1.PodCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.PodCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.PodCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastProbeTime', full_name='k8s.io.api.core.v1.PodCondition.lastProbeTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.api.core.v1.PodCondition.lastTransitionTime', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.PodCondition.reason', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.PodCondition.message', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22439,
  serialized_end=22655,
)


_PODDNSCONFIG = _descriptor.Descriptor(
  name='PodDNSConfig',
  full_name='k8s.io.api.core.v1.PodDNSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nameservers', full_name='k8s.io.api.core.v1.PodDNSConfig.nameservers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='searches', full_name='k8s.io.api.core.v1.PodDNSConfig.searches', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='options', full_name='k8s.io.api.core.v1.PodDNSConfig.options', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22657,
  serialized_end=22767,
)


_PODDNSCONFIGOPTION = _descriptor.Descriptor(
  name='PodDNSConfigOption',
  full_name='k8s.io.api.core.v1.PodDNSConfigOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.PodDNSConfigOption.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.PodDNSConfigOption.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22769,
  serialized_end=22818,
)


_PODEXECOPTIONS = _descriptor.Descriptor(
  name='PodExecOptions',
  full_name='k8s.io.api.core.v1.PodExecOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stdin', full_name='k8s.io.api.core.v1.PodExecOptions.stdin', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stdout', full_name='k8s.io.api.core.v1.PodExecOptions.stdout', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stderr', full_name='k8s.io.api.core.v1.PodExecOptions.stderr', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tty', full_name='k8s.io.api.core.v1.PodExecOptions.tty', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='container', full_name='k8s.io.api.core.v1.PodExecOptions.container', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='k8s.io.api.core.v1.PodExecOptions.command', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22820,
  serialized_end=22932,
)


_PODIP = _descriptor.Descriptor(
  name='PodIP',
  full_name='k8s.io.api.core.v1.PodIP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip', full_name='k8s.io.api.core.v1.PodIP.ip', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22934,
  serialized_end=22953,
)


_PODLIST = _descriptor.Descriptor(
  name='PodList',
  full_name='k8s.io.api.core.v1.PodList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PodList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.PodList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22955,
  serialized_end=23070,
)


_PODLOGOPTIONS = _descriptor.Descriptor(
  name='PodLogOptions',
  full_name='k8s.io.api.core.v1.PodLogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='container', full_name='k8s.io.api.core.v1.PodLogOptions.container', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='follow', full_name='k8s.io.api.core.v1.PodLogOptions.follow', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous', full_name='k8s.io.api.core.v1.PodLogOptions.previous', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sinceSeconds', full_name='k8s.io.api.core.v1.PodLogOptions.sinceSeconds', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sinceTime', full_name='k8s.io.api.core.v1.PodLogOptions.sinceTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamps', full_name='k8s.io.api.core.v1.PodLogOptions.timestamps', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tailLines', full_name='k8s.io.api.core.v1.PodLogOptions.tailLines', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limitBytes', full_name='k8s.io.api.core.v1.PodLogOptions.limitBytes', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='insecureSkipTLSVerifyBackend', full_name='k8s.io.api.core.v1.PodLogOptions.insecureSkipTLSVerifyBackend', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23073,
  serialized_end=23323,
)


_PODPORTFORWARDOPTIONS = _descriptor.Descriptor(
  name='PodPortForwardOptions',
  full_name='k8s.io.api.core.v1.PodPortForwardOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.PodPortForwardOptions.ports', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23325,
  serialized_end=23363,
)


_PODPROXYOPTIONS = _descriptor.Descriptor(
  name='PodProxyOptions',
  full_name='k8s.io.api.core.v1.PodProxyOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.PodProxyOptions.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23365,
  serialized_end=23396,
)


_PODREADINESSGATE = _descriptor.Descriptor(
  name='PodReadinessGate',
  full_name='k8s.io.api.core.v1.PodReadinessGate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='conditionType', full_name='k8s.io.api.core.v1.PodReadinessGate.conditionType', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23398,
  serialized_end=23439,
)


_PODSECURITYCONTEXT = _descriptor.Descriptor(
  name='PodSecurityContext',
  full_name='k8s.io.api.core.v1.PodSecurityContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='seLinuxOptions', full_name='k8s.io.api.core.v1.PodSecurityContext.seLinuxOptions', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowsOptions', full_name='k8s.io.api.core.v1.PodSecurityContext.windowsOptions', index=1,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsUser', full_name='k8s.io.api.core.v1.PodSecurityContext.runAsUser', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsGroup', full_name='k8s.io.api.core.v1.PodSecurityContext.runAsGroup', index=3,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsNonRoot', full_name='k8s.io.api.core.v1.PodSecurityContext.runAsNonRoot', index=4,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='supplementalGroups', full_name='k8s.io.api.core.v1.PodSecurityContext.supplementalGroups', index=5,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsGroup', full_name='k8s.io.api.core.v1.PodSecurityContext.fsGroup', index=6,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sysctls', full_name='k8s.io.api.core.v1.PodSecurityContext.sysctls', index=7,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsGroupChangePolicy', full_name='k8s.io.api.core.v1.PodSecurityContext.fsGroupChangePolicy', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seccompProfile', full_name='k8s.io.api.core.v1.PodSecurityContext.seccompProfile', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23442,
  serialized_end=23837,
)


_PODSIGNATURE = _descriptor.Descriptor(
  name='PodSignature',
  full_name='k8s.io.api.core.v1.PodSignature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='podController', full_name='k8s.io.api.core.v1.PodSignature.podController', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23839,
  serialized_end=23930,
)


_PODSPEC_NODESELECTORENTRY = _descriptor.Descriptor(
  name='NodeSelectorEntry',
  full_name='k8s.io.api.core.v1.PodSpec.NodeSelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.PodSpec.NodeSelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.PodSpec.NodeSelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25294,
  serialized_end=25345,
)

_PODSPEC_OVERHEADENTRY = _descriptor.Descriptor(
  name='OverheadEntry',
  full_name='k8s.io.api.core.v1.PodSpec.OverheadEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.PodSpec.OverheadEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.PodSpec.OverheadEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25347,
  serialized_end=25442,
)

_PODSPEC = _descriptor.Descriptor(
  name='PodSpec',
  full_name='k8s.io.api.core.v1.PodSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumes', full_name='k8s.io.api.core.v1.PodSpec.volumes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initContainers', full_name='k8s.io.api.core.v1.PodSpec.initContainers', index=1,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containers', full_name='k8s.io.api.core.v1.PodSpec.containers', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeralContainers', full_name='k8s.io.api.core.v1.PodSpec.ephemeralContainers', index=3,
      number=34, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='restartPolicy', full_name='k8s.io.api.core.v1.PodSpec.restartPolicy', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationGracePeriodSeconds', full_name='k8s.io.api.core.v1.PodSpec.terminationGracePeriodSeconds', index=5,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activeDeadlineSeconds', full_name='k8s.io.api.core.v1.PodSpec.activeDeadlineSeconds', index=6,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dnsPolicy', full_name='k8s.io.api.core.v1.PodSpec.dnsPolicy', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeSelector', full_name='k8s.io.api.core.v1.PodSpec.nodeSelector', index=8,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceAccountName', full_name='k8s.io.api.core.v1.PodSpec.serviceAccountName', index=9,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceAccount', full_name='k8s.io.api.core.v1.PodSpec.serviceAccount', index=10,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automountServiceAccountToken', full_name='k8s.io.api.core.v1.PodSpec.automountServiceAccountToken', index=11,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodeName', full_name='k8s.io.api.core.v1.PodSpec.nodeName', index=12,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostNetwork', full_name='k8s.io.api.core.v1.PodSpec.hostNetwork', index=13,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostPID', full_name='k8s.io.api.core.v1.PodSpec.hostPID', index=14,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostIPC', full_name='k8s.io.api.core.v1.PodSpec.hostIPC', index=15,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shareProcessNamespace', full_name='k8s.io.api.core.v1.PodSpec.shareProcessNamespace', index=16,
      number=27, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='securityContext', full_name='k8s.io.api.core.v1.PodSpec.securityContext', index=17,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagePullSecrets', full_name='k8s.io.api.core.v1.PodSpec.imagePullSecrets', index=18,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='k8s.io.api.core.v1.PodSpec.hostname', index=19,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subdomain', full_name='k8s.io.api.core.v1.PodSpec.subdomain', index=20,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='affinity', full_name='k8s.io.api.core.v1.PodSpec.affinity', index=21,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedulerName', full_name='k8s.io.api.core.v1.PodSpec.schedulerName', index=22,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tolerations', full_name='k8s.io.api.core.v1.PodSpec.tolerations', index=23,
      number=22, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostAliases', full_name='k8s.io.api.core.v1.PodSpec.hostAliases', index=24,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priorityClassName', full_name='k8s.io.api.core.v1.PodSpec.priorityClassName', index=25,
      number=24, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='k8s.io.api.core.v1.PodSpec.priority', index=26,
      number=25, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dnsConfig', full_name='k8s.io.api.core.v1.PodSpec.dnsConfig', index=27,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readinessGates', full_name='k8s.io.api.core.v1.PodSpec.readinessGates', index=28,
      number=28, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtimeClassName', full_name='k8s.io.api.core.v1.PodSpec.runtimeClassName', index=29,
      number=29, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enableServiceLinks', full_name='k8s.io.api.core.v1.PodSpec.enableServiceLinks', index=30,
      number=30, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preemptionPolicy', full_name='k8s.io.api.core.v1.PodSpec.preemptionPolicy', index=31,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overhead', full_name='k8s.io.api.core.v1.PodSpec.overhead', index=32,
      number=32, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topologySpreadConstraints', full_name='k8s.io.api.core.v1.PodSpec.topologySpreadConstraints', index=33,
      number=33, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setHostnameAsFQDN', full_name='k8s.io.api.core.v1.PodSpec.setHostnameAsFQDN', index=34,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PODSPEC_NODESELECTORENTRY, _PODSPEC_OVERHEADENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23933,
  serialized_end=25442,
)


_PODSTATUS = _descriptor.Descriptor(
  name='PodStatus',
  full_name='k8s.io.api.core.v1.PodStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phase', full_name='k8s.io.api.core.v1.PodStatus.phase', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.PodStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.PodStatus.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.PodStatus.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nominatedNodeName', full_name='k8s.io.api.core.v1.PodStatus.nominatedNodeName', index=4,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostIP', full_name='k8s.io.api.core.v1.PodStatus.hostIP', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podIP', full_name='k8s.io.api.core.v1.PodStatus.podIP', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podIPs', full_name='k8s.io.api.core.v1.PodStatus.podIPs', index=7,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='k8s.io.api.core.v1.PodStatus.startTime', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initContainerStatuses', full_name='k8s.io.api.core.v1.PodStatus.initContainerStatuses', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='containerStatuses', full_name='k8s.io.api.core.v1.PodStatus.containerStatuses', index=10,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qosClass', full_name='k8s.io.api.core.v1.PodStatus.qosClass', index=11,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeralContainerStatuses', full_name='k8s.io.api.core.v1.PodStatus.ephemeralContainerStatuses', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25445,
  serialized_end=25945,
)


_PODSTATUSRESULT = _descriptor.Descriptor(
  name='PodStatusResult',
  full_name='k8s.io.api.core.v1.PodStatusResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PodStatusResult.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.PodStatusResult.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25948,
  serialized_end=26080,
)


_PODTEMPLATE = _descriptor.Descriptor(
  name='PodTemplate',
  full_name='k8s.io.api.core.v1.PodTemplate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PodTemplate.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='k8s.io.api.core.v1.PodTemplate.template', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26083,
  serialized_end=26219,
)


_PODTEMPLATELIST = _descriptor.Descriptor(
  name='PodTemplateList',
  full_name='k8s.io.api.core.v1.PodTemplateList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PodTemplateList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.PodTemplateList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26222,
  serialized_end=26353,
)


_PODTEMPLATESPEC = _descriptor.Descriptor(
  name='PodTemplateSpec',
  full_name='k8s.io.api.core.v1.PodTemplateSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.PodTemplateSpec.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.PodTemplateSpec.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26356,
  serialized_end=26484,
)


_PORTSTATUS = _descriptor.Descriptor(
  name='PortStatus',
  full_name='k8s.io.api.core.v1.PortStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='k8s.io.api.core.v1.PortStatus.port', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='k8s.io.api.core.v1.PortStatus.protocol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='k8s.io.api.core.v1.PortStatus.error', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26486,
  serialized_end=26545,
)


_PORTWORXVOLUMESOURCE = _descriptor.Descriptor(
  name='PortworxVolumeSource',
  full_name='k8s.io.api.core.v1.PortworxVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeID', full_name='k8s.io.api.core.v1.PortworxVolumeSource.volumeID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.PortworxVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.PortworxVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26547,
  serialized_end=26621,
)


_PRECONDITIONS = _descriptor.Descriptor(
  name='Preconditions',
  full_name='k8s.io.api.core.v1.Preconditions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='k8s.io.api.core.v1.Preconditions.uid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26623,
  serialized_end=26651,
)


_PREFERAVOIDPODSENTRY = _descriptor.Descriptor(
  name='PreferAvoidPodsEntry',
  full_name='k8s.io.api.core.v1.PreferAvoidPodsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='podSignature', full_name='k8s.io.api.core.v1.PreferAvoidPodsEntry.podSignature', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='evictionTime', full_name='k8s.io.api.core.v1.PreferAvoidPodsEntry.evictionTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.PreferAvoidPodsEntry.reason', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.PreferAvoidPodsEntry.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26654,
  serialized_end=26831,
)


_PREFERREDSCHEDULINGTERM = _descriptor.Descriptor(
  name='PreferredSchedulingTerm',
  full_name='k8s.io.api.core.v1.PreferredSchedulingTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight', full_name='k8s.io.api.core.v1.PreferredSchedulingTerm.weight', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preference', full_name='k8s.io.api.core.v1.PreferredSchedulingTerm.preference', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26833,
  serialized_end=26932,
)


_PROBE = _descriptor.Descriptor(
  name='Probe',
  full_name='k8s.io.api.core.v1.Probe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handler', full_name='k8s.io.api.core.v1.Probe.handler', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initialDelaySeconds', full_name='k8s.io.api.core.v1.Probe.initialDelaySeconds', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeoutSeconds', full_name='k8s.io.api.core.v1.Probe.timeoutSeconds', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='periodSeconds', full_name='k8s.io.api.core.v1.Probe.periodSeconds', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='successThreshold', full_name='k8s.io.api.core.v1.Probe.successThreshold', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failureThreshold', full_name='k8s.io.api.core.v1.Probe.failureThreshold', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terminationGracePeriodSeconds', full_name='k8s.io.api.core.v1.Probe.terminationGracePeriodSeconds', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=26935,
  serialized_end=27155,
)


_PROJECTEDVOLUMESOURCE = _descriptor.Descriptor(
  name='ProjectedVolumeSource',
  full_name='k8s.io.api.core.v1.ProjectedVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sources', full_name='k8s.io.api.core.v1.ProjectedVolumeSource.sources', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultMode', full_name='k8s.io.api.core.v1.ProjectedVolumeSource.defaultMode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27157,
  serialized_end=27256,
)


_QUOBYTEVOLUMESOURCE = _descriptor.Descriptor(
  name='QuobyteVolumeSource',
  full_name='k8s.io.api.core.v1.QuobyteVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.registry', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.volume', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.readOnly', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.user', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.group', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tenant', full_name='k8s.io.api.core.v1.QuobyteVolumeSource.tenant', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27258,
  serialized_end=27376,
)


_RBDPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='RBDPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitors', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.monitors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.pool', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.user', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyring', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.keyring', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.secretRef', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.RBDPersistentVolumeSource.readOnly', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27379,
  serialized_end=27574,
)


_RBDVOLUMESOURCE = _descriptor.Descriptor(
  name='RBDVolumeSource',
  full_name='k8s.io.api.core.v1.RBDVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='monitors', full_name='k8s.io.api.core.v1.RBDVolumeSource.monitors', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='k8s.io.api.core.v1.RBDVolumeSource.image', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.RBDVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool', full_name='k8s.io.api.core.v1.RBDVolumeSource.pool', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.RBDVolumeSource.user', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keyring', full_name='k8s.io.api.core.v1.RBDVolumeSource.keyring', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.RBDVolumeSource.secretRef', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.RBDVolumeSource.readOnly', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27577,
  serialized_end=27767,
)


_RANGEALLOCATION = _descriptor.Descriptor(
  name='RangeAllocation',
  full_name='k8s.io.api.core.v1.RangeAllocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.RangeAllocation.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='range', full_name='k8s.io.api.core.v1.RangeAllocation.range', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='k8s.io.api.core.v1.RangeAllocation.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27769,
  serialized_end=27883,
)


_REPLICATIONCONTROLLER = _descriptor.Descriptor(
  name='ReplicationController',
  full_name='k8s.io.api.core.v1.ReplicationController',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ReplicationController.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.ReplicationController.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.ReplicationController.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27886,
  serialized_end=28103,
)


_REPLICATIONCONTROLLERCONDITION = _descriptor.Descriptor(
  name='ReplicationControllerCondition',
  full_name='k8s.io.api.core.v1.ReplicationControllerCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.ReplicationControllerCondition.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.ReplicationControllerCondition.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lastTransitionTime', full_name='k8s.io.api.core.v1.ReplicationControllerCondition.lastTransitionTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='k8s.io.api.core.v1.ReplicationControllerCondition.reason', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='k8s.io.api.core.v1.ReplicationControllerCondition.message', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28106,
  serialized_end=28273,
)


_REPLICATIONCONTROLLERLIST = _descriptor.Descriptor(
  name='ReplicationControllerList',
  full_name='k8s.io.api.core.v1.ReplicationControllerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ReplicationControllerList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ReplicationControllerList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28276,
  serialized_end=28427,
)


_REPLICATIONCONTROLLERSPEC_SELECTORENTRY = _descriptor.Descriptor(
  name='SelectorEntry',
  full_name='k8s.io.api.core.v1.ReplicationControllerSpec.SelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.SelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.SelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28636,
  serialized_end=28683,
)

_REPLICATIONCONTROLLERSPEC = _descriptor.Descriptor(
  name='ReplicationControllerSpec',
  full_name='k8s.io.api.core.v1.ReplicationControllerSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minReadySeconds', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.minReadySeconds', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.selector', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='template', full_name='k8s.io.api.core.v1.ReplicationControllerSpec.template', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_REPLICATIONCONTROLLERSPEC_SELECTORENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28430,
  serialized_end=28683,
)


_REPLICATIONCONTROLLERSTATUS = _descriptor.Descriptor(
  name='ReplicationControllerStatus',
  full_name='k8s.io.api.core.v1.ReplicationControllerStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replicas', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.replicas', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fullyLabeledReplicas', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.fullyLabeledReplicas', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readyReplicas', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.readyReplicas', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='availableReplicas', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.availableReplicas', index=3,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='observedGeneration', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.observedGeneration', index=4,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.ReplicationControllerStatus.conditions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28686,
  serialized_end=28913,
)


_RESOURCEFIELDSELECTOR = _descriptor.Descriptor(
  name='ResourceFieldSelector',
  full_name='k8s.io.api.core.v1.ResourceFieldSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='containerName', full_name='k8s.io.api.core.v1.ResourceFieldSelector.containerName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='k8s.io.api.core.v1.ResourceFieldSelector.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='divisor', full_name='k8s.io.api.core.v1.ResourceFieldSelector.divisor', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28916,
  serialized_end=29045,
)


_RESOURCEQUOTA = _descriptor.Descriptor(
  name='ResourceQuota',
  full_name='k8s.io.api.core.v1.ResourceQuota',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ResourceQuota.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.ResourceQuota.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.ResourceQuota.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29048,
  serialized_end=29241,
)


_RESOURCEQUOTALIST = _descriptor.Descriptor(
  name='ResourceQuotaList',
  full_name='k8s.io.api.core.v1.ResourceQuotaList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ResourceQuotaList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ResourceQuotaList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29244,
  serialized_end=29379,
)


_RESOURCEQUOTASPEC_HARDENTRY = _descriptor.Descriptor(
  name='HardEntry',
  full_name='k8s.io.api.core.v1.ResourceQuotaSpec.HardEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ResourceQuotaSpec.HardEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ResourceQuotaSpec.HardEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29540,
  serialized_end=29631,
)

_RESOURCEQUOTASPEC = _descriptor.Descriptor(
  name='ResourceQuotaSpec',
  full_name='k8s.io.api.core.v1.ResourceQuotaSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hard', full_name='k8s.io.api.core.v1.ResourceQuotaSpec.hard', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scopes', full_name='k8s.io.api.core.v1.ResourceQuotaSpec.scopes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scopeSelector', full_name='k8s.io.api.core.v1.ResourceQuotaSpec.scopeSelector', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEQUOTASPEC_HARDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29382,
  serialized_end=29631,
)


_RESOURCEQUOTASTATUS_HARDENTRY = _descriptor.Descriptor(
  name='HardEntry',
  full_name='k8s.io.api.core.v1.ResourceQuotaStatus.HardEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.HardEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.HardEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29540,
  serialized_end=29631,
)

_RESOURCEQUOTASTATUS_USEDENTRY = _descriptor.Descriptor(
  name='UsedEntry',
  full_name='k8s.io.api.core.v1.ResourceQuotaStatus.UsedEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.UsedEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.UsedEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29880,
  serialized_end=29971,
)

_RESOURCEQUOTASTATUS = _descriptor.Descriptor(
  name='ResourceQuotaStatus',
  full_name='k8s.io.api.core.v1.ResourceQuotaStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hard', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.hard', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used', full_name='k8s.io.api.core.v1.ResourceQuotaStatus.used', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEQUOTASTATUS_HARDENTRY, _RESOURCEQUOTASTATUS_USEDENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29634,
  serialized_end=29971,
)


_RESOURCEREQUIREMENTS_LIMITSENTRY = _descriptor.Descriptor(
  name='LimitsEntry',
  full_name='k8s.io.api.core.v1.ResourceRequirements.LimitsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ResourceRequirements.LimitsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ResourceRequirements.LimitsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30142,
  serialized_end=30235,
)

_RESOURCEREQUIREMENTS_REQUESTSENTRY = _descriptor.Descriptor(
  name='RequestsEntry',
  full_name='k8s.io.api.core.v1.ResourceRequirements.RequestsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ResourceRequirements.RequestsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ResourceRequirements.RequestsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30237,
  serialized_end=30332,
)

_RESOURCEREQUIREMENTS = _descriptor.Descriptor(
  name='ResourceRequirements',
  full_name='k8s.io.api.core.v1.ResourceRequirements',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='limits', full_name='k8s.io.api.core.v1.ResourceRequirements.limits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requests', full_name='k8s.io.api.core.v1.ResourceRequirements.requests', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RESOURCEREQUIREMENTS_LIMITSENTRY, _RESOURCEREQUIREMENTS_REQUESTSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=29974,
  serialized_end=30332,
)


_SELINUXOPTIONS = _descriptor.Descriptor(
  name='SELinuxOptions',
  full_name='k8s.io.api.core.v1.SELinuxOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user', full_name='k8s.io.api.core.v1.SELinuxOptions.user', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='role', full_name='k8s.io.api.core.v1.SELinuxOptions.role', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.SELinuxOptions.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='level', full_name='k8s.io.api.core.v1.SELinuxOptions.level', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30334,
  serialized_end=30407,
)


_SCALEIOPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='ScaleIOPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.gateway', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.system', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.secretRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sslEnabled', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.sslEnabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protectionDomain', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.protectionDomain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storagePool', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.storagePool', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageMode', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.storageMode', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeName', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.volumeName', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.fsType', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.ScaleIOPersistentVolumeSource.readOnly', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30410,
  serialized_end=30672,
)


_SCALEIOVOLUMESOURCE = _descriptor.Descriptor(
  name='ScaleIOVolumeSource',
  full_name='k8s.io.api.core.v1.ScaleIOVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gateway', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.gateway', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.system', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.secretRef', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sslEnabled', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.sslEnabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protectionDomain', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.protectionDomain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storagePool', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.storagePool', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageMode', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.storageMode', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeName', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.volumeName', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.fsType', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.ScaleIOVolumeSource.readOnly', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30675,
  serialized_end=30932,
)


_SCOPESELECTOR = _descriptor.Descriptor(
  name='ScopeSelector',
  full_name='k8s.io.api.core.v1.ScopeSelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchExpressions', full_name='k8s.io.api.core.v1.ScopeSelector.matchExpressions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=30934,
  serialized_end=31030,
)


_SCOPEDRESOURCESELECTORREQUIREMENT = _descriptor.Descriptor(
  name='ScopedResourceSelectorRequirement',
  full_name='k8s.io.api.core.v1.ScopedResourceSelectorRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scopeName', full_name='k8s.io.api.core.v1.ScopedResourceSelectorRequirement.scopeName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='k8s.io.api.core.v1.ScopedResourceSelectorRequirement.operator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='k8s.io.api.core.v1.ScopedResourceSelectorRequirement.values', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31032,
  serialized_end=31120,
)


_SECCOMPPROFILE = _descriptor.Descriptor(
  name='SeccompProfile',
  full_name='k8s.io.api.core.v1.SeccompProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.SeccompProfile.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localhostProfile', full_name='k8s.io.api.core.v1.SeccompProfile.localhostProfile', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31122,
  serialized_end=31178,
)


_SECRET_DATAENTRY = _descriptor.Descriptor(
  name='DataEntry',
  full_name='k8s.io.api.core.v1.Secret.DataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.Secret.DataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.Secret.DataEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31408,
  serialized_end=31451,
)

_SECRET_STRINGDATAENTRY = _descriptor.Descriptor(
  name='StringDataEntry',
  full_name='k8s.io.api.core.v1.Secret.StringDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.Secret.StringDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.Secret.StringDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31453,
  serialized_end=31502,
)

_SECRET = _descriptor.Descriptor(
  name='Secret',
  full_name='k8s.io.api.core.v1.Secret',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Secret.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='immutable', full_name='k8s.io.api.core.v1.Secret.immutable', index=1,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='k8s.io.api.core.v1.Secret.data', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stringData', full_name='k8s.io.api.core.v1.Secret.stringData', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.Secret.type', index=4,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SECRET_DATAENTRY, _SECRET_STRINGDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31181,
  serialized_end=31502,
)


_SECRETENVSOURCE = _descriptor.Descriptor(
  name='SecretEnvSource',
  full_name='k8s.io.api.core.v1.SecretEnvSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.SecretEnvSource.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.SecretEnvSource.optional', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31504,
  serialized_end=31611,
)


_SECRETKEYSELECTOR = _descriptor.Descriptor(
  name='SecretKeySelector',
  full_name='k8s.io.api.core.v1.SecretKeySelector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.SecretKeySelector.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.SecretKeySelector.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.SecretKeySelector.optional', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31613,
  serialized_end=31735,
)


_SECRETLIST = _descriptor.Descriptor(
  name='SecretList',
  full_name='k8s.io.api.core.v1.SecretList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.SecretList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.SecretList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31737,
  serialized_end=31858,
)


_SECRETPROJECTION = _descriptor.Descriptor(
  name='SecretProjection',
  full_name='k8s.io.api.core.v1.SecretProjection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localObjectReference', full_name='k8s.io.api.core.v1.SecretProjection.localObjectReference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.SecretProjection.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.SecretProjection.optional', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31861,
  serialized_end=32015,
)


_SECRETREFERENCE = _descriptor.Descriptor(
  name='SecretReference',
  full_name='k8s.io.api.core.v1.SecretReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.SecretReference.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='k8s.io.api.core.v1.SecretReference.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32017,
  serialized_end=32067,
)


_SECRETVOLUMESOURCE = _descriptor.Descriptor(
  name='SecretVolumeSource',
  full_name='k8s.io.api.core.v1.SecretVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secretName', full_name='k8s.io.api.core.v1.SecretVolumeSource.secretName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.SecretVolumeSource.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='defaultMode', full_name='k8s.io.api.core.v1.SecretVolumeSource.defaultMode', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optional', full_name='k8s.io.api.core.v1.SecretVolumeSource.optional', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32069,
  serialized_end=32194,
)


_SECURITYCONTEXT = _descriptor.Descriptor(
  name='SecurityContext',
  full_name='k8s.io.api.core.v1.SecurityContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='k8s.io.api.core.v1.SecurityContext.capabilities', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privileged', full_name='k8s.io.api.core.v1.SecurityContext.privileged', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seLinuxOptions', full_name='k8s.io.api.core.v1.SecurityContext.seLinuxOptions', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='windowsOptions', full_name='k8s.io.api.core.v1.SecurityContext.windowsOptions', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsUser', full_name='k8s.io.api.core.v1.SecurityContext.runAsUser', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsGroup', full_name='k8s.io.api.core.v1.SecurityContext.runAsGroup', index=5,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsNonRoot', full_name='k8s.io.api.core.v1.SecurityContext.runAsNonRoot', index=6,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnlyRootFilesystem', full_name='k8s.io.api.core.v1.SecurityContext.readOnlyRootFilesystem', index=7,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowPrivilegeEscalation', full_name='k8s.io.api.core.v1.SecurityContext.allowPrivilegeEscalation', index=8,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='procMount', full_name='k8s.io.api.core.v1.SecurityContext.procMount', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seccompProfile', full_name='k8s.io.api.core.v1.SecurityContext.seccompProfile', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32197,
  serialized_end=32631,
)


_SERIALIZEDREFERENCE = _descriptor.Descriptor(
  name='SerializedReference',
  full_name='k8s.io.api.core.v1.SerializedReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='k8s.io.api.core.v1.SerializedReference.reference', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32633,
  serialized_end=32710,
)


_SERVICE = _descriptor.Descriptor(
  name='Service',
  full_name='k8s.io.api.core.v1.Service',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.Service.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='k8s.io.api.core.v1.Service.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='k8s.io.api.core.v1.Service.status', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32713,
  serialized_end=32888,
)


_SERVICEACCOUNT = _descriptor.Descriptor(
  name='ServiceAccount',
  full_name='k8s.io.api.core.v1.ServiceAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ServiceAccount.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secrets', full_name='k8s.io.api.core.v1.ServiceAccount.secrets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imagePullSecrets', full_name='k8s.io.api.core.v1.ServiceAccount.imagePullSecrets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='automountServiceAccountToken', full_name='k8s.io.api.core.v1.ServiceAccount.automountServiceAccountToken', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=32891,
  serialized_end=33135,
)


_SERVICEACCOUNTLIST = _descriptor.Descriptor(
  name='ServiceAccountList',
  full_name='k8s.io.api.core.v1.ServiceAccountList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ServiceAccountList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ServiceAccountList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33138,
  serialized_end=33275,
)


_SERVICEACCOUNTTOKENPROJECTION = _descriptor.Descriptor(
  name='ServiceAccountTokenProjection',
  full_name='k8s.io.api.core.v1.ServiceAccountTokenProjection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audience', full_name='k8s.io.api.core.v1.ServiceAccountTokenProjection.audience', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expirationSeconds', full_name='k8s.io.api.core.v1.ServiceAccountTokenProjection.expirationSeconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.ServiceAccountTokenProjection.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33277,
  serialized_end=33367,
)


_SERVICELIST = _descriptor.Descriptor(
  name='ServiceList',
  full_name='k8s.io.api.core.v1.ServiceList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='k8s.io.api.core.v1.ServiceList.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='k8s.io.api.core.v1.ServiceList.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33369,
  serialized_end=33492,
)


_SERVICEPORT = _descriptor.Descriptor(
  name='ServicePort',
  full_name='k8s.io.api.core.v1.ServicePort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.ServicePort.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='k8s.io.api.core.v1.ServicePort.protocol', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appProtocol', full_name='k8s.io.api.core.v1.ServicePort.appProtocol', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='k8s.io.api.core.v1.ServicePort.port', index=3,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='targetPort', full_name='k8s.io.api.core.v1.ServicePort.targetPort', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nodePort', full_name='k8s.io.api.core.v1.ServicePort.nodePort', index=5,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33495,
  serialized_end=33663,
)


_SERVICEPROXYOPTIONS = _descriptor.Descriptor(
  name='ServiceProxyOptions',
  full_name='k8s.io.api.core.v1.ServiceProxyOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='k8s.io.api.core.v1.ServiceProxyOptions.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33665,
  serialized_end=33700,
)


_SERVICESPEC_SELECTORENTRY = _descriptor.Descriptor(
  name='SelectorEntry',
  full_name='k8s.io.api.core.v1.ServiceSpec.SelectorEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.ServiceSpec.SelectorEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.ServiceSpec.SelectorEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=28636,
  serialized_end=28683,
)

_SERVICESPEC = _descriptor.Descriptor(
  name='ServiceSpec',
  full_name='k8s.io.api.core.v1.ServiceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='k8s.io.api.core.v1.ServiceSpec.ports', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='selector', full_name='k8s.io.api.core.v1.ServiceSpec.selector', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterIP', full_name='k8s.io.api.core.v1.ServiceSpec.clusterIP', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clusterIPs', full_name='k8s.io.api.core.v1.ServiceSpec.clusterIPs', index=3,
      number=18, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='k8s.io.api.core.v1.ServiceSpec.type', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='externalIPs', full_name='k8s.io.api.core.v1.ServiceSpec.externalIPs', index=5,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionAffinity', full_name='k8s.io.api.core.v1.ServiceSpec.sessionAffinity', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loadBalancerIP', full_name='k8s.io.api.core.v1.ServiceSpec.loadBalancerIP', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loadBalancerSourceRanges', full_name='k8s.io.api.core.v1.ServiceSpec.loadBalancerSourceRanges', index=8,
      number=9, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='externalName', full_name='k8s.io.api.core.v1.ServiceSpec.externalName', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='externalTrafficPolicy', full_name='k8s.io.api.core.v1.ServiceSpec.externalTrafficPolicy', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthCheckNodePort', full_name='k8s.io.api.core.v1.ServiceSpec.healthCheckNodePort', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='publishNotReadyAddresses', full_name='k8s.io.api.core.v1.ServiceSpec.publishNotReadyAddresses', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sessionAffinityConfig', full_name='k8s.io.api.core.v1.ServiceSpec.sessionAffinityConfig', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topologyKeys', full_name='k8s.io.api.core.v1.ServiceSpec.topologyKeys', index=14,
      number=16, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipFamilies', full_name='k8s.io.api.core.v1.ServiceSpec.ipFamilies', index=15,
      number=19, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipFamilyPolicy', full_name='k8s.io.api.core.v1.ServiceSpec.ipFamilyPolicy', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allocateLoadBalancerNodePorts', full_name='k8s.io.api.core.v1.ServiceSpec.allocateLoadBalancerNodePorts', index=17,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loadBalancerClass', full_name='k8s.io.api.core.v1.ServiceSpec.loadBalancerClass', index=18,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internalTrafficPolicy', full_name='k8s.io.api.core.v1.ServiceSpec.internalTrafficPolicy', index=19,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SERVICESPEC_SELECTORENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=33703,
  serialized_end=34388,
)


_SERVICESTATUS = _descriptor.Descriptor(
  name='ServiceStatus',
  full_name='k8s.io.api.core.v1.ServiceStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='loadBalancer', full_name='k8s.io.api.core.v1.ServiceStatus.loadBalancer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conditions', full_name='k8s.io.api.core.v1.ServiceStatus.conditions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34391,
  serialized_end=34537,
)


_SESSIONAFFINITYCONFIG = _descriptor.Descriptor(
  name='SessionAffinityConfig',
  full_name='k8s.io.api.core.v1.SessionAffinityConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientIP', full_name='k8s.io.api.core.v1.SessionAffinityConfig.clientIP', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34539,
  serialized_end=34616,
)


_STORAGEOSPERSISTENTVOLUMESOURCE = _descriptor.Descriptor(
  name='StorageOSPersistentVolumeSource',
  full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeName', full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource.volumeName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeNamespace', full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource.volumeNamespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.StorageOSPersistentVolumeSource.secretRef', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34619,
  serialized_end=34787,
)


_STORAGEOSVOLUMESOURCE = _descriptor.Descriptor(
  name='StorageOSVolumeSource',
  full_name='k8s.io.api.core.v1.StorageOSVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumeName', full_name='k8s.io.api.core.v1.StorageOSVolumeSource.volumeName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeNamespace', full_name='k8s.io.api.core.v1.StorageOSVolumeSource.volumeNamespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.StorageOSVolumeSource.fsType', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.StorageOSVolumeSource.readOnly', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secretRef', full_name='k8s.io.api.core.v1.StorageOSVolumeSource.secretRef', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34790,
  serialized_end=34953,
)


_SYSCTL = _descriptor.Descriptor(
  name='Sysctl',
  full_name='k8s.io.api.core.v1.Sysctl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.Sysctl.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.Sysctl.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34955,
  serialized_end=34992,
)


_TCPSOCKETACTION = _descriptor.Descriptor(
  name='TCPSocketAction',
  full_name='k8s.io.api.core.v1.TCPSocketAction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port', full_name='k8s.io.api.core.v1.TCPSocketAction.port', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='k8s.io.api.core.v1.TCPSocketAction.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34994,
  serialized_end=35089,
)


_TAINT = _descriptor.Descriptor(
  name='Taint',
  full_name='k8s.io.api.core.v1.Taint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.Taint.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.Taint.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='k8s.io.api.core.v1.Taint.effect', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeAdded', full_name='k8s.io.api.core.v1.Taint.timeAdded', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35091,
  serialized_end=35205,
)


_TOLERATION = _descriptor.Descriptor(
  name='Toleration',
  full_name='k8s.io.api.core.v1.Toleration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.Toleration.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operator', full_name='k8s.io.api.core.v1.Toleration.operator', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='k8s.io.api.core.v1.Toleration.value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='k8s.io.api.core.v1.Toleration.effect', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tolerationSeconds', full_name='k8s.io.api.core.v1.Toleration.tolerationSeconds', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35207,
  serialized_end=35308,
)


_TOPOLOGYSELECTORLABELREQUIREMENT = _descriptor.Descriptor(
  name='TopologySelectorLabelRequirement',
  full_name='k8s.io.api.core.v1.TopologySelectorLabelRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='k8s.io.api.core.v1.TopologySelectorLabelRequirement.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='k8s.io.api.core.v1.TopologySelectorLabelRequirement.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35310,
  serialized_end=35373,
)


_TOPOLOGYSELECTORTERM = _descriptor.Descriptor(
  name='TopologySelectorTerm',
  full_name='k8s.io.api.core.v1.TopologySelectorTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='matchLabelExpressions', full_name='k8s.io.api.core.v1.TopologySelectorTerm.matchLabelExpressions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35375,
  serialized_end=35482,
)


_TOPOLOGYSPREADCONSTRAINT = _descriptor.Descriptor(
  name='TopologySpreadConstraint',
  full_name='k8s.io.api.core.v1.TopologySpreadConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='maxSkew', full_name='k8s.io.api.core.v1.TopologySpreadConstraint.maxSkew', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='topologyKey', full_name='k8s.io.api.core.v1.TopologySpreadConstraint.topologyKey', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='whenUnsatisfiable', full_name='k8s.io.api.core.v1.TopologySpreadConstraint.whenUnsatisfiable', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labelSelector', full_name='k8s.io.api.core.v1.TopologySpreadConstraint.labelSelector', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35485,
  serialized_end=35652,
)


_TYPEDLOCALOBJECTREFERENCE = _descriptor.Descriptor(
  name='TypedLocalObjectReference',
  full_name='k8s.io.api.core.v1.TypedLocalObjectReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apiGroup', full_name='k8s.io.api.core.v1.TypedLocalObjectReference.apiGroup', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kind', full_name='k8s.io.api.core.v1.TypedLocalObjectReference.kind', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.TypedLocalObjectReference.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35654,
  serialized_end=35727,
)


_VOLUME = _descriptor.Descriptor(
  name='Volume',
  full_name='k8s.io.api.core.v1.Volume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.Volume.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volumeSource', full_name='k8s.io.api.core.v1.Volume.volumeSource', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35729,
  serialized_end=35807,
)


_VOLUMEDEVICE = _descriptor.Descriptor(
  name='VolumeDevice',
  full_name='k8s.io.api.core.v1.VolumeDevice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.VolumeDevice.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='devicePath', full_name='k8s.io.api.core.v1.VolumeDevice.devicePath', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35809,
  serialized_end=35857,
)


_VOLUMEMOUNT = _descriptor.Descriptor(
  name='VolumeMount',
  full_name='k8s.io.api.core.v1.VolumeMount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='k8s.io.api.core.v1.VolumeMount.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='readOnly', full_name='k8s.io.api.core.v1.VolumeMount.readOnly', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mountPath', full_name='k8s.io.api.core.v1.VolumeMount.mountPath', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPath', full_name='k8s.io.api.core.v1.VolumeMount.subPath', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mountPropagation', full_name='k8s.io.api.core.v1.VolumeMount.mountPropagation', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subPathExpr', full_name='k8s.io.api.core.v1.VolumeMount.subPathExpr', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35860,
  serialized_end=35988,
)


_VOLUMENODEAFFINITY = _descriptor.Descriptor(
  name='VolumeNodeAffinity',
  full_name='k8s.io.api.core.v1.VolumeNodeAffinity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='required', full_name='k8s.io.api.core.v1.VolumeNodeAffinity.required', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35990,
  serialized_end=36062,
)


_VOLUMEPROJECTION = _descriptor.Descriptor(
  name='VolumeProjection',
  full_name='k8s.io.api.core.v1.VolumeProjection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='k8s.io.api.core.v1.VolumeProjection.secret', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downwardAPI', full_name='k8s.io.api.core.v1.VolumeProjection.downwardAPI', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configMap', full_name='k8s.io.api.core.v1.VolumeProjection.configMap', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serviceAccountToken', full_name='k8s.io.api.core.v1.VolumeProjection.serviceAccountToken', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36065,
  serialized_end=36341,
)


_VOLUMESOURCE = _descriptor.Descriptor(
  name='VolumeSource',
  full_name='k8s.io.api.core.v1.VolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostPath', full_name='k8s.io.api.core.v1.VolumeSource.hostPath', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emptyDir', full_name='k8s.io.api.core.v1.VolumeSource.emptyDir', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gcePersistentDisk', full_name='k8s.io.api.core.v1.VolumeSource.gcePersistentDisk', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='awsElasticBlockStore', full_name='k8s.io.api.core.v1.VolumeSource.awsElasticBlockStore', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gitRepo', full_name='k8s.io.api.core.v1.VolumeSource.gitRepo', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='k8s.io.api.core.v1.VolumeSource.secret', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nfs', full_name='k8s.io.api.core.v1.VolumeSource.nfs', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='iscsi', full_name='k8s.io.api.core.v1.VolumeSource.iscsi', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='glusterfs', full_name='k8s.io.api.core.v1.VolumeSource.glusterfs', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='persistentVolumeClaim', full_name='k8s.io.api.core.v1.VolumeSource.persistentVolumeClaim', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rbd', full_name='k8s.io.api.core.v1.VolumeSource.rbd', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flexVolume', full_name='k8s.io.api.core.v1.VolumeSource.flexVolume', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cinder', full_name='k8s.io.api.core.v1.VolumeSource.cinder', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cephfs', full_name='k8s.io.api.core.v1.VolumeSource.cephfs', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flocker', full_name='k8s.io.api.core.v1.VolumeSource.flocker', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='downwardAPI', full_name='k8s.io.api.core.v1.VolumeSource.downwardAPI', index=15,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fc', full_name='k8s.io.api.core.v1.VolumeSource.fc', index=16,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azureFile', full_name='k8s.io.api.core.v1.VolumeSource.azureFile', index=17,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configMap', full_name='k8s.io.api.core.v1.VolumeSource.configMap', index=18,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vsphereVolume', full_name='k8s.io.api.core.v1.VolumeSource.vsphereVolume', index=19,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quobyte', full_name='k8s.io.api.core.v1.VolumeSource.quobyte', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='azureDisk', full_name='k8s.io.api.core.v1.VolumeSource.azureDisk', index=21,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='photonPersistentDisk', full_name='k8s.io.api.core.v1.VolumeSource.photonPersistentDisk', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='projected', full_name='k8s.io.api.core.v1.VolumeSource.projected', index=23,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portworxVolume', full_name='k8s.io.api.core.v1.VolumeSource.portworxVolume', index=24,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scaleIO', full_name='k8s.io.api.core.v1.VolumeSource.scaleIO', index=25,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storageos', full_name='k8s.io.api.core.v1.VolumeSource.storageos', index=26,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='csi', full_name='k8s.io.api.core.v1.VolumeSource.csi', index=27,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ephemeral', full_name='k8s.io.api.core.v1.VolumeSource.ephemeral', index=28,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36344,
  serialized_end=38161,
)


_VSPHEREVIRTUALDISKVOLUMESOURCE = _descriptor.Descriptor(
  name='VsphereVirtualDiskVolumeSource',
  full_name='k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volumePath', full_name='k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource.volumePath', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fsType', full_name='k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource.fsType', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storagePolicyName', full_name='k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource.storagePolicyName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storagePolicyID', full_name='k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource.storagePolicyID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38163,
  serialized_end=38283,
)


_WEIGHTEDPODAFFINITYTERM = _descriptor.Descriptor(
  name='WeightedPodAffinityTerm',
  full_name='k8s.io.api.core.v1.WeightedPodAffinityTerm',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='weight', full_name='k8s.io.api.core.v1.WeightedPodAffinityTerm.weight', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='podAffinityTerm', full_name='k8s.io.api.core.v1.WeightedPodAffinityTerm.podAffinityTerm', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38285,
  serialized_end=38388,
)


_WINDOWSSECURITYCONTEXTOPTIONS = _descriptor.Descriptor(
  name='WindowsSecurityContextOptions',
  full_name='k8s.io.api.core.v1.WindowsSecurityContextOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gmsaCredentialSpecName', full_name='k8s.io.api.core.v1.WindowsSecurityContextOptions.gmsaCredentialSpecName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gmsaCredentialSpec', full_name='k8s.io.api.core.v1.WindowsSecurityContextOptions.gmsaCredentialSpec', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runAsUserName', full_name='k8s.io.api.core.v1.WindowsSecurityContextOptions.runAsUserName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38390,
  serialized_end=38504,
)

_AFFINITY.fields_by_name['nodeAffinity'].message_type = _NODEAFFINITY
_AFFINITY.fields_by_name['podAffinity'].message_type = _PODAFFINITY
_AFFINITY.fields_by_name['podAntiAffinity'].message_type = _PODANTIAFFINITY
_AVOIDPODS.fields_by_name['preferAvoidPods'].message_type = _PREFERAVOIDPODSENTRY
_BINDING.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_BINDING.fields_by_name['target'].message_type = _OBJECTREFERENCE
_CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY.containing_type = _CSIPERSISTENTVOLUMESOURCE
_CSIPERSISTENTVOLUMESOURCE.fields_by_name['volumeAttributes'].message_type = _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY
_CSIPERSISTENTVOLUMESOURCE.fields_by_name['controllerPublishSecretRef'].message_type = _SECRETREFERENCE
_CSIPERSISTENTVOLUMESOURCE.fields_by_name['nodeStageSecretRef'].message_type = _SECRETREFERENCE
_CSIPERSISTENTVOLUMESOURCE.fields_by_name['nodePublishSecretRef'].message_type = _SECRETREFERENCE
_CSIPERSISTENTVOLUMESOURCE.fields_by_name['controllerExpandSecretRef'].message_type = _SECRETREFERENCE
_CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY.containing_type = _CSIVOLUMESOURCE
_CSIVOLUMESOURCE.fields_by_name['volumeAttributes'].message_type = _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY
_CSIVOLUMESOURCE.fields_by_name['nodePublishSecretRef'].message_type = _LOCALOBJECTREFERENCE
_CEPHFSPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_CEPHFSVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_CINDERPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_CINDERVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_COMPONENTSTATUS.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_COMPONENTSTATUS.fields_by_name['conditions'].message_type = _COMPONENTCONDITION
_COMPONENTSTATUSLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_COMPONENTSTATUSLIST.fields_by_name['items'].message_type = _COMPONENTSTATUS
_CONFIGMAP_DATAENTRY.containing_type = _CONFIGMAP
_CONFIGMAP_BINARYDATAENTRY.containing_type = _CONFIGMAP
_CONFIGMAP.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_CONFIGMAP.fields_by_name['data'].message_type = _CONFIGMAP_DATAENTRY
_CONFIGMAP.fields_by_name['binaryData'].message_type = _CONFIGMAP_BINARYDATAENTRY
_CONFIGMAPENVSOURCE.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_CONFIGMAPKEYSELECTOR.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_CONFIGMAPLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_CONFIGMAPLIST.fields_by_name['items'].message_type = _CONFIGMAP
_CONFIGMAPPROJECTION.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_CONFIGMAPPROJECTION.fields_by_name['items'].message_type = _KEYTOPATH
_CONFIGMAPVOLUMESOURCE.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_CONFIGMAPVOLUMESOURCE.fields_by_name['items'].message_type = _KEYTOPATH
_CONTAINER.fields_by_name['ports'].message_type = _CONTAINERPORT
_CONTAINER.fields_by_name['envFrom'].message_type = _ENVFROMSOURCE
_CONTAINER.fields_by_name['env'].message_type = _ENVVAR
_CONTAINER.fields_by_name['resources'].message_type = _RESOURCEREQUIREMENTS
_CONTAINER.fields_by_name['volumeMounts'].message_type = _VOLUMEMOUNT
_CONTAINER.fields_by_name['volumeDevices'].message_type = _VOLUMEDEVICE
_CONTAINER.fields_by_name['livenessProbe'].message_type = _PROBE
_CONTAINER.fields_by_name['readinessProbe'].message_type = _PROBE
_CONTAINER.fields_by_name['startupProbe'].message_type = _PROBE
_CONTAINER.fields_by_name['lifecycle'].message_type = _LIFECYCLE
_CONTAINER.fields_by_name['securityContext'].message_type = _SECURITYCONTEXT
_CONTAINERSTATE.fields_by_name['waiting'].message_type = _CONTAINERSTATEWAITING
_CONTAINERSTATE.fields_by_name['running'].message_type = _CONTAINERSTATERUNNING
_CONTAINERSTATE.fields_by_name['terminated'].message_type = _CONTAINERSTATETERMINATED
_CONTAINERSTATERUNNING.fields_by_name['startedAt'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_CONTAINERSTATETERMINATED.fields_by_name['startedAt'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_CONTAINERSTATETERMINATED.fields_by_name['finishedAt'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_CONTAINERSTATUS.fields_by_name['state'].message_type = _CONTAINERSTATE
_CONTAINERSTATUS.fields_by_name['lastState'].message_type = _CONTAINERSTATE
_DOWNWARDAPIPROJECTION.fields_by_name['items'].message_type = _DOWNWARDAPIVOLUMEFILE
_DOWNWARDAPIVOLUMEFILE.fields_by_name['fieldRef'].message_type = _OBJECTFIELDSELECTOR
_DOWNWARDAPIVOLUMEFILE.fields_by_name['resourceFieldRef'].message_type = _RESOURCEFIELDSELECTOR
_DOWNWARDAPIVOLUMESOURCE.fields_by_name['items'].message_type = _DOWNWARDAPIVOLUMEFILE
_EMPTYDIRVOLUMESOURCE.fields_by_name['sizeLimit'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_ENDPOINTADDRESS.fields_by_name['targetRef'].message_type = _OBJECTREFERENCE
_ENDPOINTSUBSET.fields_by_name['addresses'].message_type = _ENDPOINTADDRESS
_ENDPOINTSUBSET.fields_by_name['notReadyAddresses'].message_type = _ENDPOINTADDRESS
_ENDPOINTSUBSET.fields_by_name['ports'].message_type = _ENDPOINTPORT
_ENDPOINTS.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_ENDPOINTS.fields_by_name['subsets'].message_type = _ENDPOINTSUBSET
_ENDPOINTSLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_ENDPOINTSLIST.fields_by_name['items'].message_type = _ENDPOINTS
_ENVFROMSOURCE.fields_by_name['configMapRef'].message_type = _CONFIGMAPENVSOURCE
_ENVFROMSOURCE.fields_by_name['secretRef'].message_type = _SECRETENVSOURCE
_ENVVAR.fields_by_name['valueFrom'].message_type = _ENVVARSOURCE
_ENVVARSOURCE.fields_by_name['fieldRef'].message_type = _OBJECTFIELDSELECTOR
_ENVVARSOURCE.fields_by_name['resourceFieldRef'].message_type = _RESOURCEFIELDSELECTOR
_ENVVARSOURCE.fields_by_name['configMapKeyRef'].message_type = _CONFIGMAPKEYSELECTOR
_ENVVARSOURCE.fields_by_name['secretKeyRef'].message_type = _SECRETKEYSELECTOR
_EPHEMERALCONTAINER.fields_by_name['ephemeralContainerCommon'].message_type = _EPHEMERALCONTAINERCOMMON
_EPHEMERALCONTAINERCOMMON.fields_by_name['ports'].message_type = _CONTAINERPORT
_EPHEMERALCONTAINERCOMMON.fields_by_name['envFrom'].message_type = _ENVFROMSOURCE
_EPHEMERALCONTAINERCOMMON.fields_by_name['env'].message_type = _ENVVAR
_EPHEMERALCONTAINERCOMMON.fields_by_name['resources'].message_type = _RESOURCEREQUIREMENTS
_EPHEMERALCONTAINERCOMMON.fields_by_name['volumeMounts'].message_type = _VOLUMEMOUNT
_EPHEMERALCONTAINERCOMMON.fields_by_name['volumeDevices'].message_type = _VOLUMEDEVICE
_EPHEMERALCONTAINERCOMMON.fields_by_name['livenessProbe'].message_type = _PROBE
_EPHEMERALCONTAINERCOMMON.fields_by_name['readinessProbe'].message_type = _PROBE
_EPHEMERALCONTAINERCOMMON.fields_by_name['startupProbe'].message_type = _PROBE
_EPHEMERALCONTAINERCOMMON.fields_by_name['lifecycle'].message_type = _LIFECYCLE
_EPHEMERALCONTAINERCOMMON.fields_by_name['securityContext'].message_type = _SECURITYCONTEXT
_EPHEMERALCONTAINERS.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_EPHEMERALCONTAINERS.fields_by_name['ephemeralContainers'].message_type = _EPHEMERALCONTAINER
_EPHEMERALVOLUMESOURCE.fields_by_name['volumeClaimTemplate'].message_type = _PERSISTENTVOLUMECLAIMTEMPLATE
_EVENT.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_EVENT.fields_by_name['involvedObject'].message_type = _OBJECTREFERENCE
_EVENT.fields_by_name['source'].message_type = _EVENTSOURCE
_EVENT.fields_by_name['firstTimestamp'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_EVENT.fields_by_name['lastTimestamp'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_EVENT.fields_by_name['eventTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._MICROTIME
_EVENT.fields_by_name['series'].message_type = _EVENTSERIES
_EVENT.fields_by_name['related'].message_type = _OBJECTREFERENCE
_EVENTLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_EVENTLIST.fields_by_name['items'].message_type = _EVENT
_EVENTSERIES.fields_by_name['lastObservedTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._MICROTIME
_FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY.containing_type = _FLEXPERSISTENTVOLUMESOURCE
_FLEXPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_FLEXPERSISTENTVOLUMESOURCE.fields_by_name['options'].message_type = _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY
_FLEXVOLUMESOURCE_OPTIONSENTRY.containing_type = _FLEXVOLUMESOURCE
_FLEXVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_FLEXVOLUMESOURCE.fields_by_name['options'].message_type = _FLEXVOLUMESOURCE_OPTIONSENTRY
_HTTPGETACTION.fields_by_name['port'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2._INTORSTRING
_HTTPGETACTION.fields_by_name['httpHeaders'].message_type = _HTTPHEADER
_HANDLER.fields_by_name['exec'].message_type = _EXECACTION
_HANDLER.fields_by_name['httpGet'].message_type = _HTTPGETACTION
_HANDLER.fields_by_name['tcpSocket'].message_type = _TCPSOCKETACTION
_ISCSIPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_ISCSIVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_LIFECYCLE.fields_by_name['postStart'].message_type = _HANDLER
_LIFECYCLE.fields_by_name['preStop'].message_type = _HANDLER
_LIMITRANGE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_LIMITRANGE.fields_by_name['spec'].message_type = _LIMITRANGESPEC
_LIMITRANGEITEM_MAXENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_LIMITRANGEITEM_MAXENTRY.containing_type = _LIMITRANGEITEM
_LIMITRANGEITEM_MINENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_LIMITRANGEITEM_MINENTRY.containing_type = _LIMITRANGEITEM
_LIMITRANGEITEM_DEFAULTENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_LIMITRANGEITEM_DEFAULTENTRY.containing_type = _LIMITRANGEITEM
_LIMITRANGEITEM_DEFAULTREQUESTENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_LIMITRANGEITEM_DEFAULTREQUESTENTRY.containing_type = _LIMITRANGEITEM
_LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY.containing_type = _LIMITRANGEITEM
_LIMITRANGEITEM.fields_by_name['max'].message_type = _LIMITRANGEITEM_MAXENTRY
_LIMITRANGEITEM.fields_by_name['min'].message_type = _LIMITRANGEITEM_MINENTRY
_LIMITRANGEITEM.fields_by_name['default'].message_type = _LIMITRANGEITEM_DEFAULTENTRY
_LIMITRANGEITEM.fields_by_name['defaultRequest'].message_type = _LIMITRANGEITEM_DEFAULTREQUESTENTRY
_LIMITRANGEITEM.fields_by_name['maxLimitRequestRatio'].message_type = _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY
_LIMITRANGELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_LIMITRANGELIST.fields_by_name['items'].message_type = _LIMITRANGE
_LIMITRANGESPEC.fields_by_name['limits'].message_type = _LIMITRANGEITEM
_LIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_LIST.fields_by_name['items'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_runtime_dot_generated__pb2._RAWEXTENSION
_LOADBALANCERINGRESS.fields_by_name['ports'].message_type = _PORTSTATUS
_LOADBALANCERSTATUS.fields_by_name['ingress'].message_type = _LOADBALANCERINGRESS
_NAMESPACE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_NAMESPACE.fields_by_name['spec'].message_type = _NAMESPACESPEC
_NAMESPACE.fields_by_name['status'].message_type = _NAMESPACESTATUS
_NAMESPACECONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_NAMESPACELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_NAMESPACELIST.fields_by_name['items'].message_type = _NAMESPACE
_NAMESPACESTATUS.fields_by_name['conditions'].message_type = _NAMESPACECONDITION
_NODE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_NODE.fields_by_name['spec'].message_type = _NODESPEC
_NODE.fields_by_name['status'].message_type = _NODESTATUS
_NODEAFFINITY.fields_by_name['requiredDuringSchedulingIgnoredDuringExecution'].message_type = _NODESELECTOR
_NODEAFFINITY.fields_by_name['preferredDuringSchedulingIgnoredDuringExecution'].message_type = _PREFERREDSCHEDULINGTERM
_NODECONDITION.fields_by_name['lastHeartbeatTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_NODECONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_NODECONFIGSOURCE.fields_by_name['configMap'].message_type = _CONFIGMAPNODECONFIGSOURCE
_NODECONFIGSTATUS.fields_by_name['assigned'].message_type = _NODECONFIGSOURCE
_NODECONFIGSTATUS.fields_by_name['active'].message_type = _NODECONFIGSOURCE
_NODECONFIGSTATUS.fields_by_name['lastKnownGood'].message_type = _NODECONFIGSOURCE
_NODEDAEMONENDPOINTS.fields_by_name['kubeletEndpoint'].message_type = _DAEMONENDPOINT
_NODELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_NODELIST.fields_by_name['items'].message_type = _NODE
_NODERESOURCES_CAPACITYENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_NODERESOURCES_CAPACITYENTRY.containing_type = _NODERESOURCES
_NODERESOURCES.fields_by_name['capacity'].message_type = _NODERESOURCES_CAPACITYENTRY
_NODESELECTOR.fields_by_name['nodeSelectorTerms'].message_type = _NODESELECTORTERM
_NODESELECTORTERM.fields_by_name['matchExpressions'].message_type = _NODESELECTORREQUIREMENT
_NODESELECTORTERM.fields_by_name['matchFields'].message_type = _NODESELECTORREQUIREMENT
_NODESPEC.fields_by_name['taints'].message_type = _TAINT
_NODESPEC.fields_by_name['configSource'].message_type = _NODECONFIGSOURCE
_NODESTATUS_CAPACITYENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_NODESTATUS_CAPACITYENTRY.containing_type = _NODESTATUS
_NODESTATUS_ALLOCATABLEENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_NODESTATUS_ALLOCATABLEENTRY.containing_type = _NODESTATUS
_NODESTATUS.fields_by_name['capacity'].message_type = _NODESTATUS_CAPACITYENTRY
_NODESTATUS.fields_by_name['allocatable'].message_type = _NODESTATUS_ALLOCATABLEENTRY
_NODESTATUS.fields_by_name['conditions'].message_type = _NODECONDITION
_NODESTATUS.fields_by_name['addresses'].message_type = _NODEADDRESS
_NODESTATUS.fields_by_name['daemonEndpoints'].message_type = _NODEDAEMONENDPOINTS
_NODESTATUS.fields_by_name['nodeInfo'].message_type = _NODESYSTEMINFO
_NODESTATUS.fields_by_name['images'].message_type = _CONTAINERIMAGE
_NODESTATUS.fields_by_name['volumesAttached'].message_type = _ATTACHEDVOLUME
_NODESTATUS.fields_by_name['config'].message_type = _NODECONFIGSTATUS
_PERSISTENTVOLUME.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PERSISTENTVOLUME.fields_by_name['spec'].message_type = _PERSISTENTVOLUMESPEC
_PERSISTENTVOLUME.fields_by_name['status'].message_type = _PERSISTENTVOLUMESTATUS
_PERSISTENTVOLUMECLAIM.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PERSISTENTVOLUMECLAIM.fields_by_name['spec'].message_type = _PERSISTENTVOLUMECLAIMSPEC
_PERSISTENTVOLUMECLAIM.fields_by_name['status'].message_type = _PERSISTENTVOLUMECLAIMSTATUS
_PERSISTENTVOLUMECLAIMCONDITION.fields_by_name['lastProbeTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PERSISTENTVOLUMECLAIMCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PERSISTENTVOLUMECLAIMLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_PERSISTENTVOLUMECLAIMLIST.fields_by_name['items'].message_type = _PERSISTENTVOLUMECLAIM
_PERSISTENTVOLUMECLAIMSPEC.fields_by_name['selector'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LABELSELECTOR
_PERSISTENTVOLUMECLAIMSPEC.fields_by_name['resources'].message_type = _RESOURCEREQUIREMENTS
_PERSISTENTVOLUMECLAIMSPEC.fields_by_name['dataSource'].message_type = _TYPEDLOCALOBJECTREFERENCE
_PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY.containing_type = _PERSISTENTVOLUMECLAIMSTATUS
_PERSISTENTVOLUMECLAIMSTATUS.fields_by_name['capacity'].message_type = _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY
_PERSISTENTVOLUMECLAIMSTATUS.fields_by_name['conditions'].message_type = _PERSISTENTVOLUMECLAIMCONDITION
_PERSISTENTVOLUMECLAIMTEMPLATE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PERSISTENTVOLUMECLAIMTEMPLATE.fields_by_name['spec'].message_type = _PERSISTENTVOLUMECLAIMSPEC
_PERSISTENTVOLUMELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_PERSISTENTVOLUMELIST.fields_by_name['items'].message_type = _PERSISTENTVOLUME
_PERSISTENTVOLUMESOURCE.fields_by_name['gcePersistentDisk'].message_type = _GCEPERSISTENTDISKVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['awsElasticBlockStore'].message_type = _AWSELASTICBLOCKSTOREVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['hostPath'].message_type = _HOSTPATHVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['glusterfs'].message_type = _GLUSTERFSPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['nfs'].message_type = _NFSVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['rbd'].message_type = _RBDPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['iscsi'].message_type = _ISCSIPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['cinder'].message_type = _CINDERPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['cephfs'].message_type = _CEPHFSPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['fc'].message_type = _FCVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['flocker'].message_type = _FLOCKERVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['flexVolume'].message_type = _FLEXPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['azureFile'].message_type = _AZUREFILEPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['vsphereVolume'].message_type = _VSPHEREVIRTUALDISKVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['quobyte'].message_type = _QUOBYTEVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['azureDisk'].message_type = _AZUREDISKVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['photonPersistentDisk'].message_type = _PHOTONPERSISTENTDISKVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['portworxVolume'].message_type = _PORTWORXVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['scaleIO'].message_type = _SCALEIOPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['local'].message_type = _LOCALVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['storageos'].message_type = _STORAGEOSPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESOURCE.fields_by_name['csi'].message_type = _CSIPERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESPEC_CAPACITYENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_PERSISTENTVOLUMESPEC_CAPACITYENTRY.containing_type = _PERSISTENTVOLUMESPEC
_PERSISTENTVOLUMESPEC.fields_by_name['capacity'].message_type = _PERSISTENTVOLUMESPEC_CAPACITYENTRY
_PERSISTENTVOLUMESPEC.fields_by_name['persistentVolumeSource'].message_type = _PERSISTENTVOLUMESOURCE
_PERSISTENTVOLUMESPEC.fields_by_name['claimRef'].message_type = _OBJECTREFERENCE
_PERSISTENTVOLUMESPEC.fields_by_name['nodeAffinity'].message_type = _VOLUMENODEAFFINITY
_POD.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_POD.fields_by_name['spec'].message_type = _PODSPEC
_POD.fields_by_name['status'].message_type = _PODSTATUS
_PODAFFINITY.fields_by_name['requiredDuringSchedulingIgnoredDuringExecution'].message_type = _PODAFFINITYTERM
_PODAFFINITY.fields_by_name['preferredDuringSchedulingIgnoredDuringExecution'].message_type = _WEIGHTEDPODAFFINITYTERM
_PODAFFINITYTERM.fields_by_name['labelSelector'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LABELSELECTOR
_PODAFFINITYTERM.fields_by_name['namespaceSelector'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LABELSELECTOR
_PODANTIAFFINITY.fields_by_name['requiredDuringSchedulingIgnoredDuringExecution'].message_type = _PODAFFINITYTERM
_PODANTIAFFINITY.fields_by_name['preferredDuringSchedulingIgnoredDuringExecution'].message_type = _WEIGHTEDPODAFFINITYTERM
_PODCONDITION.fields_by_name['lastProbeTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PODCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PODDNSCONFIG.fields_by_name['options'].message_type = _PODDNSCONFIGOPTION
_PODLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_PODLIST.fields_by_name['items'].message_type = _POD
_PODLOGOPTIONS.fields_by_name['sinceTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PODSECURITYCONTEXT.fields_by_name['seLinuxOptions'].message_type = _SELINUXOPTIONS
_PODSECURITYCONTEXT.fields_by_name['windowsOptions'].message_type = _WINDOWSSECURITYCONTEXTOPTIONS
_PODSECURITYCONTEXT.fields_by_name['sysctls'].message_type = _SYSCTL
_PODSECURITYCONTEXT.fields_by_name['seccompProfile'].message_type = _SECCOMPPROFILE
_PODSIGNATURE.fields_by_name['podController'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OWNERREFERENCE
_PODSPEC_NODESELECTORENTRY.containing_type = _PODSPEC
_PODSPEC_OVERHEADENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_PODSPEC_OVERHEADENTRY.containing_type = _PODSPEC
_PODSPEC.fields_by_name['volumes'].message_type = _VOLUME
_PODSPEC.fields_by_name['initContainers'].message_type = _CONTAINER
_PODSPEC.fields_by_name['containers'].message_type = _CONTAINER
_PODSPEC.fields_by_name['ephemeralContainers'].message_type = _EPHEMERALCONTAINER
_PODSPEC.fields_by_name['nodeSelector'].message_type = _PODSPEC_NODESELECTORENTRY
_PODSPEC.fields_by_name['securityContext'].message_type = _PODSECURITYCONTEXT
_PODSPEC.fields_by_name['imagePullSecrets'].message_type = _LOCALOBJECTREFERENCE
_PODSPEC.fields_by_name['affinity'].message_type = _AFFINITY
_PODSPEC.fields_by_name['tolerations'].message_type = _TOLERATION
_PODSPEC.fields_by_name['hostAliases'].message_type = _HOSTALIAS
_PODSPEC.fields_by_name['dnsConfig'].message_type = _PODDNSCONFIG
_PODSPEC.fields_by_name['readinessGates'].message_type = _PODREADINESSGATE
_PODSPEC.fields_by_name['overhead'].message_type = _PODSPEC_OVERHEADENTRY
_PODSPEC.fields_by_name['topologySpreadConstraints'].message_type = _TOPOLOGYSPREADCONSTRAINT
_PODSTATUS.fields_by_name['conditions'].message_type = _PODCONDITION
_PODSTATUS.fields_by_name['podIPs'].message_type = _PODIP
_PODSTATUS.fields_by_name['startTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PODSTATUS.fields_by_name['initContainerStatuses'].message_type = _CONTAINERSTATUS
_PODSTATUS.fields_by_name['containerStatuses'].message_type = _CONTAINERSTATUS
_PODSTATUS.fields_by_name['ephemeralContainerStatuses'].message_type = _CONTAINERSTATUS
_PODSTATUSRESULT.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PODSTATUSRESULT.fields_by_name['status'].message_type = _PODSTATUS
_PODTEMPLATE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PODTEMPLATE.fields_by_name['template'].message_type = _PODTEMPLATESPEC
_PODTEMPLATELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_PODTEMPLATELIST.fields_by_name['items'].message_type = _PODTEMPLATE
_PODTEMPLATESPEC.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_PODTEMPLATESPEC.fields_by_name['spec'].message_type = _PODSPEC
_PREFERAVOIDPODSENTRY.fields_by_name['podSignature'].message_type = _PODSIGNATURE
_PREFERAVOIDPODSENTRY.fields_by_name['evictionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_PREFERREDSCHEDULINGTERM.fields_by_name['preference'].message_type = _NODESELECTORTERM
_PROBE.fields_by_name['handler'].message_type = _HANDLER
_PROJECTEDVOLUMESOURCE.fields_by_name['sources'].message_type = _VOLUMEPROJECTION
_RBDPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_RBDVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_RANGEALLOCATION.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_REPLICATIONCONTROLLER.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_REPLICATIONCONTROLLER.fields_by_name['spec'].message_type = _REPLICATIONCONTROLLERSPEC
_REPLICATIONCONTROLLER.fields_by_name['status'].message_type = _REPLICATIONCONTROLLERSTATUS
_REPLICATIONCONTROLLERCONDITION.fields_by_name['lastTransitionTime'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_REPLICATIONCONTROLLERLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_REPLICATIONCONTROLLERLIST.fields_by_name['items'].message_type = _REPLICATIONCONTROLLER
_REPLICATIONCONTROLLERSPEC_SELECTORENTRY.containing_type = _REPLICATIONCONTROLLERSPEC
_REPLICATIONCONTROLLERSPEC.fields_by_name['selector'].message_type = _REPLICATIONCONTROLLERSPEC_SELECTORENTRY
_REPLICATIONCONTROLLERSPEC.fields_by_name['template'].message_type = _PODTEMPLATESPEC
_REPLICATIONCONTROLLERSTATUS.fields_by_name['conditions'].message_type = _REPLICATIONCONTROLLERCONDITION
_RESOURCEFIELDSELECTOR.fields_by_name['divisor'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEQUOTA.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_RESOURCEQUOTA.fields_by_name['spec'].message_type = _RESOURCEQUOTASPEC
_RESOURCEQUOTA.fields_by_name['status'].message_type = _RESOURCEQUOTASTATUS
_RESOURCEQUOTALIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_RESOURCEQUOTALIST.fields_by_name['items'].message_type = _RESOURCEQUOTA
_RESOURCEQUOTASPEC_HARDENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEQUOTASPEC_HARDENTRY.containing_type = _RESOURCEQUOTASPEC
_RESOURCEQUOTASPEC.fields_by_name['hard'].message_type = _RESOURCEQUOTASPEC_HARDENTRY
_RESOURCEQUOTASPEC.fields_by_name['scopeSelector'].message_type = _SCOPESELECTOR
_RESOURCEQUOTASTATUS_HARDENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEQUOTASTATUS_HARDENTRY.containing_type = _RESOURCEQUOTASTATUS
_RESOURCEQUOTASTATUS_USEDENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEQUOTASTATUS_USEDENTRY.containing_type = _RESOURCEQUOTASTATUS
_RESOURCEQUOTASTATUS.fields_by_name['hard'].message_type = _RESOURCEQUOTASTATUS_HARDENTRY
_RESOURCEQUOTASTATUS.fields_by_name['used'].message_type = _RESOURCEQUOTASTATUS_USEDENTRY
_RESOURCEREQUIREMENTS_LIMITSENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEREQUIREMENTS_LIMITSENTRY.containing_type = _RESOURCEREQUIREMENTS
_RESOURCEREQUIREMENTS_REQUESTSENTRY.fields_by_name['value'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_api_dot_resource_dot_generated__pb2._QUANTITY
_RESOURCEREQUIREMENTS_REQUESTSENTRY.containing_type = _RESOURCEREQUIREMENTS
_RESOURCEREQUIREMENTS.fields_by_name['limits'].message_type = _RESOURCEREQUIREMENTS_LIMITSENTRY
_RESOURCEREQUIREMENTS.fields_by_name['requests'].message_type = _RESOURCEREQUIREMENTS_REQUESTSENTRY
_SCALEIOPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _SECRETREFERENCE
_SCALEIOVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_SCOPESELECTOR.fields_by_name['matchExpressions'].message_type = _SCOPEDRESOURCESELECTORREQUIREMENT
_SECRET_DATAENTRY.containing_type = _SECRET
_SECRET_STRINGDATAENTRY.containing_type = _SECRET
_SECRET.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_SECRET.fields_by_name['data'].message_type = _SECRET_DATAENTRY
_SECRET.fields_by_name['stringData'].message_type = _SECRET_STRINGDATAENTRY
_SECRETENVSOURCE.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_SECRETKEYSELECTOR.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_SECRETLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_SECRETLIST.fields_by_name['items'].message_type = _SECRET
_SECRETPROJECTION.fields_by_name['localObjectReference'].message_type = _LOCALOBJECTREFERENCE
_SECRETPROJECTION.fields_by_name['items'].message_type = _KEYTOPATH
_SECRETVOLUMESOURCE.fields_by_name['items'].message_type = _KEYTOPATH
_SECURITYCONTEXT.fields_by_name['capabilities'].message_type = _CAPABILITIES
_SECURITYCONTEXT.fields_by_name['seLinuxOptions'].message_type = _SELINUXOPTIONS
_SECURITYCONTEXT.fields_by_name['windowsOptions'].message_type = _WINDOWSSECURITYCONTEXTOPTIONS
_SECURITYCONTEXT.fields_by_name['seccompProfile'].message_type = _SECCOMPPROFILE
_SERIALIZEDREFERENCE.fields_by_name['reference'].message_type = _OBJECTREFERENCE
_SERVICE.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_SERVICE.fields_by_name['spec'].message_type = _SERVICESPEC
_SERVICE.fields_by_name['status'].message_type = _SERVICESTATUS
_SERVICEACCOUNT.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._OBJECTMETA
_SERVICEACCOUNT.fields_by_name['secrets'].message_type = _OBJECTREFERENCE
_SERVICEACCOUNT.fields_by_name['imagePullSecrets'].message_type = _LOCALOBJECTREFERENCE
_SERVICEACCOUNTLIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_SERVICEACCOUNTLIST.fields_by_name['items'].message_type = _SERVICEACCOUNT
_SERVICELIST.fields_by_name['metadata'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LISTMETA
_SERVICELIST.fields_by_name['items'].message_type = _SERVICE
_SERVICEPORT.fields_by_name['targetPort'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2._INTORSTRING
_SERVICESPEC_SELECTORENTRY.containing_type = _SERVICESPEC
_SERVICESPEC.fields_by_name['ports'].message_type = _SERVICEPORT
_SERVICESPEC.fields_by_name['selector'].message_type = _SERVICESPEC_SELECTORENTRY
_SERVICESPEC.fields_by_name['sessionAffinityConfig'].message_type = _SESSIONAFFINITYCONFIG
_SERVICESTATUS.fields_by_name['loadBalancer'].message_type = _LOADBALANCERSTATUS
_SERVICESTATUS.fields_by_name['conditions'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._CONDITION
_SESSIONAFFINITYCONFIG.fields_by_name['clientIP'].message_type = _CLIENTIPCONFIG
_STORAGEOSPERSISTENTVOLUMESOURCE.fields_by_name['secretRef'].message_type = _OBJECTREFERENCE
_STORAGEOSVOLUMESOURCE.fields_by_name['secretRef'].message_type = _LOCALOBJECTREFERENCE
_TCPSOCKETACTION.fields_by_name['port'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_util_dot_intstr_dot_generated__pb2._INTORSTRING
_TAINT.fields_by_name['timeAdded'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._TIME
_TOPOLOGYSELECTORTERM.fields_by_name['matchLabelExpressions'].message_type = _TOPOLOGYSELECTORLABELREQUIREMENT
_TOPOLOGYSPREADCONSTRAINT.fields_by_name['labelSelector'].message_type = k8s_dot_io_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1_dot_generated__pb2._LABELSELECTOR
_VOLUME.fields_by_name['volumeSource'].message_type = _VOLUMESOURCE
_VOLUMENODEAFFINITY.fields_by_name['required'].message_type = _NODESELECTOR
_VOLUMEPROJECTION.fields_by_name['secret'].message_type = _SECRETPROJECTION
_VOLUMEPROJECTION.fields_by_name['downwardAPI'].message_type = _DOWNWARDAPIPROJECTION
_VOLUMEPROJECTION.fields_by_name['configMap'].message_type = _CONFIGMAPPROJECTION
_VOLUMEPROJECTION.fields_by_name['serviceAccountToken'].message_type = _SERVICEACCOUNTTOKENPROJECTION
_VOLUMESOURCE.fields_by_name['hostPath'].message_type = _HOSTPATHVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['emptyDir'].message_type = _EMPTYDIRVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['gcePersistentDisk'].message_type = _GCEPERSISTENTDISKVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['awsElasticBlockStore'].message_type = _AWSELASTICBLOCKSTOREVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['gitRepo'].message_type = _GITREPOVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['secret'].message_type = _SECRETVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['nfs'].message_type = _NFSVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['iscsi'].message_type = _ISCSIVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['glusterfs'].message_type = _GLUSTERFSVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['persistentVolumeClaim'].message_type = _PERSISTENTVOLUMECLAIMVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['rbd'].message_type = _RBDVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['flexVolume'].message_type = _FLEXVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['cinder'].message_type = _CINDERVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['cephfs'].message_type = _CEPHFSVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['flocker'].message_type = _FLOCKERVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['downwardAPI'].message_type = _DOWNWARDAPIVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['fc'].message_type = _FCVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['azureFile'].message_type = _AZUREFILEVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['configMap'].message_type = _CONFIGMAPVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['vsphereVolume'].message_type = _VSPHEREVIRTUALDISKVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['quobyte'].message_type = _QUOBYTEVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['azureDisk'].message_type = _AZUREDISKVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['photonPersistentDisk'].message_type = _PHOTONPERSISTENTDISKVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['projected'].message_type = _PROJECTEDVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['portworxVolume'].message_type = _PORTWORXVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['scaleIO'].message_type = _SCALEIOVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['storageos'].message_type = _STORAGEOSVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['csi'].message_type = _CSIVOLUMESOURCE
_VOLUMESOURCE.fields_by_name['ephemeral'].message_type = _EPHEMERALVOLUMESOURCE
_WEIGHTEDPODAFFINITYTERM.fields_by_name['podAffinityTerm'].message_type = _PODAFFINITYTERM
DESCRIPTOR.message_types_by_name['AWSElasticBlockStoreVolumeSource'] = _AWSELASTICBLOCKSTOREVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Affinity'] = _AFFINITY
DESCRIPTOR.message_types_by_name['AttachedVolume'] = _ATTACHEDVOLUME
DESCRIPTOR.message_types_by_name['AvoidPods'] = _AVOIDPODS
DESCRIPTOR.message_types_by_name['AzureDiskVolumeSource'] = _AZUREDISKVOLUMESOURCE
DESCRIPTOR.message_types_by_name['AzureFilePersistentVolumeSource'] = _AZUREFILEPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['AzureFileVolumeSource'] = _AZUREFILEVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Binding'] = _BINDING
DESCRIPTOR.message_types_by_name['CSIPersistentVolumeSource'] = _CSIPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['CSIVolumeSource'] = _CSIVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Capabilities'] = _CAPABILITIES
DESCRIPTOR.message_types_by_name['CephFSPersistentVolumeSource'] = _CEPHFSPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['CephFSVolumeSource'] = _CEPHFSVOLUMESOURCE
DESCRIPTOR.message_types_by_name['CinderPersistentVolumeSource'] = _CINDERPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['CinderVolumeSource'] = _CINDERVOLUMESOURCE
DESCRIPTOR.message_types_by_name['ClientIPConfig'] = _CLIENTIPCONFIG
DESCRIPTOR.message_types_by_name['ComponentCondition'] = _COMPONENTCONDITION
DESCRIPTOR.message_types_by_name['ComponentStatus'] = _COMPONENTSTATUS
DESCRIPTOR.message_types_by_name['ComponentStatusList'] = _COMPONENTSTATUSLIST
DESCRIPTOR.message_types_by_name['ConfigMap'] = _CONFIGMAP
DESCRIPTOR.message_types_by_name['ConfigMapEnvSource'] = _CONFIGMAPENVSOURCE
DESCRIPTOR.message_types_by_name['ConfigMapKeySelector'] = _CONFIGMAPKEYSELECTOR
DESCRIPTOR.message_types_by_name['ConfigMapList'] = _CONFIGMAPLIST
DESCRIPTOR.message_types_by_name['ConfigMapNodeConfigSource'] = _CONFIGMAPNODECONFIGSOURCE
DESCRIPTOR.message_types_by_name['ConfigMapProjection'] = _CONFIGMAPPROJECTION
DESCRIPTOR.message_types_by_name['ConfigMapVolumeSource'] = _CONFIGMAPVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Container'] = _CONTAINER
DESCRIPTOR.message_types_by_name['ContainerImage'] = _CONTAINERIMAGE
DESCRIPTOR.message_types_by_name['ContainerPort'] = _CONTAINERPORT
DESCRIPTOR.message_types_by_name['ContainerState'] = _CONTAINERSTATE
DESCRIPTOR.message_types_by_name['ContainerStateRunning'] = _CONTAINERSTATERUNNING
DESCRIPTOR.message_types_by_name['ContainerStateTerminated'] = _CONTAINERSTATETERMINATED
DESCRIPTOR.message_types_by_name['ContainerStateWaiting'] = _CONTAINERSTATEWAITING
DESCRIPTOR.message_types_by_name['ContainerStatus'] = _CONTAINERSTATUS
DESCRIPTOR.message_types_by_name['DaemonEndpoint'] = _DAEMONENDPOINT
DESCRIPTOR.message_types_by_name['DownwardAPIProjection'] = _DOWNWARDAPIPROJECTION
DESCRIPTOR.message_types_by_name['DownwardAPIVolumeFile'] = _DOWNWARDAPIVOLUMEFILE
DESCRIPTOR.message_types_by_name['DownwardAPIVolumeSource'] = _DOWNWARDAPIVOLUMESOURCE
DESCRIPTOR.message_types_by_name['EmptyDirVolumeSource'] = _EMPTYDIRVOLUMESOURCE
DESCRIPTOR.message_types_by_name['EndpointAddress'] = _ENDPOINTADDRESS
DESCRIPTOR.message_types_by_name['EndpointPort'] = _ENDPOINTPORT
DESCRIPTOR.message_types_by_name['EndpointSubset'] = _ENDPOINTSUBSET
DESCRIPTOR.message_types_by_name['Endpoints'] = _ENDPOINTS
DESCRIPTOR.message_types_by_name['EndpointsList'] = _ENDPOINTSLIST
DESCRIPTOR.message_types_by_name['EnvFromSource'] = _ENVFROMSOURCE
DESCRIPTOR.message_types_by_name['EnvVar'] = _ENVVAR
DESCRIPTOR.message_types_by_name['EnvVarSource'] = _ENVVARSOURCE
DESCRIPTOR.message_types_by_name['EphemeralContainer'] = _EPHEMERALCONTAINER
DESCRIPTOR.message_types_by_name['EphemeralContainerCommon'] = _EPHEMERALCONTAINERCOMMON
DESCRIPTOR.message_types_by_name['EphemeralContainers'] = _EPHEMERALCONTAINERS
DESCRIPTOR.message_types_by_name['EphemeralVolumeSource'] = _EPHEMERALVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EventList'] = _EVENTLIST
DESCRIPTOR.message_types_by_name['EventSeries'] = _EVENTSERIES
DESCRIPTOR.message_types_by_name['EventSource'] = _EVENTSOURCE
DESCRIPTOR.message_types_by_name['ExecAction'] = _EXECACTION
DESCRIPTOR.message_types_by_name['FCVolumeSource'] = _FCVOLUMESOURCE
DESCRIPTOR.message_types_by_name['FlexPersistentVolumeSource'] = _FLEXPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['FlexVolumeSource'] = _FLEXVOLUMESOURCE
DESCRIPTOR.message_types_by_name['FlockerVolumeSource'] = _FLOCKERVOLUMESOURCE
DESCRIPTOR.message_types_by_name['GCEPersistentDiskVolumeSource'] = _GCEPERSISTENTDISKVOLUMESOURCE
DESCRIPTOR.message_types_by_name['GitRepoVolumeSource'] = _GITREPOVOLUMESOURCE
DESCRIPTOR.message_types_by_name['GlusterfsPersistentVolumeSource'] = _GLUSTERFSPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['GlusterfsVolumeSource'] = _GLUSTERFSVOLUMESOURCE
DESCRIPTOR.message_types_by_name['HTTPGetAction'] = _HTTPGETACTION
DESCRIPTOR.message_types_by_name['HTTPHeader'] = _HTTPHEADER
DESCRIPTOR.message_types_by_name['Handler'] = _HANDLER
DESCRIPTOR.message_types_by_name['HostAlias'] = _HOSTALIAS
DESCRIPTOR.message_types_by_name['HostPathVolumeSource'] = _HOSTPATHVOLUMESOURCE
DESCRIPTOR.message_types_by_name['ISCSIPersistentVolumeSource'] = _ISCSIPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['ISCSIVolumeSource'] = _ISCSIVOLUMESOURCE
DESCRIPTOR.message_types_by_name['KeyToPath'] = _KEYTOPATH
DESCRIPTOR.message_types_by_name['Lifecycle'] = _LIFECYCLE
DESCRIPTOR.message_types_by_name['LimitRange'] = _LIMITRANGE
DESCRIPTOR.message_types_by_name['LimitRangeItem'] = _LIMITRANGEITEM
DESCRIPTOR.message_types_by_name['LimitRangeList'] = _LIMITRANGELIST
DESCRIPTOR.message_types_by_name['LimitRangeSpec'] = _LIMITRANGESPEC
DESCRIPTOR.message_types_by_name['List'] = _LIST
DESCRIPTOR.message_types_by_name['LoadBalancerIngress'] = _LOADBALANCERINGRESS
DESCRIPTOR.message_types_by_name['LoadBalancerStatus'] = _LOADBALANCERSTATUS
DESCRIPTOR.message_types_by_name['LocalObjectReference'] = _LOCALOBJECTREFERENCE
DESCRIPTOR.message_types_by_name['LocalVolumeSource'] = _LOCALVOLUMESOURCE
DESCRIPTOR.message_types_by_name['NFSVolumeSource'] = _NFSVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Namespace'] = _NAMESPACE
DESCRIPTOR.message_types_by_name['NamespaceCondition'] = _NAMESPACECONDITION
DESCRIPTOR.message_types_by_name['NamespaceList'] = _NAMESPACELIST
DESCRIPTOR.message_types_by_name['NamespaceSpec'] = _NAMESPACESPEC
DESCRIPTOR.message_types_by_name['NamespaceStatus'] = _NAMESPACESTATUS
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['NodeAddress'] = _NODEADDRESS
DESCRIPTOR.message_types_by_name['NodeAffinity'] = _NODEAFFINITY
DESCRIPTOR.message_types_by_name['NodeCondition'] = _NODECONDITION
DESCRIPTOR.message_types_by_name['NodeConfigSource'] = _NODECONFIGSOURCE
DESCRIPTOR.message_types_by_name['NodeConfigStatus'] = _NODECONFIGSTATUS
DESCRIPTOR.message_types_by_name['NodeDaemonEndpoints'] = _NODEDAEMONENDPOINTS
DESCRIPTOR.message_types_by_name['NodeList'] = _NODELIST
DESCRIPTOR.message_types_by_name['NodeProxyOptions'] = _NODEPROXYOPTIONS
DESCRIPTOR.message_types_by_name['NodeResources'] = _NODERESOURCES
DESCRIPTOR.message_types_by_name['NodeSelector'] = _NODESELECTOR
DESCRIPTOR.message_types_by_name['NodeSelectorRequirement'] = _NODESELECTORREQUIREMENT
DESCRIPTOR.message_types_by_name['NodeSelectorTerm'] = _NODESELECTORTERM
DESCRIPTOR.message_types_by_name['NodeSpec'] = _NODESPEC
DESCRIPTOR.message_types_by_name['NodeStatus'] = _NODESTATUS
DESCRIPTOR.message_types_by_name['NodeSystemInfo'] = _NODESYSTEMINFO
DESCRIPTOR.message_types_by_name['ObjectFieldSelector'] = _OBJECTFIELDSELECTOR
DESCRIPTOR.message_types_by_name['ObjectReference'] = _OBJECTREFERENCE
DESCRIPTOR.message_types_by_name['PersistentVolume'] = _PERSISTENTVOLUME
DESCRIPTOR.message_types_by_name['PersistentVolumeClaim'] = _PERSISTENTVOLUMECLAIM
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimCondition'] = _PERSISTENTVOLUMECLAIMCONDITION
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimList'] = _PERSISTENTVOLUMECLAIMLIST
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimSpec'] = _PERSISTENTVOLUMECLAIMSPEC
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimStatus'] = _PERSISTENTVOLUMECLAIMSTATUS
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimTemplate'] = _PERSISTENTVOLUMECLAIMTEMPLATE
DESCRIPTOR.message_types_by_name['PersistentVolumeClaimVolumeSource'] = _PERSISTENTVOLUMECLAIMVOLUMESOURCE
DESCRIPTOR.message_types_by_name['PersistentVolumeList'] = _PERSISTENTVOLUMELIST
DESCRIPTOR.message_types_by_name['PersistentVolumeSource'] = _PERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['PersistentVolumeSpec'] = _PERSISTENTVOLUMESPEC
DESCRIPTOR.message_types_by_name['PersistentVolumeStatus'] = _PERSISTENTVOLUMESTATUS
DESCRIPTOR.message_types_by_name['PhotonPersistentDiskVolumeSource'] = _PHOTONPERSISTENTDISKVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Pod'] = _POD
DESCRIPTOR.message_types_by_name['PodAffinity'] = _PODAFFINITY
DESCRIPTOR.message_types_by_name['PodAffinityTerm'] = _PODAFFINITYTERM
DESCRIPTOR.message_types_by_name['PodAntiAffinity'] = _PODANTIAFFINITY
DESCRIPTOR.message_types_by_name['PodAttachOptions'] = _PODATTACHOPTIONS
DESCRIPTOR.message_types_by_name['PodCondition'] = _PODCONDITION
DESCRIPTOR.message_types_by_name['PodDNSConfig'] = _PODDNSCONFIG
DESCRIPTOR.message_types_by_name['PodDNSConfigOption'] = _PODDNSCONFIGOPTION
DESCRIPTOR.message_types_by_name['PodExecOptions'] = _PODEXECOPTIONS
DESCRIPTOR.message_types_by_name['PodIP'] = _PODIP
DESCRIPTOR.message_types_by_name['PodList'] = _PODLIST
DESCRIPTOR.message_types_by_name['PodLogOptions'] = _PODLOGOPTIONS
DESCRIPTOR.message_types_by_name['PodPortForwardOptions'] = _PODPORTFORWARDOPTIONS
DESCRIPTOR.message_types_by_name['PodProxyOptions'] = _PODPROXYOPTIONS
DESCRIPTOR.message_types_by_name['PodReadinessGate'] = _PODREADINESSGATE
DESCRIPTOR.message_types_by_name['PodSecurityContext'] = _PODSECURITYCONTEXT
DESCRIPTOR.message_types_by_name['PodSignature'] = _PODSIGNATURE
DESCRIPTOR.message_types_by_name['PodSpec'] = _PODSPEC
DESCRIPTOR.message_types_by_name['PodStatus'] = _PODSTATUS
DESCRIPTOR.message_types_by_name['PodStatusResult'] = _PODSTATUSRESULT
DESCRIPTOR.message_types_by_name['PodTemplate'] = _PODTEMPLATE
DESCRIPTOR.message_types_by_name['PodTemplateList'] = _PODTEMPLATELIST
DESCRIPTOR.message_types_by_name['PodTemplateSpec'] = _PODTEMPLATESPEC
DESCRIPTOR.message_types_by_name['PortStatus'] = _PORTSTATUS
DESCRIPTOR.message_types_by_name['PortworxVolumeSource'] = _PORTWORXVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Preconditions'] = _PRECONDITIONS
DESCRIPTOR.message_types_by_name['PreferAvoidPodsEntry'] = _PREFERAVOIDPODSENTRY
DESCRIPTOR.message_types_by_name['PreferredSchedulingTerm'] = _PREFERREDSCHEDULINGTERM
DESCRIPTOR.message_types_by_name['Probe'] = _PROBE
DESCRIPTOR.message_types_by_name['ProjectedVolumeSource'] = _PROJECTEDVOLUMESOURCE
DESCRIPTOR.message_types_by_name['QuobyteVolumeSource'] = _QUOBYTEVOLUMESOURCE
DESCRIPTOR.message_types_by_name['RBDPersistentVolumeSource'] = _RBDPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['RBDVolumeSource'] = _RBDVOLUMESOURCE
DESCRIPTOR.message_types_by_name['RangeAllocation'] = _RANGEALLOCATION
DESCRIPTOR.message_types_by_name['ReplicationController'] = _REPLICATIONCONTROLLER
DESCRIPTOR.message_types_by_name['ReplicationControllerCondition'] = _REPLICATIONCONTROLLERCONDITION
DESCRIPTOR.message_types_by_name['ReplicationControllerList'] = _REPLICATIONCONTROLLERLIST
DESCRIPTOR.message_types_by_name['ReplicationControllerSpec'] = _REPLICATIONCONTROLLERSPEC
DESCRIPTOR.message_types_by_name['ReplicationControllerStatus'] = _REPLICATIONCONTROLLERSTATUS
DESCRIPTOR.message_types_by_name['ResourceFieldSelector'] = _RESOURCEFIELDSELECTOR
DESCRIPTOR.message_types_by_name['ResourceQuota'] = _RESOURCEQUOTA
DESCRIPTOR.message_types_by_name['ResourceQuotaList'] = _RESOURCEQUOTALIST
DESCRIPTOR.message_types_by_name['ResourceQuotaSpec'] = _RESOURCEQUOTASPEC
DESCRIPTOR.message_types_by_name['ResourceQuotaStatus'] = _RESOURCEQUOTASTATUS
DESCRIPTOR.message_types_by_name['ResourceRequirements'] = _RESOURCEREQUIREMENTS
DESCRIPTOR.message_types_by_name['SELinuxOptions'] = _SELINUXOPTIONS
DESCRIPTOR.message_types_by_name['ScaleIOPersistentVolumeSource'] = _SCALEIOPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['ScaleIOVolumeSource'] = _SCALEIOVOLUMESOURCE
DESCRIPTOR.message_types_by_name['ScopeSelector'] = _SCOPESELECTOR
DESCRIPTOR.message_types_by_name['ScopedResourceSelectorRequirement'] = _SCOPEDRESOURCESELECTORREQUIREMENT
DESCRIPTOR.message_types_by_name['SeccompProfile'] = _SECCOMPPROFILE
DESCRIPTOR.message_types_by_name['Secret'] = _SECRET
DESCRIPTOR.message_types_by_name['SecretEnvSource'] = _SECRETENVSOURCE
DESCRIPTOR.message_types_by_name['SecretKeySelector'] = _SECRETKEYSELECTOR
DESCRIPTOR.message_types_by_name['SecretList'] = _SECRETLIST
DESCRIPTOR.message_types_by_name['SecretProjection'] = _SECRETPROJECTION
DESCRIPTOR.message_types_by_name['SecretReference'] = _SECRETREFERENCE
DESCRIPTOR.message_types_by_name['SecretVolumeSource'] = _SECRETVOLUMESOURCE
DESCRIPTOR.message_types_by_name['SecurityContext'] = _SECURITYCONTEXT
DESCRIPTOR.message_types_by_name['SerializedReference'] = _SERIALIZEDREFERENCE
DESCRIPTOR.message_types_by_name['Service'] = _SERVICE
DESCRIPTOR.message_types_by_name['ServiceAccount'] = _SERVICEACCOUNT
DESCRIPTOR.message_types_by_name['ServiceAccountList'] = _SERVICEACCOUNTLIST
DESCRIPTOR.message_types_by_name['ServiceAccountTokenProjection'] = _SERVICEACCOUNTTOKENPROJECTION
DESCRIPTOR.message_types_by_name['ServiceList'] = _SERVICELIST
DESCRIPTOR.message_types_by_name['ServicePort'] = _SERVICEPORT
DESCRIPTOR.message_types_by_name['ServiceProxyOptions'] = _SERVICEPROXYOPTIONS
DESCRIPTOR.message_types_by_name['ServiceSpec'] = _SERVICESPEC
DESCRIPTOR.message_types_by_name['ServiceStatus'] = _SERVICESTATUS
DESCRIPTOR.message_types_by_name['SessionAffinityConfig'] = _SESSIONAFFINITYCONFIG
DESCRIPTOR.message_types_by_name['StorageOSPersistentVolumeSource'] = _STORAGEOSPERSISTENTVOLUMESOURCE
DESCRIPTOR.message_types_by_name['StorageOSVolumeSource'] = _STORAGEOSVOLUMESOURCE
DESCRIPTOR.message_types_by_name['Sysctl'] = _SYSCTL
DESCRIPTOR.message_types_by_name['TCPSocketAction'] = _TCPSOCKETACTION
DESCRIPTOR.message_types_by_name['Taint'] = _TAINT
DESCRIPTOR.message_types_by_name['Toleration'] = _TOLERATION
DESCRIPTOR.message_types_by_name['TopologySelectorLabelRequirement'] = _TOPOLOGYSELECTORLABELREQUIREMENT
DESCRIPTOR.message_types_by_name['TopologySelectorTerm'] = _TOPOLOGYSELECTORTERM
DESCRIPTOR.message_types_by_name['TopologySpreadConstraint'] = _TOPOLOGYSPREADCONSTRAINT
DESCRIPTOR.message_types_by_name['TypedLocalObjectReference'] = _TYPEDLOCALOBJECTREFERENCE
DESCRIPTOR.message_types_by_name['Volume'] = _VOLUME
DESCRIPTOR.message_types_by_name['VolumeDevice'] = _VOLUMEDEVICE
DESCRIPTOR.message_types_by_name['VolumeMount'] = _VOLUMEMOUNT
DESCRIPTOR.message_types_by_name['VolumeNodeAffinity'] = _VOLUMENODEAFFINITY
DESCRIPTOR.message_types_by_name['VolumeProjection'] = _VOLUMEPROJECTION
DESCRIPTOR.message_types_by_name['VolumeSource'] = _VOLUMESOURCE
DESCRIPTOR.message_types_by_name['VsphereVirtualDiskVolumeSource'] = _VSPHEREVIRTUALDISKVOLUMESOURCE
DESCRIPTOR.message_types_by_name['WeightedPodAffinityTerm'] = _WEIGHTEDPODAFFINITYTERM
DESCRIPTOR.message_types_by_name['WindowsSecurityContextOptions'] = _WINDOWSSECURITYCONTEXTOPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AWSElasticBlockStoreVolumeSource = _reflection.GeneratedProtocolMessageType('AWSElasticBlockStoreVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _AWSELASTICBLOCKSTOREVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AWSElasticBlockStoreVolumeSource)
  })
_sym_db.RegisterMessage(AWSElasticBlockStoreVolumeSource)

Affinity = _reflection.GeneratedProtocolMessageType('Affinity', (_message.Message,), {
  'DESCRIPTOR' : _AFFINITY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Affinity)
  })
_sym_db.RegisterMessage(Affinity)

AttachedVolume = _reflection.GeneratedProtocolMessageType('AttachedVolume', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDVOLUME,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AttachedVolume)
  })
_sym_db.RegisterMessage(AttachedVolume)

AvoidPods = _reflection.GeneratedProtocolMessageType('AvoidPods', (_message.Message,), {
  'DESCRIPTOR' : _AVOIDPODS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AvoidPods)
  })
_sym_db.RegisterMessage(AvoidPods)

AzureDiskVolumeSource = _reflection.GeneratedProtocolMessageType('AzureDiskVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _AZUREDISKVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AzureDiskVolumeSource)
  })
_sym_db.RegisterMessage(AzureDiskVolumeSource)

AzureFilePersistentVolumeSource = _reflection.GeneratedProtocolMessageType('AzureFilePersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _AZUREFILEPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AzureFilePersistentVolumeSource)
  })
_sym_db.RegisterMessage(AzureFilePersistentVolumeSource)

AzureFileVolumeSource = _reflection.GeneratedProtocolMessageType('AzureFileVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _AZUREFILEVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.AzureFileVolumeSource)
  })
_sym_db.RegisterMessage(AzureFileVolumeSource)

Binding = _reflection.GeneratedProtocolMessageType('Binding', (_message.Message,), {
  'DESCRIPTOR' : _BINDING,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Binding)
  })
_sym_db.RegisterMessage(Binding)

CSIPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('CSIPersistentVolumeSource', (_message.Message,), {

  'VolumeAttributesEntry' : _reflection.GeneratedProtocolMessageType('VolumeAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CSIPersistentVolumeSource.VolumeAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CSIPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CSIPersistentVolumeSource)
  })
_sym_db.RegisterMessage(CSIPersistentVolumeSource)
_sym_db.RegisterMessage(CSIPersistentVolumeSource.VolumeAttributesEntry)

CSIVolumeSource = _reflection.GeneratedProtocolMessageType('CSIVolumeSource', (_message.Message,), {

  'VolumeAttributesEntry' : _reflection.GeneratedProtocolMessageType('VolumeAttributesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CSIVolumeSource.VolumeAttributesEntry)
    })
  ,
  'DESCRIPTOR' : _CSIVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CSIVolumeSource)
  })
_sym_db.RegisterMessage(CSIVolumeSource)
_sym_db.RegisterMessage(CSIVolumeSource.VolumeAttributesEntry)

Capabilities = _reflection.GeneratedProtocolMessageType('Capabilities', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITIES,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Capabilities)
  })
_sym_db.RegisterMessage(Capabilities)

CephFSPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('CephFSPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _CEPHFSPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CephFSPersistentVolumeSource)
  })
_sym_db.RegisterMessage(CephFSPersistentVolumeSource)

CephFSVolumeSource = _reflection.GeneratedProtocolMessageType('CephFSVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _CEPHFSVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CephFSVolumeSource)
  })
_sym_db.RegisterMessage(CephFSVolumeSource)

CinderPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('CinderPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _CINDERPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CinderPersistentVolumeSource)
  })
_sym_db.RegisterMessage(CinderPersistentVolumeSource)

CinderVolumeSource = _reflection.GeneratedProtocolMessageType('CinderVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _CINDERVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.CinderVolumeSource)
  })
_sym_db.RegisterMessage(CinderVolumeSource)

ClientIPConfig = _reflection.GeneratedProtocolMessageType('ClientIPConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTIPCONFIG,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ClientIPConfig)
  })
_sym_db.RegisterMessage(ClientIPConfig)

ComponentCondition = _reflection.GeneratedProtocolMessageType('ComponentCondition', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTCONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ComponentCondition)
  })
_sym_db.RegisterMessage(ComponentCondition)

ComponentStatus = _reflection.GeneratedProtocolMessageType('ComponentStatus', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ComponentStatus)
  })
_sym_db.RegisterMessage(ComponentStatus)

ComponentStatusList = _reflection.GeneratedProtocolMessageType('ComponentStatusList', (_message.Message,), {
  'DESCRIPTOR' : _COMPONENTSTATUSLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ComponentStatusList)
  })
_sym_db.RegisterMessage(ComponentStatusList)

ConfigMap = _reflection.GeneratedProtocolMessageType('ConfigMap', (_message.Message,), {

  'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGMAP_DATAENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMap.DataEntry)
    })
  ,

  'BinaryDataEntry' : _reflection.GeneratedProtocolMessageType('BinaryDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONFIGMAP_BINARYDATAENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMap.BinaryDataEntry)
    })
  ,
  'DESCRIPTOR' : _CONFIGMAP,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMap)
  })
_sym_db.RegisterMessage(ConfigMap)
_sym_db.RegisterMessage(ConfigMap.DataEntry)
_sym_db.RegisterMessage(ConfigMap.BinaryDataEntry)

ConfigMapEnvSource = _reflection.GeneratedProtocolMessageType('ConfigMapEnvSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPENVSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapEnvSource)
  })
_sym_db.RegisterMessage(ConfigMapEnvSource)

ConfigMapKeySelector = _reflection.GeneratedProtocolMessageType('ConfigMapKeySelector', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPKEYSELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapKeySelector)
  })
_sym_db.RegisterMessage(ConfigMapKeySelector)

ConfigMapList = _reflection.GeneratedProtocolMessageType('ConfigMapList', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapList)
  })
_sym_db.RegisterMessage(ConfigMapList)

ConfigMapNodeConfigSource = _reflection.GeneratedProtocolMessageType('ConfigMapNodeConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPNODECONFIGSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapNodeConfigSource)
  })
_sym_db.RegisterMessage(ConfigMapNodeConfigSource)

ConfigMapProjection = _reflection.GeneratedProtocolMessageType('ConfigMapProjection', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPPROJECTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapProjection)
  })
_sym_db.RegisterMessage(ConfigMapProjection)

ConfigMapVolumeSource = _reflection.GeneratedProtocolMessageType('ConfigMapVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _CONFIGMAPVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ConfigMapVolumeSource)
  })
_sym_db.RegisterMessage(ConfigMapVolumeSource)

Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINER,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Container)
  })
_sym_db.RegisterMessage(Container)

ContainerImage = _reflection.GeneratedProtocolMessageType('ContainerImage', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERIMAGE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerImage)
  })
_sym_db.RegisterMessage(ContainerImage)

ContainerPort = _reflection.GeneratedProtocolMessageType('ContainerPort', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERPORT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerPort)
  })
_sym_db.RegisterMessage(ContainerPort)

ContainerState = _reflection.GeneratedProtocolMessageType('ContainerState', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerState)
  })
_sym_db.RegisterMessage(ContainerState)

ContainerStateRunning = _reflection.GeneratedProtocolMessageType('ContainerStateRunning', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATERUNNING,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerStateRunning)
  })
_sym_db.RegisterMessage(ContainerStateRunning)

ContainerStateTerminated = _reflection.GeneratedProtocolMessageType('ContainerStateTerminated', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATETERMINATED,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerStateTerminated)
  })
_sym_db.RegisterMessage(ContainerStateTerminated)

ContainerStateWaiting = _reflection.GeneratedProtocolMessageType('ContainerStateWaiting', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATEWAITING,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerStateWaiting)
  })
_sym_db.RegisterMessage(ContainerStateWaiting)

ContainerStatus = _reflection.GeneratedProtocolMessageType('ContainerStatus', (_message.Message,), {
  'DESCRIPTOR' : _CONTAINERSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ContainerStatus)
  })
_sym_db.RegisterMessage(ContainerStatus)

DaemonEndpoint = _reflection.GeneratedProtocolMessageType('DaemonEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _DAEMONENDPOINT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.DaemonEndpoint)
  })
_sym_db.RegisterMessage(DaemonEndpoint)

DownwardAPIProjection = _reflection.GeneratedProtocolMessageType('DownwardAPIProjection', (_message.Message,), {
  'DESCRIPTOR' : _DOWNWARDAPIPROJECTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.DownwardAPIProjection)
  })
_sym_db.RegisterMessage(DownwardAPIProjection)

DownwardAPIVolumeFile = _reflection.GeneratedProtocolMessageType('DownwardAPIVolumeFile', (_message.Message,), {
  'DESCRIPTOR' : _DOWNWARDAPIVOLUMEFILE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.DownwardAPIVolumeFile)
  })
_sym_db.RegisterMessage(DownwardAPIVolumeFile)

DownwardAPIVolumeSource = _reflection.GeneratedProtocolMessageType('DownwardAPIVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _DOWNWARDAPIVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.DownwardAPIVolumeSource)
  })
_sym_db.RegisterMessage(DownwardAPIVolumeSource)

EmptyDirVolumeSource = _reflection.GeneratedProtocolMessageType('EmptyDirVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYDIRVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EmptyDirVolumeSource)
  })
_sym_db.RegisterMessage(EmptyDirVolumeSource)

EndpointAddress = _reflection.GeneratedProtocolMessageType('EndpointAddress', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTADDRESS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EndpointAddress)
  })
_sym_db.RegisterMessage(EndpointAddress)

EndpointPort = _reflection.GeneratedProtocolMessageType('EndpointPort', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTPORT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EndpointPort)
  })
_sym_db.RegisterMessage(EndpointPort)

EndpointSubset = _reflection.GeneratedProtocolMessageType('EndpointSubset', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTSUBSET,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EndpointSubset)
  })
_sym_db.RegisterMessage(EndpointSubset)

Endpoints = _reflection.GeneratedProtocolMessageType('Endpoints', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Endpoints)
  })
_sym_db.RegisterMessage(Endpoints)

EndpointsList = _reflection.GeneratedProtocolMessageType('EndpointsList', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTSLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EndpointsList)
  })
_sym_db.RegisterMessage(EndpointsList)

EnvFromSource = _reflection.GeneratedProtocolMessageType('EnvFromSource', (_message.Message,), {
  'DESCRIPTOR' : _ENVFROMSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EnvFromSource)
  })
_sym_db.RegisterMessage(EnvFromSource)

EnvVar = _reflection.GeneratedProtocolMessageType('EnvVar', (_message.Message,), {
  'DESCRIPTOR' : _ENVVAR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EnvVar)
  })
_sym_db.RegisterMessage(EnvVar)

EnvVarSource = _reflection.GeneratedProtocolMessageType('EnvVarSource', (_message.Message,), {
  'DESCRIPTOR' : _ENVVARSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EnvVarSource)
  })
_sym_db.RegisterMessage(EnvVarSource)

EphemeralContainer = _reflection.GeneratedProtocolMessageType('EphemeralContainer', (_message.Message,), {
  'DESCRIPTOR' : _EPHEMERALCONTAINER,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EphemeralContainer)
  })
_sym_db.RegisterMessage(EphemeralContainer)

EphemeralContainerCommon = _reflection.GeneratedProtocolMessageType('EphemeralContainerCommon', (_message.Message,), {
  'DESCRIPTOR' : _EPHEMERALCONTAINERCOMMON,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EphemeralContainerCommon)
  })
_sym_db.RegisterMessage(EphemeralContainerCommon)

EphemeralContainers = _reflection.GeneratedProtocolMessageType('EphemeralContainers', (_message.Message,), {
  'DESCRIPTOR' : _EPHEMERALCONTAINERS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EphemeralContainers)
  })
_sym_db.RegisterMessage(EphemeralContainers)

EphemeralVolumeSource = _reflection.GeneratedProtocolMessageType('EphemeralVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _EPHEMERALVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EphemeralVolumeSource)
  })
_sym_db.RegisterMessage(EphemeralVolumeSource)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Event)
  })
_sym_db.RegisterMessage(Event)

EventList = _reflection.GeneratedProtocolMessageType('EventList', (_message.Message,), {
  'DESCRIPTOR' : _EVENTLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EventList)
  })
_sym_db.RegisterMessage(EventList)

EventSeries = _reflection.GeneratedProtocolMessageType('EventSeries', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSERIES,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EventSeries)
  })
_sym_db.RegisterMessage(EventSeries)

EventSource = _reflection.GeneratedProtocolMessageType('EventSource', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.EventSource)
  })
_sym_db.RegisterMessage(EventSource)

ExecAction = _reflection.GeneratedProtocolMessageType('ExecAction', (_message.Message,), {
  'DESCRIPTOR' : _EXECACTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ExecAction)
  })
_sym_db.RegisterMessage(ExecAction)

FCVolumeSource = _reflection.GeneratedProtocolMessageType('FCVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _FCVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FCVolumeSource)
  })
_sym_db.RegisterMessage(FCVolumeSource)

FlexPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('FlexPersistentVolumeSource', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FlexPersistentVolumeSource.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _FLEXPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FlexPersistentVolumeSource)
  })
_sym_db.RegisterMessage(FlexPersistentVolumeSource)
_sym_db.RegisterMessage(FlexPersistentVolumeSource.OptionsEntry)

FlexVolumeSource = _reflection.GeneratedProtocolMessageType('FlexVolumeSource', (_message.Message,), {

  'OptionsEntry' : _reflection.GeneratedProtocolMessageType('OptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _FLEXVOLUMESOURCE_OPTIONSENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FlexVolumeSource.OptionsEntry)
    })
  ,
  'DESCRIPTOR' : _FLEXVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FlexVolumeSource)
  })
_sym_db.RegisterMessage(FlexVolumeSource)
_sym_db.RegisterMessage(FlexVolumeSource.OptionsEntry)

FlockerVolumeSource = _reflection.GeneratedProtocolMessageType('FlockerVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _FLOCKERVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.FlockerVolumeSource)
  })
_sym_db.RegisterMessage(FlockerVolumeSource)

GCEPersistentDiskVolumeSource = _reflection.GeneratedProtocolMessageType('GCEPersistentDiskVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _GCEPERSISTENTDISKVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.GCEPersistentDiskVolumeSource)
  })
_sym_db.RegisterMessage(GCEPersistentDiskVolumeSource)

GitRepoVolumeSource = _reflection.GeneratedProtocolMessageType('GitRepoVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _GITREPOVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.GitRepoVolumeSource)
  })
_sym_db.RegisterMessage(GitRepoVolumeSource)

GlusterfsPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('GlusterfsPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _GLUSTERFSPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.GlusterfsPersistentVolumeSource)
  })
_sym_db.RegisterMessage(GlusterfsPersistentVolumeSource)

GlusterfsVolumeSource = _reflection.GeneratedProtocolMessageType('GlusterfsVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _GLUSTERFSVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.GlusterfsVolumeSource)
  })
_sym_db.RegisterMessage(GlusterfsVolumeSource)

HTTPGetAction = _reflection.GeneratedProtocolMessageType('HTTPGetAction', (_message.Message,), {
  'DESCRIPTOR' : _HTTPGETACTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.HTTPGetAction)
  })
_sym_db.RegisterMessage(HTTPGetAction)

HTTPHeader = _reflection.GeneratedProtocolMessageType('HTTPHeader', (_message.Message,), {
  'DESCRIPTOR' : _HTTPHEADER,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.HTTPHeader)
  })
_sym_db.RegisterMessage(HTTPHeader)

Handler = _reflection.GeneratedProtocolMessageType('Handler', (_message.Message,), {
  'DESCRIPTOR' : _HANDLER,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Handler)
  })
_sym_db.RegisterMessage(Handler)

HostAlias = _reflection.GeneratedProtocolMessageType('HostAlias', (_message.Message,), {
  'DESCRIPTOR' : _HOSTALIAS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.HostAlias)
  })
_sym_db.RegisterMessage(HostAlias)

HostPathVolumeSource = _reflection.GeneratedProtocolMessageType('HostPathVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _HOSTPATHVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.HostPathVolumeSource)
  })
_sym_db.RegisterMessage(HostPathVolumeSource)

ISCSIPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('ISCSIPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _ISCSIPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ISCSIPersistentVolumeSource)
  })
_sym_db.RegisterMessage(ISCSIPersistentVolumeSource)

ISCSIVolumeSource = _reflection.GeneratedProtocolMessageType('ISCSIVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _ISCSIVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ISCSIVolumeSource)
  })
_sym_db.RegisterMessage(ISCSIVolumeSource)

KeyToPath = _reflection.GeneratedProtocolMessageType('KeyToPath', (_message.Message,), {
  'DESCRIPTOR' : _KEYTOPATH,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.KeyToPath)
  })
_sym_db.RegisterMessage(KeyToPath)

Lifecycle = _reflection.GeneratedProtocolMessageType('Lifecycle', (_message.Message,), {
  'DESCRIPTOR' : _LIFECYCLE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Lifecycle)
  })
_sym_db.RegisterMessage(Lifecycle)

LimitRange = _reflection.GeneratedProtocolMessageType('LimitRange', (_message.Message,), {
  'DESCRIPTOR' : _LIMITRANGE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRange)
  })
_sym_db.RegisterMessage(LimitRange)

LimitRangeItem = _reflection.GeneratedProtocolMessageType('LimitRangeItem', (_message.Message,), {

  'MaxEntry' : _reflection.GeneratedProtocolMessageType('MaxEntry', (_message.Message,), {
    'DESCRIPTOR' : _LIMITRANGEITEM_MAXENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem.MaxEntry)
    })
  ,

  'MinEntry' : _reflection.GeneratedProtocolMessageType('MinEntry', (_message.Message,), {
    'DESCRIPTOR' : _LIMITRANGEITEM_MINENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem.MinEntry)
    })
  ,

  'DefaultEntry' : _reflection.GeneratedProtocolMessageType('DefaultEntry', (_message.Message,), {
    'DESCRIPTOR' : _LIMITRANGEITEM_DEFAULTENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem.DefaultEntry)
    })
  ,

  'DefaultRequestEntry' : _reflection.GeneratedProtocolMessageType('DefaultRequestEntry', (_message.Message,), {
    'DESCRIPTOR' : _LIMITRANGEITEM_DEFAULTREQUESTENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem.DefaultRequestEntry)
    })
  ,

  'MaxLimitRequestRatioEntry' : _reflection.GeneratedProtocolMessageType('MaxLimitRequestRatioEntry', (_message.Message,), {
    'DESCRIPTOR' : _LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem.MaxLimitRequestRatioEntry)
    })
  ,
  'DESCRIPTOR' : _LIMITRANGEITEM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeItem)
  })
_sym_db.RegisterMessage(LimitRangeItem)
_sym_db.RegisterMessage(LimitRangeItem.MaxEntry)
_sym_db.RegisterMessage(LimitRangeItem.MinEntry)
_sym_db.RegisterMessage(LimitRangeItem.DefaultEntry)
_sym_db.RegisterMessage(LimitRangeItem.DefaultRequestEntry)
_sym_db.RegisterMessage(LimitRangeItem.MaxLimitRequestRatioEntry)

LimitRangeList = _reflection.GeneratedProtocolMessageType('LimitRangeList', (_message.Message,), {
  'DESCRIPTOR' : _LIMITRANGELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeList)
  })
_sym_db.RegisterMessage(LimitRangeList)

LimitRangeSpec = _reflection.GeneratedProtocolMessageType('LimitRangeSpec', (_message.Message,), {
  'DESCRIPTOR' : _LIMITRANGESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LimitRangeSpec)
  })
_sym_db.RegisterMessage(LimitRangeSpec)

List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), {
  'DESCRIPTOR' : _LIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.List)
  })
_sym_db.RegisterMessage(List)

LoadBalancerIngress = _reflection.GeneratedProtocolMessageType('LoadBalancerIngress', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCERINGRESS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LoadBalancerIngress)
  })
_sym_db.RegisterMessage(LoadBalancerIngress)

LoadBalancerStatus = _reflection.GeneratedProtocolMessageType('LoadBalancerStatus', (_message.Message,), {
  'DESCRIPTOR' : _LOADBALANCERSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LoadBalancerStatus)
  })
_sym_db.RegisterMessage(LoadBalancerStatus)

LocalObjectReference = _reflection.GeneratedProtocolMessageType('LocalObjectReference', (_message.Message,), {
  'DESCRIPTOR' : _LOCALOBJECTREFERENCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LocalObjectReference)
  })
_sym_db.RegisterMessage(LocalObjectReference)

LocalVolumeSource = _reflection.GeneratedProtocolMessageType('LocalVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _LOCALVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.LocalVolumeSource)
  })
_sym_db.RegisterMessage(LocalVolumeSource)

NFSVolumeSource = _reflection.GeneratedProtocolMessageType('NFSVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _NFSVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NFSVolumeSource)
  })
_sym_db.RegisterMessage(NFSVolumeSource)

Namespace = _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Namespace)
  })
_sym_db.RegisterMessage(Namespace)

NamespaceCondition = _reflection.GeneratedProtocolMessageType('NamespaceCondition', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACECONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NamespaceCondition)
  })
_sym_db.RegisterMessage(NamespaceCondition)

NamespaceList = _reflection.GeneratedProtocolMessageType('NamespaceList', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NamespaceList)
  })
_sym_db.RegisterMessage(NamespaceList)

NamespaceSpec = _reflection.GeneratedProtocolMessageType('NamespaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NamespaceSpec)
  })
_sym_db.RegisterMessage(NamespaceSpec)

NamespaceStatus = _reflection.GeneratedProtocolMessageType('NamespaceStatus', (_message.Message,), {
  'DESCRIPTOR' : _NAMESPACESTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NamespaceStatus)
  })
_sym_db.RegisterMessage(NamespaceStatus)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
  'DESCRIPTOR' : _NODE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Node)
  })
_sym_db.RegisterMessage(Node)

NodeAddress = _reflection.GeneratedProtocolMessageType('NodeAddress', (_message.Message,), {
  'DESCRIPTOR' : _NODEADDRESS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeAddress)
  })
_sym_db.RegisterMessage(NodeAddress)

NodeAffinity = _reflection.GeneratedProtocolMessageType('NodeAffinity', (_message.Message,), {
  'DESCRIPTOR' : _NODEAFFINITY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeAffinity)
  })
_sym_db.RegisterMessage(NodeAffinity)

NodeCondition = _reflection.GeneratedProtocolMessageType('NodeCondition', (_message.Message,), {
  'DESCRIPTOR' : _NODECONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeCondition)
  })
_sym_db.RegisterMessage(NodeCondition)

NodeConfigSource = _reflection.GeneratedProtocolMessageType('NodeConfigSource', (_message.Message,), {
  'DESCRIPTOR' : _NODECONFIGSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeConfigSource)
  })
_sym_db.RegisterMessage(NodeConfigSource)

NodeConfigStatus = _reflection.GeneratedProtocolMessageType('NodeConfigStatus', (_message.Message,), {
  'DESCRIPTOR' : _NODECONFIGSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeConfigStatus)
  })
_sym_db.RegisterMessage(NodeConfigStatus)

NodeDaemonEndpoints = _reflection.GeneratedProtocolMessageType('NodeDaemonEndpoints', (_message.Message,), {
  'DESCRIPTOR' : _NODEDAEMONENDPOINTS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeDaemonEndpoints)
  })
_sym_db.RegisterMessage(NodeDaemonEndpoints)

NodeList = _reflection.GeneratedProtocolMessageType('NodeList', (_message.Message,), {
  'DESCRIPTOR' : _NODELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeList)
  })
_sym_db.RegisterMessage(NodeList)

NodeProxyOptions = _reflection.GeneratedProtocolMessageType('NodeProxyOptions', (_message.Message,), {
  'DESCRIPTOR' : _NODEPROXYOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeProxyOptions)
  })
_sym_db.RegisterMessage(NodeProxyOptions)

NodeResources = _reflection.GeneratedProtocolMessageType('NodeResources', (_message.Message,), {

  'CapacityEntry' : _reflection.GeneratedProtocolMessageType('CapacityEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODERESOURCES_CAPACITYENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeResources.CapacityEntry)
    })
  ,
  'DESCRIPTOR' : _NODERESOURCES,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeResources)
  })
_sym_db.RegisterMessage(NodeResources)
_sym_db.RegisterMessage(NodeResources.CapacityEntry)

NodeSelector = _reflection.GeneratedProtocolMessageType('NodeSelector', (_message.Message,), {
  'DESCRIPTOR' : _NODESELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeSelector)
  })
_sym_db.RegisterMessage(NodeSelector)

NodeSelectorRequirement = _reflection.GeneratedProtocolMessageType('NodeSelectorRequirement', (_message.Message,), {
  'DESCRIPTOR' : _NODESELECTORREQUIREMENT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeSelectorRequirement)
  })
_sym_db.RegisterMessage(NodeSelectorRequirement)

NodeSelectorTerm = _reflection.GeneratedProtocolMessageType('NodeSelectorTerm', (_message.Message,), {
  'DESCRIPTOR' : _NODESELECTORTERM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeSelectorTerm)
  })
_sym_db.RegisterMessage(NodeSelectorTerm)

NodeSpec = _reflection.GeneratedProtocolMessageType('NodeSpec', (_message.Message,), {
  'DESCRIPTOR' : _NODESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeSpec)
  })
_sym_db.RegisterMessage(NodeSpec)

NodeStatus = _reflection.GeneratedProtocolMessageType('NodeStatus', (_message.Message,), {

  'CapacityEntry' : _reflection.GeneratedProtocolMessageType('CapacityEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODESTATUS_CAPACITYENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeStatus.CapacityEntry)
    })
  ,

  'AllocatableEntry' : _reflection.GeneratedProtocolMessageType('AllocatableEntry', (_message.Message,), {
    'DESCRIPTOR' : _NODESTATUS_ALLOCATABLEENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeStatus.AllocatableEntry)
    })
  ,
  'DESCRIPTOR' : _NODESTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeStatus)
  })
_sym_db.RegisterMessage(NodeStatus)
_sym_db.RegisterMessage(NodeStatus.CapacityEntry)
_sym_db.RegisterMessage(NodeStatus.AllocatableEntry)

NodeSystemInfo = _reflection.GeneratedProtocolMessageType('NodeSystemInfo', (_message.Message,), {
  'DESCRIPTOR' : _NODESYSTEMINFO,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.NodeSystemInfo)
  })
_sym_db.RegisterMessage(NodeSystemInfo)

ObjectFieldSelector = _reflection.GeneratedProtocolMessageType('ObjectFieldSelector', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTFIELDSELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ObjectFieldSelector)
  })
_sym_db.RegisterMessage(ObjectFieldSelector)

ObjectReference = _reflection.GeneratedProtocolMessageType('ObjectReference', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTREFERENCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ObjectReference)
  })
_sym_db.RegisterMessage(ObjectReference)

PersistentVolume = _reflection.GeneratedProtocolMessageType('PersistentVolume', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUME,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolume)
  })
_sym_db.RegisterMessage(PersistentVolume)

PersistentVolumeClaim = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaim', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaim)
  })
_sym_db.RegisterMessage(PersistentVolumeClaim)

PersistentVolumeClaimCondition = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimCondition', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMCONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimCondition)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimCondition)

PersistentVolumeClaimList = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimList', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimList)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimList)

PersistentVolumeClaimSpec = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimSpec', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMSPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimSpec)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimSpec)

PersistentVolumeClaimStatus = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimStatus', (_message.Message,), {

  'CapacityEntry' : _reflection.GeneratedProtocolMessageType('CapacityEntry', (_message.Message,), {
    'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimStatus.CapacityEntry)
    })
  ,
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimStatus)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimStatus)
_sym_db.RegisterMessage(PersistentVolumeClaimStatus.CapacityEntry)

PersistentVolumeClaimTemplate = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimTemplate', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMTEMPLATE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimTemplate)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimTemplate)

PersistentVolumeClaimVolumeSource = _reflection.GeneratedProtocolMessageType('PersistentVolumeClaimVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMECLAIMVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeClaimVolumeSource)
  })
_sym_db.RegisterMessage(PersistentVolumeClaimVolumeSource)

PersistentVolumeList = _reflection.GeneratedProtocolMessageType('PersistentVolumeList', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeList)
  })
_sym_db.RegisterMessage(PersistentVolumeList)

PersistentVolumeSource = _reflection.GeneratedProtocolMessageType('PersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeSource)
  })
_sym_db.RegisterMessage(PersistentVolumeSource)

PersistentVolumeSpec = _reflection.GeneratedProtocolMessageType('PersistentVolumeSpec', (_message.Message,), {

  'CapacityEntry' : _reflection.GeneratedProtocolMessageType('CapacityEntry', (_message.Message,), {
    'DESCRIPTOR' : _PERSISTENTVOLUMESPEC_CAPACITYENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeSpec.CapacityEntry)
    })
  ,
  'DESCRIPTOR' : _PERSISTENTVOLUMESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeSpec)
  })
_sym_db.RegisterMessage(PersistentVolumeSpec)
_sym_db.RegisterMessage(PersistentVolumeSpec.CapacityEntry)

PersistentVolumeStatus = _reflection.GeneratedProtocolMessageType('PersistentVolumeStatus', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTVOLUMESTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PersistentVolumeStatus)
  })
_sym_db.RegisterMessage(PersistentVolumeStatus)

PhotonPersistentDiskVolumeSource = _reflection.GeneratedProtocolMessageType('PhotonPersistentDiskVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _PHOTONPERSISTENTDISKVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PhotonPersistentDiskVolumeSource)
  })
_sym_db.RegisterMessage(PhotonPersistentDiskVolumeSource)

Pod = _reflection.GeneratedProtocolMessageType('Pod', (_message.Message,), {
  'DESCRIPTOR' : _POD,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Pod)
  })
_sym_db.RegisterMessage(Pod)

PodAffinity = _reflection.GeneratedProtocolMessageType('PodAffinity', (_message.Message,), {
  'DESCRIPTOR' : _PODAFFINITY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodAffinity)
  })
_sym_db.RegisterMessage(PodAffinity)

PodAffinityTerm = _reflection.GeneratedProtocolMessageType('PodAffinityTerm', (_message.Message,), {
  'DESCRIPTOR' : _PODAFFINITYTERM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodAffinityTerm)
  })
_sym_db.RegisterMessage(PodAffinityTerm)

PodAntiAffinity = _reflection.GeneratedProtocolMessageType('PodAntiAffinity', (_message.Message,), {
  'DESCRIPTOR' : _PODANTIAFFINITY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodAntiAffinity)
  })
_sym_db.RegisterMessage(PodAntiAffinity)

PodAttachOptions = _reflection.GeneratedProtocolMessageType('PodAttachOptions', (_message.Message,), {
  'DESCRIPTOR' : _PODATTACHOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodAttachOptions)
  })
_sym_db.RegisterMessage(PodAttachOptions)

PodCondition = _reflection.GeneratedProtocolMessageType('PodCondition', (_message.Message,), {
  'DESCRIPTOR' : _PODCONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodCondition)
  })
_sym_db.RegisterMessage(PodCondition)

PodDNSConfig = _reflection.GeneratedProtocolMessageType('PodDNSConfig', (_message.Message,), {
  'DESCRIPTOR' : _PODDNSCONFIG,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodDNSConfig)
  })
_sym_db.RegisterMessage(PodDNSConfig)

PodDNSConfigOption = _reflection.GeneratedProtocolMessageType('PodDNSConfigOption', (_message.Message,), {
  'DESCRIPTOR' : _PODDNSCONFIGOPTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodDNSConfigOption)
  })
_sym_db.RegisterMessage(PodDNSConfigOption)

PodExecOptions = _reflection.GeneratedProtocolMessageType('PodExecOptions', (_message.Message,), {
  'DESCRIPTOR' : _PODEXECOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodExecOptions)
  })
_sym_db.RegisterMessage(PodExecOptions)

PodIP = _reflection.GeneratedProtocolMessageType('PodIP', (_message.Message,), {
  'DESCRIPTOR' : _PODIP,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodIP)
  })
_sym_db.RegisterMessage(PodIP)

PodList = _reflection.GeneratedProtocolMessageType('PodList', (_message.Message,), {
  'DESCRIPTOR' : _PODLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodList)
  })
_sym_db.RegisterMessage(PodList)

PodLogOptions = _reflection.GeneratedProtocolMessageType('PodLogOptions', (_message.Message,), {
  'DESCRIPTOR' : _PODLOGOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodLogOptions)
  })
_sym_db.RegisterMessage(PodLogOptions)

PodPortForwardOptions = _reflection.GeneratedProtocolMessageType('PodPortForwardOptions', (_message.Message,), {
  'DESCRIPTOR' : _PODPORTFORWARDOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodPortForwardOptions)
  })
_sym_db.RegisterMessage(PodPortForwardOptions)

PodProxyOptions = _reflection.GeneratedProtocolMessageType('PodProxyOptions', (_message.Message,), {
  'DESCRIPTOR' : _PODPROXYOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodProxyOptions)
  })
_sym_db.RegisterMessage(PodProxyOptions)

PodReadinessGate = _reflection.GeneratedProtocolMessageType('PodReadinessGate', (_message.Message,), {
  'DESCRIPTOR' : _PODREADINESSGATE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodReadinessGate)
  })
_sym_db.RegisterMessage(PodReadinessGate)

PodSecurityContext = _reflection.GeneratedProtocolMessageType('PodSecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _PODSECURITYCONTEXT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodSecurityContext)
  })
_sym_db.RegisterMessage(PodSecurityContext)

PodSignature = _reflection.GeneratedProtocolMessageType('PodSignature', (_message.Message,), {
  'DESCRIPTOR' : _PODSIGNATURE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodSignature)
  })
_sym_db.RegisterMessage(PodSignature)

PodSpec = _reflection.GeneratedProtocolMessageType('PodSpec', (_message.Message,), {

  'NodeSelectorEntry' : _reflection.GeneratedProtocolMessageType('NodeSelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSPEC_NODESELECTORENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodSpec.NodeSelectorEntry)
    })
  ,

  'OverheadEntry' : _reflection.GeneratedProtocolMessageType('OverheadEntry', (_message.Message,), {
    'DESCRIPTOR' : _PODSPEC_OVERHEADENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodSpec.OverheadEntry)
    })
  ,
  'DESCRIPTOR' : _PODSPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodSpec)
  })
_sym_db.RegisterMessage(PodSpec)
_sym_db.RegisterMessage(PodSpec.NodeSelectorEntry)
_sym_db.RegisterMessage(PodSpec.OverheadEntry)

PodStatus = _reflection.GeneratedProtocolMessageType('PodStatus', (_message.Message,), {
  'DESCRIPTOR' : _PODSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodStatus)
  })
_sym_db.RegisterMessage(PodStatus)

PodStatusResult = _reflection.GeneratedProtocolMessageType('PodStatusResult', (_message.Message,), {
  'DESCRIPTOR' : _PODSTATUSRESULT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodStatusResult)
  })
_sym_db.RegisterMessage(PodStatusResult)

PodTemplate = _reflection.GeneratedProtocolMessageType('PodTemplate', (_message.Message,), {
  'DESCRIPTOR' : _PODTEMPLATE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodTemplate)
  })
_sym_db.RegisterMessage(PodTemplate)

PodTemplateList = _reflection.GeneratedProtocolMessageType('PodTemplateList', (_message.Message,), {
  'DESCRIPTOR' : _PODTEMPLATELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodTemplateList)
  })
_sym_db.RegisterMessage(PodTemplateList)

PodTemplateSpec = _reflection.GeneratedProtocolMessageType('PodTemplateSpec', (_message.Message,), {
  'DESCRIPTOR' : _PODTEMPLATESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PodTemplateSpec)
  })
_sym_db.RegisterMessage(PodTemplateSpec)

PortStatus = _reflection.GeneratedProtocolMessageType('PortStatus', (_message.Message,), {
  'DESCRIPTOR' : _PORTSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PortStatus)
  })
_sym_db.RegisterMessage(PortStatus)

PortworxVolumeSource = _reflection.GeneratedProtocolMessageType('PortworxVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _PORTWORXVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PortworxVolumeSource)
  })
_sym_db.RegisterMessage(PortworxVolumeSource)

Preconditions = _reflection.GeneratedProtocolMessageType('Preconditions', (_message.Message,), {
  'DESCRIPTOR' : _PRECONDITIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Preconditions)
  })
_sym_db.RegisterMessage(Preconditions)

PreferAvoidPodsEntry = _reflection.GeneratedProtocolMessageType('PreferAvoidPodsEntry', (_message.Message,), {
  'DESCRIPTOR' : _PREFERAVOIDPODSENTRY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PreferAvoidPodsEntry)
  })
_sym_db.RegisterMessage(PreferAvoidPodsEntry)

PreferredSchedulingTerm = _reflection.GeneratedProtocolMessageType('PreferredSchedulingTerm', (_message.Message,), {
  'DESCRIPTOR' : _PREFERREDSCHEDULINGTERM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.PreferredSchedulingTerm)
  })
_sym_db.RegisterMessage(PreferredSchedulingTerm)

Probe = _reflection.GeneratedProtocolMessageType('Probe', (_message.Message,), {
  'DESCRIPTOR' : _PROBE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Probe)
  })
_sym_db.RegisterMessage(Probe)

ProjectedVolumeSource = _reflection.GeneratedProtocolMessageType('ProjectedVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTEDVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ProjectedVolumeSource)
  })
_sym_db.RegisterMessage(ProjectedVolumeSource)

QuobyteVolumeSource = _reflection.GeneratedProtocolMessageType('QuobyteVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _QUOBYTEVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.QuobyteVolumeSource)
  })
_sym_db.RegisterMessage(QuobyteVolumeSource)

RBDPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('RBDPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _RBDPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.RBDPersistentVolumeSource)
  })
_sym_db.RegisterMessage(RBDPersistentVolumeSource)

RBDVolumeSource = _reflection.GeneratedProtocolMessageType('RBDVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _RBDVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.RBDVolumeSource)
  })
_sym_db.RegisterMessage(RBDVolumeSource)

RangeAllocation = _reflection.GeneratedProtocolMessageType('RangeAllocation', (_message.Message,), {
  'DESCRIPTOR' : _RANGEALLOCATION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.RangeAllocation)
  })
_sym_db.RegisterMessage(RangeAllocation)

ReplicationController = _reflection.GeneratedProtocolMessageType('ReplicationController', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONCONTROLLER,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationController)
  })
_sym_db.RegisterMessage(ReplicationController)

ReplicationControllerCondition = _reflection.GeneratedProtocolMessageType('ReplicationControllerCondition', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONCONTROLLERCONDITION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationControllerCondition)
  })
_sym_db.RegisterMessage(ReplicationControllerCondition)

ReplicationControllerList = _reflection.GeneratedProtocolMessageType('ReplicationControllerList', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONCONTROLLERLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationControllerList)
  })
_sym_db.RegisterMessage(ReplicationControllerList)

ReplicationControllerSpec = _reflection.GeneratedProtocolMessageType('ReplicationControllerSpec', (_message.Message,), {

  'SelectorEntry' : _reflection.GeneratedProtocolMessageType('SelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _REPLICATIONCONTROLLERSPEC_SELECTORENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationControllerSpec.SelectorEntry)
    })
  ,
  'DESCRIPTOR' : _REPLICATIONCONTROLLERSPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationControllerSpec)
  })
_sym_db.RegisterMessage(ReplicationControllerSpec)
_sym_db.RegisterMessage(ReplicationControllerSpec.SelectorEntry)

ReplicationControllerStatus = _reflection.GeneratedProtocolMessageType('ReplicationControllerStatus', (_message.Message,), {
  'DESCRIPTOR' : _REPLICATIONCONTROLLERSTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ReplicationControllerStatus)
  })
_sym_db.RegisterMessage(ReplicationControllerStatus)

ResourceFieldSelector = _reflection.GeneratedProtocolMessageType('ResourceFieldSelector', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEFIELDSELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceFieldSelector)
  })
_sym_db.RegisterMessage(ResourceFieldSelector)

ResourceQuota = _reflection.GeneratedProtocolMessageType('ResourceQuota', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEQUOTA,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuota)
  })
_sym_db.RegisterMessage(ResourceQuota)

ResourceQuotaList = _reflection.GeneratedProtocolMessageType('ResourceQuotaList', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEQUOTALIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaList)
  })
_sym_db.RegisterMessage(ResourceQuotaList)

ResourceQuotaSpec = _reflection.GeneratedProtocolMessageType('ResourceQuotaSpec', (_message.Message,), {

  'HardEntry' : _reflection.GeneratedProtocolMessageType('HardEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEQUOTASPEC_HARDENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaSpec.HardEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEQUOTASPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaSpec)
  })
_sym_db.RegisterMessage(ResourceQuotaSpec)
_sym_db.RegisterMessage(ResourceQuotaSpec.HardEntry)

ResourceQuotaStatus = _reflection.GeneratedProtocolMessageType('ResourceQuotaStatus', (_message.Message,), {

  'HardEntry' : _reflection.GeneratedProtocolMessageType('HardEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEQUOTASTATUS_HARDENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaStatus.HardEntry)
    })
  ,

  'UsedEntry' : _reflection.GeneratedProtocolMessageType('UsedEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEQUOTASTATUS_USEDENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaStatus.UsedEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEQUOTASTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceQuotaStatus)
  })
_sym_db.RegisterMessage(ResourceQuotaStatus)
_sym_db.RegisterMessage(ResourceQuotaStatus.HardEntry)
_sym_db.RegisterMessage(ResourceQuotaStatus.UsedEntry)

ResourceRequirements = _reflection.GeneratedProtocolMessageType('ResourceRequirements', (_message.Message,), {

  'LimitsEntry' : _reflection.GeneratedProtocolMessageType('LimitsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEREQUIREMENTS_LIMITSENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceRequirements.LimitsEntry)
    })
  ,

  'RequestsEntry' : _reflection.GeneratedProtocolMessageType('RequestsEntry', (_message.Message,), {
    'DESCRIPTOR' : _RESOURCEREQUIREMENTS_REQUESTSENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceRequirements.RequestsEntry)
    })
  ,
  'DESCRIPTOR' : _RESOURCEREQUIREMENTS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ResourceRequirements)
  })
_sym_db.RegisterMessage(ResourceRequirements)
_sym_db.RegisterMessage(ResourceRequirements.LimitsEntry)
_sym_db.RegisterMessage(ResourceRequirements.RequestsEntry)

SELinuxOptions = _reflection.GeneratedProtocolMessageType('SELinuxOptions', (_message.Message,), {
  'DESCRIPTOR' : _SELINUXOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SELinuxOptions)
  })
_sym_db.RegisterMessage(SELinuxOptions)

ScaleIOPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('ScaleIOPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _SCALEIOPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ScaleIOPersistentVolumeSource)
  })
_sym_db.RegisterMessage(ScaleIOPersistentVolumeSource)

ScaleIOVolumeSource = _reflection.GeneratedProtocolMessageType('ScaleIOVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _SCALEIOVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ScaleIOVolumeSource)
  })
_sym_db.RegisterMessage(ScaleIOVolumeSource)

ScopeSelector = _reflection.GeneratedProtocolMessageType('ScopeSelector', (_message.Message,), {
  'DESCRIPTOR' : _SCOPESELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ScopeSelector)
  })
_sym_db.RegisterMessage(ScopeSelector)

ScopedResourceSelectorRequirement = _reflection.GeneratedProtocolMessageType('ScopedResourceSelectorRequirement', (_message.Message,), {
  'DESCRIPTOR' : _SCOPEDRESOURCESELECTORREQUIREMENT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ScopedResourceSelectorRequirement)
  })
_sym_db.RegisterMessage(ScopedResourceSelectorRequirement)

SeccompProfile = _reflection.GeneratedProtocolMessageType('SeccompProfile', (_message.Message,), {
  'DESCRIPTOR' : _SECCOMPPROFILE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SeccompProfile)
  })
_sym_db.RegisterMessage(SeccompProfile)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {

  'DataEntry' : _reflection.GeneratedProtocolMessageType('DataEntry', (_message.Message,), {
    'DESCRIPTOR' : _SECRET_DATAENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Secret.DataEntry)
    })
  ,

  'StringDataEntry' : _reflection.GeneratedProtocolMessageType('StringDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _SECRET_STRINGDATAENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Secret.StringDataEntry)
    })
  ,
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Secret)
  })
_sym_db.RegisterMessage(Secret)
_sym_db.RegisterMessage(Secret.DataEntry)
_sym_db.RegisterMessage(Secret.StringDataEntry)

SecretEnvSource = _reflection.GeneratedProtocolMessageType('SecretEnvSource', (_message.Message,), {
  'DESCRIPTOR' : _SECRETENVSOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretEnvSource)
  })
_sym_db.RegisterMessage(SecretEnvSource)

SecretKeySelector = _reflection.GeneratedProtocolMessageType('SecretKeySelector', (_message.Message,), {
  'DESCRIPTOR' : _SECRETKEYSELECTOR,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretKeySelector)
  })
_sym_db.RegisterMessage(SecretKeySelector)

SecretList = _reflection.GeneratedProtocolMessageType('SecretList', (_message.Message,), {
  'DESCRIPTOR' : _SECRETLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretList)
  })
_sym_db.RegisterMessage(SecretList)

SecretProjection = _reflection.GeneratedProtocolMessageType('SecretProjection', (_message.Message,), {
  'DESCRIPTOR' : _SECRETPROJECTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretProjection)
  })
_sym_db.RegisterMessage(SecretProjection)

SecretReference = _reflection.GeneratedProtocolMessageType('SecretReference', (_message.Message,), {
  'DESCRIPTOR' : _SECRETREFERENCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretReference)
  })
_sym_db.RegisterMessage(SecretReference)

SecretVolumeSource = _reflection.GeneratedProtocolMessageType('SecretVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _SECRETVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecretVolumeSource)
  })
_sym_db.RegisterMessage(SecretVolumeSource)

SecurityContext = _reflection.GeneratedProtocolMessageType('SecurityContext', (_message.Message,), {
  'DESCRIPTOR' : _SECURITYCONTEXT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SecurityContext)
  })
_sym_db.RegisterMessage(SecurityContext)

SerializedReference = _reflection.GeneratedProtocolMessageType('SerializedReference', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZEDREFERENCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SerializedReference)
  })
_sym_db.RegisterMessage(SerializedReference)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Service)
  })
_sym_db.RegisterMessage(Service)

ServiceAccount = _reflection.GeneratedProtocolMessageType('ServiceAccount', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceAccount)
  })
_sym_db.RegisterMessage(ServiceAccount)

ServiceAccountList = _reflection.GeneratedProtocolMessageType('ServiceAccountList', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTLIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceAccountList)
  })
_sym_db.RegisterMessage(ServiceAccountList)

ServiceAccountTokenProjection = _reflection.GeneratedProtocolMessageType('ServiceAccountTokenProjection', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTTOKENPROJECTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceAccountTokenProjection)
  })
_sym_db.RegisterMessage(ServiceAccountTokenProjection)

ServiceList = _reflection.GeneratedProtocolMessageType('ServiceList', (_message.Message,), {
  'DESCRIPTOR' : _SERVICELIST,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceList)
  })
_sym_db.RegisterMessage(ServiceList)

ServicePort = _reflection.GeneratedProtocolMessageType('ServicePort', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEPORT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServicePort)
  })
_sym_db.RegisterMessage(ServicePort)

ServiceProxyOptions = _reflection.GeneratedProtocolMessageType('ServiceProxyOptions', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEPROXYOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceProxyOptions)
  })
_sym_db.RegisterMessage(ServiceProxyOptions)

ServiceSpec = _reflection.GeneratedProtocolMessageType('ServiceSpec', (_message.Message,), {

  'SelectorEntry' : _reflection.GeneratedProtocolMessageType('SelectorEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERVICESPEC_SELECTORENTRY,
    '__module__' : 'k8s.io.api.core.v1.generated_pb2'
    # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceSpec.SelectorEntry)
    })
  ,
  'DESCRIPTOR' : _SERVICESPEC,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceSpec)
  })
_sym_db.RegisterMessage(ServiceSpec)
_sym_db.RegisterMessage(ServiceSpec.SelectorEntry)

ServiceStatus = _reflection.GeneratedProtocolMessageType('ServiceStatus', (_message.Message,), {
  'DESCRIPTOR' : _SERVICESTATUS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.ServiceStatus)
  })
_sym_db.RegisterMessage(ServiceStatus)

SessionAffinityConfig = _reflection.GeneratedProtocolMessageType('SessionAffinityConfig', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONAFFINITYCONFIG,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.SessionAffinityConfig)
  })
_sym_db.RegisterMessage(SessionAffinityConfig)

StorageOSPersistentVolumeSource = _reflection.GeneratedProtocolMessageType('StorageOSPersistentVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEOSPERSISTENTVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.StorageOSPersistentVolumeSource)
  })
_sym_db.RegisterMessage(StorageOSPersistentVolumeSource)

StorageOSVolumeSource = _reflection.GeneratedProtocolMessageType('StorageOSVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEOSVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.StorageOSVolumeSource)
  })
_sym_db.RegisterMessage(StorageOSVolumeSource)

Sysctl = _reflection.GeneratedProtocolMessageType('Sysctl', (_message.Message,), {
  'DESCRIPTOR' : _SYSCTL,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Sysctl)
  })
_sym_db.RegisterMessage(Sysctl)

TCPSocketAction = _reflection.GeneratedProtocolMessageType('TCPSocketAction', (_message.Message,), {
  'DESCRIPTOR' : _TCPSOCKETACTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.TCPSocketAction)
  })
_sym_db.RegisterMessage(TCPSocketAction)

Taint = _reflection.GeneratedProtocolMessageType('Taint', (_message.Message,), {
  'DESCRIPTOR' : _TAINT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Taint)
  })
_sym_db.RegisterMessage(Taint)

Toleration = _reflection.GeneratedProtocolMessageType('Toleration', (_message.Message,), {
  'DESCRIPTOR' : _TOLERATION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Toleration)
  })
_sym_db.RegisterMessage(Toleration)

TopologySelectorLabelRequirement = _reflection.GeneratedProtocolMessageType('TopologySelectorLabelRequirement', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYSELECTORLABELREQUIREMENT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.TopologySelectorLabelRequirement)
  })
_sym_db.RegisterMessage(TopologySelectorLabelRequirement)

TopologySelectorTerm = _reflection.GeneratedProtocolMessageType('TopologySelectorTerm', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYSELECTORTERM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.TopologySelectorTerm)
  })
_sym_db.RegisterMessage(TopologySelectorTerm)

TopologySpreadConstraint = _reflection.GeneratedProtocolMessageType('TopologySpreadConstraint', (_message.Message,), {
  'DESCRIPTOR' : _TOPOLOGYSPREADCONSTRAINT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.TopologySpreadConstraint)
  })
_sym_db.RegisterMessage(TopologySpreadConstraint)

TypedLocalObjectReference = _reflection.GeneratedProtocolMessageType('TypedLocalObjectReference', (_message.Message,), {
  'DESCRIPTOR' : _TYPEDLOCALOBJECTREFERENCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.TypedLocalObjectReference)
  })
_sym_db.RegisterMessage(TypedLocalObjectReference)

Volume = _reflection.GeneratedProtocolMessageType('Volume', (_message.Message,), {
  'DESCRIPTOR' : _VOLUME,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.Volume)
  })
_sym_db.RegisterMessage(Volume)

VolumeDevice = _reflection.GeneratedProtocolMessageType('VolumeDevice', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEDEVICE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VolumeDevice)
  })
_sym_db.RegisterMessage(VolumeDevice)

VolumeMount = _reflection.GeneratedProtocolMessageType('VolumeMount', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEMOUNT,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VolumeMount)
  })
_sym_db.RegisterMessage(VolumeMount)

VolumeNodeAffinity = _reflection.GeneratedProtocolMessageType('VolumeNodeAffinity', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMENODEAFFINITY,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VolumeNodeAffinity)
  })
_sym_db.RegisterMessage(VolumeNodeAffinity)

VolumeProjection = _reflection.GeneratedProtocolMessageType('VolumeProjection', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMEPROJECTION,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VolumeProjection)
  })
_sym_db.RegisterMessage(VolumeProjection)

VolumeSource = _reflection.GeneratedProtocolMessageType('VolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _VOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VolumeSource)
  })
_sym_db.RegisterMessage(VolumeSource)

VsphereVirtualDiskVolumeSource = _reflection.GeneratedProtocolMessageType('VsphereVirtualDiskVolumeSource', (_message.Message,), {
  'DESCRIPTOR' : _VSPHEREVIRTUALDISKVOLUMESOURCE,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.VsphereVirtualDiskVolumeSource)
  })
_sym_db.RegisterMessage(VsphereVirtualDiskVolumeSource)

WeightedPodAffinityTerm = _reflection.GeneratedProtocolMessageType('WeightedPodAffinityTerm', (_message.Message,), {
  'DESCRIPTOR' : _WEIGHTEDPODAFFINITYTERM,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.WeightedPodAffinityTerm)
  })
_sym_db.RegisterMessage(WeightedPodAffinityTerm)

WindowsSecurityContextOptions = _reflection.GeneratedProtocolMessageType('WindowsSecurityContextOptions', (_message.Message,), {
  'DESCRIPTOR' : _WINDOWSSECURITYCONTEXTOPTIONS,
  '__module__' : 'k8s.io.api.core.v1.generated_pb2'
  # @@protoc_insertion_point(class_scope:k8s.io.api.core.v1.WindowsSecurityContextOptions)
  })
_sym_db.RegisterMessage(WindowsSecurityContextOptions)


DESCRIPTOR._options = None
_CSIPERSISTENTVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._options = None
_CSIVOLUMESOURCE_VOLUMEATTRIBUTESENTRY._options = None
_CONFIGMAP_DATAENTRY._options = None
_CONFIGMAP_BINARYDATAENTRY._options = None
_FLEXPERSISTENTVOLUMESOURCE_OPTIONSENTRY._options = None
_FLEXVOLUMESOURCE_OPTIONSENTRY._options = None
_LIMITRANGEITEM_MAXENTRY._options = None
_LIMITRANGEITEM_MINENTRY._options = None
_LIMITRANGEITEM_DEFAULTENTRY._options = None
_LIMITRANGEITEM_DEFAULTREQUESTENTRY._options = None
_LIMITRANGEITEM_MAXLIMITREQUESTRATIOENTRY._options = None
_NODERESOURCES_CAPACITYENTRY._options = None
_NODESTATUS_CAPACITYENTRY._options = None
_NODESTATUS_ALLOCATABLEENTRY._options = None
_PERSISTENTVOLUMECLAIMSTATUS_CAPACITYENTRY._options = None
_PERSISTENTVOLUMESPEC_CAPACITYENTRY._options = None
_PODSPEC_NODESELECTORENTRY._options = None
_PODSPEC_OVERHEADENTRY._options = None
_REPLICATIONCONTROLLERSPEC_SELECTORENTRY._options = None
_RESOURCEQUOTASPEC_HARDENTRY._options = None
_RESOURCEQUOTASTATUS_HARDENTRY._options = None
_RESOURCEQUOTASTATUS_USEDENTRY._options = None
_RESOURCEREQUIREMENTS_LIMITSENTRY._options = None
_RESOURCEREQUIREMENTS_REQUESTSENTRY._options = None
_SECRET_DATAENTRY._options = None
_SECRET_STRINGDATAENTRY._options = None
_SERVICESPEC_SELECTORENTRY._options = None
# @@protoc_insertion_point(module_scope)
