# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto',
  package='github.com.metaprov.modelaapi.services.dbproxyd.v1',
  syntax='proto3',
  serialized_options=b'Z2github.com/metaprov/modelaapi/services/dbproxyd/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAgithub.com/metaprov/modelaapi/services/dbproxyd/v1/dbproxyd.proto\x12\x32github.com.metaprov.modelaapi.services.dbproxyd.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/team/v1alpha1/generated.proto\x1a\x1bgoogle/protobuf/empty.proto\"O\n\x13ListAccountsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListAccountsResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateAccountRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"d\n\x14UpdateAccountRequest\x12L\n\x04item\x18\x02 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"7\n\x14\x44\x65leteAccountRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListAlertsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"z\n\x12ListAlertsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x12\x43reateAlertRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"`\n\x12UpdateAlertRequest\x12J\n\x04item\x18\x02 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"5\n\x12\x44\x65leteAlertRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"L\n\x10ListTodosRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"w\n\x11ListTodosResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0eGetTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"]\n\x11\x43reateTodoRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"]\n\x11UpdateTodoRequest\x12H\n\x04item\x18\x02 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"4\n\x11\x44\x65leteTodoRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListCommitsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x13ListCommitsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x13\x43reateCommitRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"b\n\x13UpdateCommitRequest\x12K\n\x04item\x18\x02 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"6\n\x13\x44\x65leteCommitRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x80\x01\n\x15ListApiTokensResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x15\x43reateApiTokenRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"f\n\x15UpdateApiTokenRequest\x12M\n\x04item\x18\x02 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListConnectionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x84\x01\n\x17ListConnectionsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"j\n\x17\x43reateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"j\n\x17UpdateConnectionRequest\x12O\n\x04item\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\":\n\x17\x44\x65leteConnectionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"K\n\x0fListLabsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"v\n\x10ListLabsResponse\x12I\n\x05items\x18\x01 \x03(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"0\n\rGetLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\\\n\x10\x43reateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\\\n\x10UpdateLabRequest\x12H\n\x04item\x18\x01 \x01(\x0b\x32:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"3\n\x10\x44\x65leteLabRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListLicensesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x14ListLicensesResponse\x12M\n\x05items\x18\x01 \x03(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"d\n\x14\x43reateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"d\n\x14UpdateLicenseRequest\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"7\n\x14\x44\x65leteLicenseRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListNotifiersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x80\x01\n\x15ListNotifiersResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"f\n\x15\x43reateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"f\n\x15UpdateNotifierRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"8\n\x15\x44\x65leteNotifierRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListServingsitesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x18ListServingsitesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x18\x43reateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"l\n\x18UpdateServingsiteRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\";\n\x18\x44\x65leteServingsiteRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListTenantsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x13ListTenantsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"b\n\x13\x43reateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"b\n\x13UpdateTenantRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"6\n\x13\x44\x65leteTenantRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListVirtualBucketsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8a\x01\n\x1aListVirtualBucketsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x1a\x43reateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"p\n\x1aUpdateVirtualBucketRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"=\n\x1a\x44\x65leteVirtualBucketRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1aListVirtualClustersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8c\x01\n\x1bListVirtualClustersResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x18GetVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"r\n\x1b\x43reateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"r\n\x1bUpdateVirtualClusterRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\">\n\x1b\x44\x65leteVirtualClusterRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListVirtualVolumesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8a\x01\n\x1aListVirtualVolumesResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x1a\x43reateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"p\n\x1aUpdateVirtualVolumeRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"=\n\x1a\x44\x65leteVirtualVolumeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"T\n\x18ListDataPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n\x19ListDataPipelinesResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n\x16GetDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x19\x43reateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"m\n\x19UpdateDataPipelineRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"<\n\x19\x44\x65leteDataPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x1bListDataPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1cListDataPipelineRunsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x19GetDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1c\x43reateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"s\n\x1cUpdateDataPipelineRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"?\n\x1c\x44\x65leteDataPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListDataProductsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x85\x01\n\x18ListDataProductsResponse\x12P\n\x05items\x18\x01 \x03(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"k\n\x18\x43reateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"k\n\x18UpdateDataProductRequest\x12O\n\x04item\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\";\n\x18\x44\x65leteDataProductRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n\x1eListDataProductVersionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1fListDataProductVersionsResponse\x12W\n\x05items\x18\x01 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x1cGetDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1f\x43reateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"y\n\x1fUpdateDataProductVersionRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"B\n\x1f\x44\x65leteDataProductVersionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListDatasetsResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"c\n\x14UpdateDatasetRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"7\n\x14\x44\x65leteDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListDatasourcesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListDatasourcesResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"i\n\x17UpdateDatasourceRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\":\n\x17\x44\x65leteDatasourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListEntitiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"|\n\x14ListEntitiesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"a\n\x13UpdateEntityRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"6\n\x13\x44\x65leteEntityRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListFeaturesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListFeaturesResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"c\n\x14UpdateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"7\n\x14\x44\x65leteFeatureRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\x1bListFeaturePipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1cListFeaturePipelinesResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"<\n\x19GetFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1c\x43reateFeaturePipelineRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"s\n\x1cUpdateFeaturePipelineRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"?\n\x1c\x44\x65leteFeaturePipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Z\n\x1eListFeaturePipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1fListFeaturePipelineRunsResponse\x12W\n\x05items\x18\x01 \x03(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"?\n\x1cGetFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1f\x43reateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"y\n\x1fUpdateFeaturePipelineRunRequest\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"B\n\x1f\x44\x65leteFeaturePipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListFeaturesetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListFeaturesetsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"i\n\x17UpdateFeaturesetRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\":\n\x17\x44\x65leteFeaturesetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListLabelingPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8f\x01\n\x1dListLabelingPipelinesResponse\x12U\n\x05items\x18\x01 \x03(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x1d\x43reateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"u\n\x1dUpdateLabelingPipelineRequest\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"@\n\x1d\x44\x65leteLabelingPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"[\n\x1fListLabelingPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x95\x01\n ListLabelingPipelineRunsResponse\x12X\n\x05items\x18\x01 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"@\n\x1dGetLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n CreateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"{\n UpdateLabelingPipelineRunRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"C\n DeleteLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListRecipesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListRecipesResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"a\n\x13UpdateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"6\n\x13\x44\x65leteRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListRecipeRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x81\x01\n\x16ListRecipeRunsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"g\n\x16\x43reateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"g\n\x16UpdateRecipeRunRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"9\n\x16\x44\x65leteRecipeRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListModelAutobuildersRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1dListModelAutobuildersResponse\x12Y\n\x05items\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1d\x43reateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"y\n\x1dUpdateModelAutobuilderRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"@\n\x1d\x44\x65leteModelAutobuilderRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"M\n\x11ListModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x12ListModelsResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"c\n\x12UpdateModelRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"5\n\x12\x44\x65leteModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"U\n\x19ListModelPipelinesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x8d\x01\n\x1aListModelPipelinesResponse\x12V\n\x05items\x18\x01 \x03(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\":\n\x17GetModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x1a\x43reateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"s\n\x1aUpdateModelPipelineRequest\x12U\n\x04item\x18\x01 \x01(\x0b\x32G.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"=\n\x1a\x44\x65leteModelPipelineRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"X\n\x1cListModelPipelineRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x93\x01\n\x1dListModelPipelineRunsResponse\x12Y\n\x05items\x18\x01 \x03(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"=\n\x1aGetModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x1d\x43reateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"y\n\x1dUpdateModelPipelineRunRequest\x12X\n\x04item\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"@\n\x1d\x44\x65leteModelPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"P\n\x14ListNotebooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x15ListNotebooksResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"5\n\x12GetNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x15\x43reateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"i\n\x15UpdateNotebookRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"8\n\x15\x44\x65leteNotebookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"S\n\x17ListNotebookRunsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x89\x01\n\x18ListNotebookRunsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n\x15GetNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"o\n\x18\x43reateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"o\n\x18UpdateNotebookRunRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\";\n\x18\x44\x65leteNotebookRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x7f\n\x13ListReportsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"e\n\x13\x43reateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"e\n\x13UpdateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListCronReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x87\x01\n\x17ListCronReportsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x17\x43reateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"m\n\x17UpdateCronReportRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\":\n\x17\x44\x65leteCronReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListStudiesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"~\n\x13ListStudiesResponse\x12N\n\x05items\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"2\n\x0fGetStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x12\x43reateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"c\n\x12UpdateStudyRequest\x12M\n\x04item\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"5\n\x12\x44\x65leteStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"V\n\x1aListCronPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x90\x01\n\x1bListCronPredictionsResponse\x12X\n\x05items\x18\x01 \x03(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x18GetCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x1b\x43reateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"v\n\x1bUpdateCronPredictionRequest\x12W\n\x04item\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\">\n\x1b\x44\x65leteCronPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListCurtainsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x82\x01\n\x14ListCurtainsResponse\x12Q\n\x05items\x18\x01 \x03(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x14\x43reateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"h\n\x14UpdateCurtainRequest\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"7\n\x14\x44\x65leteCurtainRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPredictionsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n\x17ListPredictionsResponse\x12T\n\x05items\x18\x01 \x03(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x17\x43reatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"n\n\x17UpdatePredictionRequest\x12S\n\x04item\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\":\n\x17\x44\x65letePredictionRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"Q\n\x15ListPredictorsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x86\x01\n\x16ListPredictorsResponse\x12S\n\x05items\x18\x01 \x03(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"6\n\x13GetPredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x16\x43reatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"l\n\x16UpdatePredictorRequest\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"9\n\x16\x44\x65letePredictorRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"N\n\x12ListReviewsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"{\n\x13ListReviewsResponse\x12K\n\x05items\x18\x01 \x03(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x10GetReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x13\x43reateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"a\n\x13UpdateReviewRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"6\n\x13\x44\x65leteReviewRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"R\n\x16ListPostMortemsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x83\x01\n\x17ListPostMortemsResponse\x12O\n\x05items\x18\x01 \x03(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetPostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"i\n\x17\x43reatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"i\n\x17UpdatePostMortemRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\":\n\x17\x44\x65letePostMortemRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"O\n\x13ListRunbooksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"}\n\x14ListRunbooksResponse\x12L\n\x05items\x18\x01 \x03(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"4\n\x11GetRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"c\n\x14\x43reateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"c\n\x14UpdateRunbookRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"7\n\x14\x44\x65leteRunbookRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2\xa9\x97\x02\n\x14\x44\x61tabaseProxyService\x12\xa3\x01\n\x0cListAccounts\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse\"\x00\x12\x95\x01\n\nGetAccount\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rCreateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12\x9b\x01\n\rUpdateAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Account\"\x00\x12s\n\rDeleteAccount\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListAlerts\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse\"\x00\x12\x8f\x01\n\x08GetAlert\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0b\x43reateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12\x95\x01\n\x0bUpdateAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Alert\"\x00\x12o\n\x0b\x44\x65leteAlert\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9a\x01\n\tListTodos\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest\x1a\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse\"\x00\x12\x8b\x01\n\x07GetTodo\x12\x42.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nCreateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12\x91\x01\n\nUpdateTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Todo\"\x00\x12m\n\nDeleteTodo\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListCommits\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse\"\x00\x12\x92\x01\n\tGetCommit\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12\x98\x01\n\x0c\x43reateCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12\x98\x01\n\x0cUpdateCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Commit\"\x00\x12q\n\x0c\x44\x65leteCommit\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse\"\x00\x12\x98\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12\x9e\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12\x9e\x01\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\"\x00\x12u\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListConnections\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse\"\x00\x12\x9e\x01\n\rGetConnection\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10\x43reateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12\xa4\x01\n\x10UpdateConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\"\x00\x12y\n\x10\x44\x65leteConnection\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x97\x01\n\x08ListLabs\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest\x1a\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse\"\x00\x12\x89\x01\n\x06GetLab\x12\x41.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tCreateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12\x8f\x01\n\tUpdateLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest\x1a:.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Lab\"\x00\x12k\n\tDeleteLab\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListLicenses\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse\"\x00\x12\x95\x01\n\nGetLicense\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rCreateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12\x9b\x01\n\rUpdateLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest\x1a>.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.License\"\x00\x12s\n\rDeleteLicense\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListNotifiers\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse\"\x00\x12\x98\x01\n\x0bGetNotifier\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0e\x43reateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12\x9e\x01\n\x0eUpdateNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Notifier\"\x00\x12u\n\x0e\x44\x65leteNotifier\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListServingSites\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse\"\x00\x12\xa1\x01\n\x0eGetServingSite\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11\x43reateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12\xa7\x01\n\x11UpdateServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ServingSite\"\x00\x12{\n\x11\x44\x65leteServingSite\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListTenants\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse\"\x00\x12\x92\x01\n\tGetTenant\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0c\x43reateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12\x98\x01\n\x0cUpdateTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Tenant\"\x00\x12q\n\x0c\x44\x65leteTenant\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListVirtualBuckets\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse\"\x00\x12\xa7\x01\n\x10GetVirtualBucket\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13\x43reateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\xad\x01\n\x13UpdateVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\"\x00\x12\x7f\n\x13\x44\x65leteVirtualBucket\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb8\x01\n\x13ListVirtualClusters\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest\x1aO.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse\"\x00\x12\xaa\x01\n\x11GetVirtualCluster\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\xb0\x01\n\x14\x43reateVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\xb0\x01\n\x14UpdateVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualCluster\"\x00\x12\x81\x01\n\x14\x44\x65leteVirtualCluster\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListVirtualVolumes\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse\"\x00\x12\xa7\x01\n\x10GetVirtualVolume\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\xad\x01\n\x13\x43reateVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\xad\x01\n\x13UpdateVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualVolume\"\x00\x12\x7f\n\x13\x44\x65leteVirtualVolume\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb2\x01\n\x11ListDataPipelines\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest\x1aM.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse\"\x00\x12\xa3\x01\n\x0fGetDataPipeline\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12\x43reateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12\xa9\x01\n\x12UpdateDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipeline\"\x00\x12}\n\x12\x44\x65leteDataPipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbb\x01\n\x14ListDataPipelineRuns\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest\x1aP.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse\"\x00\x12\xac\x01\n\x12GetDataPipelineRun\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15\x43reateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\xb2\x01\n\x15UpdateDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataPipelineRun\"\x00\x12\x83\x01\n\x15\x44\x65leteDataPipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListDataProducts\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse\"\x00\x12\xa0\x01\n\x0eGetDataProduct\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11\x43reateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12\xa6\x01\n\x11UpdateDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest\x1a\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProduct\"\x00\x12{\n\x11\x44\x65leteDataProduct\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc4\x01\n\x17ListDataProductVersions\x12R.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest\x1aS.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse\"\x00\x12\xb5\x01\n\x15GetDataProductVersion\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18\x43reateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\xbb\x01\n\x18UpdateDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataProductVersion\"\x00\x12\x89\x01\n\x18\x44\x65leteDataProductVersion\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListDatasets\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse\"\x00\x12\x94\x01\n\nGetDataset\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rCreateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12\x9a\x01\n\rUpdateDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x00\x12s\n\rDeleteDataset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListDataSources\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse\"\x00\x12\x9d\x01\n\rGetDataSource\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10\x43reateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12\xa3\x01\n\x10UpdateDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x00\x12y\n\x10\x44\x65leteDataSource\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListEntities\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse\"\x00\x12\x91\x01\n\tGetEntity\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0c\x43reateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12\x97\x01\n\x0cUpdateEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Entity\"\x00\x12q\n\x0c\x44\x65leteEntity\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListFeatures\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse\"\x00\x12\x94\x01\n\nGetFeature\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12\x9a\x01\n\rCreateFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12\x9a\x01\n\rUpdateFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x00\x12s\n\rDeleteFeature\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbb\x01\n\x14ListFeaturePipelines\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest\x1aP.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse\"\x00\x12\xac\x01\n\x12GetFeaturePipeline\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\xb2\x01\n\x15\x43reateFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\xb2\x01\n\x15UpdateFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipeline\"\x00\x12\x83\x01\n\x15\x44\x65leteFeaturePipeline\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc4\x01\n\x17ListFeaturePipelineRuns\x12R.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest\x1aS.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse\"\x00\x12\xb5\x01\n\x15GetFeaturePipelineRun\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\xbb\x01\n\x18\x43reateFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\xbb\x01\n\x18UpdateFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest\x1aH.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeaturePipelineRun\"\x00\x12\x89\x01\n\x18\x44\x65leteFeaturePipelineRun\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListFeaturesets\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse\"\x00\x12\x9d\x01\n\rGetFeatureset\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12\xa3\x01\n\x10\x43reateFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12\xa3\x01\n\x10UpdateFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Featureset\"\x00\x12y\n\x10\x44\x65leteFeatureset\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListLabelingPipelines\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse\"\x00\x12\xaf\x01\n\x13GetLabelingPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\xb5\x01\n\x16\x43reateLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\xb5\x01\n\x16UpdateLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest\x1a\x46.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipeline\"\x00\x12\x85\x01\n\x16\x44\x65leteLabelingPipeline\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xc7\x01\n\x18ListLabelingPipelineRuns\x12S.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest\x1aT.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse\"\x00\x12\xb8\x01\n\x16GetLabelingPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\xbe\x01\n\x19\x43reateLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\xbe\x01\n\x19UpdateLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"\x00\x12\x8b\x01\n\x19\x44\x65leteLabelingPipelineRun\x12T.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListRecipes\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse\"\x00\x12\x91\x01\n\tGetRecipe\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0c\x43reateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12\x97\x01\n\x0cUpdateRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x00\x12q\n\x0c\x44\x65leteRecipe\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListRecipeRuns\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse\"\x00\x12\x9a\x01\n\x0cGetRecipeRun\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0f\x43reateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12\xa0\x01\n\x0fUpdateRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeRun\"\x00\x12w\n\x0f\x44\x65leteRecipeRun\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListModelAutobuilders\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse\"\x00\x12\xb3\x01\n\x13GetModelAutobuilder\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\xb9\x01\n\x16\x43reateModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\xb9\x01\n\x16UpdateModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelAutobuilder\"\x00\x12\x85\x01\n\x16\x44\x65leteModelAutobuilder\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb5\x01\n\x12ListModelPipelines\x12M.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest\x1aN.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse\"\x00\x12\xaa\x01\n\x10GetModelPipeline\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\xb0\x01\n\x13\x43reateModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\xb0\x01\n\x13UpdateModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest\x1aG.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipeline\"\x00\x12\x7f\n\x13\x44\x65leteModelPipeline\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xbe\x01\n\x15ListModelPipelineRuns\x12P.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest\x1aQ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse\"\x00\x12\xb3\x01\n\x13GetModelPipelineRun\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\xb9\x01\n\x16\x43reateModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\xb9\x01\n\x16UpdateModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest\x1aJ.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ModelPipelineRun\"\x00\x12\x85\x01\n\x16\x44\x65leteModelPipelineRun\x12Q.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa6\x01\n\rListNotebooks\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest\x1aI.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse\"\x00\x12\x9b\x01\n\x0bGetNotebook\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12\xa1\x01\n\x0e\x43reateNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12\xa1\x01\n\x0eUpdateNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Notebook\"\x00\x12u\n\x0e\x44\x65leteNotebook\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xaf\x01\n\x10ListNotebookRuns\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest\x1aL.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse\"\x00\x12\xa4\x01\n\x0eGetNotebookRun\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12\xaa\x01\n\x11\x43reateNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12\xaa\x01\n\x11UpdateNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.NotebookRun\"\x00\x12{\n\x11\x44\x65leteNotebookRun\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReports\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse\"\x00\x12\x95\x01\n\tGetReport\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0c\x43reateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12\x9b\x01\n\x0cUpdateReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x00\x12q\n\x0c\x44\x65leteReport\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListCronReports\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse\"\x00\x12\xa1\x01\n\rGetCronReport\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12\xa7\x01\n\x10\x43reateCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12\xa7\x01\n\x10UpdateCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.CronReport\"\x00\x12y\n\x10\x44\x65leteCronReport\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListStudies\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse\"\x00\x12\x92\x01\n\x08GetStudy\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0b\x43reateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12\x98\x01\n\x0bUpdateStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x00\x12o\n\x0b\x44\x65leteStudy\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9d\x01\n\nListModels\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest\x1a\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse\"\x00\x12\x92\x01\n\x08GetModel\x12\x43.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0b\x43reateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12\x98\x01\n\x0bUpdateModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest\x1a?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"\x00\x12o\n\x0b\x44\x65leteModel\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xb8\x01\n\x13ListCronPredictions\x12N.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest\x1aO.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse\"\x00\x12\xae\x01\n\x11GetCronPrediction\x12L.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\xb4\x01\n\x14\x43reateCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\xb4\x01\n\x14UpdateCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest\x1aI.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.CronPrediction\"\x00\x12\x81\x01\n\x14\x44\x65leteCronPrediction\x12O.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPredictions\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse\"\x00\x12\xa2\x01\n\rGetPrediction\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10\x43reatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12\xa8\x01\n\x10UpdatePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest\x1a\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\"\x00\x12y\n\x10\x44\x65letePrediction\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa9\x01\n\x0eListPredictors\x12I.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest\x1aJ.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse\"\x00\x12\x9f\x01\n\x0cGetPredictor\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0f\x43reatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12\xa5\x01\n\x0fUpdatePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest\x1a\x44.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Predictor\"\x00\x12w\n\x0f\x44\x65letePredictor\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListCurtains\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse\"\x00\x12\x99\x01\n\nGetCurtain\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12\x9f\x01\n\rCreateCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12\x9f\x01\n\rUpdateCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest\x1a\x42.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Curtain\"\x00\x12s\n\rDeleteCurtain\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa0\x01\n\x0bListReviews\x12\x46.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest\x1aG.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse\"\x00\x12\x91\x01\n\tGetReview\x12\x44.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0c\x43reateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12\x97\x01\n\x0cUpdateReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest\x1a<.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.Review\"\x00\x12q\n\x0c\x44\x65leteReview\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xac\x01\n\x0fListPostMortems\x12J.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest\x1aK.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse\"\x00\x12\x9d\x01\n\rGetPostMortem\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10\x43reatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12\xa3\x01\n\x10UpdatePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest\x1a@.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.PostMortem\"\x00\x12y\n\x10\x44\x65letePostMortem\x12K.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\xa3\x01\n\x0cListRunBooks\x12G.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest\x1aH.github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse\"\x00\x12\x94\x01\n\nGetRunBook\x12\x45.github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rCreateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12\x9a\x01\n\rUpdateRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest\x1a=.github.com.metaprov.modelaapi.pkg.apis.team.v1alpha1.RunBook\"\x00\x12s\n\rDeleteRunBook\x12H.github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest\x1a\x16.google.protobuf.Empty\"\x00\x42\x34Z2github.com/metaprov/modelaapi/services/dbproxyd/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])




_LISTACCOUNTSREQUEST = _descriptor.Descriptor(
  name='ListAccountsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=619,
)


_LISTACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='ListAccountsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=747,
)


_GETACCOUNTREQUEST = _descriptor.Descriptor(
  name='GetAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=749,
  serialized_end=801,
)


_CREATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=903,
)


_UPDATEACCOUNTREQUEST = _descriptor.Descriptor(
  name='UpdateAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=905,
  serialized_end=1005,
)


_DELETEACCOUNTREQUEST = _descriptor.Descriptor(
  name='DeleteAccountRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1062,
)


_LISTALERTSREQUEST = _descriptor.Descriptor(
  name='ListAlertsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1064,
  serialized_end=1141,
)


_LISTALERTSRESPONSE = _descriptor.Descriptor(
  name='ListAlertsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1265,
)


_GETALERTREQUEST = _descriptor.Descriptor(
  name='GetAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1317,
)


_CREATEALERTREQUEST = _descriptor.Descriptor(
  name='CreateAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1415,
)


_UPDATEALERTREQUEST = _descriptor.Descriptor(
  name='UpdateAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1417,
  serialized_end=1513,
)


_DELETEALERTREQUEST = _descriptor.Descriptor(
  name='DeleteAlertRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1568,
)


_LISTTODOSREQUEST = _descriptor.Descriptor(
  name='ListTodosRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1646,
)


_LISTTODOSRESPONSE = _descriptor.Descriptor(
  name='ListTodosResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1648,
  serialized_end=1767,
)


_GETTODOREQUEST = _descriptor.Descriptor(
  name='GetTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1818,
)


_CREATETODOREQUEST = _descriptor.Descriptor(
  name='CreateTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1820,
  serialized_end=1913,
)


_UPDATETODOREQUEST = _descriptor.Descriptor(
  name='UpdateTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1915,
  serialized_end=2008,
)


_DELETETODOREQUEST = _descriptor.Descriptor(
  name='DeleteTodoRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2062,
)


_LISTCOMMITSREQUEST = _descriptor.Descriptor(
  name='ListCommitsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2064,
  serialized_end=2142,
)


_LISTCOMMITSRESPONSE = _descriptor.Descriptor(
  name='ListCommitsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2144,
  serialized_end=2268,
)


_GETCOMMITREQUEST = _descriptor.Descriptor(
  name='GetCommitRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2270,
  serialized_end=2321,
)


_CREATECOMMITREQUEST = _descriptor.Descriptor(
  name='CreateCommitRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2323,
  serialized_end=2421,
)


_UPDATECOMMITREQUEST = _descriptor.Descriptor(
  name='UpdateCommitRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2423,
  serialized_end=2521,
)


_DELETECOMMITREQUEST = _descriptor.Descriptor(
  name='DeleteCommitRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2523,
  serialized_end=2577,
)


_LISTAPITOKENSREQUEST = _descriptor.Descriptor(
  name='ListApiTokensRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2579,
  serialized_end=2659,
)


_LISTAPITOKENSRESPONSE = _descriptor.Descriptor(
  name='ListApiTokensResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2790,
)


_GETAPITOKENREQUEST = _descriptor.Descriptor(
  name='GetApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2792,
  serialized_end=2845,
)


_CREATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='CreateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2847,
  serialized_end=2949,
)


_UPDATEAPITOKENREQUEST = _descriptor.Descriptor(
  name='UpdateApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2951,
  serialized_end=3053,
)


_DELETEAPITOKENREQUEST = _descriptor.Descriptor(
  name='DeleteApiTokenRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3055,
  serialized_end=3111,
)


_LISTCONNECTIONSREQUEST = _descriptor.Descriptor(
  name='ListConnectionsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3113,
  serialized_end=3195,
)


_LISTCONNECTIONSRESPONSE = _descriptor.Descriptor(
  name='ListConnectionsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3198,
  serialized_end=3330,
)


_GETCONNECTIONREQUEST = _descriptor.Descriptor(
  name='GetConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3332,
  serialized_end=3387,
)


_CREATECONNECTIONREQUEST = _descriptor.Descriptor(
  name='CreateConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3389,
  serialized_end=3495,
)


_UPDATECONNECTIONREQUEST = _descriptor.Descriptor(
  name='UpdateConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest.item', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3497,
  serialized_end=3603,
)


_DELETECONNECTIONREQUEST = _descriptor.Descriptor(
  name='DeleteConnectionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3605,
  serialized_end=3663,
)


_LISTLABSREQUEST = _descriptor.Descriptor(
  name='ListLabsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3665,
  serialized_end=3740,
)


_LISTLABSRESPONSE = _descriptor.Descriptor(
  name='ListLabsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3742,
  serialized_end=3860,
)


_GETLABREQUEST = _descriptor.Descriptor(
  name='GetLabRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3862,
  serialized_end=3910,
)


_CREATELABREQUEST = _descriptor.Descriptor(
  name='CreateLabRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3912,
  serialized_end=4004,
)


_UPDATELABREQUEST = _descriptor.Descriptor(
  name='UpdateLabRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4006,
  serialized_end=4098,
)


_DELETELABREQUEST = _descriptor.Descriptor(
  name='DeleteLabRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4100,
  serialized_end=4151,
)


_LISTLICENSESREQUEST = _descriptor.Descriptor(
  name='ListLicensesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4153,
  serialized_end=4232,
)


_LISTLICENSESRESPONSE = _descriptor.Descriptor(
  name='ListLicensesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4234,
  serialized_end=4360,
)


_GETLICENSEREQUEST = _descriptor.Descriptor(
  name='GetLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4362,
  serialized_end=4414,
)


_CREATELICENSEREQUEST = _descriptor.Descriptor(
  name='CreateLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4416,
  serialized_end=4516,
)


_UPDATELICENSEREQUEST = _descriptor.Descriptor(
  name='UpdateLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4518,
  serialized_end=4618,
)


_DELETELICENSEREQUEST = _descriptor.Descriptor(
  name='DeleteLicenseRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4620,
  serialized_end=4675,
)


_LISTNOTIFIERSREQUEST = _descriptor.Descriptor(
  name='ListNotifiersRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4677,
  serialized_end=4757,
)


_LISTNOTIFIERSRESPONSE = _descriptor.Descriptor(
  name='ListNotifiersResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4760,
  serialized_end=4888,
)


_GETNOTIFIERREQUEST = _descriptor.Descriptor(
  name='GetNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4890,
  serialized_end=4943,
)


_CREATENOTIFIERREQUEST = _descriptor.Descriptor(
  name='CreateNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4945,
  serialized_end=5047,
)


_UPDATENOTIFIERREQUEST = _descriptor.Descriptor(
  name='UpdateNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5049,
  serialized_end=5151,
)


_DELETENOTIFIERREQUEST = _descriptor.Descriptor(
  name='DeleteNotifierRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5153,
  serialized_end=5209,
)


_LISTSERVINGSITESREQUEST = _descriptor.Descriptor(
  name='ListServingsitesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5211,
  serialized_end=5294,
)


_LISTSERVINGSITESRESPONSE = _descriptor.Descriptor(
  name='ListServingsitesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5297,
  serialized_end=5431,
)


_GETSERVINGSITEREQUEST = _descriptor.Descriptor(
  name='GetServingsiteRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5433,
  serialized_end=5489,
)


_CREATESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='CreateServingsiteRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5491,
  serialized_end=5599,
)


_UPDATESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='UpdateServingsiteRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5601,
  serialized_end=5709,
)


_DELETESERVINGSITEREQUEST = _descriptor.Descriptor(
  name='DeleteServingsiteRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5711,
  serialized_end=5770,
)


_LISTTENANTSREQUEST = _descriptor.Descriptor(
  name='ListTenantsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5772,
  serialized_end=5850,
)


_LISTTENANTSRESPONSE = _descriptor.Descriptor(
  name='ListTenantsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5852,
  serialized_end=5976,
)


_GETTENANTREQUEST = _descriptor.Descriptor(
  name='GetTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5978,
  serialized_end=6029,
)


_CREATETENANTREQUEST = _descriptor.Descriptor(
  name='CreateTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6031,
  serialized_end=6129,
)


_UPDATETENANTREQUEST = _descriptor.Descriptor(
  name='UpdateTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6131,
  serialized_end=6229,
)


_DELETETENANTREQUEST = _descriptor.Descriptor(
  name='DeleteTenantRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6231,
  serialized_end=6285,
)


_LISTVIRTUALBUCKETSREQUEST = _descriptor.Descriptor(
  name='ListVirtualBucketsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6287,
  serialized_end=6372,
)


_LISTVIRTUALBUCKETSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualBucketsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6375,
  serialized_end=6513,
)


_GETVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='GetVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6515,
  serialized_end=6573,
)


_CREATEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='CreateVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6575,
  serialized_end=6687,
)


_UPDATEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6689,
  serialized_end=6801,
)


_DELETEVIRTUALBUCKETREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualBucketRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6803,
  serialized_end=6864,
)


_LISTVIRTUALCLUSTERSREQUEST = _descriptor.Descriptor(
  name='ListVirtualClustersRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6866,
  serialized_end=6952,
)


_LISTVIRTUALCLUSTERSRESPONSE = _descriptor.Descriptor(
  name='ListVirtualClustersResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6955,
  serialized_end=7095,
)


_GETVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='GetVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7097,
  serialized_end=7156,
)


_CREATEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='CreateVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7158,
  serialized_end=7272,
)


_UPDATEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7274,
  serialized_end=7388,
)


_DELETEVIRTUALCLUSTERREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualClusterRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7390,
  serialized_end=7452,
)


_LISTVIRTUALVOLUMESREQUEST = _descriptor.Descriptor(
  name='ListVirtualVolumesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7454,
  serialized_end=7539,
)


_LISTVIRTUALVOLUMESRESPONSE = _descriptor.Descriptor(
  name='ListVirtualVolumesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7542,
  serialized_end=7680,
)


_GETVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='GetVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7682,
  serialized_end=7740,
)


_CREATEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='CreateVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7742,
  serialized_end=7854,
)


_UPDATEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='UpdateVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7856,
  serialized_end=7968,
)


_DELETEVIRTUALVOLUMEREQUEST = _descriptor.Descriptor(
  name='DeleteVirtualVolumeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7970,
  serialized_end=8031,
)


_LISTDATAPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListDataPipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8033,
  serialized_end=8117,
)


_LISTDATAPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListDataPipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8120,
  serialized_end=8255,
)


_GETDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8257,
  serialized_end=8314,
)


_CREATEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8316,
  serialized_end=8425,
)


_UPDATEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8427,
  serialized_end=8536,
)


_DELETEDATAPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteDataPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8538,
  serialized_end=8598,
)


_LISTDATAPIPELINERUNSREQUEST = _descriptor.Descriptor(
  name='ListDataPipelineRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8600,
  serialized_end=8687,
)


_LISTDATAPIPELINERUNSRESPONSE = _descriptor.Descriptor(
  name='ListDataPipelineRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8690,
  serialized_end=8831,
)


_GETDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8833,
  serialized_end=8893,
)


_CREATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8895,
  serialized_end=9010,
)


_UPDATEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9012,
  serialized_end=9127,
)


_DELETEDATAPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteDataPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9129,
  serialized_end=9192,
)


_LISTDATAPRODUCTSREQUEST = _descriptor.Descriptor(
  name='ListDataProductsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9194,
  serialized_end=9277,
)


_LISTDATAPRODUCTSRESPONSE = _descriptor.Descriptor(
  name='ListDataProductsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9280,
  serialized_end=9413,
)


_GETDATAPRODUCTREQUEST = _descriptor.Descriptor(
  name='GetDataProductRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9415,
  serialized_end=9471,
)


_CREATEDATAPRODUCTREQUEST = _descriptor.Descriptor(
  name='CreateDataProductRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9473,
  serialized_end=9580,
)


_UPDATEDATAPRODUCTREQUEST = _descriptor.Descriptor(
  name='UpdateDataProductRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9582,
  serialized_end=9689,
)


_DELETEDATAPRODUCTREQUEST = _descriptor.Descriptor(
  name='DeleteDataProductRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9691,
  serialized_end=9750,
)


_LISTDATAPRODUCTVERSIONSREQUEST = _descriptor.Descriptor(
  name='ListDataProductVersionsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9752,
  serialized_end=9842,
)


_LISTDATAPRODUCTVERSIONSRESPONSE = _descriptor.Descriptor(
  name='ListDataProductVersionsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9845,
  serialized_end=9992,
)


_GETDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='GetDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9994,
  serialized_end=10057,
)


_CREATEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='CreateDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10059,
  serialized_end=10180,
)


_UPDATEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='UpdateDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10182,
  serialized_end=10303,
)


_DELETEDATAPRODUCTVERSIONREQUEST = _descriptor.Descriptor(
  name='DeleteDataProductVersionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10305,
  serialized_end=10371,
)


_LISTDATASETSREQUEST = _descriptor.Descriptor(
  name='ListDatasetsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10373,
  serialized_end=10452,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListDatasetsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10454,
  serialized_end=10579,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
  name='GetDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10581,
  serialized_end=10633,
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
  name='CreateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10635,
  serialized_end=10734,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
  name='UpdateDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10736,
  serialized_end=10835,
)


_DELETEDATASETREQUEST = _descriptor.Descriptor(
  name='DeleteDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10837,
  serialized_end=10892,
)


_LISTDATASOURCESREQUEST = _descriptor.Descriptor(
  name='ListDatasourcesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10894,
  serialized_end=10976,
)


_LISTDATASOURCESRESPONSE = _descriptor.Descriptor(
  name='ListDatasourcesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10979,
  serialized_end=11110,
)


_GETDATASOURCEREQUEST = _descriptor.Descriptor(
  name='GetDatasourceRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11112,
  serialized_end=11167,
)


_CREATEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='CreateDatasourceRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11169,
  serialized_end=11274,
)


_UPDATEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='UpdateDatasourceRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11276,
  serialized_end=11381,
)


_DELETEDATASOURCEREQUEST = _descriptor.Descriptor(
  name='DeleteDatasourceRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11383,
  serialized_end=11441,
)


_LISTENTITIESREQUEST = _descriptor.Descriptor(
  name='ListEntitiesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11443,
  serialized_end=11522,
)


_LISTENTITIESRESPONSE = _descriptor.Descriptor(
  name='ListEntitiesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11524,
  serialized_end=11648,
)


_GETENTITYREQUEST = _descriptor.Descriptor(
  name='GetEntityRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11650,
  serialized_end=11701,
)


_CREATEENTITYREQUEST = _descriptor.Descriptor(
  name='CreateEntityRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11703,
  serialized_end=11800,
)


_UPDATEENTITYREQUEST = _descriptor.Descriptor(
  name='UpdateEntityRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11802,
  serialized_end=11899,
)


_DELETEENTITYREQUEST = _descriptor.Descriptor(
  name='DeleteEntityRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11901,
  serialized_end=11955,
)


_LISTFEATURESREQUEST = _descriptor.Descriptor(
  name='ListFeaturesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11957,
  serialized_end=12036,
)


_LISTFEATURESRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12038,
  serialized_end=12163,
)


_GETFEATUREREQUEST = _descriptor.Descriptor(
  name='GetFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12165,
  serialized_end=12217,
)


_CREATEFEATUREREQUEST = _descriptor.Descriptor(
  name='CreateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12219,
  serialized_end=12318,
)


_UPDATEFEATUREREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12320,
  serialized_end=12419,
)


_DELETEFEATUREREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12421,
  serialized_end=12476,
)


_LISTFEATUREPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListFeaturePipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12478,
  serialized_end=12565,
)


_LISTFEATUREPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListFeaturePipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12568,
  serialized_end=12709,
)


_GETFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12711,
  serialized_end=12771,
)


_CREATEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12773,
  serialized_end=12888,
)


_UPDATEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12890,
  serialized_end=13005,
)


_DELETEFEATUREPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturePipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13007,
  serialized_end=13070,
)


_LISTFEATUREPIPELINERUNSREQUEST = _descriptor.Descriptor(
  name='ListFeaturePipelineRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13072,
  serialized_end=13162,
)


_LISTFEATUREPIPELINERUNSRESPONSE = _descriptor.Descriptor(
  name='ListFeaturePipelineRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13165,
  serialized_end=13312,
)


_GETFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13314,
  serialized_end=13377,
)


_CREATEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13379,
  serialized_end=13500,
)


_UPDATEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13502,
  serialized_end=13623,
)


_DELETEFEATUREPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturePipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13625,
  serialized_end=13691,
)


_LISTFEATURESETSREQUEST = _descriptor.Descriptor(
  name='ListFeaturesetsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13693,
  serialized_end=13775,
)


_LISTFEATURESETSRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesetsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13778,
  serialized_end=13909,
)


_GETFEATURESETREQUEST = _descriptor.Descriptor(
  name='GetFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13911,
  serialized_end=13966,
)


_CREATEFEATURESETREQUEST = _descriptor.Descriptor(
  name='CreateFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13968,
  serialized_end=14073,
)


_UPDATEFEATURESETREQUEST = _descriptor.Descriptor(
  name='UpdateFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14075,
  serialized_end=14180,
)


_DELETEFEATURESETREQUEST = _descriptor.Descriptor(
  name='DeleteFeaturesetRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14182,
  serialized_end=14240,
)


_LISTLABELINGPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListLabelingPipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14242,
  serialized_end=14330,
)


_LISTLABELINGPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListLabelingPipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14333,
  serialized_end=14476,
)


_GETLABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14478,
  serialized_end=14539,
)


_CREATELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14541,
  serialized_end=14658,
)


_UPDATELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14660,
  serialized_end=14777,
)


_DELETELABELINGPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteLabelingPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14779,
  serialized_end=14843,
)


_LISTLABELINGPIPELINERUNSREQUEST = _descriptor.Descriptor(
  name='ListLabelingPipelineRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14845,
  serialized_end=14936,
)


_LISTLABELINGPIPELINERUNSRESPONSE = _descriptor.Descriptor(
  name='ListLabelingPipelineRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14939,
  serialized_end=15088,
)


_GETLABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15090,
  serialized_end=15154,
)


_CREATELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15156,
  serialized_end=15279,
)


_UPDATELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15281,
  serialized_end=15404,
)


_DELETELABELINGPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteLabelingPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15406,
  serialized_end=15473,
)


_LISTRECIPESREQUEST = _descriptor.Descriptor(
  name='ListRecipesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15475,
  serialized_end=15553,
)


_LISTRECIPESRESPONSE = _descriptor.Descriptor(
  name='ListRecipesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15555,
  serialized_end=15678,
)


_GETRECIPEREQUEST = _descriptor.Descriptor(
  name='GetRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15680,
  serialized_end=15731,
)


_CREATERECIPEREQUEST = _descriptor.Descriptor(
  name='CreateRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15733,
  serialized_end=15830,
)


_UPDATERECIPEREQUEST = _descriptor.Descriptor(
  name='UpdateRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15832,
  serialized_end=15929,
)


_DELETERECIPEREQUEST = _descriptor.Descriptor(
  name='DeleteRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15931,
  serialized_end=15985,
)


_LISTRECIPERUNSREQUEST = _descriptor.Descriptor(
  name='ListRecipeRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15987,
  serialized_end=16068,
)


_LISTRECIPERUNSRESPONSE = _descriptor.Descriptor(
  name='ListRecipeRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16071,
  serialized_end=16200,
)


_GETRECIPERUNREQUEST = _descriptor.Descriptor(
  name='GetRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16202,
  serialized_end=16256,
)


_CREATERECIPERUNREQUEST = _descriptor.Descriptor(
  name='CreateRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16258,
  serialized_end=16361,
)


_UPDATERECIPERUNREQUEST = _descriptor.Descriptor(
  name='UpdateRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16363,
  serialized_end=16466,
)


_DELETERECIPERUNREQUEST = _descriptor.Descriptor(
  name='DeleteRecipeRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16468,
  serialized_end=16525,
)


_LISTMODELAUTOBUILDERSREQUEST = _descriptor.Descriptor(
  name='ListModelAutobuildersRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16527,
  serialized_end=16615,
)


_LISTMODELAUTOBUILDERSRESPONSE = _descriptor.Descriptor(
  name='ListModelAutobuildersResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16618,
  serialized_end=16765,
)


_GETMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='GetModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16767,
  serialized_end=16828,
)


_CREATEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='CreateModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16830,
  serialized_end=16951,
)


_UPDATEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='UpdateModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=16953,
  serialized_end=17074,
)


_DELETEMODELAUTOBUILDERREQUEST = _descriptor.Descriptor(
  name='DeleteModelAutobuilderRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17076,
  serialized_end=17140,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
  name='ListModelsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17142,
  serialized_end=17219,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
  name='ListModelsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17221,
  serialized_end=17346,
)


_GETMODELREQUEST = _descriptor.Descriptor(
  name='GetModelRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17348,
  serialized_end=17398,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
  name='CreateModelRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17400,
  serialized_end=17499,
)


_UPDATEMODELREQUEST = _descriptor.Descriptor(
  name='UpdateModelRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17501,
  serialized_end=17600,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
  name='DeleteModelRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17602,
  serialized_end=17655,
)


_LISTMODELPIPELINESREQUEST = _descriptor.Descriptor(
  name='ListModelPipelinesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17657,
  serialized_end=17742,
)


_LISTMODELPIPELINESRESPONSE = _descriptor.Descriptor(
  name='ListModelPipelinesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17745,
  serialized_end=17886,
)


_GETMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='GetModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17888,
  serialized_end=17946,
)


_CREATEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='CreateModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=17948,
  serialized_end=18063,
)


_UPDATEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='UpdateModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18065,
  serialized_end=18180,
)


_DELETEMODELPIPELINEREQUEST = _descriptor.Descriptor(
  name='DeleteModelPipelineRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18182,
  serialized_end=18243,
)


_LISTMODELPIPELINERUNSREQUEST = _descriptor.Descriptor(
  name='ListModelPipelineRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18245,
  serialized_end=18333,
)


_LISTMODELPIPELINERUNSRESPONSE = _descriptor.Descriptor(
  name='ListModelPipelineRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18336,
  serialized_end=18483,
)


_GETMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='GetModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18485,
  serialized_end=18546,
)


_CREATEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='CreateModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18548,
  serialized_end=18669,
)


_UPDATEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='UpdateModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18671,
  serialized_end=18792,
)


_DELETEMODELPIPELINERUNREQUEST = _descriptor.Descriptor(
  name='DeleteModelPipelineRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18794,
  serialized_end=18858,
)


_LISTNOTEBOOKSREQUEST = _descriptor.Descriptor(
  name='ListNotebooksRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18860,
  serialized_end=18940,
)


_LISTNOTEBOOKSRESPONSE = _descriptor.Descriptor(
  name='ListNotebooksResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=18943,
  serialized_end=19074,
)


_GETNOTEBOOKREQUEST = _descriptor.Descriptor(
  name='GetNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19076,
  serialized_end=19129,
)


_CREATENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='CreateNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19131,
  serialized_end=19236,
)


_UPDATENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='UpdateNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19238,
  serialized_end=19343,
)


_DELETENOTEBOOKREQUEST = _descriptor.Descriptor(
  name='DeleteNotebookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19345,
  serialized_end=19401,
)


_LISTNOTEBOOKRUNSREQUEST = _descriptor.Descriptor(
  name='ListNotebookRunsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19403,
  serialized_end=19486,
)


_LISTNOTEBOOKRUNSRESPONSE = _descriptor.Descriptor(
  name='ListNotebookRunsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19489,
  serialized_end=19626,
)


_GETNOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='GetNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19628,
  serialized_end=19684,
)


_CREATENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='CreateNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19686,
  serialized_end=19797,
)


_UPDATENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='UpdateNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19799,
  serialized_end=19910,
)


_DELETENOTEBOOKRUNREQUEST = _descriptor.Descriptor(
  name='DeleteNotebookRunRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19912,
  serialized_end=19971,
)


_LISTREPORTSREQUEST = _descriptor.Descriptor(
  name='ListReportsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=19973,
  serialized_end=20051,
)


_LISTREPORTSRESPONSE = _descriptor.Descriptor(
  name='ListReportsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20053,
  serialized_end=20180,
)


_GETREPORTREQUEST = _descriptor.Descriptor(
  name='GetReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20182,
  serialized_end=20233,
)


_CREATEREPORTREQUEST = _descriptor.Descriptor(
  name='CreateReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20235,
  serialized_end=20336,
)


_UPDATEREPORTREQUEST = _descriptor.Descriptor(
  name='UpdateReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20338,
  serialized_end=20439,
)


_DELETEREPORTREQUEST = _descriptor.Descriptor(
  name='DeleteReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20441,
  serialized_end=20495,
)


_LISTCRONREPORTSREQUEST = _descriptor.Descriptor(
  name='ListCronReportsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20497,
  serialized_end=20579,
)


_LISTCRONREPORTSRESPONSE = _descriptor.Descriptor(
  name='ListCronReportsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20582,
  serialized_end=20717,
)


_GETCRONREPORTREQUEST = _descriptor.Descriptor(
  name='GetCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20719,
  serialized_end=20774,
)


_CREATECRONREPORTREQUEST = _descriptor.Descriptor(
  name='CreateCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20776,
  serialized_end=20885,
)


_UPDATECRONREPORTREQUEST = _descriptor.Descriptor(
  name='UpdateCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20887,
  serialized_end=20996,
)


_DELETECRONREPORTREQUEST = _descriptor.Descriptor(
  name='DeleteCronReportRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20998,
  serialized_end=21056,
)


_LISTSTUDIESREQUEST = _descriptor.Descriptor(
  name='ListStudiesRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21058,
  serialized_end=21136,
)


_LISTSTUDIESRESPONSE = _descriptor.Descriptor(
  name='ListStudiesResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21138,
  serialized_end=21264,
)


_GETSTUDYREQUEST = _descriptor.Descriptor(
  name='GetStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21266,
  serialized_end=21316,
)


_CREATESTUDYREQUEST = _descriptor.Descriptor(
  name='CreateStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21318,
  serialized_end=21417,
)


_UPDATESTUDYREQUEST = _descriptor.Descriptor(
  name='UpdateStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21419,
  serialized_end=21518,
)


_DELETESTUDYREQUEST = _descriptor.Descriptor(
  name='DeleteStudyRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21520,
  serialized_end=21573,
)


_LISTCRONPREDICTIONSREQUEST = _descriptor.Descriptor(
  name='ListCronPredictionsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21575,
  serialized_end=21661,
)


_LISTCRONPREDICTIONSRESPONSE = _descriptor.Descriptor(
  name='ListCronPredictionsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21664,
  serialized_end=21808,
)


_GETCRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='GetCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21810,
  serialized_end=21869,
)


_CREATECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='CreateCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21871,
  serialized_end=21989,
)


_UPDATECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='UpdateCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21991,
  serialized_end=22109,
)


_DELETECRONPREDICTIONREQUEST = _descriptor.Descriptor(
  name='DeleteCronPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22111,
  serialized_end=22173,
)


_LISTCURTAINSREQUEST = _descriptor.Descriptor(
  name='ListCurtainsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22175,
  serialized_end=22254,
)


_LISTCURTAINSRESPONSE = _descriptor.Descriptor(
  name='ListCurtainsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22257,
  serialized_end=22387,
)


_GETCURTAINREQUEST = _descriptor.Descriptor(
  name='GetCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22389,
  serialized_end=22441,
)


_CREATECURTAINREQUEST = _descriptor.Descriptor(
  name='CreateCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22443,
  serialized_end=22547,
)


_UPDATECURTAINREQUEST = _descriptor.Descriptor(
  name='UpdateCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22549,
  serialized_end=22653,
)


_DELETECURTAINREQUEST = _descriptor.Descriptor(
  name='DeleteCurtainRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22655,
  serialized_end=22710,
)


_LISTPREDICTIONSREQUEST = _descriptor.Descriptor(
  name='ListPredictionsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22712,
  serialized_end=22794,
)


_LISTPREDICTIONSRESPONSE = _descriptor.Descriptor(
  name='ListPredictionsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22797,
  serialized_end=22933,
)


_GETPREDICTIONREQUEST = _descriptor.Descriptor(
  name='GetPredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22935,
  serialized_end=22990,
)


_CREATEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='CreatePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=22992,
  serialized_end=23102,
)


_UPDATEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='UpdatePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23104,
  serialized_end=23214,
)


_DELETEPREDICTIONREQUEST = _descriptor.Descriptor(
  name='DeletePredictionRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23216,
  serialized_end=23274,
)


_LISTPREDICTORSREQUEST = _descriptor.Descriptor(
  name='ListPredictorsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23276,
  serialized_end=23357,
)


_LISTPREDICTORSRESPONSE = _descriptor.Descriptor(
  name='ListPredictorsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23360,
  serialized_end=23494,
)


_GETPREDICTORREQUEST = _descriptor.Descriptor(
  name='GetPredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23496,
  serialized_end=23550,
)


_CREATEPREDICTORREQUEST = _descriptor.Descriptor(
  name='CreatePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23552,
  serialized_end=23660,
)


_UPDATEPREDICTORREQUEST = _descriptor.Descriptor(
  name='UpdatePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23662,
  serialized_end=23770,
)


_DELETEPREDICTORREQUEST = _descriptor.Descriptor(
  name='DeletePredictorRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23772,
  serialized_end=23829,
)


_LISTREVIEWSREQUEST = _descriptor.Descriptor(
  name='ListReviewsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23831,
  serialized_end=23909,
)


_LISTREVIEWSRESPONSE = _descriptor.Descriptor(
  name='ListReviewsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=23911,
  serialized_end=24034,
)


_GETREVIEWREQUEST = _descriptor.Descriptor(
  name='GetReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24036,
  serialized_end=24087,
)


_CREATEREVIEWREQUEST = _descriptor.Descriptor(
  name='CreateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24089,
  serialized_end=24186,
)


_UPDATEREVIEWREQUEST = _descriptor.Descriptor(
  name='UpdateReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24188,
  serialized_end=24285,
)


_DELETEREVIEWREQUEST = _descriptor.Descriptor(
  name='DeleteReviewRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24287,
  serialized_end=24341,
)


_LISTPOSTMORTEMSREQUEST = _descriptor.Descriptor(
  name='ListPostMortemsRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24343,
  serialized_end=24425,
)


_LISTPOSTMORTEMSRESPONSE = _descriptor.Descriptor(
  name='ListPostMortemsResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24428,
  serialized_end=24559,
)


_GETPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='GetPostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24561,
  serialized_end=24616,
)


_CREATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='CreatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24618,
  serialized_end=24723,
)


_UPDATEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='UpdatePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24725,
  serialized_end=24830,
)


_DELETEPOSTMORTEMREQUEST = _descriptor.Descriptor(
  name='DeletePostMortemRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24832,
  serialized_end=24890,
)


_LISTRUNBOOKSREQUEST = _descriptor.Descriptor(
  name='ListRunbooksRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24892,
  serialized_end=24971,
)


_LISTRUNBOOKSRESPONSE = _descriptor.Descriptor(
  name='ListRunbooksResponse',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=24973,
  serialized_end=25098,
)


_GETRUNBOOKREQUEST = _descriptor.Descriptor(
  name='GetRunbookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25100,
  serialized_end=25152,
)


_CREATERUNBOOKREQUEST = _descriptor.Descriptor(
  name='CreateRunbookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25154,
  serialized_end=25253,
)


_UPDATERUNBOOKREQUEST = _descriptor.Descriptor(
  name='UpdateRunbookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25255,
  serialized_end=25354,
)


_DELETERUNBOOKREQUEST = _descriptor.Descriptor(
  name='DeleteRunbookRequest',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25356,
  serialized_end=25411,
)

_LISTACCOUNTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_CREATEACCOUNTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_UPDATEACCOUNTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT
_LISTALERTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_CREATEALERTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_UPDATEALERTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT
_LISTTODOSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_CREATETODOREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_UPDATETODOREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO
_LISTCOMMITSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT
_CREATECOMMITREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT
_UPDATECOMMITREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT
_LISTAPITOKENSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_CREATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_UPDATEAPITOKENREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN
_LISTCONNECTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATECONNECTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_UPDATECONNECTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_LISTLABSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_CREATELABREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_UPDATELABREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB
_LISTLICENSESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_CREATELICENSEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_UPDATELICENSEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE
_LISTNOTIFIERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
_CREATENOTIFIERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
_UPDATENOTIFIERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER
_LISTSERVINGSITESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
_CREATESERVINGSITEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
_UPDATESERVINGSITEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE
_LISTTENANTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
_CREATETENANTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
_UPDATETENANTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT
_LISTVIRTUALBUCKETSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_CREATEVIRTUALBUCKETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_UPDATEVIRTUALBUCKETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET
_LISTVIRTUALCLUSTERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
_CREATEVIRTUALCLUSTERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
_UPDATEVIRTUALCLUSTERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER
_LISTVIRTUALVOLUMESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
_CREATEVIRTUALVOLUMEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
_UPDATEVIRTUALVOLUMEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME
_LISTDATAPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_CREATEDATAPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_UPDATEDATAPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE
_LISTDATAPIPELINERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_CREATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_UPDATEDATAPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN
_LISTDATAPRODUCTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_CREATEDATAPRODUCTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_UPDATEDATAPRODUCTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT
_LISTDATAPRODUCTVERSIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_CREATEDATAPRODUCTVERSIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_UPDATEDATAPRODUCTVERSIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION
_LISTDATASETSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_CREATEDATASETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_UPDATEDATASETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET
_LISTDATASOURCESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_CREATEDATASOURCEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_UPDATEDATASOURCEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE
_LISTENTITIESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY
_CREATEENTITYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY
_UPDATEENTITYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY
_LISTFEATURESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_CREATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_UPDATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_LISTFEATUREPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
_CREATEFEATUREPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
_UPDATEFEATUREPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE
_LISTFEATUREPIPELINERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
_CREATEFEATUREPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
_UPDATEFEATUREPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN
_LISTFEATURESETSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
_CREATEFEATURESETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
_UPDATEFEATURESETREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET
_LISTLABELINGPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
_CREATELABELINGPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
_UPDATELABELINGPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE
_LISTLABELINGPIPELINERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
_CREATELABELINGPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
_UPDATELABELINGPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN
_LISTRECIPESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_CREATERECIPEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_UPDATERECIPEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_LISTRECIPERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_CREATERECIPERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_UPDATERECIPERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN
_LISTMODELAUTOBUILDERSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
_CREATEMODELAUTOBUILDERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
_UPDATEMODELAUTOBUILDERREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER
_LISTMODELSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_CREATEMODELREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_UPDATEMODELREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL
_LISTMODELPIPELINESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_CREATEMODELPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_UPDATEMODELPIPELINEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE
_LISTMODELPIPELINERUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
_CREATEMODELPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
_UPDATEMODELPIPELINERUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN
_LISTNOTEBOOKSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
_CREATENOTEBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
_UPDATENOTEBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK
_LISTNOTEBOOKRUNSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
_CREATENOTEBOOKRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
_UPDATENOTEBOOKRUNREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN
_LISTREPORTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_CREATEREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_UPDATEREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_LISTCRONREPORTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_CREATECRONREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_UPDATECRONREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT
_LISTSTUDIESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_CREATESTUDYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_UPDATESTUDYREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY
_LISTCRONPREDICTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_CREATECRONPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_UPDATECRONPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION
_LISTCURTAINSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
_CREATECURTAINREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
_UPDATECURTAINREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN
_LISTPREDICTIONSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
_CREATEPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
_UPDATEPREDICTIONREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION
_LISTPREDICTORSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_CREATEPREDICTORREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_UPDATEPREDICTORREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR
_LISTREVIEWSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW
_CREATEREVIEWREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW
_UPDATEREVIEWREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW
_LISTPOSTMORTEMSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_CREATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_UPDATEPOSTMORTEMREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM
_LISTRUNBOOKSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
_CREATERUNBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
_UPDATERUNBOOKREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK
DESCRIPTOR.message_types_by_name['ListAccountsRequest'] = _LISTACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['ListAccountsResponse'] = _LISTACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['GetAccountRequest'] = _GETACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CreateAccountRequest'] = _CREATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['UpdateAccountRequest'] = _UPDATEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccountRequest'] = _DELETEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['ListAlertsRequest'] = _LISTALERTSREQUEST
DESCRIPTOR.message_types_by_name['ListAlertsResponse'] = _LISTALERTSRESPONSE
DESCRIPTOR.message_types_by_name['GetAlertRequest'] = _GETALERTREQUEST
DESCRIPTOR.message_types_by_name['CreateAlertRequest'] = _CREATEALERTREQUEST
DESCRIPTOR.message_types_by_name['UpdateAlertRequest'] = _UPDATEALERTREQUEST
DESCRIPTOR.message_types_by_name['DeleteAlertRequest'] = _DELETEALERTREQUEST
DESCRIPTOR.message_types_by_name['ListTodosRequest'] = _LISTTODOSREQUEST
DESCRIPTOR.message_types_by_name['ListTodosResponse'] = _LISTTODOSRESPONSE
DESCRIPTOR.message_types_by_name['GetTodoRequest'] = _GETTODOREQUEST
DESCRIPTOR.message_types_by_name['CreateTodoRequest'] = _CREATETODOREQUEST
DESCRIPTOR.message_types_by_name['UpdateTodoRequest'] = _UPDATETODOREQUEST
DESCRIPTOR.message_types_by_name['DeleteTodoRequest'] = _DELETETODOREQUEST
DESCRIPTOR.message_types_by_name['ListCommitsRequest'] = _LISTCOMMITSREQUEST
DESCRIPTOR.message_types_by_name['ListCommitsResponse'] = _LISTCOMMITSRESPONSE
DESCRIPTOR.message_types_by_name['GetCommitRequest'] = _GETCOMMITREQUEST
DESCRIPTOR.message_types_by_name['CreateCommitRequest'] = _CREATECOMMITREQUEST
DESCRIPTOR.message_types_by_name['UpdateCommitRequest'] = _UPDATECOMMITREQUEST
DESCRIPTOR.message_types_by_name['DeleteCommitRequest'] = _DELETECOMMITREQUEST
DESCRIPTOR.message_types_by_name['ListApiTokensRequest'] = _LISTAPITOKENSREQUEST
DESCRIPTOR.message_types_by_name['ListApiTokensResponse'] = _LISTAPITOKENSRESPONSE
DESCRIPTOR.message_types_by_name['GetApiTokenRequest'] = _GETAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['CreateApiTokenRequest'] = _CREATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest'] = _UPDATEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest'] = _DELETEAPITOKENREQUEST
DESCRIPTOR.message_types_by_name['ListConnectionsRequest'] = _LISTCONNECTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListConnectionsResponse'] = _LISTCONNECTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetConnectionRequest'] = _GETCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['CreateConnectionRequest'] = _CREATECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateConnectionRequest'] = _UPDATECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteConnectionRequest'] = _DELETECONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['ListLabsRequest'] = _LISTLABSREQUEST
DESCRIPTOR.message_types_by_name['ListLabsResponse'] = _LISTLABSRESPONSE
DESCRIPTOR.message_types_by_name['GetLabRequest'] = _GETLABREQUEST
DESCRIPTOR.message_types_by_name['CreateLabRequest'] = _CREATELABREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabRequest'] = _UPDATELABREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabRequest'] = _DELETELABREQUEST
DESCRIPTOR.message_types_by_name['ListLicensesRequest'] = _LISTLICENSESREQUEST
DESCRIPTOR.message_types_by_name['ListLicensesResponse'] = _LISTLICENSESRESPONSE
DESCRIPTOR.message_types_by_name['GetLicenseRequest'] = _GETLICENSEREQUEST
DESCRIPTOR.message_types_by_name['CreateLicenseRequest'] = _CREATELICENSEREQUEST
DESCRIPTOR.message_types_by_name['UpdateLicenseRequest'] = _UPDATELICENSEREQUEST
DESCRIPTOR.message_types_by_name['DeleteLicenseRequest'] = _DELETELICENSEREQUEST
DESCRIPTOR.message_types_by_name['ListNotifiersRequest'] = _LISTNOTIFIERSREQUEST
DESCRIPTOR.message_types_by_name['ListNotifiersResponse'] = _LISTNOTIFIERSRESPONSE
DESCRIPTOR.message_types_by_name['GetNotifierRequest'] = _GETNOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['CreateNotifierRequest'] = _CREATENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotifierRequest'] = _UPDATENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotifierRequest'] = _DELETENOTIFIERREQUEST
DESCRIPTOR.message_types_by_name['ListServingsitesRequest'] = _LISTSERVINGSITESREQUEST
DESCRIPTOR.message_types_by_name['ListServingsitesResponse'] = _LISTSERVINGSITESRESPONSE
DESCRIPTOR.message_types_by_name['GetServingsiteRequest'] = _GETSERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['CreateServingsiteRequest'] = _CREATESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['UpdateServingsiteRequest'] = _UPDATESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['DeleteServingsiteRequest'] = _DELETESERVINGSITEREQUEST
DESCRIPTOR.message_types_by_name['ListTenantsRequest'] = _LISTTENANTSREQUEST
DESCRIPTOR.message_types_by_name['ListTenantsResponse'] = _LISTTENANTSRESPONSE
DESCRIPTOR.message_types_by_name['GetTenantRequest'] = _GETTENANTREQUEST
DESCRIPTOR.message_types_by_name['CreateTenantRequest'] = _CREATETENANTREQUEST
DESCRIPTOR.message_types_by_name['UpdateTenantRequest'] = _UPDATETENANTREQUEST
DESCRIPTOR.message_types_by_name['DeleteTenantRequest'] = _DELETETENANTREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualBucketsRequest'] = _LISTVIRTUALBUCKETSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualBucketsResponse'] = _LISTVIRTUALBUCKETSRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualBucketRequest'] = _GETVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualBucketRequest'] = _CREATEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualBucketRequest'] = _UPDATEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualBucketRequest'] = _DELETEVIRTUALBUCKETREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualClustersRequest'] = _LISTVIRTUALCLUSTERSREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualClustersResponse'] = _LISTVIRTUALCLUSTERSRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualClusterRequest'] = _GETVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualClusterRequest'] = _CREATEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualClusterRequest'] = _UPDATEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualClusterRequest'] = _DELETEVIRTUALCLUSTERREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualVolumesRequest'] = _LISTVIRTUALVOLUMESREQUEST
DESCRIPTOR.message_types_by_name['ListVirtualVolumesResponse'] = _LISTVIRTUALVOLUMESRESPONSE
DESCRIPTOR.message_types_by_name['GetVirtualVolumeRequest'] = _GETVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['CreateVirtualVolumeRequest'] = _CREATEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['UpdateVirtualVolumeRequest'] = _UPDATEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['DeleteVirtualVolumeRequest'] = _DELETEVIRTUALVOLUMEREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelinesRequest'] = _LISTDATAPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelinesResponse'] = _LISTDATAPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['GetDataPipelineRequest'] = _GETDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateDataPipelineRequest'] = _CREATEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRequest'] = _UPDATEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRequest'] = _DELETEDATAPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelineRunsRequest'] = _LISTDATAPIPELINERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListDataPipelineRunsResponse'] = _LISTDATAPIPELINERUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetDataPipelineRunRequest'] = _GETDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateDataPipelineRunRequest'] = _CREATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataPipelineRunRequest'] = _UPDATEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataPipelineRunRequest'] = _DELETEDATAPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListDataProductsRequest'] = _LISTDATAPRODUCTSREQUEST
DESCRIPTOR.message_types_by_name['ListDataProductsResponse'] = _LISTDATAPRODUCTSRESPONSE
DESCRIPTOR.message_types_by_name['GetDataProductRequest'] = _GETDATAPRODUCTREQUEST
DESCRIPTOR.message_types_by_name['CreateDataProductRequest'] = _CREATEDATAPRODUCTREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataProductRequest'] = _UPDATEDATAPRODUCTREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataProductRequest'] = _DELETEDATAPRODUCTREQUEST
DESCRIPTOR.message_types_by_name['ListDataProductVersionsRequest'] = _LISTDATAPRODUCTVERSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListDataProductVersionsResponse'] = _LISTDATAPRODUCTVERSIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetDataProductVersionRequest'] = _GETDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateDataProductVersionRequest'] = _CREATEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateDataProductVersionRequest'] = _UPDATEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteDataProductVersionRequest'] = _DELETEDATAPRODUCTVERSIONREQUEST
DESCRIPTOR.message_types_by_name['ListDatasetsRequest'] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListDatasetsResponse'] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['GetDatasetRequest'] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasetRequest'] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatasetRequest'] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatasetRequest'] = _DELETEDATASETREQUEST
DESCRIPTOR.message_types_by_name['ListDatasourcesRequest'] = _LISTDATASOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListDatasourcesResponse'] = _LISTDATASOURCESRESPONSE
DESCRIPTOR.message_types_by_name['GetDatasourceRequest'] = _GETDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['CreateDatasourceRequest'] = _CREATEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateDatasourceRequest'] = _UPDATEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteDatasourceRequest'] = _DELETEDATASOURCEREQUEST
DESCRIPTOR.message_types_by_name['ListEntitiesRequest'] = _LISTENTITIESREQUEST
DESCRIPTOR.message_types_by_name['ListEntitiesResponse'] = _LISTENTITIESRESPONSE
DESCRIPTOR.message_types_by_name['GetEntityRequest'] = _GETENTITYREQUEST
DESCRIPTOR.message_types_by_name['CreateEntityRequest'] = _CREATEENTITYREQUEST
DESCRIPTOR.message_types_by_name['UpdateEntityRequest'] = _UPDATEENTITYREQUEST
DESCRIPTOR.message_types_by_name['DeleteEntityRequest'] = _DELETEENTITYREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesRequest'] = _LISTFEATURESREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesResponse'] = _LISTFEATURESRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureRequest'] = _GETFEATUREREQUEST
DESCRIPTOR.message_types_by_name['CreateFeatureRequest'] = _CREATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureRequest'] = _UPDATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureRequest'] = _DELETEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelinesRequest'] = _LISTFEATUREPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelinesResponse'] = _LISTFEATUREPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturePipelineRequest'] = _GETFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRequest'] = _CREATEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRequest'] = _UPDATEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRequest'] = _DELETEFEATUREPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunsRequest'] = _LISTFEATUREPIPELINERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturePipelineRunsResponse'] = _LISTFEATUREPIPELINERUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturePipelineRunRequest'] = _GETFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturePipelineRunRequest'] = _CREATEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturePipelineRunRequest'] = _UPDATEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturePipelineRunRequest'] = _DELETEFEATUREPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesetsRequest'] = _LISTFEATURESETSREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesetsResponse'] = _LISTFEATURESETSRESPONSE
DESCRIPTOR.message_types_by_name['GetFeaturesetRequest'] = _GETFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['CreateFeaturesetRequest'] = _CREATEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeaturesetRequest'] = _UPDATEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeaturesetRequest'] = _DELETEFEATURESETREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelinesRequest'] = _LISTLABELINGPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelinesResponse'] = _LISTLABELINGPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['GetLabelingPipelineRequest'] = _GETLABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRequest'] = _CREATELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRequest'] = _UPDATELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRequest'] = _DELETELABELINGPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunsRequest'] = _LISTLABELINGPIPELINERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunsResponse'] = _LISTLABELINGPIPELINERUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunRequest'] = _GETLABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunRequest'] = _CREATELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunRequest'] = _UPDATELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunRequest'] = _DELETELABELINGPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListRecipesRequest'] = _LISTRECIPESREQUEST
DESCRIPTOR.message_types_by_name['ListRecipesResponse'] = _LISTRECIPESRESPONSE
DESCRIPTOR.message_types_by_name['GetRecipeRequest'] = _GETRECIPEREQUEST
DESCRIPTOR.message_types_by_name['CreateRecipeRequest'] = _CREATERECIPEREQUEST
DESCRIPTOR.message_types_by_name['UpdateRecipeRequest'] = _UPDATERECIPEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRecipeRequest'] = _DELETERECIPEREQUEST
DESCRIPTOR.message_types_by_name['ListRecipeRunsRequest'] = _LISTRECIPERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListRecipeRunsResponse'] = _LISTRECIPERUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetRecipeRunRequest'] = _GETRECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateRecipeRunRequest'] = _CREATERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateRecipeRunRequest'] = _UPDATERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteRecipeRunRequest'] = _DELETERECIPERUNREQUEST
DESCRIPTOR.message_types_by_name['ListModelAutobuildersRequest'] = _LISTMODELAUTOBUILDERSREQUEST
DESCRIPTOR.message_types_by_name['ListModelAutobuildersResponse'] = _LISTMODELAUTOBUILDERSRESPONSE
DESCRIPTOR.message_types_by_name['GetModelAutobuilderRequest'] = _GETMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['CreateModelAutobuilderRequest'] = _CREATEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelAutobuilderRequest'] = _UPDATEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelAutobuilderRequest'] = _DELETEMODELAUTOBUILDERREQUEST
DESCRIPTOR.message_types_by_name['ListModelsRequest'] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name['ListModelsResponse'] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name['GetModelRequest'] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name['CreateModelRequest'] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelRequest'] = _UPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelRequest'] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelinesRequest'] = _LISTMODELPIPELINESREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelinesResponse'] = _LISTMODELPIPELINESRESPONSE
DESCRIPTOR.message_types_by_name['GetModelPipelineRequest'] = _GETMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['CreateModelPipelineRequest'] = _CREATEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelPipelineRequest'] = _UPDATEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelPipelineRequest'] = _DELETEMODELPIPELINEREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelineRunsRequest'] = _LISTMODELPIPELINERUNSREQUEST
DESCRIPTOR.message_types_by_name['ListModelPipelineRunsResponse'] = _LISTMODELPIPELINERUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetModelPipelineRunRequest'] = _GETMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['CreateModelPipelineRunRequest'] = _CREATEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateModelPipelineRunRequest'] = _UPDATEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteModelPipelineRunRequest'] = _DELETEMODELPIPELINERUNREQUEST
DESCRIPTOR.message_types_by_name['ListNotebooksRequest'] = _LISTNOTEBOOKSREQUEST
DESCRIPTOR.message_types_by_name['ListNotebooksResponse'] = _LISTNOTEBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['GetNotebookRequest'] = _GETNOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['CreateNotebookRequest'] = _CREATENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotebookRequest'] = _UPDATENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotebookRequest'] = _DELETENOTEBOOKREQUEST
DESCRIPTOR.message_types_by_name['ListNotebookRunsRequest'] = _LISTNOTEBOOKRUNSREQUEST
DESCRIPTOR.message_types_by_name['ListNotebookRunsResponse'] = _LISTNOTEBOOKRUNSRESPONSE
DESCRIPTOR.message_types_by_name['GetNotebookRunRequest'] = _GETNOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['CreateNotebookRunRequest'] = _CREATENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['UpdateNotebookRunRequest'] = _UPDATENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['DeleteNotebookRunRequest'] = _DELETENOTEBOOKRUNREQUEST
DESCRIPTOR.message_types_by_name['ListReportsRequest'] = _LISTREPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListReportsResponse'] = _LISTREPORTSRESPONSE
DESCRIPTOR.message_types_by_name['GetReportRequest'] = _GETREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateReportRequest'] = _CREATEREPORTREQUEST
DESCRIPTOR.message_types_by_name['UpdateReportRequest'] = _UPDATEREPORTREQUEST
DESCRIPTOR.message_types_by_name['DeleteReportRequest'] = _DELETEREPORTREQUEST
DESCRIPTOR.message_types_by_name['ListCronReportsRequest'] = _LISTCRONREPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListCronReportsResponse'] = _LISTCRONREPORTSRESPONSE
DESCRIPTOR.message_types_by_name['GetCronReportRequest'] = _GETCRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateCronReportRequest'] = _CREATECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronReportRequest'] = _UPDATECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['DeleteCronReportRequest'] = _DELETECRONREPORTREQUEST
DESCRIPTOR.message_types_by_name['ListStudiesRequest'] = _LISTSTUDIESREQUEST
DESCRIPTOR.message_types_by_name['ListStudiesResponse'] = _LISTSTUDIESRESPONSE
DESCRIPTOR.message_types_by_name['GetStudyRequest'] = _GETSTUDYREQUEST
DESCRIPTOR.message_types_by_name['CreateStudyRequest'] = _CREATESTUDYREQUEST
DESCRIPTOR.message_types_by_name['UpdateStudyRequest'] = _UPDATESTUDYREQUEST
DESCRIPTOR.message_types_by_name['DeleteStudyRequest'] = _DELETESTUDYREQUEST
DESCRIPTOR.message_types_by_name['ListCronPredictionsRequest'] = _LISTCRONPREDICTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListCronPredictionsResponse'] = _LISTCRONPREDICTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetCronPredictionRequest'] = _GETCRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['CreateCronPredictionRequest'] = _CREATECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdateCronPredictionRequest'] = _UPDATECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteCronPredictionRequest'] = _DELETECRONPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['ListCurtainsRequest'] = _LISTCURTAINSREQUEST
DESCRIPTOR.message_types_by_name['ListCurtainsResponse'] = _LISTCURTAINSRESPONSE
DESCRIPTOR.message_types_by_name['GetCurtainRequest'] = _GETCURTAINREQUEST
DESCRIPTOR.message_types_by_name['CreateCurtainRequest'] = _CREATECURTAINREQUEST
DESCRIPTOR.message_types_by_name['UpdateCurtainRequest'] = _UPDATECURTAINREQUEST
DESCRIPTOR.message_types_by_name['DeleteCurtainRequest'] = _DELETECURTAINREQUEST
DESCRIPTOR.message_types_by_name['ListPredictionsRequest'] = _LISTPREDICTIONSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictionsResponse'] = _LISTPREDICTIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictionRequest'] = _GETPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['CreatePredictionRequest'] = _CREATEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictionRequest'] = _UPDATEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictionRequest'] = _DELETEPREDICTIONREQUEST
DESCRIPTOR.message_types_by_name['ListPredictorsRequest'] = _LISTPREDICTORSREQUEST
DESCRIPTOR.message_types_by_name['ListPredictorsResponse'] = _LISTPREDICTORSRESPONSE
DESCRIPTOR.message_types_by_name['GetPredictorRequest'] = _GETPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['CreatePredictorRequest'] = _CREATEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['UpdatePredictorRequest'] = _UPDATEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['DeletePredictorRequest'] = _DELETEPREDICTORREQUEST
DESCRIPTOR.message_types_by_name['ListReviewsRequest'] = _LISTREVIEWSREQUEST
DESCRIPTOR.message_types_by_name['ListReviewsResponse'] = _LISTREVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['GetReviewRequest'] = _GETREVIEWREQUEST
DESCRIPTOR.message_types_by_name['CreateReviewRequest'] = _CREATEREVIEWREQUEST
DESCRIPTOR.message_types_by_name['UpdateReviewRequest'] = _UPDATEREVIEWREQUEST
DESCRIPTOR.message_types_by_name['DeleteReviewRequest'] = _DELETEREVIEWREQUEST
DESCRIPTOR.message_types_by_name['ListPostMortemsRequest'] = _LISTPOSTMORTEMSREQUEST
DESCRIPTOR.message_types_by_name['ListPostMortemsResponse'] = _LISTPOSTMORTEMSRESPONSE
DESCRIPTOR.message_types_by_name['GetPostMortemRequest'] = _GETPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['CreatePostMortemRequest'] = _CREATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['UpdatePostMortemRequest'] = _UPDATEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['DeletePostMortemRequest'] = _DELETEPOSTMORTEMREQUEST
DESCRIPTOR.message_types_by_name['ListRunbooksRequest'] = _LISTRUNBOOKSREQUEST
DESCRIPTOR.message_types_by_name['ListRunbooksResponse'] = _LISTRUNBOOKSRESPONSE
DESCRIPTOR.message_types_by_name['GetRunbookRequest'] = _GETRUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['CreateRunbookRequest'] = _CREATERUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['UpdateRunbookRequest'] = _UPDATERUNBOOKREQUEST
DESCRIPTOR.message_types_by_name['DeleteRunbookRequest'] = _DELETERUNBOOKREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAccountsRequest = _reflection.GeneratedProtocolMessageType('ListAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsRequest)
  })
_sym_db.RegisterMessage(ListAccountsRequest)

ListAccountsResponse = _reflection.GeneratedProtocolMessageType('ListAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCOUNTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAccountsResponse)
  })
_sym_db.RegisterMessage(ListAccountsResponse)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

CreateAccountRequest = _reflection.GeneratedProtocolMessageType('CreateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAccountRequest)
  })
_sym_db.RegisterMessage(CreateAccountRequest)

UpdateAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAccountRequest)
  })
_sym_db.RegisterMessage(UpdateAccountRequest)

DeleteAccountRequest = _reflection.GeneratedProtocolMessageType('DeleteAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCOUNTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAccountRequest)
  })
_sym_db.RegisterMessage(DeleteAccountRequest)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

GetAlertRequest = _reflection.GeneratedProtocolMessageType('GetAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetAlertRequest)
  })
_sym_db.RegisterMessage(GetAlertRequest)

CreateAlertRequest = _reflection.GeneratedProtocolMessageType('CreateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateAlertRequest)
  })
_sym_db.RegisterMessage(CreateAlertRequest)

UpdateAlertRequest = _reflection.GeneratedProtocolMessageType('UpdateAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateAlertRequest)
  })
_sym_db.RegisterMessage(UpdateAlertRequest)

DeleteAlertRequest = _reflection.GeneratedProtocolMessageType('DeleteAlertRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALERTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteAlertRequest)
  })
_sym_db.RegisterMessage(DeleteAlertRequest)

ListTodosRequest = _reflection.GeneratedProtocolMessageType('ListTodosRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosRequest)
  })
_sym_db.RegisterMessage(ListTodosRequest)

ListTodosResponse = _reflection.GeneratedProtocolMessageType('ListTodosResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTODOSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTodosResponse)
  })
_sym_db.RegisterMessage(ListTodosResponse)

GetTodoRequest = _reflection.GeneratedProtocolMessageType('GetTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTodoRequest)
  })
_sym_db.RegisterMessage(GetTodoRequest)

CreateTodoRequest = _reflection.GeneratedProtocolMessageType('CreateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTodoRequest)
  })
_sym_db.RegisterMessage(CreateTodoRequest)

UpdateTodoRequest = _reflection.GeneratedProtocolMessageType('UpdateTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTodoRequest)
  })
_sym_db.RegisterMessage(UpdateTodoRequest)

DeleteTodoRequest = _reflection.GeneratedProtocolMessageType('DeleteTodoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODOREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTodoRequest)
  })
_sym_db.RegisterMessage(DeleteTodoRequest)

ListCommitsRequest = _reflection.GeneratedProtocolMessageType('ListCommitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsRequest)
  })
_sym_db.RegisterMessage(ListCommitsRequest)

ListCommitsResponse = _reflection.GeneratedProtocolMessageType('ListCommitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMITSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCommitsResponse)
  })
_sym_db.RegisterMessage(ListCommitsResponse)

GetCommitRequest = _reflection.GeneratedProtocolMessageType('GetCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCommitRequest)
  })
_sym_db.RegisterMessage(GetCommitRequest)

CreateCommitRequest = _reflection.GeneratedProtocolMessageType('CreateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCommitRequest)
  })
_sym_db.RegisterMessage(CreateCommitRequest)

UpdateCommitRequest = _reflection.GeneratedProtocolMessageType('UpdateCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCommitRequest)
  })
_sym_db.RegisterMessage(UpdateCommitRequest)

DeleteCommitRequest = _reflection.GeneratedProtocolMessageType('DeleteCommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECOMMITREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCommitRequest)
  })
_sym_db.RegisterMessage(DeleteCommitRequest)

ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

ListConnectionsRequest = _reflection.GeneratedProtocolMessageType('ListConnectionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsRequest)
  })
_sym_db.RegisterMessage(ListConnectionsRequest)

ListConnectionsResponse = _reflection.GeneratedProtocolMessageType('ListConnectionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCONNECTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListConnectionsResponse)
  })
_sym_db.RegisterMessage(ListConnectionsResponse)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

CreateConnectionRequest = _reflection.GeneratedProtocolMessageType('CreateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateConnectionRequest)
  })
_sym_db.RegisterMessage(CreateConnectionRequest)

UpdateConnectionRequest = _reflection.GeneratedProtocolMessageType('UpdateConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateConnectionRequest)
  })
_sym_db.RegisterMessage(UpdateConnectionRequest)

DeleteConnectionRequest = _reflection.GeneratedProtocolMessageType('DeleteConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECONNECTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteConnectionRequest)
  })
_sym_db.RegisterMessage(DeleteConnectionRequest)

ListLabsRequest = _reflection.GeneratedProtocolMessageType('ListLabsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsRequest)
  })
_sym_db.RegisterMessage(ListLabsRequest)

ListLabsResponse = _reflection.GeneratedProtocolMessageType('ListLabsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabsResponse)
  })
_sym_db.RegisterMessage(ListLabsResponse)

GetLabRequest = _reflection.GeneratedProtocolMessageType('GetLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabRequest)
  })
_sym_db.RegisterMessage(GetLabRequest)

CreateLabRequest = _reflection.GeneratedProtocolMessageType('CreateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabRequest)
  })
_sym_db.RegisterMessage(CreateLabRequest)

UpdateLabRequest = _reflection.GeneratedProtocolMessageType('UpdateLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabRequest)
  })
_sym_db.RegisterMessage(UpdateLabRequest)

DeleteLabRequest = _reflection.GeneratedProtocolMessageType('DeleteLabRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabRequest)
  })
_sym_db.RegisterMessage(DeleteLabRequest)

ListLicensesRequest = _reflection.GeneratedProtocolMessageType('ListLicensesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesRequest)
  })
_sym_db.RegisterMessage(ListLicensesRequest)

ListLicensesResponse = _reflection.GeneratedProtocolMessageType('ListLicensesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLICENSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLicensesResponse)
  })
_sym_db.RegisterMessage(ListLicensesResponse)

GetLicenseRequest = _reflection.GeneratedProtocolMessageType('GetLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLicenseRequest)
  })
_sym_db.RegisterMessage(GetLicenseRequest)

CreateLicenseRequest = _reflection.GeneratedProtocolMessageType('CreateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLicenseRequest)
  })
_sym_db.RegisterMessage(CreateLicenseRequest)

UpdateLicenseRequest = _reflection.GeneratedProtocolMessageType('UpdateLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLicenseRequest)
  })
_sym_db.RegisterMessage(UpdateLicenseRequest)

DeleteLicenseRequest = _reflection.GeneratedProtocolMessageType('DeleteLicenseRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELICENSEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLicenseRequest)
  })
_sym_db.RegisterMessage(DeleteLicenseRequest)

ListNotifiersRequest = _reflection.GeneratedProtocolMessageType('ListNotifiersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersRequest)
  })
_sym_db.RegisterMessage(ListNotifiersRequest)

ListNotifiersResponse = _reflection.GeneratedProtocolMessageType('ListNotifiersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTIFIERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotifiersResponse)
  })
_sym_db.RegisterMessage(ListNotifiersResponse)

GetNotifierRequest = _reflection.GeneratedProtocolMessageType('GetNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotifierRequest)
  })
_sym_db.RegisterMessage(GetNotifierRequest)

CreateNotifierRequest = _reflection.GeneratedProtocolMessageType('CreateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotifierRequest)
  })
_sym_db.RegisterMessage(CreateNotifierRequest)

UpdateNotifierRequest = _reflection.GeneratedProtocolMessageType('UpdateNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotifierRequest)
  })
_sym_db.RegisterMessage(UpdateNotifierRequest)

DeleteNotifierRequest = _reflection.GeneratedProtocolMessageType('DeleteNotifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTIFIERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotifierRequest)
  })
_sym_db.RegisterMessage(DeleteNotifierRequest)

ListServingsitesRequest = _reflection.GeneratedProtocolMessageType('ListServingsitesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesRequest)
  })
_sym_db.RegisterMessage(ListServingsitesRequest)

ListServingsitesResponse = _reflection.GeneratedProtocolMessageType('ListServingsitesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSERVINGSITESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListServingsitesResponse)
  })
_sym_db.RegisterMessage(ListServingsitesResponse)

GetServingsiteRequest = _reflection.GeneratedProtocolMessageType('GetServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetServingsiteRequest)
  })
_sym_db.RegisterMessage(GetServingsiteRequest)

CreateServingsiteRequest = _reflection.GeneratedProtocolMessageType('CreateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateServingsiteRequest)
  })
_sym_db.RegisterMessage(CreateServingsiteRequest)

UpdateServingsiteRequest = _reflection.GeneratedProtocolMessageType('UpdateServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateServingsiteRequest)
  })
_sym_db.RegisterMessage(UpdateServingsiteRequest)

DeleteServingsiteRequest = _reflection.GeneratedProtocolMessageType('DeleteServingsiteRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESERVINGSITEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteServingsiteRequest)
  })
_sym_db.RegisterMessage(DeleteServingsiteRequest)

ListTenantsRequest = _reflection.GeneratedProtocolMessageType('ListTenantsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsRequest)
  })
_sym_db.RegisterMessage(ListTenantsRequest)

ListTenantsResponse = _reflection.GeneratedProtocolMessageType('ListTenantsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTENANTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListTenantsResponse)
  })
_sym_db.RegisterMessage(ListTenantsResponse)

GetTenantRequest = _reflection.GeneratedProtocolMessageType('GetTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetTenantRequest)
  })
_sym_db.RegisterMessage(GetTenantRequest)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

UpdateTenantRequest = _reflection.GeneratedProtocolMessageType('UpdateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateTenantRequest)
  })
_sym_db.RegisterMessage(UpdateTenantRequest)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

ListVirtualBucketsRequest = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsRequest)
  })
_sym_db.RegisterMessage(ListVirtualBucketsRequest)

ListVirtualBucketsResponse = _reflection.GeneratedProtocolMessageType('ListVirtualBucketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALBUCKETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualBucketsResponse)
  })
_sym_db.RegisterMessage(ListVirtualBucketsResponse)

GetVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('GetVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualBucketRequest)
  })
_sym_db.RegisterMessage(GetVirtualBucketRequest)

CreateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(CreateVirtualBucketRequest)

UpdateVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualBucketRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualBucketRequest)

DeleteVirtualBucketRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualBucketRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALBUCKETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualBucketRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualBucketRequest)

ListVirtualClustersRequest = _reflection.GeneratedProtocolMessageType('ListVirtualClustersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersRequest)
  })
_sym_db.RegisterMessage(ListVirtualClustersRequest)

ListVirtualClustersResponse = _reflection.GeneratedProtocolMessageType('ListVirtualClustersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALCLUSTERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualClustersResponse)
  })
_sym_db.RegisterMessage(ListVirtualClustersResponse)

GetVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('GetVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualClusterRequest)
  })
_sym_db.RegisterMessage(GetVirtualClusterRequest)

CreateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(CreateVirtualClusterRequest)

UpdateVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualClusterRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualClusterRequest)

DeleteVirtualClusterRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualClusterRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALCLUSTERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualClusterRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualClusterRequest)

ListVirtualVolumesRequest = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesRequest)
  })
_sym_db.RegisterMessage(ListVirtualVolumesRequest)

ListVirtualVolumesResponse = _reflection.GeneratedProtocolMessageType('ListVirtualVolumesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIRTUALVOLUMESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListVirtualVolumesResponse)
  })
_sym_db.RegisterMessage(ListVirtualVolumesResponse)

GetVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('GetVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(GetVirtualVolumeRequest)

CreateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('CreateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(CreateVirtualVolumeRequest)

UpdateVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('UpdateVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(UpdateVirtualVolumeRequest)

DeleteVirtualVolumeRequest = _reflection.GeneratedProtocolMessageType('DeleteVirtualVolumeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIRTUALVOLUMEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteVirtualVolumeRequest)
  })
_sym_db.RegisterMessage(DeleteVirtualVolumeRequest)

ListDataPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesRequest)
  })
_sym_db.RegisterMessage(ListDataPipelinesRequest)

ListDataPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelinesResponse)
  })
_sym_db.RegisterMessage(ListDataPipelinesResponse)

GetDataPipelineRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRequest)

CreateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRequest)

UpdateDataPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRequest)

DeleteDataPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRequest)

ListDataPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsRequest)

ListDataPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListDataPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListDataPipelineRunsResponse)

GetDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetDataPipelineRunRequest)

CreateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateDataPipelineRunRequest)

UpdateDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateDataPipelineRunRequest)

DeleteDataPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteDataPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteDataPipelineRunRequest)

ListDataProductsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsRequest)
  })
_sym_db.RegisterMessage(ListDataProductsRequest)

ListDataProductsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductsResponse)
  })
_sym_db.RegisterMessage(ListDataProductsResponse)

GetDataProductRequest = _reflection.GeneratedProtocolMessageType('GetDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductRequest)
  })
_sym_db.RegisterMessage(GetDataProductRequest)

CreateDataProductRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductRequest)
  })
_sym_db.RegisterMessage(CreateDataProductRequest)

UpdateDataProductRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductRequest)

DeleteDataProductRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductRequest)

ListDataProductVersionsRequest = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsRequest)
  })
_sym_db.RegisterMessage(ListDataProductVersionsRequest)

ListDataProductVersionsResponse = _reflection.GeneratedProtocolMessageType('ListDataProductVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATAPRODUCTVERSIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDataProductVersionsResponse)
  })
_sym_db.RegisterMessage(ListDataProductVersionsResponse)

GetDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('GetDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDataProductVersionRequest)
  })
_sym_db.RegisterMessage(GetDataProductVersionRequest)

CreateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('CreateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(CreateDataProductVersionRequest)

UpdateDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDataProductVersionRequest)
  })
_sym_db.RegisterMessage(UpdateDataProductVersionRequest)

DeleteDataProductVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteDataProductVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATAPRODUCTVERSIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDataProductVersionRequest)
  })
_sym_db.RegisterMessage(DeleteDataProductVersionRequest)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteDatasetRequest)

ListDatasourcesRequest = _reflection.GeneratedProtocolMessageType('ListDatasourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesRequest)
  })
_sym_db.RegisterMessage(ListDatasourcesRequest)

ListDatasourcesResponse = _reflection.GeneratedProtocolMessageType('ListDatasourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListDatasourcesResponse)
  })
_sym_db.RegisterMessage(ListDatasourcesResponse)

GetDatasourceRequest = _reflection.GeneratedProtocolMessageType('GetDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetDatasourceRequest)
  })
_sym_db.RegisterMessage(GetDatasourceRequest)

CreateDatasourceRequest = _reflection.GeneratedProtocolMessageType('CreateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateDatasourceRequest)
  })
_sym_db.RegisterMessage(CreateDatasourceRequest)

UpdateDatasourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateDatasourceRequest)
  })
_sym_db.RegisterMessage(UpdateDatasourceRequest)

DeleteDatasourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteDatasourceRequest)
  })
_sym_db.RegisterMessage(DeleteDatasourceRequest)

ListEntitiesRequest = _reflection.GeneratedProtocolMessageType('ListEntitiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesRequest)
  })
_sym_db.RegisterMessage(ListEntitiesRequest)

ListEntitiesResponse = _reflection.GeneratedProtocolMessageType('ListEntitiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTENTITIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListEntitiesResponse)
  })
_sym_db.RegisterMessage(ListEntitiesResponse)

GetEntityRequest = _reflection.GeneratedProtocolMessageType('GetEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetEntityRequest)
  })
_sym_db.RegisterMessage(GetEntityRequest)

CreateEntityRequest = _reflection.GeneratedProtocolMessageType('CreateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateEntityRequest)
  })
_sym_db.RegisterMessage(CreateEntityRequest)

UpdateEntityRequest = _reflection.GeneratedProtocolMessageType('UpdateEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateEntityRequest)
  })
_sym_db.RegisterMessage(UpdateEntityRequest)

DeleteEntityRequest = _reflection.GeneratedProtocolMessageType('DeleteEntityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEENTITYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteEntityRequest)
  })
_sym_db.RegisterMessage(DeleteEntityRequest)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

ListFeaturePipelinesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelinesRequest)

ListFeaturePipelinesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelinesResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelinesResponse)

GetFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRequest)

CreateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRequest)

UpdateFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRequest)

DeleteFeaturePipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRequest)

ListFeaturePipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunsRequest)

ListFeaturePipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListFeaturePipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATUREPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturePipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListFeaturePipelineRunsResponse)

GetFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(GetFeaturePipelineRunRequest)

CreateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateFeaturePipelineRunRequest)

UpdateFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturePipelineRunRequest)

DeleteFeaturePipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturePipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturePipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturePipelineRunRequest)

ListFeaturesetsRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsRequest)
  })
_sym_db.RegisterMessage(ListFeaturesetsRequest)

ListFeaturesetsResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListFeaturesetsResponse)
  })
_sym_db.RegisterMessage(ListFeaturesetsResponse)

GetFeaturesetRequest = _reflection.GeneratedProtocolMessageType('GetFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetFeaturesetRequest)
  })
_sym_db.RegisterMessage(GetFeaturesetRequest)

CreateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('CreateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateFeaturesetRequest)
  })
_sym_db.RegisterMessage(CreateFeaturesetRequest)

UpdateFeaturesetRequest = _reflection.GeneratedProtocolMessageType('UpdateFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateFeaturesetRequest)
  })
_sym_db.RegisterMessage(UpdateFeaturesetRequest)

DeleteFeaturesetRequest = _reflection.GeneratedProtocolMessageType('DeleteFeaturesetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURESETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteFeaturesetRequest)
  })
_sym_db.RegisterMessage(DeleteFeaturesetRequest)

ListLabelingPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelinesRequest)

ListLabelingPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelinesResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelinesResponse)

GetLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRequest)

CreateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRequest)

UpdateLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRequest)

DeleteLabelingPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRequest)

ListLabelingPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunsRequest)

ListLabelingPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListLabelingPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunsResponse)

GetLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunRequest)

CreateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunRequest)

UpdateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunRequest)

DeleteLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunRequest)

ListRecipesRequest = _reflection.GeneratedProtocolMessageType('ListRecipesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesRequest)
  })
_sym_db.RegisterMessage(ListRecipesRequest)

ListRecipesResponse = _reflection.GeneratedProtocolMessageType('ListRecipesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipesResponse)
  })
_sym_db.RegisterMessage(ListRecipesResponse)

GetRecipeRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRequest)
  })
_sym_db.RegisterMessage(GetRecipeRequest)

CreateRecipeRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRequest)

UpdateRecipeRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRequest)

DeleteRecipeRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRequest)

ListRecipeRunsRequest = _reflection.GeneratedProtocolMessageType('ListRecipeRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsRequest)
  })
_sym_db.RegisterMessage(ListRecipeRunsRequest)

ListRecipeRunsResponse = _reflection.GeneratedProtocolMessageType('ListRecipeRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRecipeRunsResponse)
  })
_sym_db.RegisterMessage(ListRecipeRunsResponse)

GetRecipeRunRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRecipeRunRequest)
  })
_sym_db.RegisterMessage(GetRecipeRunRequest)

CreateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRecipeRunRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRunRequest)

UpdateRecipeRunRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRecipeRunRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRunRequest)

DeleteRecipeRunRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRecipeRunRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRunRequest)

ListModelAutobuildersRequest = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersRequest)
  })
_sym_db.RegisterMessage(ListModelAutobuildersRequest)

ListModelAutobuildersResponse = _reflection.GeneratedProtocolMessageType('ListModelAutobuildersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELAUTOBUILDERSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelAutobuildersResponse)
  })
_sym_db.RegisterMessage(ListModelAutobuildersResponse)

GetModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('GetModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(GetModelAutobuilderRequest)

CreateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('CreateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(CreateModelAutobuilderRequest)

UpdateModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('UpdateModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(UpdateModelAutobuilderRequest)

DeleteModelAutobuilderRequest = _reflection.GeneratedProtocolMessageType('DeleteModelAutobuilderRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELAUTOBUILDERREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelAutobuilderRequest)
  })
_sym_db.RegisterMessage(DeleteModelAutobuilderRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType('ListModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsRequest)
  })
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType('ListModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelsResponse)
  })
_sym_db.RegisterMessage(ListModelsResponse)

GetModelRequest = _reflection.GeneratedProtocolMessageType('GetModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelRequest)
  })
_sym_db.RegisterMessage(GetModelRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType('CreateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelRequest)
  })
_sym_db.RegisterMessage(CreateModelRequest)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType('UpdateModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelRequest)
  })
_sym_db.RegisterMessage(UpdateModelRequest)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType('DeleteModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelRequest)
  })
_sym_db.RegisterMessage(DeleteModelRequest)

ListModelPipelinesRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelinesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesRequest)
  })
_sym_db.RegisterMessage(ListModelPipelinesRequest)

ListModelPipelinesResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelinesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelinesResponse)
  })
_sym_db.RegisterMessage(ListModelPipelinesResponse)

GetModelPipelineRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRequest)

CreateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRequest)

UpdateModelPipelineRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRequest)

DeleteModelPipelineRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRequest)

ListModelPipelineRunsRequest = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsRequest)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsRequest)

ListModelPipelineRunsResponse = _reflection.GeneratedProtocolMessageType('ListModelPipelineRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMODELPIPELINERUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListModelPipelineRunsResponse)
  })
_sym_db.RegisterMessage(ListModelPipelineRunsResponse)

GetModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetModelPipelineRunRequest)

CreateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateModelPipelineRunRequest)

UpdateModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateModelPipelineRunRequest)

DeleteModelPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteModelPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteModelPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteModelPipelineRunRequest)

ListNotebooksRequest = _reflection.GeneratedProtocolMessageType('ListNotebooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksRequest)
  })
_sym_db.RegisterMessage(ListNotebooksRequest)

ListNotebooksResponse = _reflection.GeneratedProtocolMessageType('ListNotebooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebooksResponse)
  })
_sym_db.RegisterMessage(ListNotebooksResponse)

GetNotebookRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRequest)
  })
_sym_db.RegisterMessage(GetNotebookRequest)

CreateNotebookRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRequest)

UpdateNotebookRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRequest)

DeleteNotebookRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRequest)

ListNotebookRunsRequest = _reflection.GeneratedProtocolMessageType('ListNotebookRunsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsRequest)
  })
_sym_db.RegisterMessage(ListNotebookRunsRequest)

ListNotebookRunsResponse = _reflection.GeneratedProtocolMessageType('ListNotebookRunsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNOTEBOOKRUNSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListNotebookRunsResponse)
  })
_sym_db.RegisterMessage(ListNotebookRunsResponse)

GetNotebookRunRequest = _reflection.GeneratedProtocolMessageType('GetNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetNotebookRunRequest)
  })
_sym_db.RegisterMessage(GetNotebookRunRequest)

CreateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('CreateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateNotebookRunRequest)
  })
_sym_db.RegisterMessage(CreateNotebookRunRequest)

UpdateNotebookRunRequest = _reflection.GeneratedProtocolMessageType('UpdateNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateNotebookRunRequest)
  })
_sym_db.RegisterMessage(UpdateNotebookRunRequest)

DeleteNotebookRunRequest = _reflection.GeneratedProtocolMessageType('DeleteNotebookRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENOTEBOOKRUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteNotebookRunRequest)
  })
_sym_db.RegisterMessage(DeleteNotebookRunRequest)

ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

ListCronReportsRequest = _reflection.GeneratedProtocolMessageType('ListCronReportsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsRequest)
  })
_sym_db.RegisterMessage(ListCronReportsRequest)

ListCronReportsResponse = _reflection.GeneratedProtocolMessageType('ListCronReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronReportsResponse)
  })
_sym_db.RegisterMessage(ListCronReportsResponse)

GetCronReportRequest = _reflection.GeneratedProtocolMessageType('GetCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronReportRequest)
  })
_sym_db.RegisterMessage(GetCronReportRequest)

CreateCronReportRequest = _reflection.GeneratedProtocolMessageType('CreateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronReportRequest)
  })
_sym_db.RegisterMessage(CreateCronReportRequest)

UpdateCronReportRequest = _reflection.GeneratedProtocolMessageType('UpdateCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronReportRequest)
  })
_sym_db.RegisterMessage(UpdateCronReportRequest)

DeleteCronReportRequest = _reflection.GeneratedProtocolMessageType('DeleteCronReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronReportRequest)
  })
_sym_db.RegisterMessage(DeleteCronReportRequest)

ListStudiesRequest = _reflection.GeneratedProtocolMessageType('ListStudiesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesRequest)
  })
_sym_db.RegisterMessage(ListStudiesRequest)

ListStudiesResponse = _reflection.GeneratedProtocolMessageType('ListStudiesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDIESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListStudiesResponse)
  })
_sym_db.RegisterMessage(ListStudiesResponse)

GetStudyRequest = _reflection.GeneratedProtocolMessageType('GetStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetStudyRequest)
  })
_sym_db.RegisterMessage(GetStudyRequest)

CreateStudyRequest = _reflection.GeneratedProtocolMessageType('CreateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateStudyRequest)
  })
_sym_db.RegisterMessage(CreateStudyRequest)

UpdateStudyRequest = _reflection.GeneratedProtocolMessageType('UpdateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateStudyRequest)
  })
_sym_db.RegisterMessage(UpdateStudyRequest)

DeleteStudyRequest = _reflection.GeneratedProtocolMessageType('DeleteStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteStudyRequest)
  })
_sym_db.RegisterMessage(DeleteStudyRequest)

ListCronPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListCronPredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsRequest)
  })
_sym_db.RegisterMessage(ListCronPredictionsRequest)

ListCronPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListCronPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCRONPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCronPredictionsResponse)
  })
_sym_db.RegisterMessage(ListCronPredictionsResponse)

GetCronPredictionRequest = _reflection.GeneratedProtocolMessageType('GetCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCronPredictionRequest)
  })
_sym_db.RegisterMessage(GetCronPredictionRequest)

CreateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('CreateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCronPredictionRequest)
  })
_sym_db.RegisterMessage(CreateCronPredictionRequest)

UpdateCronPredictionRequest = _reflection.GeneratedProtocolMessageType('UpdateCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCronPredictionRequest)
  })
_sym_db.RegisterMessage(UpdateCronPredictionRequest)

DeleteCronPredictionRequest = _reflection.GeneratedProtocolMessageType('DeleteCronPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECRONPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCronPredictionRequest)
  })
_sym_db.RegisterMessage(DeleteCronPredictionRequest)

ListCurtainsRequest = _reflection.GeneratedProtocolMessageType('ListCurtainsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsRequest)
  })
_sym_db.RegisterMessage(ListCurtainsRequest)

ListCurtainsResponse = _reflection.GeneratedProtocolMessageType('ListCurtainsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCURTAINSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListCurtainsResponse)
  })
_sym_db.RegisterMessage(ListCurtainsResponse)

GetCurtainRequest = _reflection.GeneratedProtocolMessageType('GetCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetCurtainRequest)
  })
_sym_db.RegisterMessage(GetCurtainRequest)

CreateCurtainRequest = _reflection.GeneratedProtocolMessageType('CreateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateCurtainRequest)
  })
_sym_db.RegisterMessage(CreateCurtainRequest)

UpdateCurtainRequest = _reflection.GeneratedProtocolMessageType('UpdateCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateCurtainRequest)
  })
_sym_db.RegisterMessage(UpdateCurtainRequest)

DeleteCurtainRequest = _reflection.GeneratedProtocolMessageType('DeleteCurtainRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETECURTAINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteCurtainRequest)
  })
_sym_db.RegisterMessage(DeleteCurtainRequest)

ListPredictionsRequest = _reflection.GeneratedProtocolMessageType('ListPredictionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsRequest)
  })
_sym_db.RegisterMessage(ListPredictionsRequest)

ListPredictionsResponse = _reflection.GeneratedProtocolMessageType('ListPredictionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTIONSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictionsResponse)
  })
_sym_db.RegisterMessage(ListPredictionsResponse)

GetPredictionRequest = _reflection.GeneratedProtocolMessageType('GetPredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictionRequest)
  })
_sym_db.RegisterMessage(GetPredictionRequest)

CreatePredictionRequest = _reflection.GeneratedProtocolMessageType('CreatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictionRequest)
  })
_sym_db.RegisterMessage(CreatePredictionRequest)

UpdatePredictionRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictionRequest)
  })
_sym_db.RegisterMessage(UpdatePredictionRequest)

DeletePredictionRequest = _reflection.GeneratedProtocolMessageType('DeletePredictionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTIONREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictionRequest)
  })
_sym_db.RegisterMessage(DeletePredictionRequest)

ListPredictorsRequest = _reflection.GeneratedProtocolMessageType('ListPredictorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsRequest)
  })
_sym_db.RegisterMessage(ListPredictorsRequest)

ListPredictorsResponse = _reflection.GeneratedProtocolMessageType('ListPredictorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPREDICTORSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPredictorsResponse)
  })
_sym_db.RegisterMessage(ListPredictorsResponse)

GetPredictorRequest = _reflection.GeneratedProtocolMessageType('GetPredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPredictorRequest)
  })
_sym_db.RegisterMessage(GetPredictorRequest)

CreatePredictorRequest = _reflection.GeneratedProtocolMessageType('CreatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePredictorRequest)
  })
_sym_db.RegisterMessage(CreatePredictorRequest)

UpdatePredictorRequest = _reflection.GeneratedProtocolMessageType('UpdatePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePredictorRequest)
  })
_sym_db.RegisterMessage(UpdatePredictorRequest)

DeletePredictorRequest = _reflection.GeneratedProtocolMessageType('DeletePredictorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPREDICTORREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePredictorRequest)
  })
_sym_db.RegisterMessage(DeletePredictorRequest)

ListReviewsRequest = _reflection.GeneratedProtocolMessageType('ListReviewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsRequest)
  })
_sym_db.RegisterMessage(ListReviewsRequest)

ListReviewsResponse = _reflection.GeneratedProtocolMessageType('ListReviewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREVIEWSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListReviewsResponse)
  })
_sym_db.RegisterMessage(ListReviewsResponse)

GetReviewRequest = _reflection.GeneratedProtocolMessageType('GetReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetReviewRequest)
  })
_sym_db.RegisterMessage(GetReviewRequest)

CreateReviewRequest = _reflection.GeneratedProtocolMessageType('CreateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateReviewRequest)
  })
_sym_db.RegisterMessage(CreateReviewRequest)

UpdateReviewRequest = _reflection.GeneratedProtocolMessageType('UpdateReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateReviewRequest)
  })
_sym_db.RegisterMessage(UpdateReviewRequest)

DeleteReviewRequest = _reflection.GeneratedProtocolMessageType('DeleteReviewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteReviewRequest)
  })
_sym_db.RegisterMessage(DeleteReviewRequest)

ListPostMortemsRequest = _reflection.GeneratedProtocolMessageType('ListPostMortemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsRequest)
  })
_sym_db.RegisterMessage(ListPostMortemsRequest)

ListPostMortemsResponse = _reflection.GeneratedProtocolMessageType('ListPostMortemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOSTMORTEMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListPostMortemsResponse)
  })
_sym_db.RegisterMessage(ListPostMortemsResponse)

GetPostMortemRequest = _reflection.GeneratedProtocolMessageType('GetPostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetPostMortemRequest)
  })
_sym_db.RegisterMessage(GetPostMortemRequest)

CreatePostMortemRequest = _reflection.GeneratedProtocolMessageType('CreatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreatePostMortemRequest)
  })
_sym_db.RegisterMessage(CreatePostMortemRequest)

UpdatePostMortemRequest = _reflection.GeneratedProtocolMessageType('UpdatePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdatePostMortemRequest)
  })
_sym_db.RegisterMessage(UpdatePostMortemRequest)

DeletePostMortemRequest = _reflection.GeneratedProtocolMessageType('DeletePostMortemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPOSTMORTEMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeletePostMortemRequest)
  })
_sym_db.RegisterMessage(DeletePostMortemRequest)

ListRunbooksRequest = _reflection.GeneratedProtocolMessageType('ListRunbooksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksRequest)
  })
_sym_db.RegisterMessage(ListRunbooksRequest)

ListRunbooksResponse = _reflection.GeneratedProtocolMessageType('ListRunbooksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRUNBOOKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.ListRunbooksResponse)
  })
_sym_db.RegisterMessage(ListRunbooksResponse)

GetRunbookRequest = _reflection.GeneratedProtocolMessageType('GetRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.GetRunbookRequest)
  })
_sym_db.RegisterMessage(GetRunbookRequest)

CreateRunbookRequest = _reflection.GeneratedProtocolMessageType('CreateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.CreateRunbookRequest)
  })
_sym_db.RegisterMessage(CreateRunbookRequest)

UpdateRunbookRequest = _reflection.GeneratedProtocolMessageType('UpdateRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.UpdateRunbookRequest)
  })
_sym_db.RegisterMessage(UpdateRunbookRequest)

DeleteRunbookRequest = _reflection.GeneratedProtocolMessageType('DeleteRunbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERUNBOOKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dbproxyd.v1.dbproxyd_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dbproxyd.v1.DeleteRunbookRequest)
  })
_sym_db.RegisterMessage(DeleteRunbookRequest)


DESCRIPTOR._options = None

_DATABASEPROXYSERVICE = _descriptor.ServiceDescriptor(
  name='DatabaseProxyService',
  full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=25415,
  serialized_end=61168,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAccounts',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListAccounts',
    index=0,
    containing_service=None,
    input_type=_LISTACCOUNTSREQUEST,
    output_type=_LISTACCOUNTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccount',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetAccount',
    index=1,
    containing_service=None,
    input_type=_GETACCOUNTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAccount',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateAccount',
    index=2,
    containing_service=None,
    input_type=_CREATEACCOUNTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAccount',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateAccount',
    index=3,
    containing_service=None,
    input_type=_UPDATEACCOUNTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ACCOUNT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAccount',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteAccount',
    index=4,
    containing_service=None,
    input_type=_DELETEACCOUNTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListAlerts',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListAlerts',
    index=5,
    containing_service=None,
    input_type=_LISTALERTSREQUEST,
    output_type=_LISTALERTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAlert',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetAlert',
    index=6,
    containing_service=None,
    input_type=_GETALERTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateAlert',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateAlert',
    index=7,
    containing_service=None,
    input_type=_CREATEALERTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAlert',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateAlert',
    index=8,
    containing_service=None,
    input_type=_UPDATEALERTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._ALERT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAlert',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteAlert',
    index=9,
    containing_service=None,
    input_type=_DELETEALERTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTodos',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListTodos',
    index=10,
    containing_service=None,
    input_type=_LISTTODOSREQUEST,
    output_type=_LISTTODOSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTodo',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetTodo',
    index=11,
    containing_service=None,
    input_type=_GETTODOREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTodo',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateTodo',
    index=12,
    containing_service=None,
    input_type=_CREATETODOREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTodo',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateTodo',
    index=13,
    containing_service=None,
    input_type=_UPDATETODOREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._TODO,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTodo',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteTodo',
    index=14,
    containing_service=None,
    input_type=_DELETETODOREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCommits',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListCommits',
    index=15,
    containing_service=None,
    input_type=_LISTCOMMITSREQUEST,
    output_type=_LISTCOMMITSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCommit',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetCommit',
    index=16,
    containing_service=None,
    input_type=_GETCOMMITREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCommit',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateCommit',
    index=17,
    containing_service=None,
    input_type=_CREATECOMMITREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCommit',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateCommit',
    index=18,
    containing_service=None,
    input_type=_UPDATECOMMITREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._COMMIT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCommit',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteCommit',
    index=19,
    containing_service=None,
    input_type=_DELETECOMMITREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListApiTokens',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListApiTokens',
    index=20,
    containing_service=None,
    input_type=_LISTAPITOKENSREQUEST,
    output_type=_LISTAPITOKENSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetApiToken',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetApiToken',
    index=21,
    containing_service=None,
    input_type=_GETAPITOKENREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateApiToken',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateApiToken',
    index=22,
    containing_service=None,
    input_type=_CREATEAPITOKENREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateApiToken',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateApiToken',
    index=23,
    containing_service=None,
    input_type=_UPDATEAPITOKENREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._APITOKEN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteApiToken',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteApiToken',
    index=24,
    containing_service=None,
    input_type=_DELETEAPITOKENREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListConnections',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListConnections',
    index=25,
    containing_service=None,
    input_type=_LISTCONNECTIONSREQUEST,
    output_type=_LISTCONNECTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetConnection',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetConnection',
    index=26,
    containing_service=None,
    input_type=_GETCONNECTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateConnection',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateConnection',
    index=27,
    containing_service=None,
    input_type=_CREATECONNECTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateConnection',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateConnection',
    index=28,
    containing_service=None,
    input_type=_UPDATECONNECTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteConnection',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteConnection',
    index=29,
    containing_service=None,
    input_type=_DELETECONNECTIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLabs',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListLabs',
    index=30,
    containing_service=None,
    input_type=_LISTLABSREQUEST,
    output_type=_LISTLABSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLab',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetLab',
    index=31,
    containing_service=None,
    input_type=_GETLABREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLab',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateLab',
    index=32,
    containing_service=None,
    input_type=_CREATELABREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLab',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateLab',
    index=33,
    containing_service=None,
    input_type=_UPDATELABREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LAB,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLab',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteLab',
    index=34,
    containing_service=None,
    input_type=_DELETELABREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLicenses',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListLicenses',
    index=35,
    containing_service=None,
    input_type=_LISTLICENSESREQUEST,
    output_type=_LISTLICENSESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLicense',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetLicense',
    index=36,
    containing_service=None,
    input_type=_GETLICENSEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLicense',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateLicense',
    index=37,
    containing_service=None,
    input_type=_CREATELICENSEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLicense',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateLicense',
    index=38,
    containing_service=None,
    input_type=_UPDATELICENSEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._LICENSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLicense',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteLicense',
    index=39,
    containing_service=None,
    input_type=_DELETELICENSEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNotifiers',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListNotifiers',
    index=40,
    containing_service=None,
    input_type=_LISTNOTIFIERSREQUEST,
    output_type=_LISTNOTIFIERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotifier',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetNotifier',
    index=41,
    containing_service=None,
    input_type=_GETNOTIFIERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotifier',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateNotifier',
    index=42,
    containing_service=None,
    input_type=_CREATENOTIFIERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotifier',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateNotifier',
    index=43,
    containing_service=None,
    input_type=_UPDATENOTIFIERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._NOTIFIER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotifier',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteNotifier',
    index=44,
    containing_service=None,
    input_type=_DELETENOTIFIERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListServingSites',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListServingSites',
    index=45,
    containing_service=None,
    input_type=_LISTSERVINGSITESREQUEST,
    output_type=_LISTSERVINGSITESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetServingSite',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetServingSite',
    index=46,
    containing_service=None,
    input_type=_GETSERVINGSITEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateServingSite',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateServingSite',
    index=47,
    containing_service=None,
    input_type=_CREATESERVINGSITEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateServingSite',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateServingSite',
    index=48,
    containing_service=None,
    input_type=_UPDATESERVINGSITEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._SERVINGSITE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteServingSite',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteServingSite',
    index=49,
    containing_service=None,
    input_type=_DELETESERVINGSITEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListTenants',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListTenants',
    index=50,
    containing_service=None,
    input_type=_LISTTENANTSREQUEST,
    output_type=_LISTTENANTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTenant',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetTenant',
    index=51,
    containing_service=None,
    input_type=_GETTENANTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTenant',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateTenant',
    index=52,
    containing_service=None,
    input_type=_CREATETENANTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTenant',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateTenant',
    index=53,
    containing_service=None,
    input_type=_UPDATETENANTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._TENANT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTenant',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteTenant',
    index=54,
    containing_service=None,
    input_type=_DELETETENANTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVirtualBuckets',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListVirtualBuckets',
    index=55,
    containing_service=None,
    input_type=_LISTVIRTUALBUCKETSREQUEST,
    output_type=_LISTVIRTUALBUCKETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetVirtualBucket',
    index=56,
    containing_service=None,
    input_type=_GETVIRTUALBUCKETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateVirtualBucket',
    index=57,
    containing_service=None,
    input_type=_CREATEVIRTUALBUCKETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateVirtualBucket',
    index=58,
    containing_service=None,
    input_type=_UPDATEVIRTUALBUCKETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALBUCKET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualBucket',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteVirtualBucket',
    index=59,
    containing_service=None,
    input_type=_DELETEVIRTUALBUCKETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVirtualClusters',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListVirtualClusters',
    index=60,
    containing_service=None,
    input_type=_LISTVIRTUALCLUSTERSREQUEST,
    output_type=_LISTVIRTUALCLUSTERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetVirtualCluster',
    index=61,
    containing_service=None,
    input_type=_GETVIRTUALCLUSTERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateVirtualCluster',
    index=62,
    containing_service=None,
    input_type=_CREATEVIRTUALCLUSTERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateVirtualCluster',
    index=63,
    containing_service=None,
    input_type=_UPDATEVIRTUALCLUSTERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALCLUSTER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualCluster',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteVirtualCluster',
    index=64,
    containing_service=None,
    input_type=_DELETEVIRTUALCLUSTERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListVirtualVolumes',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListVirtualVolumes',
    index=65,
    containing_service=None,
    input_type=_LISTVIRTUALVOLUMESREQUEST,
    output_type=_LISTVIRTUALVOLUMESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetVirtualVolume',
    index=66,
    containing_service=None,
    input_type=_GETVIRTUALVOLUMEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateVirtualVolume',
    index=67,
    containing_service=None,
    input_type=_CREATEVIRTUALVOLUMEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateVirtualVolume',
    index=68,
    containing_service=None,
    input_type=_UPDATEVIRTUALVOLUMEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._VIRTUALVOLUME,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteVirtualVolume',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteVirtualVolume',
    index=69,
    containing_service=None,
    input_type=_DELETEVIRTUALVOLUMEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataPipelines',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDataPipelines',
    index=70,
    containing_service=None,
    input_type=_LISTDATAPIPELINESREQUEST,
    output_type=_LISTDATAPIPELINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataPipeline',
    index=71,
    containing_service=None,
    input_type=_GETDATAPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataPipeline',
    index=72,
    containing_service=None,
    input_type=_CREATEDATAPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataPipeline',
    index=73,
    containing_service=None,
    input_type=_UPDATEDATAPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataPipeline',
    index=74,
    containing_service=None,
    input_type=_DELETEDATAPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDataPipelineRuns',
    index=75,
    containing_service=None,
    input_type=_LISTDATAPIPELINERUNSREQUEST,
    output_type=_LISTDATAPIPELINERUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataPipelineRun',
    index=76,
    containing_service=None,
    input_type=_GETDATAPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataPipelineRun',
    index=77,
    containing_service=None,
    input_type=_CREATEDATAPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataPipelineRun',
    index=78,
    containing_service=None,
    input_type=_UPDATEDATAPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataPipelineRun',
    index=79,
    containing_service=None,
    input_type=_DELETEDATAPIPELINERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataProducts',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDataProducts',
    index=80,
    containing_service=None,
    input_type=_LISTDATAPRODUCTSREQUEST,
    output_type=_LISTDATAPRODUCTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataProduct',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataProduct',
    index=81,
    containing_service=None,
    input_type=_GETDATAPRODUCTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataProduct',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataProduct',
    index=82,
    containing_service=None,
    input_type=_CREATEDATAPRODUCTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataProduct',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataProduct',
    index=83,
    containing_service=None,
    input_type=_UPDATEDATAPRODUCTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataProduct',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataProduct',
    index=84,
    containing_service=None,
    input_type=_DELETEDATAPRODUCTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataProductVersions',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDataProductVersions',
    index=85,
    containing_service=None,
    input_type=_LISTDATAPRODUCTVERSIONSREQUEST,
    output_type=_LISTDATAPRODUCTVERSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataProductVersion',
    index=86,
    containing_service=None,
    input_type=_GETDATAPRODUCTVERSIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataProductVersion',
    index=87,
    containing_service=None,
    input_type=_CREATEDATAPRODUCTVERSIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataProductVersion',
    index=88,
    containing_service=None,
    input_type=_UPDATEDATAPRODUCTVERSIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATAPRODUCTVERSION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataProductVersion',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataProductVersion',
    index=89,
    containing_service=None,
    input_type=_DELETEDATAPRODUCTVERSIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDatasets',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDatasets',
    index=90,
    containing_service=None,
    input_type=_LISTDATASETSREQUEST,
    output_type=_LISTDATASETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataset',
    index=91,
    containing_service=None,
    input_type=_GETDATASETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataset',
    index=92,
    containing_service=None,
    input_type=_CREATEDATASETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataset',
    index=93,
    containing_service=None,
    input_type=_UPDATEDATASETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataset',
    index=94,
    containing_service=None,
    input_type=_DELETEDATASETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListDataSources',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListDataSources',
    index=95,
    containing_service=None,
    input_type=_LISTDATASOURCESREQUEST,
    output_type=_LISTDATASOURCESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataSource',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetDataSource',
    index=96,
    containing_service=None,
    input_type=_GETDATASOURCEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateDataSource',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateDataSource',
    index=97,
    containing_service=None,
    input_type=_CREATEDATASOURCEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateDataSource',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateDataSource',
    index=98,
    containing_service=None,
    input_type=_UPDATEDATASOURCEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._DATASOURCE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteDataSource',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteDataSource',
    index=99,
    containing_service=None,
    input_type=_DELETEDATASOURCEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListEntities',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListEntities',
    index=100,
    containing_service=None,
    input_type=_LISTENTITIESREQUEST,
    output_type=_LISTENTITIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetEntity',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetEntity',
    index=101,
    containing_service=None,
    input_type=_GETENTITYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateEntity',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateEntity',
    index=102,
    containing_service=None,
    input_type=_CREATEENTITYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateEntity',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateEntity',
    index=103,
    containing_service=None,
    input_type=_UPDATEENTITYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._ENTITY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteEntity',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteEntity',
    index=104,
    containing_service=None,
    input_type=_DELETEENTITYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatures',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListFeatures',
    index=105,
    containing_service=None,
    input_type=_LISTFEATURESREQUEST,
    output_type=_LISTFEATURESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeature',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetFeature',
    index=106,
    containing_service=None,
    input_type=_GETFEATUREREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeature',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateFeature',
    index=107,
    containing_service=None,
    input_type=_CREATEFEATUREREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeature',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateFeature',
    index=108,
    containing_service=None,
    input_type=_UPDATEFEATUREREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeature',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteFeature',
    index=109,
    containing_service=None,
    input_type=_DELETEFEATUREREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeaturePipelines',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListFeaturePipelines',
    index=110,
    containing_service=None,
    input_type=_LISTFEATUREPIPELINESREQUEST,
    output_type=_LISTFEATUREPIPELINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetFeaturePipeline',
    index=111,
    containing_service=None,
    input_type=_GETFEATUREPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateFeaturePipeline',
    index=112,
    containing_service=None,
    input_type=_CREATEFEATUREPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateFeaturePipeline',
    index=113,
    containing_service=None,
    input_type=_UPDATEFEATUREPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeaturePipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteFeaturePipeline',
    index=114,
    containing_service=None,
    input_type=_DELETEFEATUREPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeaturePipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListFeaturePipelineRuns',
    index=115,
    containing_service=None,
    input_type=_LISTFEATUREPIPELINERUNSREQUEST,
    output_type=_LISTFEATUREPIPELINERUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetFeaturePipelineRun',
    index=116,
    containing_service=None,
    input_type=_GETFEATUREPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateFeaturePipelineRun',
    index=117,
    containing_service=None,
    input_type=_CREATEFEATUREPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateFeaturePipelineRun',
    index=118,
    containing_service=None,
    input_type=_UPDATEFEATUREPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATUREPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeaturePipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteFeaturePipelineRun',
    index=119,
    containing_service=None,
    input_type=_DELETEFEATUREPIPELINERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeaturesets',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListFeaturesets',
    index=120,
    containing_service=None,
    input_type=_LISTFEATURESETSREQUEST,
    output_type=_LISTFEATURESETSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeatureset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetFeatureset',
    index=121,
    containing_service=None,
    input_type=_GETFEATURESETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateFeatureset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateFeatureset',
    index=122,
    containing_service=None,
    input_type=_CREATEFEATURESETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeatureset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateFeatureset',
    index=123,
    containing_service=None,
    input_type=_UPDATEFEATURESETREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURESET,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeatureset',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteFeatureset',
    index=124,
    containing_service=None,
    input_type=_DELETEFEATURESETREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLabelingPipelines',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListLabelingPipelines',
    index=125,
    containing_service=None,
    input_type=_LISTLABELINGPIPELINESREQUEST,
    output_type=_LISTLABELINGPIPELINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetLabelingPipeline',
    index=126,
    containing_service=None,
    input_type=_GETLABELINGPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateLabelingPipeline',
    index=127,
    containing_service=None,
    input_type=_CREATELABELINGPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateLabelingPipeline',
    index=128,
    containing_service=None,
    input_type=_UPDATELABELINGPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLabelingPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteLabelingPipeline',
    index=129,
    containing_service=None,
    input_type=_DELETELABELINGPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListLabelingPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListLabelingPipelineRuns',
    index=130,
    containing_service=None,
    input_type=_LISTLABELINGPIPELINERUNSREQUEST,
    output_type=_LISTLABELINGPIPELINERUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetLabelingPipelineRun',
    index=131,
    containing_service=None,
    input_type=_GETLABELINGPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateLabelingPipelineRun',
    index=132,
    containing_service=None,
    input_type=_CREATELABELINGPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateLabelingPipelineRun',
    index=133,
    containing_service=None,
    input_type=_UPDATELABELINGPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._LABELINGPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteLabelingPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteLabelingPipelineRun',
    index=134,
    containing_service=None,
    input_type=_DELETELABELINGPIPELINERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRecipes',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListRecipes',
    index=135,
    containing_service=None,
    input_type=_LISTRECIPESREQUEST,
    output_type=_LISTRECIPESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecipe',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetRecipe',
    index=136,
    containing_service=None,
    input_type=_GETRECIPEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecipe',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateRecipe',
    index=137,
    containing_service=None,
    input_type=_CREATERECIPEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecipe',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateRecipe',
    index=138,
    containing_service=None,
    input_type=_UPDATERECIPEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRecipe',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteRecipe',
    index=139,
    containing_service=None,
    input_type=_DELETERECIPEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRecipeRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListRecipeRuns',
    index=140,
    containing_service=None,
    input_type=_LISTRECIPERUNSREQUEST,
    output_type=_LISTRECIPERUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetRecipeRun',
    index=141,
    containing_service=None,
    input_type=_GETRECIPERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateRecipeRun',
    index=142,
    containing_service=None,
    input_type=_CREATERECIPERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateRecipeRun',
    index=143,
    containing_service=None,
    input_type=_UPDATERECIPERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRecipeRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteRecipeRun',
    index=144,
    containing_service=None,
    input_type=_DELETERECIPERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListModelAutobuilders',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListModelAutobuilders',
    index=145,
    containing_service=None,
    input_type=_LISTMODELAUTOBUILDERSREQUEST,
    output_type=_LISTMODELAUTOBUILDERSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetModelAutobuilder',
    index=146,
    containing_service=None,
    input_type=_GETMODELAUTOBUILDERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateModelAutobuilder',
    index=147,
    containing_service=None,
    input_type=_CREATEMODELAUTOBUILDERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateModelAutobuilder',
    index=148,
    containing_service=None,
    input_type=_UPDATEMODELAUTOBUILDERREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELAUTOBUILDER,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelAutobuilder',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteModelAutobuilder',
    index=149,
    containing_service=None,
    input_type=_DELETEMODELAUTOBUILDERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListModelPipelines',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListModelPipelines',
    index=150,
    containing_service=None,
    input_type=_LISTMODELPIPELINESREQUEST,
    output_type=_LISTMODELPIPELINESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetModelPipeline',
    index=151,
    containing_service=None,
    input_type=_GETMODELPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateModelPipeline',
    index=152,
    containing_service=None,
    input_type=_CREATEMODELPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateModelPipeline',
    index=153,
    containing_service=None,
    input_type=_UPDATEMODELPIPELINEREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelPipeline',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteModelPipeline',
    index=154,
    containing_service=None,
    input_type=_DELETEMODELPIPELINEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListModelPipelineRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListModelPipelineRuns',
    index=155,
    containing_service=None,
    input_type=_LISTMODELPIPELINERUNSREQUEST,
    output_type=_LISTMODELPIPELINERUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetModelPipelineRun',
    index=156,
    containing_service=None,
    input_type=_GETMODELPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateModelPipelineRun',
    index=157,
    containing_service=None,
    input_type=_CREATEMODELPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateModelPipelineRun',
    index=158,
    containing_service=None,
    input_type=_UPDATEMODELPIPELINERUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODELPIPELINERUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModelPipelineRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteModelPipelineRun',
    index=159,
    containing_service=None,
    input_type=_DELETEMODELPIPELINERUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNotebooks',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListNotebooks',
    index=160,
    containing_service=None,
    input_type=_LISTNOTEBOOKSREQUEST,
    output_type=_LISTNOTEBOOKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotebook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetNotebook',
    index=161,
    containing_service=None,
    input_type=_GETNOTEBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotebook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateNotebook',
    index=162,
    containing_service=None,
    input_type=_CREATENOTEBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotebook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateNotebook',
    index=163,
    containing_service=None,
    input_type=_UPDATENOTEBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotebook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteNotebook',
    index=164,
    containing_service=None,
    input_type=_DELETENOTEBOOKREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListNotebookRuns',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListNotebookRuns',
    index=165,
    containing_service=None,
    input_type=_LISTNOTEBOOKRUNSREQUEST,
    output_type=_LISTNOTEBOOKRUNSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetNotebookRun',
    index=166,
    containing_service=None,
    input_type=_GETNOTEBOOKRUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateNotebookRun',
    index=167,
    containing_service=None,
    input_type=_CREATENOTEBOOKRUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateNotebookRun',
    index=168,
    containing_service=None,
    input_type=_UPDATENOTEBOOKRUNREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._NOTEBOOKRUN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteNotebookRun',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteNotebookRun',
    index=169,
    containing_service=None,
    input_type=_DELETENOTEBOOKRUNREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListReports',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListReports',
    index=170,
    containing_service=None,
    input_type=_LISTREPORTSREQUEST,
    output_type=_LISTREPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetReport',
    index=171,
    containing_service=None,
    input_type=_GETREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateReport',
    index=172,
    containing_service=None,
    input_type=_CREATEREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateReport',
    index=173,
    containing_service=None,
    input_type=_UPDATEREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteReport',
    index=174,
    containing_service=None,
    input_type=_DELETEREPORTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCronReports',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListCronReports',
    index=175,
    containing_service=None,
    input_type=_LISTCRONREPORTSREQUEST,
    output_type=_LISTCRONREPORTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCronReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetCronReport',
    index=176,
    containing_service=None,
    input_type=_GETCRONREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCronReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateCronReport',
    index=177,
    containing_service=None,
    input_type=_CREATECRONREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCronReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateCronReport',
    index=178,
    containing_service=None,
    input_type=_UPDATECRONREPORTREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._CRONREPORT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCronReport',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteCronReport',
    index=179,
    containing_service=None,
    input_type=_DELETECRONREPORTREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListStudies',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListStudies',
    index=180,
    containing_service=None,
    input_type=_LISTSTUDIESREQUEST,
    output_type=_LISTSTUDIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStudy',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetStudy',
    index=181,
    containing_service=None,
    input_type=_GETSTUDYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStudy',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateStudy',
    index=182,
    containing_service=None,
    input_type=_CREATESTUDYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateStudy',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateStudy',
    index=183,
    containing_service=None,
    input_type=_UPDATESTUDYREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._STUDY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteStudy',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteStudy',
    index=184,
    containing_service=None,
    input_type=_DELETESTUDYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListModels',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListModels',
    index=185,
    containing_service=None,
    input_type=_LISTMODELSREQUEST,
    output_type=_LISTMODELSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetModel',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetModel',
    index=186,
    containing_service=None,
    input_type=_GETMODELREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateModel',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateModel',
    index=187,
    containing_service=None,
    input_type=_CREATEMODELREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateModel',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateModel',
    index=188,
    containing_service=None,
    input_type=_UPDATEMODELREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._MODEL,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteModel',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteModel',
    index=189,
    containing_service=None,
    input_type=_DELETEMODELREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCronPredictions',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListCronPredictions',
    index=190,
    containing_service=None,
    input_type=_LISTCRONPREDICTIONSREQUEST,
    output_type=_LISTCRONPREDICTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetCronPrediction',
    index=191,
    containing_service=None,
    input_type=_GETCRONPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateCronPrediction',
    index=192,
    containing_service=None,
    input_type=_CREATECRONPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateCronPrediction',
    index=193,
    containing_service=None,
    input_type=_UPDATECRONPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CRONPREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCronPrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteCronPrediction',
    index=194,
    containing_service=None,
    input_type=_DELETECRONPREDICTIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPredictions',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListPredictions',
    index=195,
    containing_service=None,
    input_type=_LISTPREDICTIONSREQUEST,
    output_type=_LISTPREDICTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetPrediction',
    index=196,
    containing_service=None,
    input_type=_GETPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreatePrediction',
    index=197,
    containing_service=None,
    input_type=_CREATEPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdatePrediction',
    index=198,
    containing_service=None,
    input_type=_UPDATEPREDICTIONREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePrediction',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeletePrediction',
    index=199,
    containing_service=None,
    input_type=_DELETEPREDICTIONREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPredictors',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListPredictors',
    index=200,
    containing_service=None,
    input_type=_LISTPREDICTORSREQUEST,
    output_type=_LISTPREDICTORSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPredictor',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetPredictor',
    index=201,
    containing_service=None,
    input_type=_GETPREDICTORREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePredictor',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreatePredictor',
    index=202,
    containing_service=None,
    input_type=_CREATEPREDICTORREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePredictor',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdatePredictor',
    index=203,
    containing_service=None,
    input_type=_UPDATEPREDICTORREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._PREDICTOR,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePredictor',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeletePredictor',
    index=204,
    containing_service=None,
    input_type=_DELETEPREDICTORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListCurtains',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListCurtains',
    index=205,
    containing_service=None,
    input_type=_LISTCURTAINSREQUEST,
    output_type=_LISTCURTAINSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCurtain',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetCurtain',
    index=206,
    containing_service=None,
    input_type=_GETCURTAINREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateCurtain',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateCurtain',
    index=207,
    containing_service=None,
    input_type=_CREATECURTAINREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateCurtain',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateCurtain',
    index=208,
    containing_service=None,
    input_type=_UPDATECURTAINREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2._CURTAIN,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteCurtain',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteCurtain',
    index=209,
    containing_service=None,
    input_type=_DELETECURTAINREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListReviews',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListReviews',
    index=210,
    containing_service=None,
    input_type=_LISTREVIEWSREQUEST,
    output_type=_LISTREVIEWSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReview',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetReview',
    index=211,
    containing_service=None,
    input_type=_GETREVIEWREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateReview',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateReview',
    index=212,
    containing_service=None,
    input_type=_CREATEREVIEWREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReview',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateReview',
    index=213,
    containing_service=None,
    input_type=_UPDATEREVIEWREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._REVIEW,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReview',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteReview',
    index=214,
    containing_service=None,
    input_type=_DELETEREVIEWREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPostMortems',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListPostMortems',
    index=215,
    containing_service=None,
    input_type=_LISTPOSTMORTEMSREQUEST,
    output_type=_LISTPOSTMORTEMSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPostMortem',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetPostMortem',
    index=216,
    containing_service=None,
    input_type=_GETPOSTMORTEMREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreatePostMortem',
    index=217,
    containing_service=None,
    input_type=_CREATEPOSTMORTEMREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdatePostMortem',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdatePostMortem',
    index=218,
    containing_service=None,
    input_type=_UPDATEPOSTMORTEMREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._POSTMORTEM,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeletePostMortem',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeletePostMortem',
    index=219,
    containing_service=None,
    input_type=_DELETEPOSTMORTEMREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListRunBooks',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.ListRunBooks',
    index=220,
    containing_service=None,
    input_type=_LISTRUNBOOKSREQUEST,
    output_type=_LISTRUNBOOKSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRunBook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.GetRunBook',
    index=221,
    containing_service=None,
    input_type=_GETRUNBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRunBook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.CreateRunBook',
    index=222,
    containing_service=None,
    input_type=_CREATERUNBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRunBook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.UpdateRunBook',
    index=223,
    containing_service=None,
    input_type=_UPDATERUNBOOKREQUEST,
    output_type=github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_team_dot_v1alpha1_dot_generated__pb2._RUNBOOK,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRunBook',
    full_name='github.com.metaprov.modelaapi.services.dbproxyd.v1.DatabaseProxyService.DeleteRunBook',
    index=224,
    containing_service=None,
    input_type=_DELETERUNBOOKREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATABASEPROXYSERVICE)

DESCRIPTOR.services_by_name['DatabaseProxyService'] = _DATABASEPROXYSERVICE

# @@protoc_insertion_point(module_scope)
